All Classes and Interfaces
Class
Description
Base class for three following implementations:
HasKeyTranslator
SubPropertyChainOfTranslator
DisjointUnionTranslator
Created by @ssz on 18.10.2016.A base
ONTAxiomImpl for simplification code.Base class for following axioms:
EquivalentClasses (
EquivalentClassesTranslator)
EquivalentObjectProperties (EquivalentObjectPropertiesTranslator)
EquivalentDataProperties (EquivalentDataPropertiesTranslator)
SameIndividual (SameIndividualTranslator)
Also for AbstractTwoWayNaryTranslator with following subclasses:
DisjointClasses (DisjointClassesTranslator)
DisjointObjectProperties (DisjointObjectPropertiesTranslator)
DisjointDataProperties (DisjointDataPropertiesTranslator)
DifferentIndividuals (DifferentIndividualsTranslator)
An abstract
OWLNaryClassAxiom implementation.An abstract
OWLNaryPropertyAxiom implementation for member-type OWLDataPropertyExpression.An abstract
OWLNaryIndividualAxiom implementation.A base for N-Ary axiom impls.
An abstract
OWLNaryPropertyAxiom implementation for member-type OWLObjectPropertyExpression.An abstraction for data and object negative property assertion.
A base for data or object negative assertions
A common super-type for all property assertion axiom translators.
A base for annotation and positive property assertion axioms.
The base class for
ObjectPropertyDomainTranslator,
DataPropertyDomainTranslator and AnnotationPropertyDomainTranslator axioms.The base class for
ObjectPropertyRangeTranslator and DataPropertyRangeTranslator
and AnnotationPropertyRangeTranslator.The base class to read and write axiom which is related to simple typed triple associated with object or data property.
The base for
ONTAxiom with one object property.The base for
ONTAxiom with one object or data property.The base class for
SubObjectPropertyOfTranslator, SubDataPropertyOfTranslator
and SubAnnotationPropertyOfTranslator.A base
rdfs:subPropertyOf axiom.This is a base for the following translators for axioms with two or more than two entities:
DisjointClasses (
DisjointClassesTranslator)
DisjointObjectProperties (DisjointObjectPropertiesTranslator)
DisjointDataProperties (DisjointDataPropertiesTranslator),
DifferentIndividuals (DifferentIndividualsTranslator)
Each of these axioms could be written in two ways: as single triple (or sequence of single triples) or as special anonymous node with rdf:List inside.Created by @ssz on 18.04.2020.
A translator that provides
OWLAnnotationAssertionAxiom implementations.An
OWLAnnotationAssertionAxiom that has no sub-annotations.An
OWLAnnotationAssertionAxiom that has sub-annotations.A translator that provides
OWLAnnotationPropertyDomainAxiom implementations.An
OWLAnnotationPropertyDomainAxiom without annotations.An
OWLAnnotationPropertyDomainAxiom with annotations.A translator that provides
OWLAnnotationPropertyRangeAxiom implementations.An
OWLAnnotationPropertyRangeAxiom without annotations.An
OWLAnnotationPropertyRangeAxiom with annotations.Created by @ssz on 26.07.2020.
An abstraction for anonymous data range expressions.
An ON-API implementation of
OWLAnonymousIndividual,
encapsulated Jena Bkank Node Id.An interface for objects that front a
Node in some context.An interface for objects that front a
RDFNode in a model context.The generic interface for things that can be seen as wrappers round
Ontology Statement,
which is an extended Jena Statement,
which, in turn, is a Triple within Jena Model
(in our case Ontology Model).A translator that provides
OWLAsymmetricObjectPropertyAxiom implementations,
which are defined as object property declarations with owl:AsymmetricProperty type.An
OWLAsymmetricObjectPropertyAxiom
that either has annotations or an anonymous object property expression (inverse object property)
in the main triple's subject position.An
OWLAsymmetricObjectPropertyAxiom
that has a named object property as subject and has no annotations.Axiom Graph Translator accessor.
A common interface to access axioms settings.
The base abstract class that intended to perform Axiom Graph Translator (operator
T) in both directions:
for reading and writing.The collection of base methods for
ManifestDeclarator and ReasonerDeclaratorA technical interface-helper that serves as a bridge between
Jena RDF model and
OWLAPI ontology through the InternalGraphModel on the one hand,
and between all these things and OWLAPI manager
through the ModelConfig on the other hand.An abstract
OWL-API Ontology implementation with methods to read information
in the form of OWL Objects from the underling graph-model.A base abstraction for
AxiomTranslators and searchers.An InputStream with cached head.
An optimised implementation of
OWLDatatype,
that is actually a wrapper for OWL2Datatype.A searcher for
OWLAnnotationProperty.A searcher for
OWLAnonymousIndividual.A searcher for
OWLClass.Created by @ssz on 31.03.2020.
A searcher for
OWLDatatype.A base searcher for
OWLEntity.Created by @ssz on 12.04.2020.
A searcher for
OWLLiteral
Created by @ssz on 11.04.2020.Created by @ssz on 31.03.2020.
A searcher for
OWLObjectProperty.A searcher that lists axioms by object.
A base abstraction for any axioms-by-primitive search helper (referencing-axioms functionality).
Created by @ssz on 29.03.2020.
The internal cache holder which is using while reading owl-objects.
An auxiliary class-container (bucket) to provide
a common way for working with
OWLObjects and Triples all together.An internal map-object that holds true-
Map with CacheObjectMapImpl.CachedMap-keys and CacheObjectMapImpl.CachedMap-values.A common interface to access cache settings.
Created by @ssz on 17.05.2020.
Created by @ssz on 17.05.2020.
A translator that provides
OWLClassAssertionAxiom implementations.An
OWLClassAssertionAxiom that either has annotations
or contains anonymous class expressions in the main triple's object position.An
OWLClassAssertionAxiom with named class expressions and without annotations.An
ObjectsSearcher that retrieves OWL-API Classes.Created by @ssz on 16.05.2020.
An extended
OWL-API DataFactory for creating entities, axioms and axiom components.The facility to create
OWL-API Objects including OWL Axioms.A translator that provides
OWLDataPropertyAssertionAxiom implementations.An
OWLDataPropertyAssertionAxiom that has no sub-annotations.An
OWLDataPropertyAssertionAxiom that has sub-annotations.A translator that provides
OWLDataPropertyDomainAxiom implementations.An
OWLDataPropertyDomainAxiom
that either has annotations or anonymous class expression as domain (in main triple's object position).An
OWLDataPropertyDomainAxiom
that has named class expression (OWL Class) as an object and has no annotations.A translator that provides
OWLDataPropertyRangeAxiom implementations.An
OWLDataPropertyRangeAxiom
that either has annotations or anonymous data range expression as domain (in main triple's object position).An
OWLDataPropertyRangeAxiom
that has named data range expression (i.e.Created by @ssz on 26.07.2020.
A translator that provides
OWLDatatypeDefinitionAxiom implementations.An
OWLDatatypeDefinitionAxiom
that either has annotations or anonymous data range expression in main triple's object position.An
OWLDatatypeDefinitionAxiom
that has named data range expressions (i.e.An
ObjectsSearcher that retrieves OWL-API Datatypes.Created by @ssz on 18.04.2020.
It is a translator for axioms of the
AxiomType.DECLARATION type.An
OWLDeclarationAxiom that has no annotations.An
OWLDeclarationAxiom that has annotations.A collection of deprecated IRIs, that are used in obsolete ontologies,
possible written in OWL1.1 specification or in some other propositional OWL1 dialects.
A translator that provides
OWLDifferentIndividualsAxiom implementations.An
OWLDifferentIndividualsAxiom
that either has annotations or anonymous class expressions in subject or object positions,
or it is based on OntDisjoint.Individuals resource.An
OWLDifferentIndividualsAxiom
that is based on a single unannotated triple s owl:differentFrom o,
where s and o are named classes (URI Resources).The implementation of
ObjectMap that redirects calls directly to a graph, without any caching.Created by @ssz on 09.05.2020.
A translator that provides
OWLDisjointClassesAxiom implementations.An
OWLDisjointClassesAxiom
that either has annotations or anonymous class expressions in subject or object positions,
or it is based on OntDisjoint.Classes resource.An
OWLDisjointClassesAxiom that is based on a single unannotated triple s owl:disjointWith o,
where s and o are named classes (URI Resources).A translator that provides
OWLDisjointDataPropertiesAxiom implementations.An
OWLDisjointDataPropertiesAxiom
that either has annotations or it is based on OntDisjoint.DataProperties resource.An
OWLDisjointDataPropertiesAxiom
that is based on a single unannotated triple s owl:propertyDisjointWith o,
where s and o are data properties (URI Resources).A translator that provides
OWLDisjointObjectPropertiesAxiom implementations.An
OWLDisjointObjectPropertiesAxiom
that either has annotations or anonymous object property expressions in the subject or the object positions,
or it is based on OntDisjoint.ObjectProperties resource.An
OWLDisjointObjectPropertiesAxiom
that is based on a single unannotated triple s owl:propertyDisjointWith o,
where s and o are named object property expression (URI Resources).A translator that provides
OWLDisjointUnionAxiom implementations.Created by @ssz on 18.04.2020.
A translator that provides
OWLEquivalentClassesAxiom implementations.Although the
OWLNaryAxiom interface allows axioms with any arity,
an instance of this implementation has exactly 2 operands, no more, no less.An
OWLEquivalentClassesAxiom
that either has annotations or anonymous class expressions in subject or object positions.An
OWLEquivalentClassesAxiom that has named classes as subject and object and has no annotations.A translator that provides
OWLEquivalentDataPropertiesAxiom implementations.An
OWLEquivalentDataPropertiesAxiom that has no annotations.An
OWLEquivalentDataPropertiesAxiom that has annotations.A translator that provides
OWLEquivalentObjectPropertiesAxiom implementations.An
OWLEquivalentObjectPropertiesAxiom
that either has annotations or anonymous object property expressions in the subject or the object positions.An
OWLEquivalentObjectPropertiesAxiom that has named object property expressions
as subject and object and has no annotations.This is a simple extended
Properties with supporting several primitive typed objects.A technical annotation-marker.
Created by @ssz on 06.09.2020.
Created by @ssz on 06.09.2020.
A technical interface that contains functionality common for searchers
(
ObjectsSearcher
and ByObjectSearcher)
which have generic type OWLClass or
OWLDatatype.A translator that provides
OWLFunctionalDataPropertyAxiom implementations.An
OWLFunctionalDataPropertyAxiom
that either has annotations or an anonymous object property expression (inverse object property)
in the main triple's subject position.An
OWLFunctionalDataPropertyAxiom
that has a named object property as subject and has no annotations.A translator that provides
OWLFunctionalObjectPropertyAxiom implementations.An
OWLFunctionalObjectPropertyAxiom
that either has annotations or an anonymous object property expression (inverse object property)
in the main triple's subject position.An
OWLFunctionalObjectPropertyAxiom
that has a named object property as subject and has no annotations.An extended
Predicate to test graphs.A transformation statistic object, which is an outcome of transform process.
A type of triples.
This is a manager to perform transformations over a
RDF Graph.An exception, which can be thrown by
GraphTransformers.transform(Graph, Set) method.The listener to control graph changes while transformations.
An abstract
InternalConfig holder.A translator that provides
OWLHasKeyAxiom implementations.An abstract
ModelObjectFactory provider.An enhanced
OWLOntologyID that is based on Jena Graph Node.The simplest common Cache Adapter interface for internal use.
A
InternalCache implementations that wraps the Caffeine Cache.Loading cache.
A
InternalCache implementations that wraps the standard Map.A container with various configuration settings
to manage mappings of the structural representation to RDF and vice versa.
Snapshot config implementation.
A Buffer Graph OWL model,
that extends
ONTAPI Jena Model providing various methods to work with OWLAPI Objects.A Buffer Graph OWL model, which supports both listing OWL-API objects (OWL Axioms, Entities and Annotations)
and Jena interfaces (through the
OntModel view of RDF Graph).Entities that are commonly used in implementations.
An extended Object Factory impl which maps
OntObjects
to OWLObjects directly having no cache.A translator that provides
OWLInverseFunctionalObjectPropertyAxiom implementations.An
OWLInverseFunctionalObjectPropertyAxiom
that either has annotations or an anonymous object property expression (inverse object property)
in the main triple's subject position.An
OWLInverseFunctionalObjectPropertyAxiom
that has a named object property as subject and has no annotations.A translator that provides
OWLInverseObjectPropertiesAxiom implementations.An
OWLInverseObjectPropertiesAxiom
that either has annotations or anonymous object expressions (OWLObjectInverseOf)
in subject or object positions.An
OWLInverseObjectPropertiesAxiom
that has named object properties as subject and object and has no annotations.A translator that provides
OWLIrreflexiveObjectPropertyAxiom implementations.An
OWLIrreflexiveObjectPropertyAxiom
that either has annotations or an anonymous object property expression (inverse object property)
in the main triple's subject position.An
OWLIrreflexiveObjectPropertyAxiom
that has a named object property as subject and has no annotations.An ONT-API implementation of
OWLLiteral, encapsulated Jena Literal Label.A common interface to access loading settings.
An interface that represents an IRI schema,
intended to control source
IRIs while loading.The transformer to restore declarations in the clear cases
(all notations are taken from the OWL2 Short Guide):
1) The declaration in annotation
_:x a owl:Annotation; owl:annotatedSource s; owl:annotatedProperty rdf:type; owl:annotatedTarget U.
2) Explicit class:
C1 rdfs:subClassOf C2
C1 owl:disjointWith C2
_:x owl:complementOf C
_:x rdf:type owl:AllDisjointClasses; owl:members ( C1 ... Cn )
CN owl:disjointUnionOf ( C1 ... Cn )
C owl:hasKey ( P1 ... Pm R1 ... Rn )
_:x a owl:Restriction; _:x owl:onClass C
3) Explicit data-range:
_:x owl:datatypeComplementOf D.
_:x owl:onDatatype DN; owl:withRestrictions ( _:x1 ... _:xn )
_x: a owl:Restriction; owl:onProperties ( R1 ... Rn ); owl:allValuesFrom Dn
_x: a owl:Restriction; owl:onProperties ( R1 ... Rn ); owl:someValuesFrom Dn
_:x a owl:Restriction; owl:onDataRange D.
4) Data range or class expression:
_:x owl:oneOf ( a1 ... an ) or _:x owl:oneOf ( v1 ... vn )
5) Explicit object property expression:
P a owl:InverseFunctionalProperty
P rdf:type owl:ReflexiveProperty
P rdf:type owl:IrreflexiveProperty
P rdf:type owl:SymmetricProperty
P rdf:type owl:AsymmetricProperty
P rdf:type owl:TransitiveProperty
P1 owl:inverseOf P2
P owl:propertyChainAxiom ( P1 ... Pn )
_:x a owl:Restriction; owl:onProperty P; owl:hasSelf "true"^^xsd:boolean
6) Data property or object property expression:
_:x a owl:Restriction; owl:onProperty R; owl:hasValue v or _:x a owl:Restriction; owl:onProperty P; owl:hasValue a
_:x rdf:type owl:NegativePropertyAssertion; owl:sourceIndividual a1; owl:assertionProperty P; owl:targetIndividual a2 or
_:x rdf:type owl:NegativePropertyAssertion; owl:sourceIndividual a1; owl:assertionProperty R; owl:targetValue v
7) Explicit individuals:
a1 owl:sameAs a2 and a1 owl:differentFrom a2
_:x rdf:type owl:AllDifferent; owl:members ( a1 ... an )
8) Class assertions (individuals declarations):
a rdf:type C
9) SWRL rules. see SWRLAn implementation of
InternalConfig with a reference to a manager,
which is necessary to provide access to its settings (loader and writer configurations).Represents an
ONTObject attached to the model.An interface describing an
ONTObjectFactory that has a link to a specific model.An
ObjectsSearcher that retrieves OWL-API Named Individuals.A translator that provides
OWLNegativeDataPropertyAssertionAxiom implementations.A translator that provides
OWLNegativeObjectPropertyAssertionAxiom implementations.An implementation of
ReadWriteLock with no-operation behaviour.Created by @ssz on 16.05.2020.
The generic interface, similar to
java.util.Map, that provides access to a collection of ONTObjects.A translator that provides
OWLObjectPropertyAssertionAxiom implementations.An
OWLObjectPropertyAssertionAxiom that has no sub-annotations.An
OWLObjectPropertyAssertionAxiom that has sub-annotations.Created by @ssz on 19.05.2020.
A translator that provides
OWLObjectPropertyDomainAxiom implementations.An
OWLObjectPropertyDomainAxiom
that either has annotations
or anonymous object/class expressions in main triple's subject/object positions respectively.An
OWLObjectPropertyDomainAxiom
that has named object property and class expressions and has no annotations.Created by @ssz on 17.05.2020.
A translator that provides
OWLObjectPropertyRangeAxiom implementations.An
OWLObjectPropertyRangeAxiom
that either has annotations
or anonymous object/class expressions in main triple's subject/object positions respectively.An
OWLObjectPropertyRangeAxiom
that has named object property and class expressions and has no annotations.Created by @ssz on 25.07.2020.
An
OWL Objects searcher.An
OWLAnnotation implementation that is also an instance of ONTObject.An
OWLAnnotation that has no sub-annotations.An
OWLAnnotation that has sub-annotations.An
OWLAnnotationProperty implementation that is also ONTObject.An abstraction for any anonymous class expressions
(i.e. for all class expressions with except of
OWLClasses).An
ObjectHasSelf implementation.A base for all
owl:Restriction class expressions.A base for all
owl:Restriction class expressions and for ObjectComplementOf expression.Represents an object class expression,
that has reference to another class expression and object property expression.
Represents an object class expression with cardinality.
An abstraction for simplification code,
that describes
owl:Restriction containing datatype property.Represents a data property restriction that has a reference to a data range.
Represents a data property restriction (class expression) with cardinality.
Represents an n-ary universal or existential data property restriction.
Represents a unary data property restriction that has a reference to a data range.
Describes a class expression that is based on []-list.
Represents a class expression with a reference to an object property expression.
An abstraction for any anonymous data range expressions
(i.e. for all data ranges with except of
OWLDatatypes).An
OWLAnonymousIndividual implementation that is also an instance of ONTObject.Vocabulary with (possible, temporary) resources used by ONT-API only.
A base
RuntimeException, that must be used only in OWL-API part of implementation.A
RuntimeException to indicate wrong input.A
RuntimeException to indicate wrong object state.A runtime exception to indicate that modification is not allowed.
A
RuntimeException for unsupported things.A base axiom.
An
OWLClass implementation that is also an instance of ONTObject.A collection of
OWL-API Object Visitors used internally.A collector to find first occurrence.
A visitor to collect
Class Expressions in the form of Set.A visitor to collect
Entities in the form of Set.Base collector.
A base visitor that collects a
Set.A generic interface describing an
ONTObject that has components and signature.This is the global config and also the builder for the separated load and write configs.
An
OWLDataProperty implementation that is also ONTObject.An
OWLDatatype implementation that is also ONTObject.A base
OWLEntity implementation which has a reference to a model.A base class that represents any anonymous OWL2 expression.
An
OWLFacetRestriction implementation that is also ONTObject.The map between jena languages (
Lang) and OWL-API syntax formats (OWLLangRegistry.OWLLang).This is an extended
OWLOntologyDocumentSource that allows to pass any graph into the manager as is.This is an extended
OWLOntologyDocumentSource to provide possibility to pass any graph as is.Helper to work with
Apache Jena Graphs in OWL-API terms.An
IRI implementation that is also ONTObject.An implementation of
OWLLiteral that is also an ONTObject.This is an extended
OWLOntologyLoaderConfiguration with ONT-API specific settings.com.github.owlcs.ontapi.OntManagers is a main access point to the system, a collection of factory methods
to provide different implementations of OWLOntologyManager interface with its commonly required features.A profile to provide standard cache-based
ONT-API impls.The creation profile for
OWLAPI, based on straightforward reflection.Deprecated.
An
OWLNamedIndividual implementation that is also ONTObject.An unmodifiable container for
OWLObject and associated with it RDF Triples.An Internal Object Factory, which is responsible for mapping
OntObject => OWLObject and
for creating ONTObjects.An
OWLObjectInverseOf implementation that is also ONTObject.An
OWLObjectProperty implementation that is also ONTObject.A Structural Ontological Model, that is an extended
OWL-API Ontology.An implementation of
OntologyFactory.Builder - a technical factory to create standalone ontology instances.A collection to store anything that has
Ontology ID,
it maps these key-ids to element-containers and behaves like a Map.A collection to store anything that has
Ontology ID.An interface to create
Ontology instances.The factory to create and load ontologies into the manager.
A part of the factory, that is responsible for creating
Graph-based ontologies.A part of the factory, that is responsible for reading ontologies from different document sources.
The ontology building and loading factory, the 'core' - the main point to create and load ontologies.
An interface intended to process OWL document sources
and produce
Ontology instances inside a OntologyManager instance.Jena based implementation of
OntologyLoader.A container for a
graph and some load parameters, such as source-iri and format.An ONT-API Ontology manager, which is an extended
OWL-API manager.The Document Source mapping.
An ONT-API default implementation of
Ontology Manager.Listener's holder.
Implementation of
OWLOntologyLoaderMetaData.The main ontology model implementation.
A concurrent version of
Ontology.A base RDF-object component, which encapsulates both node and model references.
The
Enum of all ONT-API settings (22 OWL-API options + 15 ONT-API specific options)
Note: System properties are not taken into account (this is a difference from OWL-API-impl).A base triple object-component that is attached to a model.
A
SWRLAtom implementation that is also ONTObject.An abstract binary atom impl.
An abstract object binary atom.
An abstract unary atom impl
A
SWRLIndividualArgument implementation that is also ONTObject.A
SWRLLiteralArgument implementation that is also ONTObject.A
SWRLVariable implementation that is also ONTObject.An unmodifiable container for
OWLObject and associated with it set of rdf-graph triples.Extended
OWLOntologyWriterConfiguration.An 'adapter' to convert OWL-API things to ONT-API ones and to gain access to internal objects.
The transformer to convert OWL 1 DL => OWL 2 DL
Enum of mostly used OWL-API object types, that are not
OWLAxiom or OWLAnnotation,
to be used in various filter operations.Class to perform the final tuning of the OWL-2 ontology: mostly for fixing missed owl-declarations where it is possible.
An implementation of
OntologyLoader which is actually OWLOntologyFactory decorator.A copy-pasted OWL-API-impl utility class.
This is a copy-paste the original OWL-API
OWLOntologyFactory implementation,
which is used if syntax format of source can not be handled by Apache Jena.Class to perform ontology id transformation.
The global OWL-API format syntax registry.
A set of constants reflecting OWL-API I/O subsystem.
A container for OWL-Language details (owl-format).
A base for any OWLObject in ONT-API.
Helper to work with
OWLObject (mostly for retrieving components from owl-axioms).A decorator for any
OWLOntology instance.To perform recursive transformation in terms of OWL2.
Enum, that represents all public content meta-types of
OWLOntology:
one for the ontology header (OWLTopObjectType.ANNOTATION) and 39 for each type of axiom.An
ONTObject implementation that holds triples in memory.A
Graph Listener implementation
that monitors the Graph mutation while adding OWLObject into the cache-map.An
OWLObjectRendererQuantified data restriction impl.
Quantified object restriction impl.
To perform preliminary fixing: transform the RDFS ontological graph to the OWL ontological graph.
A collection of helper methods to perform translation of RDF-Graph to the
OWLObjects (i.e. reading from a Graph).The transformer to restore declarations in the implicit cases
(all notations are taken from the OWL2 Short Guide):
1) data or object universal or existential quantifications (restrictions):
_:x rdf:type owl:Restriction; owl:onProperty P; owl:allValuesFrom C
_:x rdf:type owl:Restriction; owl:onProperty R; owl:someValuesFrom D
2) property domains:
A rdfs:domain U
P rdfs:domain C
R rdfs:domain C
3) property ranges:
A rdfs:range U
R rdfs:range D
P rdfs:range C
4) property assertions (during reasoning the C owl:hasKey ( P1 ... Pm R1 ... Rn )
and U rdf:type owl:FunctionalProperty are used):
s A t
a R v
a1 PN a2
5) other expression and property constructions where one part could be determined from some another:
C1 owl:equivalentClass C2
DN owl:equivalentClass D
P1 owl:equivalentProperty P2
R1 owl:propertyDisjointWith R2
A1 rdfs:subPropertyOf A2
P1 rdfs:subPropertyOf P2
R1 rdfs:subPropertyOf R2
_:x owl:unionOf ( D1 ... Dn )
_:x owl:intersectionOf ( C1 ... Cn )
_:x rdf:type owl:AllDisjointProperties; owl:members ( P1 ... Pn )
A control interface, which determines the behaviour in ambiguous situations.
To remove/replace possible graph recursions
Example of graph with a simple recursions:
A helper to work with reflection.
A translator that provides
OWLReflexiveObjectPropertyAxiom implementations.An
OWLReflexiveObjectPropertyAxiom
that either has annotations or an anonymous object property expression (inverse object property)
in the main triple's subject position.An
OWLReflexiveObjectPropertyAxiom
that has a named object property as subject and has no annotations.An extended
OWL-API Priority Collection
that supports concurrent reading and writing through a ReadWriteLock.A translator that provides
OWLSameIndividualAxiom implementations.An
OWLSameIndividualAxiom
that either has annotations or anonymous class expressions in subject or object positions.An
OWLSameIndividualAxiom that has named classes as subject and object and has no annotations.Model with optimizations including nodes' cache.
A
EnhNodeFactory impl with nodes' cache.An Object Factory impl which maps
OntObject to OWLObject directly having no cache.A translator that provides
OWLSubAnnotationPropertyOfAxiom implementations.An
OWLSubAnnotationPropertyOfAxiom that has annotations.An
OWLSubAnnotationPropertyOfAxiom
that has named object properties as subject and object and has no annotations.Created by @ssz on 07.05.2020.
Created by @ssz on 18.04.2020.
A translator that provides
OWLSubClassOfAxiom implementations.An
OWLSubClassOfAxiom
that either has annotations or anonymous class expressions in subject or object positions.An
OWLSubClassOfAxiom that has named classes as subject and object and has no annotations.A translator that provides
OWLSubDataPropertyOfAxiom implementations.An
OWLSubDataPropertyOfAxiom that has annotations.An
OWLSubDataPropertyOfAxiom that has no annotations.A translator that provides
OWLSubObjectPropertyOfAxiom implementations.An
OWLSubObjectPropertyOfAxiom
that either has annotations or anonymous object property expressions (inverse object properties)
in its subject or object positions.An
OWLSubObjectPropertyOfAxiom
that has named object properties as subject and object and has no annotations.A translator that provides
OWLSubPropertyChainOfAxiom implementations.A translator that provides
SWRLRule implementations.Class for performing transformations that fix known syntax errors in graphs containing SWRL.
A translator that provides
OWLSymmetricObjectPropertyAxiom implementations.An
OWLSymmetricObjectPropertyAxiom
that either has annotations or an anonymous object property expression (inverse object property)
in the main triple's subject position.An
OWLSymmetricObjectPropertyAxiom
that has a named object property as subject and has no annotations.Represents a transformation operation
that accepts
RDF Graph and returns a set of RDF Triples.A factory to produce
Transforms.The default impl of
Transform, which is based on TransformationModel.The base interface for any graph transformer implementations.
A Graph-wrapper to use as base in a
working model.The jena exception to use inside
this package only.A translator that provides
OWLTransitiveObjectPropertyAxiom implementations.An
OWLTransitiveObjectPropertyAxiom
that either has annotations or an anonymous object property expression (inverse object property)
in the main triple's subject position.An
OWLTransitiveObjectPropertyAxiom
that has a named object property as subject and has no annotations.Created by @ssz on 24.10.2020.
A
GraphListener that allows to connect two UnionGraph
so that changing hierarchy structures of one graph will reflect the other.The generic interface describing an object that has annotation.
A technical interface that describes an object that has content cache,
which can be restored from a
Graph.A technical interface that describes a merge operation.
A technical interface, a collection of default method-implementations of
WithAnnotations.Created by @ssz on 19.04.2020.
A collection of helper methods to perform translation of
OWLObjects to the RDF-form (i.e. writing to a Graph).