Interface BaseOntologyModel

All Known Implementing Classes:
BaseOntologyModelImpl, OntologyModelImpl, OntologyModelImpl.Concurrent

public interface BaseOntologyModel
A technical interface-helper that serves as a bridge between Jena RDF model and OWLAPI ontology through the InternalGraphModel on the one hand, and between all these things and OWLAPI manager through the ModelConfig on the other hand. Also, it is a collection of factory-methods to produce various InternalGraphModel instances. Note: this is an internal mechanism that can be changed at any time.

Created by @ssz on 07.04.2017.

  • Method Details

    • getBaseGraphModel

      InternalGraphModel getBaseGraphModel()
      Returns an encapsulated InternalGraphModel instance - the facility to work both with Jena and OWL-API objects simultaneously.
      Returns:
      InternalGraphModel
    • setBaseGraphModel

      void setBaseGraphModel(InternalGraphModel m)
      Sets new internals. Not for public use: only Java Serialization mechanisms can explicitly call this method.
      Parameters:
      m - InternalGraphModel, not null
    • getConfig

      ModelConfig getConfig()
      Returns a model config instance, that is a collection of settings and, also, a facility which binds together the ontology and manager.
      Returns:
      ModelConfig
    • setConfig

      void setConfig(ModelConfig conf)
      Sets new model config. Not for public use: only Java Serialization mechanisms can explicitly call this method.
      Parameters:
      conf - ModelConfig, not null
    • createInternalGraphModel

      static InternalGraphModel createInternalGraphModel(org.apache.jena.graph.Graph graph)
      A factory method to create InternalGraphModel instance with default settings. Can be used to provide a dummy instance for testing or debugging.
      Parameters:
      graph - Graph, not null
      Returns:
      InternalGraphModel
    • createInternalGraphModel

      static InternalGraphModel createInternalGraphModel(org.apache.jena.graph.Graph graph, org.apache.jena.ontapi.OntSpecification specification, InternalConfig config, DataFactory dataFactory, Map<Class<? extends org.semanticweb.owlapi.model.OWLPrimitive>,InternalCache<?,?>> caches)
      A primary factory method to create fresh InternalGraphModel.
      Parameters:
      graph - Graph, not null, a base data-store
      specification - OntSpecification, not null
      config - InternalConfig, not null, to control behavior
      dataFactory - DataFactory, not null, to produces OWLObjects
      caches - a Map with OWLPrimitive class-types as keys and manager-wide InternalCaches as values to enable data sharing between different ontologies
      Returns:
      InternalGraphModel