Interface OWLOntologyWrapper.WithThrowable<T extends Throwable>

Enclosing class:
OWLOntologyWrapper
Functional Interface:
This is a functional interface and can therefore be used as the assignment target for a lambda expression or method reference.

@FunctionalInterface protected static interface OWLOntologyWrapper.WithThrowable<T extends Throwable>
  • Method Summary

    Modifier and Type
    Method
    Description
    void
     
  • Method Details

    • apply

      void apply() throws T
      Throws:
      T