Interface OntologyManager.DocumentSourceMapping

All Superinterfaces:
Serializable
Enclosing interface:
OntologyManager
Functional Interface:
This is a functional interface and can therefore be used as the assignment target for a lambda expression or method reference.

@FunctionalInterface public static interface OntologyManager.DocumentSourceMapping extends Serializable
The Document Source mapping. To customize ontology loading.
Since:
1.0.1
See Also:
  • OWLOntologyDocumentSource
  • Method Summary

    Modifier and Type
    Method
    Description
    default org.semanticweb.owlapi.io.OWLOntologyDocumentSource
    map(org.semanticweb.owlapi.model.IRI iri)
    Finds a OWL Document Source object by the IRI that may be either version IRI or ontology IRI.
    org.semanticweb.owlapi.io.OWLOntologyDocumentSource
    map(org.semanticweb.owlapi.model.OWLOntologyID id)
    Finds a OWL Document Source object by the Ontology ID.
  • Method Details

    • map

      org.semanticweb.owlapi.io.OWLOntologyDocumentSource map(org.semanticweb.owlapi.model.OWLOntologyID id)
      Finds a OWL Document Source object by the Ontology ID.
      Parameters:
      id - OWLOntologyID, not null
      Returns:
      OWLOntologyDocumentSource or null
    • map

      default org.semanticweb.owlapi.io.OWLOntologyDocumentSource map(org.semanticweb.owlapi.model.IRI iri)
      Finds a OWL Document Source object by the IRI that may be either version IRI or ontology IRI.
      Parameters:
      iri - IRI, not null
      Returns:
      OWLOntologyDocumentSource or null if no mapping found
      Since:
      1.3.2