Class OntConfig

java.lang.Object
org.semanticweb.owlapi.model.OntologyConfigurator
com.github.owlcs.ontapi.config.OntConfig
All Implemented Interfaces:
AxiomsSettings, CacheSettings, LoadSettings, Serializable
Direct Known Subclasses:
OntConfig.Concurrent

public class OntConfig extends org.semanticweb.owlapi.model.OntologyConfigurator
This is the global config and also the builder for the separated load and write configs. Used to manage general load/store behaviour of a manager (while immutable configs are for particular ontologies). It overrides OWL-API OntologyConfigurator and provides access to the new (ONT-API) settings. Note: this configuration is mutable, while load and write configs are not. Additional (new) ONT-API methods:

Created @ssz on 27.02.2017.

See Also:
  • Field Details

  • Constructor Details

    • OntConfig

      public OntConfig()
      Constructs a config. All its settings are taken from the ./resources/ontapi.properties file or, if missed in the file, from the defaults.
  • Method Details

    • createConfig

      public static OntConfig createConfig(ReadWriteLock lock)
      Creates a new config instance with the default settings and the given ReadWriteLock.
      Parameters:
      lock - ReadWriteLock or null for non-concurrent version
      Returns:
      OntConfig
      Since:
      1.4.0
    • withLock

      public static OntConfig withLock(OntConfig conf, ReadWriteLock lock)
      Makes a concurrent version of the specified config with the given R/W lock if needed, otherwise returns the same config. A concurrent config is backed by the given and vice versa.
      Parameters:
      conf - OntConfig, not null
      lock - ReadWriteLock, possible null
      Returns:
      an instance with lock
      Since:
      1.4.0
    • copy

      public static OntConfig copy(org.semanticweb.owlapi.model.OntologyConfigurator from)
      Copies all settings from the given OntologyConfigurator to a new instance.
      Parameters:
      from - OntologyConfigurator or null to create config with default settings.
      Returns:
      OntConfig new instance
    • serializableOnly

      protected static Map<OntSettings,Object> serializableOnly(Map<OntSettings,Object> data)
    • ignoredImports

      protected static Set<org.semanticweb.owlapi.model.IRI> ignoredImports(org.semanticweb.owlapi.model.OntologyConfigurator owl)
    • lockProperty

      public OntConfig lockProperty(OntSettings... keys)
      Makes the given property-keys prohibited for modification. An attempt to modify the value for a locked property will cause OntApiException.ModificationDenied.
      Parameters:
      keys - Array of OntSettings-keys to lock
      Returns:
      OntConfig this config
      Since:
      2.1.0
    • putAll

      public OntConfig putAll(org.semanticweb.owlapi.model.OntologyConfigurator from)
      Copies configuration from the given config.
      Parameters:
      from - OntologyConfigurator, the source, can be null
      Returns:
      OntConfig this config
      Since:
      1.4.0
    • data

      protected Map<OntSettings,Object> data()
    • store

      protected Map<OntSettings,Object> store()
    • get

      protected <X> X get(OntSettings key)
    • put

      protected OntConfig put(OntSettings key, Object value)
    • putPositive

      protected OntConfig putPositive(OntSettings k, int v)
    • putNonNegative

      protected OntConfig putNonNegative(OntSettings k, int v)
    • getSpecification

      public org.apache.jena.ontapi.OntSpecification getSpecification()
      An ONT-API manager's load config getter. Gets OntSpecification configuration object.
      Specified by:
      getSpecification in interface LoadSettings
      Returns:
      OntSpecification
      See Also:
    • setSpecification

      public OntConfig setSpecification(org.apache.jena.ontapi.OntSpecification specification, String constantFieldPath)
      An ONT-API manager's load config setter. Sets OntSpecification model configuration object.
      Parameters:
      specification - OntPersonality the personality
      constantFieldPath - String a path to constant for serialization, e.g. "org.apache.jena.ontapi.OntSpecification#OWL2_DL_MEM"; if null no attempt to serialize this field
      Returns:
      this instance
      See Also:
    • getGraphTransformers

      public GraphTransformers getGraphTransformers()
      An ONT-API manager's load config getter. Gets Transformers Store.

      Transformers Store is a collection of actions that are performed on Graph before it enters into the main system. One of the goals of this mechanism is a data transformation in accordance with OWL2 specification. Any RDF Graph can be presented by the system in the form of RDF Model or Axiomatic Model, but without a proper transformation you may not find a valid Axioms inside that data. Transformations can be simply disabled through the method LoadControl.setGraphTransformers(GraphTransformers). It is recommended to do this in case there is confidence that the data is OWL2, since transformations may take significant processor time. With the method GraphTransformers.setFilter(GraphFilter) a whole graph family may be skipped from the transformation process. And there is one more facility to selectively turn off transformations: the method OntGraphDocumentSource.withTransforms(), which is used while passing externally loaded graph into the manager (see OntologyManager.addOntology(Graph)).

      Specified by:
      getGraphTransformers in interface LoadSettings
      Returns:
      GraphTransformers
      See Also:
    • setGraphTransformers

      public OntConfig setGraphTransformers(GraphTransformers transformers)
      An ONT-API manager's load config setter. Sets GraphTransformers.Store collection.
      Parameters:
      transformers - GraphTransformers
      Returns:
      this instance
      See Also:
    • getManagerIRIsCacheSize

      public int getManagerIRIsCacheSize()
      An ONT-API manager's load config getter. Returns the IRI cache size, that is used inside a manager to share IRIs between ontologies. The default size is 2048, it is a magic number which is taken from OWL-API impl (see uk.ac.manchester.cs.owl.owlapi.OWLDataFactoryInternalsImpl, v5) A negative or zero number means that IRIs cache is disabled.
      Returns:
      int, possible non-positive number to disable whole IRIs caching
      Since:
      1.4.0
      See Also:
    • setManagerIRIsCacheSize

      protected OntConfig setManagerIRIsCacheSize(int size)
      An ONT-API manager's load config setter. Sets a new IRIs cache size. Protected, since this is a manager's initialization setting, that must not be changed during manager's lifetime.
      Parameters:
      size - int, possible negative
      Returns:
      this instance
    • getLoadNodesCacheSize

      public int getLoadNodesCacheSize()
      An ONT-API manager's load config getter. Returns the maximum size of nodes' cache, which is used as optimization while reading OWLObjects from a graph (see SearchModel). The system default size is 50_000.

      Each object factory has its own nodes cache with the same size, but, as a rule, only a few factories have many nodes in their cache. Average Node (uri and blank) size is about 160 bytes (internal string ~ 150byte), Experiments show that for the limit = 100_000, the total number of cached nodes is not more than 190_000 (it is for teleost and galen, significantly less for the rest tested ontologies), The number 190_000 uri or blank nodes means about 30 MB. Here the list of tested ontologies:

      • teleost(59mb, 336_291 axioms, 650_339 triples)
      • hp(38mb, 143_855 axioms, 367_315 triples)
      • galen(33mb, 96_463 axioms, 281_492 triples)
      • psychology(4mb, 38_872 axioms, 38_873 triples)
      • family(0.2mb, 2_845 axioms)
      • pizza(0.1mb, 945 axioms)
      Specified by:
      getLoadNodesCacheSize in interface CacheSettings
      Returns:
      int
      See Also:
    • setLoadNodesCacheSize

      public OntConfig setLoadNodesCacheSize(int size)
      An ONT-API manager's load config setter. Sets a new maximum nodes cache size to the specified positive number or disables nodes caching at all in case of non-positive number.
      Parameters:
      size - int
      Returns:
      this instance
    • getLoadObjectsCacheSize

      public int getLoadObjectsCacheSize()
      An ONT-API manager's load config getter. Returns the maximum size of objects factory cache, which is used as optimization while reading OWLObjects from a graph (see CacheObjectFactory). The system default size is 2048. This is a magic number from OWL-API impl, which has also similar caches.
      Specified by:
      getLoadObjectsCacheSize in interface CacheSettings
      Returns:
      int
      See Also:
    • setLoadObjectsCacheSize

      public OntConfig setLoadObjectsCacheSize(int size)
      An ONT-API manager's load config setter. Sets a new maximum objects cache size to the specified positive number or disables objects caching at all in case of non-positive number.
      Parameters:
      size - int
      Returns:
      this instance
    • getModelCacheLevel

      public int getModelCacheLevel()
      An ONT-API manager's load config getter. Returns the model content cache level. Currently, there are the following possible levels: Note: the list above may be changed in the ONT-API evolution.
      Specified by:
      getModelCacheLevel in interface CacheSettings
      Returns:
      boolean
      See Also:
    • setModelCacheLevel

      public OntConfig setModelCacheLevel(int level)
      An ONT-API manager's load config setter. Sets the model content cache level to the specified integer value. The number 0 means disabling all model's caches.

      The content cache consists of several levels:

      Parameters:
      level - int
      Returns:
      this instance
      See Also:
    • getSupportedSchemes

      public List<LoadSettings.Scheme> getSupportedSchemes()
      An ONT-API manager's load config getter. Answers a Collection of allowed LoadSettings.Scheme-controllers. This mechanism is used during preliminary analysis of IRI before loading a document. If an IRI fails any of the LoadSettings.Scheme-tests from the Collection, the document source is rejected and the system throws an exception. Note: there is also possible to prohibit the processing of only one IRI (see addIgnoredImport(IRI) and OntLoaderConfiguration.addIgnoredImport(IRI)) or all imports (see LoadControl.setProcessImports(boolean)).
      Specified by:
      getSupportedSchemes in interface LoadSettings
      Returns:
      unmodifiable Collection of supported schemas
      See Also:
    • setSupportedSchemes

      public OntConfig setSupportedSchemes(List<LoadSettings.Scheme> schemes)
      An ONT-API manager's load config setter. Sets a new collection of LoadSettings.Scheme-controllers.
      Parameters:
      schemes - List of LoadSettings.Scheme
      Returns:
      OntConfig this instance
      See Also:
    • disableWebAccess

      public OntConfig disableWebAccess()
      An ONT-API manager's load config setter. Disables all schemes with except of file to prevent internet diving. While loading only IRIs starting with file will be processed.
      Returns:
      this manager
      Since:
      1.1.0
      See Also:
    • isPerformTransformation

      public boolean isPerformTransformation()
      An ONT-API manager's load config getter. Answers true if the mechanism of graph transformers is enabled, which is true by default. If it is enabled, the process of any document RDF source will begin with the graph transformers, otherwise a raw graph will be loaded as it is. In the last case, the final ontology may not contain OWL2 data (with except of Ontology ID). If you pretty sure that you are loading OWL2 ontology, it might make sense to disable transformers using the method LoadControl.setPerformTransformation(boolean), since graph transformers require an additional processor time. For more info see the description for the LoadSettings.getGraphTransformers() method.
      Specified by:
      isPerformTransformation in interface LoadSettings
      Returns:
      boolean, (true by default)
      See Also:
    • setPerformTransformation

      public OntConfig setPerformTransformation(boolean b)
      An ONT-API manager's load config setter. Disables or enables the Graph Transformation mechanism depending on the given flag.
      Parameters:
      b - true to enable transformation (by default it is enabled)
      Returns:
      OntConfig this instance
      See Also:
    • isProcessImports

      public boolean isProcessImports()
      An ONT-API manager's load config getter. Answers true if the imports' processing is enabled. In this case the document source loading entails owl:imports processing and subsequent loading all related to them sources. If the imports' processing is disabled, then no additional work is performed and one document source is matched with one ontology. Note: there is also possible to prohibit the processing of one IRI (see addIgnoredImport(IRI) and OntLoaderConfiguration.addIgnoredImport(IRI)) or whole scheme (see LoadControl.setSupportedSchemes(List)).
      Specified by:
      isProcessImports in interface LoadSettings
      Returns:
      boolean, (true by default)
      See Also:
    • setProcessImports

      public OntConfig setProcessImports(boolean b)
      An ONT-API manager's load config setter. Disables or enables the processing imports depending on the given flag.
    • isAllowBulkAnnotationAssertions

      public boolean isAllowBulkAnnotationAssertions()
      An ONT-API manager's load config getter. Answers whether the bulk annotations is allowed in declaration axioms or annotations should go separately as annotation assertion axioms. More specifically, this optional setting stands to manage behaviour of annotation assertions in conjunction with declarations: depending on this parameter bulk annotations fall either into declaration or annotation assertion. Consider the following RDF example:
      
       <C>   a                       owl:Class ;
             rdfs:comment            "plain assertion" ;
             rdfs:label              "bulk assertion" .
       [     a                       owl:Axiom ;
             rdfs:comment            "the child" ;
             owl:annotatedProperty   rdfs:label ;
             owl:annotatedSource     <C> ;
             owl:annotatedTarget     "bulk assertion"
       ] .
       
      In case this option is turned on, the RDF slice above corresponds to the following list of axioms:
      • AnnotationAssertion(rdfs:comment <C> "plain assertion"^^xsd:string)
      • AnnotationAssertion(Annotation(rdfs:comment "the child"^^xsd:string) rdfs:label <C> "bulk assertion"^^xsd:string)
      • Declaration(Class(<C>))
      In case it is turned off there would be the following axioms:
      • Declaration(Annotation(Annotation(rdfs:comment "the child"^^xsd:string) rdfs:label "bulk assertion"^^xsd:string) Class(<C>))
      • AnnotationAssertion(rdfs:comment <C> "plain assertion"^^xsd:string)
      Note: the Manchester OWL-API Parser does NOT seem to work correctly in the second case (checked version: 5.1.4) - the loss of annotations is expected in case of reload ontology in manchester syntax. By default, annotated annotation assertions are allowed (the method answers true).
      Specified by:
      isAllowBulkAnnotationAssertions in interface AxiomsSettings
      Returns:
      true if bulk annotations are allowed (that is by default)
      See Also:
    • setAllowBulkAnnotationAssertions

      public OntConfig setAllowBulkAnnotationAssertions(boolean b)
      An ONT-API manager's load config setter. Sets bulk annotation assertions option to the specified state.
      Parameters:
      b - true to enable bulk annotations
      Returns:
      this instance
      See Also:
    • isAllowReadDeclarations

      public boolean isAllowReadDeclarations()
      An ONT-API manager's load config getter. Answers whether the declaration axioms should be listed. This method is invited to match OWL-API behaviour. Some native OWL-API parsers skips declarations on loading. Using this option you can uniform global behaviour by discarding declarations in live ontology. The default value of this option is true.
      Specified by:
      isAllowReadDeclarations in interface AxiomsSettings
      Returns:
      true if declarations are enabled (default)
      See Also:
    • setAllowReadDeclarations

      public OntConfig setAllowReadDeclarations(boolean b)
      An ONT-API manager's load config setter. Sets the read declarations option to the desired state.
      Parameters:
      b - boolean enable/disable declarations
      Returns:
      this instance
      See Also:
    • isIgnoreAnnotationAxiomOverlaps

      public boolean isIgnoreAnnotationAxiomOverlaps()
      An ONT-API manager's load config getter. Answers whether the Range, Domain and SubClassOf axioms should be separated in case there is a 'punning' in annotation property with the other property (data or object). More specifically, the option determines the behavior while reading annotation axioms in case of a punning entity as subject in the root statement. There are three types of annotation axioms with following defining statements:
      • Ai rdfs:subPropertyOf Aj
      • A rdfs:domain U
      • A rdfs:range U
      If the annotation property A is also an object property (P) or data property (R) then, in case this option is turned on, the statements above define also corresponded object or data property axioms. Otherwise, (if the option is turned off), the annotation axioms of above type are ignored in favour of object or data property axioms.

      Please note: OntPersonality.Punnings is the general mechanism to control punnings. It is accessible through the config methods getSpecification() and OntLoaderConfiguration.getSpecification().

      The default value of this option is true.

      Specified by:
      isIgnoreAnnotationAxiomOverlaps in interface AxiomsSettings
      Returns:
      true if annotation axiom overlaps are ignored (default)
      See Also:
    • setIgnoreAnnotationAxiomOverlaps

      public OntConfig setIgnoreAnnotationAxiomOverlaps(boolean b)
      An ONT-API manager's load config setter. Sets ignore annotation axioms overlaps option to the specified state.
      Parameters:
      b - boolean to enable/disable this config parameter
      Returns:
      this instance
      See Also:
    • isUseOWLParsersToLoad

      public boolean isUseOWLParsersToLoad()
      An ONT-API manager's load config getter. Answers true if the native OWL-API parsers must be preferred while loading ontology, which is strongly not recommended (and the method returns false by default).

      The method is used by the Ontology Factory default implementation to choose the preferable way to load. If this parameter is set to false then ONT-API (i.e., Apache Jena) loading mechanisms are used in case the document format is supported both by Jena and OWL-API (like Turtle, RDF/XML, etc. See OntFormat). Otherwise, loading is always performed using only the native OWL-API Parsers, which, actually, do not read RDF graph fully, but rather assemble it axiom by axiom. Remember, the OWL-API loading mechanisms (as well as OWL-API default impl) are OWL-centric. As a result, in fact, they work buggy in many cases (e.g., when data is not produced by OWL-API itself). A data Graph may not present correct OWL2, but be rather RDFS, or whatever else. For example, SPIN ontology contains a lot of SPARQL queries in a special spin form, that is using custom rdf:Lists (an example of such []-list is the right part of any triple with predicate sp:where). After loading such an ontology with the help of OWL Turtle Parser (checked v 5.1.4), it will contain garbage instead of the original constructs. With the default ONT-API loading mechanism you get Graph as it is, but with, maybe, several controlled changes caused by the transformers (see LoadSettings.getGraphTransformers()). So please do not change the default value without a good reason

      Specified by:
      isUseOWLParsersToLoad in interface LoadSettings
      Returns:
      boolean, (false by default)
      See Also:
    • setUseOWLParsersToLoad

      public OntConfig setUseOWLParsersToLoad(boolean b)
      An ONT-API manager's load config setter. Changes the preferable way to load a Graph. If true specified, the OWL-API native parsers will be used. Though, it is not recommended, for more details see the getter description.
      Parameters:
      b - boolean to enable/disable this config parameter
      Returns:
      this instance
    • isUseDistinctUnionGraph

      public boolean isUseDistinctUnionGraph()
      An ONT-API manager's load config getter. Answers true if union graph must be distinct. A non-distinct graph does not prevent data duplication when querying (see generic query method Graph.find(Node, Node, Node)). The data duplication may happen if a subgraph contains the same triples as the base graph. Note that distinct graphs require additional memory. A non-distinct graphs, for example, can be used when axioms/content cache is disabled to list raw/inferred entities and axioms.
      Specified by:
      isUseDistinctUnionGraph in interface LoadSettings
      Returns:
      true if underlying graph must be distinct
      See Also:
    • setUseDistinctUnionGraph

      public OntConfig setUseDistinctUnionGraph(boolean b)
      An ONT-API manager's load config setter. Disables or enables the behavior of UnionGraph: if the parameter is true, the graph is distinct, meaning there will be no duplicates in the query data.
      Parameters:
      b - boolean to enable/ disable this config parameter
      Returns:
      this instance
    • isIgnoreAxiomsReadErrors

      public boolean isIgnoreAxiomsReadErrors()
      An ONT-API manager's load config getter. Answers whether errors that arise when parsing axioms from a graph should be ignored. More specifically, it manages handling exceptions in case unable to read axioms of some type from a graph. If specified all errors would be silently ignored. AN RDF recursion (i.e. <A> rdfs:subClassOf <A>) is an example of such buggy situation. The default value of this option is false.
      Specified by:
      isIgnoreAxiomsReadErrors in interface AxiomsSettings
      Returns:
      true if any errors while reading axioms are ignored (by default it is false)
      Since:
      1.1.0
      See Also:
    • isReadONTObjects

      public boolean isReadONTObjects()
      An ONT-API manager's load config getter. Answers whether the Ontology read methods should return ONTObjects. If true, than every method that provides OWLObjects in any form, will actually return corresponding ONTObject implementation, otherwise, it will return a plain OWLObject. An ONTObject has an RDF-graph reference inside, and, therefore, all OWLObject-related RDF triples can be retrieved from it. A plain OWLObject is detached from parent ontology, it can be stored somewhere separately without dangerous of memory leak. The default value of this option is false.
      Specified by:
      isReadONTObjects in interface AxiomsSettings
      Returns:
      true if ONTObjects should be returned by Ontology getters
      Since:
      3.3.0
      See Also:
    • setIgnoreAxiomsReadErrors

      public OntConfig setIgnoreAxiomsReadErrors(boolean b)
      An ONT-API manager's load config setter. Sets the ignore read errors option to the desired state.
      Parameters:
      b - boolean to enable/disable ignoring axioms reading errors
      Returns:
      this instance
      Since:
      1.1.0
      See Also:
    • setReadONTObjects

      public OntConfig setReadONTObjects(boolean b)
      An ONT-API manager's load config setter. Sets the read-ont-objects flag to the desired state.
      Parameters:
      b - boolean to enable/disable ONTObject reading
      Returns:
      this instance
      Since:
      3.3.0
      See Also:
    • isSplitAxiomAnnotations

      public boolean isSplitAxiomAnnotations()
      An ONT-API manager's load config getter. Answers whether the different bulk annotations for the same axiom should go as different axioms. If this optional parameter is set to true, each bulk annotation RDF resource will generate a separated axiom. Otherwise, all bulk-annotations RDF resources with the same main statement in axiomatic view go together as a part of a single axiom that corresponds the main triple. Consider the following ontology snippet:
      
       <A>     a                owl:Class ;
               rdfs:subClassOf  owl:Thing .
       [ a                      owl:Axiom ;
         rdfs:comment           "X" ;
         rdfs:label             "Z" ;
         owl:annotatedProperty  rdfs:subClassOf ;
         owl:annotatedSource    <A> ;
         owl:annotatedTarget    owl:Thing
       ] .
       [ a                      owl:Axiom ;
         rdfs:comment           "W" ;
         owl:annotatedProperty  rdfs:subClassOf ;
         owl:annotatedSource    <A> ;
         owl:annotatedTarget    owl:Thing
       ] .
       
      If isSplitAxiomAnnotations() equals true then the ontology above gives the following two axioms:
      
       SubClassOf(Annotation(rdfs:comment "W"^^xsd:string) <A> owl:Thing)
       SubClassOf(Annotation(rdfs:comment "X"^^xsd:string) Annotation(rdfs:label "Z"^^xsd:string) <A> owl:Thing)
       
      If isSplitAxiomAnnotations() equals false, then there is only single SubClassOf axiom:
      
       SubClassOf(Annotation(rdfs:comment "W"^^xsd:string) Annotation(rdfs:comment "X"^^xsd:string) Annotation(rdfs:label "Z"^^xsd:string) <string:A> owl:Thing)
       
      The default value of this option is false.
      Specified by:
      isSplitAxiomAnnotations in interface AxiomsSettings
      Returns:
      boolean
      See Also:
    • setSplitAxiomAnnotations

      public OntConfig setSplitAxiomAnnotations(boolean b)
      An ONT-API manager's load config setter. Sets the axiom-annotations-split option setting to the desired state.
      Parameters:
      b - boolean
      Returns:
      this instance
      Since:
      1.3.0
      See Also:
    • isControlImports

      public boolean isControlImports()
      An ONT-API manager's write config getter. By default 'ont.api.write.conf.control.imports' is disabled.
      Returns:
      true if 'ont.api.write.conf.control.imports' is enabled
      See Also:
    • setControlImports

      public OntConfig setControlImports(boolean b)
      An ONT-API manager's write config setter.
      Parameters:
      b - boolean to enable/disable this config parameter
      Returns:
      this instance
      See Also:
    • shouldLoadAnnotations

      public boolean shouldLoadAnnotations()
      Overrides:
      shouldLoadAnnotations in class org.semanticweb.owlapi.model.OntologyConfigurator
      Returns:
      boolean
      See Also:
      • OntologyConfigurator.shouldLoadAnnotations()
    • isLoadAnnotationAxioms

      public boolean isLoadAnnotationAxioms()
      OWL-API(NEW) manager load config getter. Answers whether annotation axioms (instances of OWLAnnotationAxiom) should be retrieved from the Graph. If false then Annotation Property Domain, Annotation Property Range, Annotation Property Assertion and SubAnnotationPropertyOf OWL Axioms are ignored. It is native OWL-API option, in OWL-API-impl it controls axioms loading from a source, while in ONT-API it is a graph reading option, which can be turned on or off without any actual changing underlying data. By default, the reading (loading) of annotation axioms is enabled (i.e. the method returns true).

      Note: the behaviour is slightly different from OWL-API (checked version: 5.1.4): if read annotation axioms is disabled, all Annotation Property Assertion axioms turn into OWL Annotations in the composition of the nearest declaration axioms. For example, consider the snippet:

      
       <C>  rdf:type      owl:Class ;
            rdfs:comment  "comment1"@ex .
       
      If this option is off, there above RDF corresponds to the axiom Declaration(Annotation(rdfs:comment "comment1"@es) Class(<C>)) in ONT-API structural view, while in OWL-API it would be just naked declaration (i.e. Declaration(Class(<C>))).
      Specified by:
      isLoadAnnotationAxioms in interface AxiomsSettings
      Returns:
      boolean
      See Also:
    • setLoadAnnotationAxioms

      public OntConfig setLoadAnnotationAxioms(boolean b)
      An ONT-API manager's load config setter.
      Overrides:
      setLoadAnnotationAxioms in class org.semanticweb.owlapi.model.OntologyConfigurator
      See Also:
      • OntologyConfigurator.setLoadAnnotationAxioms(boolean)
    • withEntityExpansionLimit

      public OntConfig withEntityExpansionLimit(@Nonnull String s)
      OWL-API(NEW) manager load config setter. This is NOT override method: there is NO such method in the original general OWL-API config (OntologyConfigurator), but it present in load-config.
      Parameters:
      s - String
      Returns:
      this instance
      See Also:
    • getEntityExpansionLimit

      public String getEntityExpansionLimit()
      OWL-API(NEW) manager load config getter. This is NOT override method: there is NO such method in the original general OWL-API config (OntologyConfigurator), but it present in load-config.
      Returns:
      String, for more info see:
      See Also:
    • withBannedParsers

      public OntConfig withBannedParsers(@Nonnull String parsers)
      Overrides:
      withBannedParsers in class org.semanticweb.owlapi.model.OntologyConfigurator
      See Also:
      • OntologyConfigurator.withBannedParsers(String)
    • getBannedParsers

      public String getBannedParsers()
      Overrides:
      getBannedParsers in class org.semanticweb.owlapi.model.OntologyConfigurator
      See Also:
      • OntologyConfigurator.getBannedParsers()
    • getPriorityCollectionSorting

      public org.semanticweb.owlapi.model.PriorityCollectionSorting getPriorityCollectionSorting()
      Overrides:
      getPriorityCollectionSorting in class org.semanticweb.owlapi.model.OntologyConfigurator
      See Also:
      • OntologyConfigurator.getPriorityCollectionSorting()
    • setPriorityCollectionSorting

      public OntConfig setPriorityCollectionSorting(@Nonnull org.semanticweb.owlapi.model.PriorityCollectionSorting sorting)
      Overrides:
      setPriorityCollectionSorting in class org.semanticweb.owlapi.model.OntologyConfigurator
      See Also:
      • OntologyConfigurator.setPriorityCollectionSorting(PriorityCollectionSorting)
    • getIgnoredImports

      protected List<org.semanticweb.owlapi.model.IRI> getIgnoredImports()
    • putIgnoredImports

      protected OntConfig putIgnoredImports(List<org.semanticweb.owlapi.model.IRI> imports)
    • addIgnoredImport

      public OntConfig addIgnoredImport(@Nonnull org.semanticweb.owlapi.model.IRI iri)
      Overrides:
      addIgnoredImport in class org.semanticweb.owlapi.model.OntologyConfigurator
      See Also:
      • OntologyConfigurator.addIgnoredImport(IRI)
    • clearIgnoredImports

      public OntConfig clearIgnoredImports()
      Overrides:
      clearIgnoredImports in class org.semanticweb.owlapi.model.OntologyConfigurator
      See Also:
      • OntologyConfigurator.clearIgnoredImports()
    • removeIgnoredImport

      public OntConfig removeIgnoredImport(@Nonnull org.semanticweb.owlapi.model.IRI iri)
      Overrides:
      removeIgnoredImport in class org.semanticweb.owlapi.model.OntologyConfigurator
      See Also:
      • OntologyConfigurator.removeIgnoredImport(IRI)
    • setAcceptingHTTPCompression

      public OntConfig setAcceptingHTTPCompression(boolean b)
      Overrides:
      setAcceptingHTTPCompression in class org.semanticweb.owlapi.model.OntologyConfigurator
      See Also:
      • OntologyConfigurator.setAcceptingHTTPCompression(boolean)
    • shouldAcceptHTTPCompression

      public boolean shouldAcceptHTTPCompression()
      Overrides:
      shouldAcceptHTTPCompression in class org.semanticweb.owlapi.model.OntologyConfigurator
      See Also:
      • OntologyConfigurator.shouldAcceptHTTPCompression()
    • getConnectionTimeout

      public int getConnectionTimeout()
      Overrides:
      getConnectionTimeout in class org.semanticweb.owlapi.model.OntologyConfigurator
      See Also:
      • OntologyConfigurator.getConnectionTimeout()
    • setConnectionTimeout

      public OntConfig setConnectionTimeout(int t)
      Overrides:
      setConnectionTimeout in class org.semanticweb.owlapi.model.OntologyConfigurator
      See Also:
      • OntologyConfigurator.setConnectionTimeout(int)
    • setFollowRedirects

      public OntConfig setFollowRedirects(boolean b)
      Overrides:
      setFollowRedirects in class org.semanticweb.owlapi.model.OntologyConfigurator
      See Also:
      • OntologyConfigurator.setFollowRedirects(boolean)
    • shouldFollowRedirects

      public boolean shouldFollowRedirects()
      Overrides:
      shouldFollowRedirects in class org.semanticweb.owlapi.model.OntologyConfigurator
      See Also:
      • OntologyConfigurator.shouldFollowRedirects()
    • getMissingImportHandlingStrategy

      public org.semanticweb.owlapi.model.MissingImportHandlingStrategy getMissingImportHandlingStrategy()
      Overrides:
      getMissingImportHandlingStrategy in class org.semanticweb.owlapi.model.OntologyConfigurator
      See Also:
      • OntologyConfigurator.getMissingImportHandlingStrategy()
    • setMissingImportHandlingStrategy

      public OntConfig setMissingImportHandlingStrategy(@Nonnull org.semanticweb.owlapi.model.MissingImportHandlingStrategy strategy)
      Overrides:
      setMissingImportHandlingStrategy in class org.semanticweb.owlapi.model.OntologyConfigurator
      See Also:
      • OntologyConfigurator.setMissingImportHandlingStrategy(MissingImportHandlingStrategy)
    • getMissingOntologyHeaderStrategy

      public org.semanticweb.owlapi.model.MissingOntologyHeaderStrategy getMissingOntologyHeaderStrategy()
      Overrides:
      getMissingOntologyHeaderStrategy in class org.semanticweb.owlapi.model.OntologyConfigurator
      See Also:
      • OntologyConfigurator.getMissingOntologyHeaderStrategy()
    • setMissingOntologyHeaderStrategy

      public OntConfig setMissingOntologyHeaderStrategy(@Nonnull org.semanticweb.owlapi.model.MissingOntologyHeaderStrategy strategy)
      Overrides:
      setMissingOntologyHeaderStrategy in class org.semanticweb.owlapi.model.OntologyConfigurator
      See Also:
      • OntologyConfigurator.setMissingOntologyHeaderStrategy(MissingOntologyHeaderStrategy)
    • setReportStackTraces

      public OntConfig setReportStackTraces(boolean b)
      Overrides:
      setReportStackTraces in class org.semanticweb.owlapi.model.OntologyConfigurator
      See Also:
      • OntologyConfigurator.setReportStackTraces(boolean)
    • shouldReportStackTraces

      public boolean shouldReportStackTraces()
      Overrides:
      shouldReportStackTraces in class org.semanticweb.owlapi.model.OntologyConfigurator
      See Also:
      • OntologyConfigurator.shouldReportStackTraces()
    • getRetriesToAttempt

      public int getRetriesToAttempt()
      Overrides:
      getRetriesToAttempt in class org.semanticweb.owlapi.model.OntologyConfigurator
      See Also:
      • OntologyConfigurator.getRetriesToAttempt()
    • setRetriesToAttempt

      public OntConfig setRetriesToAttempt(int retries)
      Overrides:
      setRetriesToAttempt in class org.semanticweb.owlapi.model.OntologyConfigurator
      See Also:
      • OntologyConfigurator.setRetriesToAttempt(int)
    • setStrict

      public OntConfig setStrict(boolean strict)
      Overrides:
      setStrict in class org.semanticweb.owlapi.model.OntologyConfigurator
      See Also:
      • OntologyConfigurator.setStrict(boolean)
    • shouldParseWithStrictConfiguration

      public boolean shouldParseWithStrictConfiguration()
      Overrides:
      shouldParseWithStrictConfiguration in class org.semanticweb.owlapi.model.OntologyConfigurator
      See Also:
      • OntologyConfigurator.shouldParseWithStrictConfiguration()
    • setTreatDublinCoreAsBuiltIn

      public OntConfig setTreatDublinCoreAsBuiltIn(boolean value)
      Overrides:
      setTreatDublinCoreAsBuiltIn in class org.semanticweb.owlapi.model.OntologyConfigurator
      See Also:
      • OntologyConfigurator.setTreatDublinCoreAsBuiltIn(boolean)
    • shouldTreatDublinCoreAsBuiltin

      public boolean shouldTreatDublinCoreAsBuiltin()
      Overrides:
      shouldTreatDublinCoreAsBuiltin in class org.semanticweb.owlapi.model.OntologyConfigurator
      See Also:
      • OntologyConfigurator.shouldTreatDublinCoreAsBuiltin()
    • withSaveIdsForAllAnonymousIndividuals

      public OntConfig withSaveIdsForAllAnonymousIndividuals(boolean b)
      Overrides:
      withSaveIdsForAllAnonymousIndividuals in class org.semanticweb.owlapi.model.OntologyConfigurator
      See Also:
      • OntologyConfigurator.withSaveIdsForAllAnonymousIndividuals(boolean)
    • shouldSaveIds

      public boolean shouldSaveIds()
      Overrides:
      shouldSaveIds in class org.semanticweb.owlapi.model.OntologyConfigurator
      See Also:
      • OntologyConfigurator.shouldSaveIds()
    • withRemapAllAnonymousIndividualsIds

      public OntConfig withRemapAllAnonymousIndividualsIds(boolean b)
      Overrides:
      withRemapAllAnonymousIndividualsIds in class org.semanticweb.owlapi.model.OntologyConfigurator
      See Also:
      • OntologyConfigurator.withRemapAllAnonymousIndividualsIds(boolean)
    • shouldRemapIds

      public boolean shouldRemapIds()
      Overrides:
      shouldRemapIds in class org.semanticweb.owlapi.model.OntologyConfigurator
      See Also:
      • OntologyConfigurator.shouldRemapIds()
    • withUseNamespaceEntities

      public OntConfig withUseNamespaceEntities(boolean b)
      Overrides:
      withUseNamespaceEntities in class org.semanticweb.owlapi.model.OntologyConfigurator
      See Also:
      • OntologyConfigurator.withUseNamespaceEntities(boolean)
    • shouldUseNamespaceEntities

      public boolean shouldUseNamespaceEntities()
      Overrides:
      shouldUseNamespaceEntities in class org.semanticweb.owlapi.model.OntologyConfigurator
      See Also:
      • OntologyConfigurator.shouldUseNamespaceEntities()
    • withIndenting

      public OntConfig withIndenting(boolean b)
      Overrides:
      withIndenting in class org.semanticweb.owlapi.model.OntologyConfigurator
      See Also:
      • OntologyConfigurator.withIndenting(boolean)
    • shouldIndent

      public boolean shouldIndent()
      Overrides:
      shouldIndent in class org.semanticweb.owlapi.model.OntologyConfigurator
      See Also:
      • OntologyConfigurator.shouldIndent()
    • withIndentSize

      public OntConfig withIndentSize(int indent)
      Overrides:
      withIndentSize in class org.semanticweb.owlapi.model.OntologyConfigurator
      See Also:
      • OntologyConfigurator.withIndentSize(int)
    • getIndentSize

      public int getIndentSize()
      Overrides:
      getIndentSize in class org.semanticweb.owlapi.model.OntologyConfigurator
      See Also:
      • OntologyConfigurator.getIndentSize()
    • withLabelsAsBanner

      public OntConfig withLabelsAsBanner(boolean b)
      Overrides:
      withLabelsAsBanner in class org.semanticweb.owlapi.model.OntologyConfigurator
      See Also:
      • OntologyConfigurator.withLabelsAsBanner(boolean)
    • shouldUseLabelsAsBanner

      public boolean shouldUseLabelsAsBanner()
      Overrides:
      shouldUseLabelsAsBanner in class org.semanticweb.owlapi.model.OntologyConfigurator
      See Also:
      • OntologyConfigurator.shouldUseLabelsAsBanner()
    • withBannersEnabled

      public OntConfig withBannersEnabled(boolean b)
      Overrides:
      withBannersEnabled in class org.semanticweb.owlapi.model.OntologyConfigurator
      See Also:
      • OntologyConfigurator.withBannersEnabled(boolean)
    • shouldUseBanners

      public boolean shouldUseBanners()
      Overrides:
      shouldUseBanners in class org.semanticweb.owlapi.model.OntologyConfigurator
      See Also:
      • OntologyConfigurator.shouldUseBanners()
    • shouldRepairIllegalPunnings

      public boolean shouldRepairIllegalPunnings()
      Always returns true since this functionality is not supported by ONT-API.
      Overrides:
      shouldRepairIllegalPunnings in class org.semanticweb.owlapi.model.OntologyConfigurator
      Returns:
      true
      Since:
      OWL-API 5.1.1, ONT-API 1.3.0
    • withRepairIllegalPunnings

      public OntConfig withRepairIllegalPunnings(boolean b)
      No-op since this functionality is not supported by ONT-API.
      Overrides:
      withRepairIllegalPunnings in class org.semanticweb.owlapi.model.OntologyConfigurator
      Parameters:
      b - anything
      Returns:
      this instance
      Since:
      OWL-API 5.1.1, ONT-API 1.3.0
    • buildLoaderConfiguration

      public OntLoaderConfiguration buildLoaderConfiguration()
      Builds new loader configuration.
      Overrides:
      buildLoaderConfiguration in class org.semanticweb.owlapi.model.OntologyConfigurator
      Returns:
      new OntLoaderConfiguration
      See Also:
      • OntologyConfigurator.buildLoaderConfiguration()
    • buildWriterConfiguration

      public OntWriterConfiguration buildWriterConfiguration()
      Builds new writer configuration.
      Overrides:
      buildWriterConfiguration in class org.semanticweb.owlapi.model.OntologyConfigurator
      Returns:
      new OntWriterConfiguration
      See Also:
      • OntologyConfigurator.buildWriterConfiguration()
    • equals

      public boolean equals(Object o)
      Overrides:
      equals in class Object
    • hashCode

      public int hashCode()
      Overrides:
      hashCode in class Object
    • asMap

      protected Map<OntSettings,Object> asMap()
    • setSpecification

      default OntConfig setSpecification(org.apache.jena.ontapi.OntSpecification specification)
      Sets OntSpecification model configuration object.
      Parameters:
      specification - OntSpecification, not null
      Returns:
      LoadControl (this or copied instance)
      See Also:
    • setModelCacheLevel

      default OntConfig setModelCacheLevel(int constant, boolean b)
      Turns on/off the content cache use. Other cache settings are untouched, which means if there is a component cache enabled, it will remain enabled (if existent constant do not equal to the given one).
      Parameters:
      constant - a non-negative int number
      b - true to turn on, false to turn off
      Returns:
      CacheControl
      See Also: