Package com.github.owlcs.ontapi.config
Class OntConfig.Concurrent
java.lang.Object
org.semanticweb.owlapi.model.OntologyConfigurator
com.github.owlcs.ontapi.config.OntConfig
com.github.owlcs.ontapi.config.OntConfig.Concurrent
- All Implemented Interfaces:
AxiomsSettings,CacheSettings,LoadSettings,Serializable
- Enclosing class:
OntConfig
- See Also:
-
Nested Class Summary
Nested classes/interfaces inherited from class com.github.owlcs.ontapi.config.OntConfig
OntConfig.Concurrent, OntConfig.DefaultSchemeNested classes/interfaces inherited from interface com.github.owlcs.ontapi.config.LoadSettings
LoadSettings.Scheme -
Field Summary
FieldsFields inherited from interface com.github.owlcs.ontapi.config.CacheSettings
CACHE_ALL, CACHE_COMPONENT, CACHE_CONTENT, CACHE_ITERATOR -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionaddIgnoredImport(org.semanticweb.owlapi.model.IRI iri) protected Map<OntSettings, Object> asMap()Builds new loader configuration.Builds new writer configuration.protected Map<OntSettings, Object> data()booleanprotected <X> Xget(OntSettings key) inthashCode()protected OntConfig.Concurrentput(OntSettings key, Object value) putAll(org.semanticweb.owlapi.model.OntologyConfigurator from) Copies configuration from the given config.removeIgnoredImport(org.semanticweb.owlapi.model.IRI iri) default OntConfigsetModelCacheLevel(int constant, boolean b) Turns on/off the content cache use.default OntConfigsetSpecification(org.apache.jena.ontapi.OntSpecification specification) SetsOntSpecificationmodel configuration object.protected Map<OntSettings, Object> store()Methods inherited from class com.github.owlcs.ontapi.config.OntConfig
copy, createConfig, disableWebAccess, getBannedParsers, getConnectionTimeout, getEntityExpansionLimit, getGraphTransformers, getIgnoredImports, getIndentSize, getLoadNodesCacheSize, getLoadObjectsCacheSize, getManagerIRIsCacheSize, getMissingImportHandlingStrategy, getMissingOntologyHeaderStrategy, getModelCacheLevel, getPriorityCollectionSorting, getRetriesToAttempt, getSpecification, getSupportedSchemes, ignoredImports, isAllowBulkAnnotationAssertions, isAllowReadDeclarations, isControlImports, isIgnoreAnnotationAxiomOverlaps, isIgnoreAxiomsReadErrors, isLoadAnnotationAxioms, isPerformTransformation, isProcessImports, isReadONTObjects, isSplitAxiomAnnotations, isUseDistinctUnionGraph, isUseOWLParsersToLoad, lockProperty, putIgnoredImports, putNonNegative, putPositive, serializableOnly, setAcceptingHTTPCompression, setAllowBulkAnnotationAssertions, setAllowReadDeclarations, setConnectionTimeout, setControlImports, setFollowRedirects, setGraphTransformers, setIgnoreAnnotationAxiomOverlaps, setIgnoreAxiomsReadErrors, setLoadAnnotationAxioms, setLoadNodesCacheSize, setLoadObjectsCacheSize, setManagerIRIsCacheSize, setMissingImportHandlingStrategy, setMissingOntologyHeaderStrategy, setModelCacheLevel, setPerformTransformation, setPriorityCollectionSorting, setProcessImports, setReadONTObjects, setReportStackTraces, setRetriesToAttempt, setSpecification, setSplitAxiomAnnotations, setStrict, setSupportedSchemes, setTreatDublinCoreAsBuiltIn, setUseDistinctUnionGraph, setUseOWLParsersToLoad, shouldAcceptHTTPCompression, shouldFollowRedirects, shouldIndent, shouldLoadAnnotations, shouldParseWithStrictConfiguration, shouldRemapIds, shouldRepairIllegalPunnings, shouldReportStackTraces, shouldSaveIds, shouldTreatDublinCoreAsBuiltin, shouldUseBanners, shouldUseLabelsAsBanner, shouldUseNamespaceEntities, withBannedParsers, withBannersEnabled, withEntityExpansionLimit, withIndenting, withIndentSize, withLabelsAsBanner, withLock, withRemapAllAnonymousIndividualsIds, withRepairIllegalPunnings, withSaveIdsForAllAnonymousIndividuals, withUseNamespaceEntitiesMethods inherited from class org.semanticweb.owlapi.model.OntologyConfigurator
shouldOutputNamedGraphIRI, withNamedGraphIRIEnabledMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, toString, wait, wait, waitMethods inherited from interface com.github.owlcs.ontapi.config.CacheSettings
useComponentCache, useContentCache, useIteratorCache, useLoadNodesCache, useLoadObjectsCache
-
Field Details
-
lock
-
delegate
-
-
Constructor Details
-
Concurrent
-
-
Method Details
-
asMap
-
putAll
Description copied from class:OntConfigCopies configuration from the given config. -
data
-
store
-
get
-
put
-
buildLoaderConfiguration
Description copied from class:OntConfigBuilds new loader configuration.- Overrides:
buildLoaderConfigurationin classOntConfig- Returns:
- new
OntLoaderConfiguration - See Also:
-
buildWriterConfiguration
Description copied from class:OntConfigBuilds new writer configuration.- Overrides:
buildWriterConfigurationin classOntConfig- Returns:
- new
OntWriterConfiguration - See Also:
-
addIgnoredImport
Description copied from class:OntConfig- Overrides:
addIgnoredImportin classOntConfig- See Also:
-
clearIgnoredImports
Description copied from class:OntConfig- Overrides:
clearIgnoredImportsin classOntConfig- See Also:
-
removeIgnoredImport
Description copied from class:OntConfig- Overrides:
removeIgnoredImportin classOntConfig- See Also:
-
equals
-
hashCode
public int hashCode() -
setSpecification
SetsOntSpecificationmodel configuration object.- Parameters:
specification-OntSpecification, notnull- Returns:
LoadControl(this or copied instance)- See Also:
-
setModelCacheLevel
Turns on/off the content cache use. Other cache settings are untouched, which means if there is a component cache enabled, it will remain enabled (if existent constant do not equal to the given one).- Parameters:
constant- a non-negative int numberb-trueto turn on,falseto turn off- Returns:
CacheControl- See Also:
-