Package com.github.owlcs.ontapi.config
Enum Class OntSettings
- All Implemented Interfaces:
Serializable,Comparable<OntSettings>,Constable
The
Enum of all ONT-API settings (22 OWL-API options + 15 ONT-API specific options)
Note: System properties are not taken into account (this is a difference from OWL-API-impl).
The properties file is used as the primary settings store.
The default value, that is encoding in this enum,
is used as secondary attempt in case a property entry is absent in the file.
See ontapi.properties
Created by @ssz on 14.04.2017.
- See Also:
-
Nested Class Summary
Nested classes/interfaces inherited from class java.lang.Enum
Enum.EnumDesc<E extends Enum<E>> -
Enum Constant Summary
Enum ConstantsEnum ConstantDescription -
Field Summary
Fields -
Method Summary
Modifier and TypeMethodDescriptionReturns a default option value.booleanisLoad()booleanisONT()booleanisWrite()key()static OntSettingsReturns the enum constant of this class with the specified name.static OntSettings[]values()Returns an array containing the constants of this enum class, in the order they are declared.
-
Enum Constant Details
-
OWL_API_LOAD_CONF_IGNORED_IMPORTS
-
ONT_API_LOAD_CONF_SUPPORTED_SCHEMES
-
ONT_API_LOAD_CONF_PERFORM_TRANSFORMATIONS
-
ONT_API_LOAD_CONF_ALLOW_BULK_ANNOTATION_ASSERTIONS
-
ONT_API_LOAD_CONF_ALLOW_READ_DECLARATIONS
-
ONT_API_LOAD_CONF_IGNORE_ANNOTATION_AXIOM_OVERLAPS
-
ONT_API_LOAD_CONF_USE_OWL_PARSERS_TO_LOAD
-
ONT_API_LOAD_CONF_IGNORE_AXIOMS_READ_ERRORS
-
ONT_API_LOAD_CONF_SPLIT_AXIOM_ANNOTATIONS
-
ONT_API_LOAD_CONF_READ_ONT_OBJECTS
-
ONT_API_LOAD_CONF_CACHE_MODEL
-
ONT_API_LOAD_CONF_CACHE_OBJECTS
-
ONT_API_LOAD_CONF_CACHE_NODES
-
ONT_API_LOAD_CONF_PROCESS_IMPORTS
-
ONT_API_LOAD_CONF_USE_DISTINCT_UNION_GRAPH
-
ONT_API_MANAGER_CACHE_IRIS
-
OWL_API_LOAD_CONF_ACCEPT_HTTP_COMPRESSION
-
OWL_API_LOAD_CONF_CONNECTION_TIMEOUT
-
OWL_API_LOAD_CONF_FOLLOW_REDIRECTS
-
OWL_API_LOAD_CONF_LOAD_ANNOTATIONS
-
OWL_API_LOAD_CONF_MISSING_IMPORT_HANDLING_STRATEGY
-
OWL_API_LOAD_CONF_MISSING_ONTOLOGY_HEADER_STRATEGY
-
OWL_API_LOAD_CONF_REPORT_STACK_TRACES
-
OWL_API_LOAD_CONF_RETRIES_TO_ATTEMPT
-
OWL_API_LOAD_CONF_PARSE_WITH_STRICT_CONFIGURATION
-
OWL_API_LOAD_CONF_TREAT_DUBLINCORE_AS_BUILTIN
-
OWL_API_LOAD_CONF_PRIORITY_COLLECTION_SORTING
-
OWL_API_LOAD_CONF_BANNED_PARSERS
-
OWL_API_LOAD_CONF_ENTITY_EXPANSION_LIMIT
-
OWL_API_AUTHORIZATION_VALUE
-
ONT_API_WRITE_CONF_CONTROL_IMPORTS
-
OWL_API_WRITE_CONF_SAVE_IDS
-
OWL_API_WRITE_CONF_REMAP_IDS
-
OWL_API_WRITE_CONF_USE_NAMESPACE_ENTITIES
-
OWL_API_WRITE_CONF_INDENTING
-
OWL_API_WRITE_CONF_LABEL_AS_BANNER
-
OWL_API_WRITE_CONF_BANNERS_ENABLED
-
OWL_API_WRITE_CONF_INDENT_SIZE
-
ONT_API_LOAD_CONF_SPECIFICATION
-
ONT_API_LOAD_CONF_TRANSFORMERS
-
-
Field Details
-
PROPERTIES
-
-
Method Details
-
values
Returns an array containing the constants of this enum class, in the order they are declared.- Returns:
- an array containing the constants of this enum class, in the order they are declared
-
valueOf
Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum class has no constant with the specified nameNullPointerException- if the argument is null
-
getDefaultValue
Returns a default option value. Looks firstly into properties file, if the record is not found returns the default enum value.- Returns:
- an immutable (or unmodifiable) object that is associated with this key
-
isLoad
public boolean isLoad() -
isWrite
public boolean isWrite() -
isONT
public boolean isONT() -
key
-