content
40 key-value pairs, 39 for kinds of axioms and one for the ontology header.- See Also:
HasConfig, HasObjectFactory, InternalGraphModel, org.apache.jena.ontapi.common.OntEnhGraph, org.apache.jena.ontapi.model.OntModel, org.apache.jena.rdf.model.InfModel, org.apache.jena.rdf.model.Model, org.apache.jena.rdf.model.ModelCon, org.apache.jena.rdf.model.ModelGraphInterface, org.apache.jena.rdf.model.RDFReaderF, org.apache.jena.rdf.model.RDFWriterF, org.apache.jena.shared.Lock, org.apache.jena.shared.PrefixMapping, org.semanticweb.owlapi.model.HasOntologyIDOntModel view of RDF Graph).
It is an analogue of uk.ac.manchester.cs.owl.owlapi.Internals.
This model is used by the facade model (i.e. by Ontology) while reading and writing
the structural (axiomatic) representation of ontology.
Notice that this model is a non-serializable (while everything in OWL-API is Serializable),
since it is part of ONT-API internal implementation.
Unlike native OWL-API (see owl-api-impl) implementation,
this model does not store all possible OWL objects in memory.
Instead, there are several caches.
The main cache is divided into buckets by OWL objects types (39 OWL Axioms types plus Header Annotations).
And each of these buckets is indivisible.
It means that only the whole bucket can be loaded or invalidated, not just part of it.
This is the major restriction of the current implementation:
if you have such a large ontology that can not even be partially placed in memory
(that is, the set of axioms of any type, but with the exclusion of their components, exceeds the memory limit),
then this solution won't work.
To work with such large ontologies, it is recommended to use Axiom Translators directly
(see AxiomTranslator.get(AxiomType)).
TODO: Should it return ONTObjects, not just naked OWLObjects (see #87, #72)?
It seems it would be more convenient and could make this class useful not only as part of inner implementation.
Created by @ssz on 26.10.2016.
class org.apache.jena.shared.PrefixMapping.Factory, org.apache.jena.shared.PrefixMapping.IllegalPrefixException, org.apache.jena.shared.PrefixMapping.JenaLockedExceptionprotected final ByObjectSearcher<org.semanticweb.owlapi.model.OWLAnnotationAssertionAxiom,org.semanticweb.owlapi.model.OWLAnnotationSubject> protected final ObjectsSearcher<org.semanticweb.owlapi.model.OWLAnnotationProperty> protected final ByObjectSearcher<org.semanticweb.owlapi.model.OWLAxiom,org.semanticweb.owlapi.model.OWLAnnotationProperty> protected final ByObjectSearcher<org.semanticweb.owlapi.model.OWLAxiom,org.semanticweb.owlapi.model.OWLAnonymousIndividual> protected final ByObjectSearcher<org.semanticweb.owlapi.model.OWLAxiom,org.semanticweb.owlapi.model.OWLClass> protected final ByObjectSearcher<org.semanticweb.owlapi.model.OWLAxiom,org.semanticweb.owlapi.model.OWLDataProperty> protected final ByObjectSearcher<org.semanticweb.owlapi.model.OWLAxiom,org.semanticweb.owlapi.model.OWLDatatype> protected final ByObjectSearcher<org.semanticweb.owlapi.model.OWLAxiom,org.semanticweb.owlapi.model.IRI> protected final ByObjectSearcher<org.semanticweb.owlapi.model.OWLAxiom,org.semanticweb.owlapi.model.OWLLiteral> protected final ByObjectSearcher<org.semanticweb.owlapi.model.OWLAxiom,org.semanticweb.owlapi.model.OWLNamedIndividual> protected final ByObjectSearcher<org.semanticweb.owlapi.model.OWLAxiom,org.semanticweb.owlapi.model.OWLObjectProperty> protected IDprotected final ByObjectSearcher<org.semanticweb.owlapi.model.OWLClassAssertionAxiom,org.semanticweb.owlapi.model.OWLClassExpression> protected final ByObjectSearcher<org.semanticweb.owlapi.model.OWLClassAssertionAxiom,org.semanticweb.owlapi.model.OWLIndividual> protected final ObjectsSearcher<org.semanticweb.owlapi.model.OWLClass> protected final InternalCache.Loading<com.github.owlcs.ontapi.internal.InternalReadGraphModel,Map<OWLComponentType,ObjectMap<org.semanticweb.owlapi.model.OWLObject>>> protected final InternalCache.Loading<com.github.owlcs.ontapi.internal.InternalReadGraphModel,InternalConfig> protected final InternalCache.Loading<com.github.owlcs.ontapi.internal.InternalReadGraphModel,Map<OWLTopObjectType,ObjectMap<? extends org.semanticweb.owlapi.model.OWLObject>>> protected final ByObjectSearcher<org.semanticweb.owlapi.model.OWLDataPropertyAssertionAxiom,org.semanticweb.owlapi.model.OWLIndividual> protected final ObjectsSearcher<org.semanticweb.owlapi.model.OWLDataProperty> protected final ObjectsSearcher<org.semanticweb.owlapi.model.OWLDatatype> protected final ByObjectSearcher<org.semanticweb.owlapi.model.OWLDeclarationAxiom,org.semanticweb.owlapi.model.OWLEntity> protected final InternalGraphModelImpl.DirectListenerprotected final ByObjectSearcher<org.semanticweb.owlapi.model.OWLDisjointClassesAxiom,org.semanticweb.owlapi.model.OWLClass> protected final ByObjectSearcher<org.semanticweb.owlapi.model.OWLEquivalentClassesAxiom,org.semanticweb.owlapi.model.OWLClass> protected final ObjectsSearcher<org.semanticweb.owlapi.model.OWLNamedIndividual> protected final ByObjectSearcher<org.semanticweb.owlapi.model.OWLObjectPropertyAssertionAxiom,org.semanticweb.owlapi.model.OWLIndividual> protected final InternalCache.Loading<com.github.owlcs.ontapi.internal.InternalReadGraphModel,ModelObjectFactory> ONT Jena Objects to OWL-API objects.protected final ByObjectSearcher<org.semanticweb.owlapi.model.OWLObjectPropertyDomainAxiom,org.semanticweb.owlapi.model.OWLObjectPropertyExpression> protected final ByObjectSearcher<org.semanticweb.owlapi.model.OWLObjectPropertyRangeAxiom,org.semanticweb.owlapi.model.OWLObjectPropertyExpression> protected final ObjectsSearcher<org.semanticweb.owlapi.model.OWLObjectProperty> protected final InternalCache.Loading<com.github.owlcs.ontapi.internal.InternalReadGraphModel,org.apache.jena.ontapi.impl.OntGraphModelImpl> nodes cache.protected final ByObjectSearcher<org.semanticweb.owlapi.model.OWLSubClassOfAxiom,org.semanticweb.owlapi.model.OWLClass> protected final ByObjectSearcher<org.semanticweb.owlapi.model.OWLSubClassOfAxiom,org.semanticweb.owlapi.model.OWLClass> dtTypes, propertyStoregraphREAD, WRITEExtended, StandardInternalGraphModelImpl(org.apache.jena.graph.Graph base,
org.apache.jena.ontapi.common.OntPersonality personality,
InternalConfig config,
DataFactory dataFactory,
Map<Class<? extends org.semanticweb.owlapi.model.OWLPrimitive>,InternalCache<?,?>> fromManager) protected booleanadd(OWLTopObjectType key,
org.semanticweb.owlapi.model.OWLObject container) OWLObject into the model.org.apache.jena.ontapi.model.OntModelorg.apache.jena.ontapi.model.OntModeladd(org.apache.jena.rdf.model.Model arg0) org.apache.jena.ontapi.model.OntModelorg.apache.jena.ontapi.model.OntModeladd(org.apache.jena.rdf.model.Resource arg0,
org.apache.jena.rdf.model.Property arg1,
String arg2,
String arg3) org.apache.jena.ontapi.model.OntModeladd(org.apache.jena.rdf.model.Resource arg0,
org.apache.jena.rdf.model.Property arg1,
String arg2,
org.apache.jena.datatypes.RDFDatatype arg3) org.apache.jena.ontapi.model.OntModeladd(org.apache.jena.rdf.model.Resource arg0,
org.apache.jena.rdf.model.Property arg1,
org.apache.jena.rdf.model.RDFNode arg2) org.apache.jena.ontapi.model.OntModeladd(org.apache.jena.rdf.model.Statement arg0) org.apache.jena.ontapi.model.OntModeladd(org.apache.jena.rdf.model.Statement[] arg0) org.apache.jena.ontapi.model.OntModeladd(org.apache.jena.rdf.model.StmtIterator arg0) booleanadd(org.semanticweb.owlapi.model.OWLAnnotation annotation) booleanadd(org.semanticweb.owlapi.model.OWLAxiom axiom) org.apache.jena.ontapi.model.OntModeladdLiteral(org.apache.jena.rdf.model.Resource arg0,
org.apache.jena.rdf.model.Property arg1,
boolean arg2) org.apache.jena.ontapi.model.OntModeladdLiteral(org.apache.jena.rdf.model.Resource arg0,
org.apache.jena.rdf.model.Property arg1,
char arg2) org.apache.jena.ontapi.model.OntModeladdLiteral(org.apache.jena.rdf.model.Resource arg0,
org.apache.jena.rdf.model.Property arg1,
double arg2) org.apache.jena.ontapi.model.OntModeladdLiteral(org.apache.jena.rdf.model.Resource arg0,
org.apache.jena.rdf.model.Property arg1,
float arg2) org.apache.jena.ontapi.model.OntModeladdLiteral(org.apache.jena.rdf.model.Resource arg0,
org.apache.jena.rdf.model.Property arg1,
int arg2) org.apache.jena.ontapi.model.OntModeladdLiteral(org.apache.jena.rdf.model.Resource arg0,
org.apache.jena.rdf.model.Property arg1,
long arg2) org.apache.jena.ontapi.model.OntModeladdLiteral(org.apache.jena.rdf.model.Resource arg0,
org.apache.jena.rdf.model.Property arg1,
org.apache.jena.rdf.model.Literal arg2) protected voidcacheComponents(org.semanticweb.owlapi.model.OWLObject container) container and puts them into the InternalReadGraphModel.components cache.voidvoidprotected voidclearComponents(org.semanticweb.owlapi.model.OWLObject container) cache for all components parsed from the given container.protected voidInternalReadGraphModel.components,
InternalReadGraphModel.objectFactory and InternalReadGraphModel.searchModel caches.org.apache.jena.ontapi.model.OntModelprotected voidbooleancontains(org.semanticweb.owlapi.model.OWLAnnotation a) booleancontains(org.semanticweb.owlapi.model.OWLAxiom a) protected booleancontainsComponent(OWLComponentType type,
org.semanticweb.owlapi.model.OWLObject o) booleancontainsIgnoreAnnotations(org.semanticweb.owlapi.model.OWLAxiom a) protected booleancontainsNoAnnotations(ObjectMap<? extends org.semanticweb.owlapi.model.OWLAxiom> map) true if the specified map does not contain annotated axioms.booleancontainsOWLDeclaration(org.semanticweb.owlapi.model.OWLEntity e) booleancontainsOWLEntity(org.semanticweb.owlapi.model.OWLAnnotationProperty p) booleancontainsOWLEntity(org.semanticweb.owlapi.model.OWLClass c) booleancontainsOWLEntity(org.semanticweb.owlapi.model.OWLDataProperty p) booleancontainsOWLEntity(org.semanticweb.owlapi.model.OWLDatatype d) booleancontainsOWLEntity(org.semanticweb.owlapi.model.OWLNamedIndividual i) booleancontainsOWLEntity(org.semanticweb.owlapi.model.OWLObjectProperty p) org.apache.jena.ontapi.model.OntSWRL.Atom.WithBuiltincreateBuiltInSWRLAtom(org.apache.jena.rdf.model.Resource arg0,
Collection<org.apache.jena.ontapi.model.OntSWRL.DArg> arg1) org.apache.jena.ontapi.model.OntSWRL.Atom.WithClasscreateClassSWRLAtom(org.apache.jena.ontapi.model.OntClass arg0,
org.apache.jena.ontapi.model.OntSWRL.IArg arg1) protected ObjectMap<org.semanticweb.owlapi.model.OWLObject> ObjectMap container for the given OWLComponentType.protected Map<OWLComponentType,ObjectMap<org.semanticweb.owlapi.model.OWLObject>> Map.protected ObjectMap<org.semanticweb.owlapi.model.OWLObject> ObjectMap container for the given OWLTopObjectType.protected Map<OWLTopObjectType,ObjectMap<? extends org.semanticweb.owlapi.model.OWLObject>> Map.org.apache.jena.ontapi.model.OntClass.NaryDataAllValuesFromcreateDataAllValuesFrom(Collection<org.apache.jena.ontapi.model.OntDataProperty> arg0,
org.apache.jena.ontapi.model.OntDataRange arg1) org.apache.jena.ontapi.model.OntClass.DataAllValuesFromcreateDataAllValuesFrom(org.apache.jena.ontapi.model.OntDataProperty arg0,
org.apache.jena.ontapi.model.OntDataRange arg1) org.apache.jena.ontapi.model.OntClass.DataCardinalitycreateDataCardinality(org.apache.jena.ontapi.model.OntDataProperty arg0,
int arg1,
org.apache.jena.ontapi.model.OntDataRange arg2) org.apache.jena.ontapi.model.OntDataRange.ComplementOfcreateDataComplementOf(org.apache.jena.ontapi.model.OntDataRange arg0) org.apache.jena.ontapi.model.OntClass.DataHasValuecreateDataHasValue(org.apache.jena.ontapi.model.OntDataProperty arg0,
org.apache.jena.rdf.model.Literal arg1) org.apache.jena.ontapi.model.OntDataRange.IntersectionOfcreateDataIntersectionOf(Collection<org.apache.jena.ontapi.model.OntDataRange> arg0) default org.apache.jena.ontapi.model.OntDataRange.IntersectionOfcreateDataIntersectionOf(org.apache.jena.ontapi.model.OntDataRange... arg0) org.apache.jena.ontapi.model.OntClass.DataMaxCardinalitycreateDataMaxCardinality(org.apache.jena.ontapi.model.OntDataProperty arg0,
int arg1,
org.apache.jena.ontapi.model.OntDataRange arg2) org.apache.jena.ontapi.model.OntClass.DataMinCardinalitycreateDataMinCardinality(org.apache.jena.ontapi.model.OntDataProperty arg0,
int arg1,
org.apache.jena.ontapi.model.OntDataRange arg2) org.apache.jena.ontapi.model.OntDataRange.OneOfcreateDataOneOf(Collection<org.apache.jena.rdf.model.Literal> arg0) default org.apache.jena.ontapi.model.OntDataRange.OneOfcreateDataOneOf(org.apache.jena.rdf.model.Literal... arg0) org.apache.jena.ontapi.model.OntSWRL.Atom.WithDataPropertycreateDataPropertySWRLAtom(org.apache.jena.ontapi.model.OntDataProperty arg0,
org.apache.jena.ontapi.model.OntSWRL.IArg arg1,
org.apache.jena.ontapi.model.OntSWRL.DArg arg2) org.apache.jena.ontapi.model.OntSWRL.Atom.WithDataRangecreateDataRangeSWRLAtom(org.apache.jena.ontapi.model.OntDataRange arg0,
org.apache.jena.ontapi.model.OntSWRL.DArg arg1) org.apache.jena.ontapi.model.OntDataRange.RestrictioncreateDataRestriction(org.apache.jena.ontapi.model.OntDataRange.Named arg0,
Collection<org.apache.jena.ontapi.model.OntFacetRestriction> arg1) default org.apache.jena.ontapi.model.OntDataRange.RestrictioncreateDataRestriction(org.apache.jena.ontapi.model.OntDataRange.Named arg0,
org.apache.jena.ontapi.model.OntFacetRestriction... arg1) org.apache.jena.ontapi.model.OntClass.NaryDataSomeValuesFromcreateDataSomeValuesFrom(Collection<org.apache.jena.ontapi.model.OntDataProperty> arg0,
org.apache.jena.ontapi.model.OntDataRange arg1) org.apache.jena.ontapi.model.OntClass.DataSomeValuesFromcreateDataSomeValuesFrom(org.apache.jena.ontapi.model.OntDataProperty arg0,
org.apache.jena.ontapi.model.OntDataRange arg1) org.apache.jena.ontapi.model.OntDataRange.UnionOfcreateDataUnionOf(Collection<org.apache.jena.ontapi.model.OntDataRange> arg0) default org.apache.jena.ontapi.model.OntDataRange.UnionOfcreateDataUnionOf(org.apache.jena.ontapi.model.OntDataRange... arg0) org.apache.jena.ontapi.model.OntDisjoint.IndividualscreateDifferentIndividuals(Collection<org.apache.jena.ontapi.model.OntIndividual> arg0) default org.apache.jena.ontapi.model.OntDisjoint.IndividualscreateDifferentIndividuals(org.apache.jena.ontapi.model.OntIndividual... arg0) org.apache.jena.ontapi.model.OntSWRL.Atom.WithDifferentIndividualscreateDifferentIndividualsSWRLAtom(org.apache.jena.ontapi.model.OntSWRL.IArg arg0,
org.apache.jena.ontapi.model.OntSWRL.IArg arg1) protected InternalGraphModelImpl.DirectListenerorg.apache.jena.ontapi.model.OntDisjoint.ClassescreateDisjointClasses(Collection<org.apache.jena.ontapi.model.OntClass> arg0) default org.apache.jena.ontapi.model.OntDisjoint.ClassescreateDisjointClasses(org.apache.jena.ontapi.model.OntClass... arg0) org.apache.jena.ontapi.model.OntDisjoint.DataPropertiescreateDisjointDataProperties(Collection<org.apache.jena.ontapi.model.OntDataProperty> arg0) default org.apache.jena.ontapi.model.OntDisjoint.DataPropertiescreateDisjointDataProperties(org.apache.jena.ontapi.model.OntDataProperty... arg0) org.apache.jena.ontapi.model.OntDisjoint.ObjectPropertiescreateDisjointObjectProperties(Collection<org.apache.jena.ontapi.model.OntObjectProperty> arg0) default org.apache.jena.ontapi.model.OntDisjoint.ObjectPropertiescreateDisjointObjectProperties(org.apache.jena.ontapi.model.OntObjectProperty... arg0) org.apache.jena.ontapi.model.OntClass.HasSelfcreateHasSelf(org.apache.jena.ontapi.model.OntObjectProperty arg0) createMapStore(Class<K> type,
Stream<K> keys,
Function<K,V> loader) Map that has Enum-keys using the specified parameters.org.apache.jena.ontapi.model.OntClass.ObjectAllValuesFromcreateObjectAllValuesFrom(org.apache.jena.ontapi.model.OntObjectProperty arg0,
org.apache.jena.ontapi.model.OntClass arg1) org.apache.jena.ontapi.model.OntClass.ObjectCardinalitycreateObjectCardinality(org.apache.jena.ontapi.model.OntObjectProperty arg0,
int arg1,
org.apache.jena.ontapi.model.OntClass arg2) org.apache.jena.ontapi.model.OntClass.ComplementOfcreateObjectComplementOf(org.apache.jena.ontapi.model.OntClass arg0) protected ModelObjectFactorycreateObjectFactory(DataFactory df,
Map<Class<? extends org.semanticweb.owlapi.model.OWLPrimitive>,InternalCache<?,?>> external) Object Factory instance,
which is responsible for mapping Node (and OntObject) to OWLObject.org.apache.jena.ontapi.model.OntClass.ObjectHasValuecreateObjectHasValue(org.apache.jena.ontapi.model.OntObjectProperty arg0,
org.apache.jena.ontapi.model.OntIndividual arg1) org.apache.jena.ontapi.model.OntClass.IntersectionOfcreateObjectIntersectionOf(Collection<org.apache.jena.ontapi.model.OntClass> arg0) default org.apache.jena.ontapi.model.OntClass.IntersectionOfcreateObjectIntersectionOf(org.apache.jena.ontapi.model.OntClass... arg0) org.apache.jena.ontapi.model.OntClass.ObjectMaxCardinalitycreateObjectMaxCardinality(org.apache.jena.ontapi.model.OntObjectProperty arg0,
int arg1,
org.apache.jena.ontapi.model.OntClass arg2) org.apache.jena.ontapi.model.OntClass.ObjectMinCardinalitycreateObjectMinCardinality(org.apache.jena.ontapi.model.OntObjectProperty arg0,
int arg1,
org.apache.jena.ontapi.model.OntClass arg2) org.apache.jena.ontapi.model.OntClass.OneOfcreateObjectOneOf(Collection<org.apache.jena.ontapi.model.OntIndividual> arg0) default org.apache.jena.ontapi.model.OntClass.OneOfcreateObjectOneOf(org.apache.jena.ontapi.model.OntIndividual... arg0) org.apache.jena.ontapi.model.OntSWRL.Atom.WithObjectPropertycreateObjectPropertySWRLAtom(org.apache.jena.ontapi.model.OntObjectProperty arg0,
org.apache.jena.ontapi.model.OntSWRL.IArg arg1,
org.apache.jena.ontapi.model.OntSWRL.IArg arg2) org.apache.jena.ontapi.model.OntClass.ObjectSomeValuesFromcreateObjectSomeValuesFrom(org.apache.jena.ontapi.model.OntObjectProperty arg0,
org.apache.jena.ontapi.model.OntClass arg1) org.apache.jena.ontapi.model.OntClass.UnionOfcreateObjectUnionOf(Collection<org.apache.jena.ontapi.model.OntClass> arg0) default org.apache.jena.ontapi.model.OntClass.UnionOfcreateObjectUnionOf(org.apache.jena.ontapi.model.OntClass... arg0) org.apache.jena.ontapi.model.OntSWRL.Atom.WithSameIndividualscreateSameIndividualsSWRLAtom(org.apache.jena.ontapi.model.OntSWRL.IArg arg0,
org.apache.jena.ontapi.model.OntSWRL.IArg arg1) protected org.apache.jena.ontapi.impl.OntGraphModelImplorg.apache.jena.ontapi.model.OntSWRL.ImpcreateSWRLImp(Collection<org.apache.jena.ontapi.model.OntSWRL.Atom<?>> arg0,
Collection<org.apache.jena.ontapi.model.OntSWRL.Atom<?>> arg1) org.apache.jena.ontapi.model.OntSWRL.VariablecreateSWRLVariable(String arg0) protected voiddelete(org.apache.jena.graph.Triple triple) protected voidprotected voidvoidenterCriticalSection(boolean requestReadLock) protected Optional<org.semanticweb.owlapi.model.OWLObject> findUsedContentContainer(org.semanticweb.owlapi.model.OWLObject entity,
org.semanticweb.owlapi.model.OWLObject... excludes) voidprotected ObjectMap<org.semanticweb.owlapi.model.OWLAxiom> ObjectMap for the given OWLTopObjectType.protected <O extends org.semanticweb.owlapi.model.OWLObject>
ObjectMap<O> type in the form of ObjectMap.InternalConfig snapshot instance, which is an immutable object.protected <X extends org.semanticweb.owlapi.model.OWLObject>
ObjectMap<X> ObjectMap-cache.protected Map<OWLTopObjectType,ObjectMap<? extends org.semanticweb.owlapi.model.OWLObject>> Map.protected ObjectMap<org.semanticweb.owlapi.model.OWLAnnotation> org.apache.jena.shared.LockgetLock()InternalDataFactory, a helper (possibly, with cache) to read OWL-API objects.longorg.apache.jena.ontapi.impl.OntGraphModelImplOntGraphModelImpl version with search optimizations.org.apache.jena.ontapi.UnionGraphUnionGraph which this Model is presenting.protected Set<org.apache.jena.graph.Triple> getUsedTriples(org.apache.jena.ontapi.model.OntModel model,
org.semanticweb.owlapi.model.OWLObject container) triples,
that belong to both the given content-container and some other one.protected booleanbooleanvoidStream<org.semanticweb.owlapi.model.OWLAnonymousIndividual> Stream<org.semanticweb.owlapi.model.OWLNamedIndividual> protected <O extends org.semanticweb.owlapi.model.OWLObject>
Stream<O> type.Stream<org.semanticweb.owlapi.model.OWLAnonymousIndividual> Stream<org.semanticweb.owlapi.model.OWLNamedIndividual> Stream<org.semanticweb.owlapi.model.OWLAnnotationAssertionAxiom> listOWLAnnotationAssertionAxioms(org.semanticweb.owlapi.model.OWLAnnotationSubject subject) default Stream<org.semanticweb.owlapi.model.OWLAnnotationAssertionAxiom> listOWLAnnotationAssertionAxioms(org.semanticweb.owlapi.model.OWLAnnotationSubject subject) Annotation Assertion Axioms
with the given subject.Stream<org.semanticweb.owlapi.model.OWLAnnotationProperty> default Stream<org.semanticweb.owlapi.model.OWLAnnotationPropertyDomainAxiom> listOWLAnnotationPropertyDomainAxioms(org.semanticweb.owlapi.model.OWLAnnotationProperty subject) default Stream<org.semanticweb.owlapi.model.OWLAnnotationPropertyRangeAxiom> listOWLAnnotationPropertyRangeAxioms(org.semanticweb.owlapi.model.OWLAnnotationProperty subject) Stream<org.semanticweb.owlapi.model.OWLAnnotation> default Stream<org.semanticweb.owlapi.model.OWLAsymmetricObjectPropertyAxiom> listOWLAsymmetricObjectPropertyAxioms(org.semanticweb.owlapi.model.OWLObjectPropertyExpression subject) Stream<org.semanticweb.owlapi.model.OWLAxiom> protected <A extends org.semanticweb.owlapi.model.OWLAxiom,
K extends org.semanticweb.owlapi.model.OWLObject>
Stream<A> listOWLAxioms(ByObjectSearcher<A,K> searcher,
Class<A> type,
K parameter,
InternalConfig config) <A extends org.semanticweb.owlapi.model.OWLAxiom>
Stream<A> listOWLAxioms(Class<A> type) <A extends org.semanticweb.owlapi.model.OWLAxiom>
Stream<A> listOWLAxioms(Class<A> type) <A extends org.semanticweb.owlapi.model.OWLAxiom>
Stream<A> listOWLAxioms(Class<A> type,
org.semanticweb.owlapi.model.OWLObject object) Stream<org.semanticweb.owlapi.model.OWLAxiom> listOWLAxioms(Iterable<org.semanticweb.owlapi.model.AxiomType<?>> filter) <A extends org.semanticweb.owlapi.model.OWLAxiom>
Stream<A> listOWLAxioms(org.semanticweb.owlapi.model.AxiomType<A> type) Stream<org.semanticweb.owlapi.model.OWLAxiom> listOWLAxioms(org.semanticweb.owlapi.model.OWLPrimitive primitive) Stream<org.semanticweb.owlapi.model.OWLClassAssertionAxiom> listOWLClassAssertionAxioms(org.semanticweb.owlapi.model.OWLClassExpression object) default Stream<org.semanticweb.owlapi.model.OWLClassAssertionAxiom> listOWLClassAssertionAxioms(org.semanticweb.owlapi.model.OWLClassExpression object) ClassAssertion Axioms by the given class-object.Stream<org.semanticweb.owlapi.model.OWLClassAssertionAxiom> listOWLClassAssertionAxioms(org.semanticweb.owlapi.model.OWLIndividual subject) default Stream<org.semanticweb.owlapi.model.OWLClassAssertionAxiom> listOWLClassAssertionAxioms(org.semanticweb.owlapi.model.OWLIndividual subject) ClassAssertion Axioms by the given individual-subject.Stream<org.semanticweb.owlapi.model.OWLClass> Stream<org.semanticweb.owlapi.model.OWLClassExpression> Stream<org.semanticweb.owlapi.model.OWLDataProperty> Stream<org.semanticweb.owlapi.model.OWLDataPropertyAssertionAxiom> listOWLDataPropertyAssertionAxioms(org.semanticweb.owlapi.model.OWLIndividual subject) default Stream<org.semanticweb.owlapi.model.OWLDataPropertyAssertionAxiom> listOWLDataPropertyAssertionAxioms(org.semanticweb.owlapi.model.OWLIndividual subject) DataPropertyAssertion Axioms by the given individual-subject.default Stream<org.semanticweb.owlapi.model.OWLDataPropertyDomainAxiom> listOWLDataPropertyDomainAxioms(org.semanticweb.owlapi.model.OWLDataProperty subject) default Stream<org.semanticweb.owlapi.model.OWLDataPropertyRangeAxiom> listOWLDataPropertyRangeAxioms(org.semanticweb.owlapi.model.OWLDataProperty subject) default Stream<org.semanticweb.owlapi.model.OWLDatatypeDefinitionAxiom> listOWLDatatypeDefinitionAxioms(org.semanticweb.owlapi.model.OWLDatatype datatype) Stream<org.semanticweb.owlapi.model.OWLDatatype> Stream<org.semanticweb.owlapi.model.OWLDeclarationAxiom> listOWLDeclarationAxioms(org.semanticweb.owlapi.model.OWLEntity entity) default Stream<org.semanticweb.owlapi.model.OWLDeclarationAxiom> listOWLDeclarationAxioms(org.semanticweb.owlapi.model.OWLEntity entity) Declaration Axioms for the specified entity.default Stream<org.semanticweb.owlapi.model.OWLDifferentIndividualsAxiom> listOWLDifferentIndividualsAxioms(org.semanticweb.owlapi.model.OWLIndividual operand) Stream<org.semanticweb.owlapi.model.OWLDisjointClassesAxiom> listOWLDisjointClassesAxioms(org.semanticweb.owlapi.model.OWLClass clazz) default Stream<org.semanticweb.owlapi.model.OWLDisjointClassesAxiom> listOWLDisjointClassesAxioms(org.semanticweb.owlapi.model.OWLClass clazz) DisjointClasses Axioms by the given class-component.default Stream<org.semanticweb.owlapi.model.OWLDisjointDataPropertiesAxiom> listOWLDisjointDataPropertiesAxioms(org.semanticweb.owlapi.model.OWLDataProperty operand) default Stream<org.semanticweb.owlapi.model.OWLDisjointObjectPropertiesAxiom> listOWLDisjointObjectPropertiesAxioms(org.semanticweb.owlapi.model.OWLObjectPropertyExpression operand) default Stream<org.semanticweb.owlapi.model.OWLDisjointUnionAxiom> listOWLDisjointUnionAxioms(org.semanticweb.owlapi.model.OWLClass subject) Stream<org.semanticweb.owlapi.model.OWLEntity> listOWLEntities(org.semanticweb.owlapi.model.IRI iri) Stream<org.semanticweb.owlapi.model.OWLEquivalentClassesAxiom> listOWLEquivalentClassesAxioms(org.semanticweb.owlapi.model.OWLClass clazz) default Stream<org.semanticweb.owlapi.model.OWLEquivalentClassesAxiom> listOWLEquivalentClassesAxioms(org.semanticweb.owlapi.model.OWLClass clazz) EquivalentClasses Axioms by the given class-component.default Stream<org.semanticweb.owlapi.model.OWLEquivalentDataPropertiesAxiom> listOWLEquivalentDataPropertiesAxioms(org.semanticweb.owlapi.model.OWLDataProperty operand) default Stream<org.semanticweb.owlapi.model.OWLEquivalentObjectPropertiesAxiom> listOWLEquivalentObjectPropertiesAxioms(org.semanticweb.owlapi.model.OWLObjectPropertyExpression operand) default Stream<org.semanticweb.owlapi.model.OWLFunctionalDataPropertyAxiom> listOWLFunctionalDataPropertyAxioms(org.semanticweb.owlapi.model.OWLDataProperty subject) default Stream<org.semanticweb.owlapi.model.OWLFunctionalObjectPropertyAxiom> listOWLFunctionalObjectPropertyAxioms(org.semanticweb.owlapi.model.OWLObjectPropertyExpression subject) default Stream<org.semanticweb.owlapi.model.OWLHasKeyAxiom> listOWLHasKeyAxioms(org.semanticweb.owlapi.model.OWLClass subject) Stream<org.semanticweb.owlapi.model.OWLImportsDeclaration> default Stream<org.semanticweb.owlapi.model.OWLInverseFunctionalObjectPropertyAxiom> listOWLInverseFunctionalObjectPropertyAxioms(org.semanticweb.owlapi.model.OWLObjectPropertyExpression subject) default Stream<org.semanticweb.owlapi.model.OWLInverseObjectPropertiesAxiom> listOWLInverseObjectPropertiesAxioms(org.semanticweb.owlapi.model.OWLObjectPropertyExpression operand) default Stream<org.semanticweb.owlapi.model.OWLIrreflexiveObjectPropertyAxiom> listOWLIrreflexiveObjectPropertyAxioms(org.semanticweb.owlapi.model.OWLObjectPropertyExpression subject) Stream<org.semanticweb.owlapi.model.OWLLogicalAxiom> default <A extends org.semanticweb.owlapi.model.OWLNaryAxiom<? super K>,
K extends org.semanticweb.owlapi.model.OWLObject>
Stream<A> listOWLNaryAxiomAxiomsByOperand(Class<A> type,
K operand) protected <A extends org.semanticweb.owlapi.model.OWLNaryAxiom<? super K>,
K extends org.semanticweb.owlapi.model.OWLObject>
Stream<A> listOWLNaryAxiomAxiomsByOperand(K operand,
Class<A> type,
ByObjectSearcher<A,K> searcher) N-Ary Axioms by the given OWLObject operand.default Stream<org.semanticweb.owlapi.model.OWLNegativeDataPropertyAssertionAxiom> listOWLNegativeDataPropertyAssertionAxioms(org.semanticweb.owlapi.model.OWLIndividual subject) default Stream<org.semanticweb.owlapi.model.OWLNegativeObjectPropertyAssertionAxiom> listOWLNegativeObjectPropertyAssertionAxioms(org.semanticweb.owlapi.model.OWLIndividual subject) Stream<org.semanticweb.owlapi.model.OWLObjectProperty> Stream<org.semanticweb.owlapi.model.OWLObjectPropertyAssertionAxiom> listOWLObjectPropertyAssertionAxioms(org.semanticweb.owlapi.model.OWLIndividual subject) default Stream<org.semanticweb.owlapi.model.OWLObjectPropertyAssertionAxiom> listOWLObjectPropertyAssertionAxioms(org.semanticweb.owlapi.model.OWLIndividual subject) ObjectPropertyAssertion Axioms
by the given individual-subject.Stream<org.semanticweb.owlapi.model.OWLObjectPropertyDomainAxiom> listOWLObjectPropertyDomainAxioms(org.semanticweb.owlapi.model.OWLObjectPropertyExpression subject) default Stream<org.semanticweb.owlapi.model.OWLObjectPropertyDomainAxiom> listOWLObjectPropertyDomainAxioms(org.semanticweb.owlapi.model.OWLObjectPropertyExpression subject) ObjectPropertyDomain Axioms
by the given property-subject.Stream<org.semanticweb.owlapi.model.OWLObjectPropertyRangeAxiom> listOWLObjectPropertyRangeAxioms(org.semanticweb.owlapi.model.OWLObjectPropertyExpression subject) default Stream<org.semanticweb.owlapi.model.OWLObjectPropertyRangeAxiom> listOWLObjectPropertyRangeAxioms(org.semanticweb.owlapi.model.OWLObjectPropertyExpression subject) ObjectPropertyRange Axioms
by the given property-subject.listOWLObjects(OWLComponentType type,
InternalConfig conf) type.default <A extends org.semanticweb.owlapi.model.OWLAxiom & org.semanticweb.owlapi.model.HasProperty<P>,
P extends org.semanticweb.owlapi.model.OWLPropertyExpression>
Stream<A> listOWLPropertyAxioms(Class<A> type,
P property) default Stream<org.semanticweb.owlapi.model.OWLReflexiveObjectPropertyAxiom> listOWLReflexiveObjectPropertyAxioms(org.semanticweb.owlapi.model.OWLObjectPropertyExpression subject) default Stream<org.semanticweb.owlapi.model.OWLSameIndividualAxiom> listOWLSameIndividualAxioms(org.semanticweb.owlapi.model.OWLIndividual operand) default Stream<org.semanticweb.owlapi.model.OWLSubAnnotationPropertyOfAxiom> listOWLSubAnnotationPropertyOfAxiomsByObject(org.semanticweb.owlapi.model.OWLAnnotationProperty object) default Stream<org.semanticweb.owlapi.model.OWLSubAnnotationPropertyOfAxiom> listOWLSubAnnotationPropertyOfAxiomsBySubject(org.semanticweb.owlapi.model.OWLAnnotationProperty subject) Stream<org.semanticweb.owlapi.model.OWLSubClassOfAxiom> listOWLSubClassOfAxiomsByObject(org.semanticweb.owlapi.model.OWLClass object) default Stream<org.semanticweb.owlapi.model.OWLSubClassOfAxiom> listOWLSubClassOfAxiomsByObject(org.semanticweb.owlapi.model.OWLClass object) SubClassOf Axioms by the given super class.Stream<org.semanticweb.owlapi.model.OWLSubClassOfAxiom> listOWLSubClassOfAxiomsBySubject(org.semanticweb.owlapi.model.OWLClass subject) default Stream<org.semanticweb.owlapi.model.OWLSubClassOfAxiom> listOWLSubClassOfAxiomsBySubject(org.semanticweb.owlapi.model.OWLClass subject) SubClassOf Axioms by the given sub class.default Stream<org.semanticweb.owlapi.model.OWLSubDataPropertyOfAxiom> listOWLSubDataPropertyOfAxiomsByObject(org.semanticweb.owlapi.model.OWLDataProperty object) default Stream<org.semanticweb.owlapi.model.OWLSubDataPropertyOfAxiom> listOWLSubDataPropertyOfAxiomsBySubject(org.semanticweb.owlapi.model.OWLDataProperty subject) default Stream<org.semanticweb.owlapi.model.OWLSubObjectPropertyOfAxiom> listOWLSubObjectPropertyOfAxiomsByObject(org.semanticweb.owlapi.model.OWLObjectPropertyExpression object) default Stream<org.semanticweb.owlapi.model.OWLSubObjectPropertyOfAxiom> listOWLSubObjectPropertyOfAxiomsBySubject(org.semanticweb.owlapi.model.OWLObjectPropertyExpression subject) default <A extends org.semanticweb.owlapi.model.OWLSubPropertyAxiom<P>,
P extends org.semanticweb.owlapi.model.OWLPropertyExpression>
Stream<A> listOWLSubPropertyOfAxiomsByObject(Class<A> type,
P object) default <A extends org.semanticweb.owlapi.model.OWLSubPropertyAxiom<P>,
P extends org.semanticweb.owlapi.model.OWLPropertyExpression>
Stream<A> listOWLSubPropertyOfAxiomsBySubject(Class<A> type,
P subject) default Stream<org.semanticweb.owlapi.model.OWLSymmetricObjectPropertyAxiom> listOWLSymmetricObjectPropertyAxioms(org.semanticweb.owlapi.model.OWLObjectPropertyExpression subject) default Stream<org.semanticweb.owlapi.model.OWLTransitiveObjectPropertyAxiom> listOWLTransitiveObjectPropertyAxioms(org.semanticweb.owlapi.model.OWLObjectPropertyExpression subject) Stream<org.semanticweb.owlapi.model.IRI> listPunningIRIs(boolean withImports) org.apache.jena.ontapi.model.OntModellock()org.apache.jena.ontapi.model.OntModelnotifyEvent(Object arg0) org.apache.jena.ontapi.model.OntModelread(InputStream arg0,
String arg1) org.apache.jena.ontapi.model.OntModelread(InputStream arg0,
String arg1,
String arg2) org.apache.jena.ontapi.model.OntModelorg.apache.jena.ontapi.model.OntModelorg.apache.jena.ontapi.model.OntModelorg.apache.jena.ontapi.model.OntModelorg.apache.jena.ontapi.model.OntModelorg.apache.jena.ontapi.model.OntModelregister(org.apache.jena.rdf.model.ModelChangedListener arg0) protected booleanremove(OWLTopObjectType key,
org.semanticweb.owlapi.model.OWLObject container) container from the corresponding cache and the model.org.apache.jena.ontapi.model.OntModelorg.apache.jena.ontapi.model.OntModelremove(org.apache.jena.rdf.model.Model arg0) org.apache.jena.ontapi.model.OntModelremove(org.apache.jena.rdf.model.Resource arg0,
org.apache.jena.rdf.model.Property arg1,
org.apache.jena.rdf.model.RDFNode arg2) org.apache.jena.ontapi.model.OntModelremove(org.apache.jena.rdf.model.Statement arg0) org.apache.jena.ontapi.model.OntModelremove(org.apache.jena.rdf.model.Statement[] arg0) org.apache.jena.ontapi.model.OntModelremove(org.apache.jena.rdf.model.StmtIterator arg0) booleanremove(org.semanticweb.owlapi.model.OWLAnnotation annotation) booleanremove(org.semanticweb.owlapi.model.OWLAxiom axiom) org.apache.jena.ontapi.model.OntModelremoveAll(org.apache.jena.rdf.model.Resource arg0,
org.apache.jena.rdf.model.Property arg1,
org.apache.jena.rdf.model.RDFNode arg2) org.apache.jena.ontapi.model.OntModelremoveNsPrefix(String arg0) <N extends org.apache.jena.rdf.model.RDFNode>
NsafeFindNodeAs(org.apache.jena.graph.Node node,
Class<N> type) protected <R> Stream<R> selectContent(OWLComponentType type,
Function<OWLTopObjectType,Stream<R>> toStream,
BiPredicate<OWLTopObjectType,R> withAnnotations) InternalReadGraphModel.content cache, that may hold a component of the given type.InternalReadGraphModel.content cache, that may hold a component of the given type.protected Stream<org.semanticweb.owlapi.model.OWLObject> InternalReadGraphModel.content cache, that may hold a component of the given type.org.apache.jena.ontapi.model.OntModelsetNsPrefix(String arg0,
String arg1) org.apache.jena.ontapi.model.OntModelsetNsPrefixes(Map<String,String> arg0) org.apache.jena.ontapi.model.OntModelsetNsPrefixes(org.apache.jena.shared.PrefixMapping arg0) voidsetOntologyID(org.semanticweb.owlapi.model.OWLOntologyID id) OWL Ontology ID to the model.protected org.apache.jena.ontapi.model.OntModelOWL Graph Model.toString()org.apache.jena.ontapi.model.OntModelunregister(org.apache.jena.rdf.model.ModelChangedListener arg0) protected booleantrue if there is a need to use ByObjectSearcher-search optimization instead of parsing cache.protected booleantrue if SearchModel optimization should be used to speed up content reading.protected booleantrue if ObjectsSearcher optimization
should be used to fill the component cache for the specified type.protected booleantrue if the graph optimization for referencing axiom functionality is allowed and makes sense.org.apache.jena.ontapi.model.OntModelwithDefaultMappings(org.apache.jena.shared.PrefixMapping arg0) org.apache.jena.ontapi.model.OntModelwrite(OutputStream arg0,
String arg1) org.apache.jena.ontapi.model.OntModelwrite(OutputStream arg0,
String arg1,
String arg2) org.apache.jena.ontapi.model.OntModelorg.apache.jena.ontapi.model.OntModelorg.apache.jena.ontapi.model.OntModelwriteAll(OutputStream arg0,
String arg1) org.apache.jena.ontapi.model.OntModelwriteAll(OutputStream arg0,
String arg1,
String arg2) org.apache.jena.ontapi.model.OntModelorg.apache.jena.ontapi.model.OntModeladd, add, add, add, add, add, add, add, add, addImport, addImportModel, addLiteral, addLiteral, addLiteral, addLiteral, addLiteral, addLiteral, addLiteral, ambiguousEntities, asInferenceModel, asOntList, asOntList, asStatement, checkCreate, checkFeature, clearNsPrefixMap, configValue, containsLocal, createBuiltInSWRLAtom, createClassSWRLAtom, createDataAllValuesFrom, createDataAllValuesFrom, createDataCardinality, createDataComplementOf, createDataHasValue, createDataIntersectionOf, createDataMaxCardinality, createDataMinCardinality, createDataOneOf, createDataPropertySWRLAtom, createDataRangeSWRLAtom, createDataRestriction, createDataSomeValuesFrom, createDataSomeValuesFrom, createDataUnionOf, createDifferentIndividuals, createDifferentIndividualsSWRLAtom, createDisjointClasses, createDisjointDataProperties, createDisjointObjectProperties, createFacetRestriction, createHasSelf, createIndividual, createObjectAllValuesFrom, createObjectCardinality, createObjectComplementOf, createObjectHasValue, createObjectIntersectionOf, createObjectMaxCardinality, createObjectMinCardinality, createObjectOneOf, createObjectPropertySWRLAtom, createObjectSomeValuesFrom, createObjectUnionOf, createOntEntity, createOntList, createOntList, createOntObject, createSameIndividualsSWRLAtom, createStatement, createSWRLImp, createSWRLVariable, deleteOntList, findImportAsRawModel, findNodeAs, getBaseGraph, getBaseModel, getDeductionsModel, getDerivation, getID, getInfGraph, getNodeAs, getNodeAsInternal, getOntEntity, getOntPersonality, getOWLBottomDataProperty, getOWLBottomObjectProperty, getOWLNothing, getOWLThing, getOWLTopDataProperty, getOWLTopObjectProperty, getPrefixMapping, getRawModel, getRDFDatatype, getRDFSComment, getRDFSLabel, getRDFSLiteral, getReasoner, getTopModel, hasImport, hasImport, hierarchyRoots, id, imports, imports, independent, individuals, isBuiltIn, listAnnotations, listHierarchyRoots, listImportGraphs, listImportModels, listIndividuals, listIndividuals, listLocalOntEntities, listLocalOntObjects, listLocalStatements, listOntEntities, listOntObjects, listOntObjects, listOntStatements, listStatements, listStatements, localStatements, lock, makeGraph, notifyEvent, ontEntities, ontObjects, prepare, read, read, read, read, read, read, read, rebind, register, remove, remove, remove, remove, remove, remove, removeAll, removeImport, removeImport, removeImportModel, removeNsPrefix, removeOntObject, removeOntStatement, reset, setDerivationLogging, setID, setNsPrefix, setNsPrefixes, setNsPrefixes, statements, statements, unregister, validate, withDefaultMappings, write, write, write, write, writeAll, writeAll, writeAll, writeAllabort, adapt, add, addCommon, addNamespaces, asModel, asNode, asRDFNode, asStatements, asStatements, asStatements, begin, calculateInTxn, close, commit, contains, contains, contains, contains, contains, contains, containsAll, containsAll, containsAllThenClose, containsAny, containsAny, containsAnyThenClose, containsLiteral, containsLiteral, containsLiteral, containsLiteral, containsLiteral, containsLiteral, containsLiteral, containsResource, createAlt, createAlt, createBag, createBag, createList, createList, createList, createLiteral, createLiteral, createLiteral, createLiteralStatement, createLiteralStatement, createLiteralStatement, createLiteralStatement, createLiteralStatement, createLiteralStatement, createLiteralStatement, createProperty, createProperty, createResource, createResource, createResource, createResource, createResource, createSeq, createSeq, createStatement, createStatement, createStatementTerm, createTypedLiteral, createTypedLiteral, createTypedLiteral, createTypedLiteral, createTypedLiteral, createTypedLiteral, createTypedLiteral, createTypedLiteral, createTypedLiteral, createTypedLiteral, createTypedLiteral, createTypedLiteral, createTypedLiteral, createWorkModel, difference, executeInTxn, expandPrefix, getAlt, getAlt, getBag, getBag, getGraph, getList, getList, getModelLock, getNsPrefixMap, getNsPrefixURI, getNsURIPrefix, getProperty, getProperty, getProperty, getProperty, getRDFNode, getReader, getRequiredProperty, getRequiredProperty, getResource, getResource, getSeq, getSeq, getWriter, hasNoMappings, intersect, intersection, isClosed, isEmpty, isIsomorphicWith, listBySubject, listLiteralStatements, listLiteralStatements, listLiteralStatements, listLiteralStatements, listLiteralStatements, listLiteralStatements, listNameSpaces, listObjects, listObjectsOfProperty, listObjectsOfProperty, listResourcesWithProperty, listResourcesWithProperty, listResourcesWithProperty, listResourcesWithProperty, listResourcesWithProperty, listResourcesWithProperty, listResourcesWithProperty, listResourcesWithProperty, listStatements, listStatements, listStatements, listStatements, listStatements, listSubjects, listSubjectsWithProperty, listSubjectsWithProperty, listSubjectsWithProperty, listSubjectsWithProperty, listSubjectsWithProperty, numPrefixes, qnameFor, reifiedToString, samePrefixMappingAs, shortForm, size, statementsToString, supportsSetOperations, supportsTransactions, union, wrapAsResourceasGraph, equals, getPersonality, hashCode, isIsomorphicWithclone, finalize, getClass, notify, notifyAll, wait, wait, waitgetDataFactorycontains, contains, containsIgnoreAnnotations, containsOWLDeclaration, containsOWLEntity, containsOWLEntity, containsOWLEntity, containsOWLEntity, containsOWLEntity, containsOWLEntity, getOntologyID, getOWLAxiomCount, isOntologyEmpty, listComponentOWLAnonymousIndividuals, listComponentOWLNamedIndividuals, listGraphOWLAnonymousIndividuals, listGraphOWLNamedIndividuals, listOWLAnnotationProperties, listOWLAnnotations, listOWLAxioms, listOWLAxioms, listOWLAxioms, listOWLAxioms, listOWLAxioms, listOWLClasses, listOWLClassExpressions, listOWLDataProperties, listOWLDatatypes, listOWLEntities, listOWLImportDeclarations, listOWLLogicalAxioms, listOWLObjectProperties, listPunningIRIsenterCriticalSection, leaveCriticalSectionabort, begin, calculateInTxn, clearNsPrefixMap, close, commit, contains, contains, contains, containsAll, containsAll, containsAny, containsAny, containsResource, createList, createList, createList, createLiteral, createLiteral, createProperty, createReifier, createReifier, createResource, createResource, createResource, createStatement, createStatementTerm, createTypedLiteral, createTypedLiteral, createTypedLiteral, difference, equals, executeInTxn, getLock, getProperty, getProperty, getProperty, getReader, getRequiredProperty, getRequiredProperty, getResource, getResource, getWriter, independent, intersection, isClosed, isEmpty, isIsomorphicWith, listNameSpaces, listObjects, listObjectsOfProperty, listObjectsOfProperty, listResourcesWithProperty, listResourcesWithProperty, listStatements, listStatements, listSubjects, listSubjectsWithProperty, listSubjectsWithProperty, removeNsPrefix, setNsPrefix, setNsPrefixes, setNsPrefixes, size, supportsSetOperations, supportsTransactions, union, withDefaultMappings, write, writeadd, contains, contains, contains, containsLiteral, containsLiteral, containsLiteral, containsLiteral, containsLiteral, containsLiteral, containsLiteral, createAlt, createAlt, createBag, createBag, createLiteral, createLiteralStatement, createLiteralStatement, createLiteralStatement, createLiteralStatement, createLiteralStatement, createLiteralStatement, createLiteralStatement, createProperty, createResource, createResource, createSeq, createSeq, createStatement, createStatement, createTypedLiteral, createTypedLiteral, createTypedLiteral, createTypedLiteral, createTypedLiteral, createTypedLiteral, createTypedLiteral, createTypedLiteral, createTypedLiteral, createTypedLiteral, getAlt, getAlt, getBag, getBag, getList, getList, getProperty, getRDFNode, getSeq, getSeq, listLiteralStatements, listLiteralStatements, listLiteralStatements, listLiteralStatements, listLiteralStatements, listLiteralStatements, listResourcesWithProperty, listResourcesWithProperty, listResourcesWithProperty, listResourcesWithProperty, listResourcesWithProperty, listResourcesWithProperty, listStatements, listStatements, listStatements, listSubjectsWithProperty, listSubjectsWithProperty, listSubjectsWithPropertyasRDFNode, getGraph, wrapAsResourcecanNodeAs, checkType, findNodeAs, getNodeAs, getOntPersonality, safeFindNodeAsaddImport, annotationProperties, asInferenceModel, asStatement, classes, createAnnotationProperty, createDataProperty, createDatatype, createFacetRestriction, createIndividual, createIndividual, createObjectProperty, createOntClass, createOntEntity, createRDFProperty, dataProperties, datatypes, fetchOntEntity, getAnnotationProperty, getAnnotationProperty, getBaseGraph, getBaseModel, getDataProperty, getDataProperty, getDatatype, getDatatype, getDatatype, getID, getIndividual, getIndividual, getObjectProperty, getObjectProperty, getOntClass, getOntClass, getOntEntity, getOntEntity, getOWLBackwardCompatibleWith, getOWLBottomDataProperty, getOWLBottomObjectProperty, getOWLDeprecated, getOWLIncompatibleWith, getOWLNothing, getOWLPriorVersion, getOWLThing, getOWLTopDataProperty, getOWLTopObjectProperty, getOWLVersionInfo, getRDFSComment, getRDFSIsDefinedBy, getRDFSLabel, getRDFSLiteral, getRDFSSeeAlso, hasImport, hasImport, hierarchyRoots, id, imports, individuals, localStatements, localStatements, namedIndividuals, objectProperties, ontEntities, ontEntities, ontObjects, properties, removeImport, removeImport, removeOntObject, removeOntStatement, setID, statements, statementsexpandPrefix, getNsPrefixMap, getNsPrefixURI, getNsURIPrefix, hasNoMappings, numPrefixes, qnameFor, samePrefixMappingAs, shortFormclearCache().ONT Jena Objects to OWL-API objects.
It is used while collecting axioms, may be reset to release memory.
Any change in the base graph must reset this cache.
Designed as a SoftReference
since it is mostly needed only to optimize reading operations and may contain huge number of objects.nodes cache.
Any change in the base graph must also reset this cache.
Designed as a SoftReference
since it is mostly needed only to optimize reading operations and may contain huge number of objects.40 key-value pairs, 39 for kinds of axioms and one for the ontology header.content.
Any direct (manual) change in the graph must also reset this cache.base - Graph, not null, a primary and single data-storagepersonality - OntPersonality, not null,
a facility to conduct Node to OntObject mappingsconfig - InternalConfig, not null, to control caches and ontological viewsdataFactory - DataFactory, not null, to produce standard OWLObjectsfromManager - Map or null,
a possibility to share cache-data between different model instancesInternalGraphModelUnionGraph which this Model is presenting.getUnionGraph in interface InternalGraphModelgetUnionGraph in class org.apache.jena.ontapi.impl.OntGraphModelImplUnionGraphInternalGraphModelOWL Ontology ID to the model.setOntologyID in interface InternalGraphModelid - OWLOntologyIDIllegalArgumentException - in case the given id is brokenInternalGraphModeladd in interface InternalGraphModelaxiom - OWLAxiomtrue if the axiom has been added to the graphInternalGraphModeladd in interface InternalGraphModelannotation - OWLAnnotationtrue if the annotation has been added to the graphInternalGraphModelremove in interface InternalGraphModelaxiom - OWLAxiomtrue if the axiom has been removed from the graphInternalGraphModelremove in interface InternalGraphModelannotation - OWLAnnotationtrue if the annotation has been removed from the graphOWLObject into the model.key - OWLTopObjectType, not nullcontainer - either OWLAxiom or OWLAnnotation,
that corresponds to the key, not nulltrue if the graph has been changedOntApiException - in case the object cannot be added into the modelcontainer from the corresponding cache and the model.
In case some container's triple is associated with other object, it cannot be deleted from the graph.
Example of such intersection in triples is reusing b-nodes:
<A> rdfs:subClassOf _:b0 and <B> rdfs:subClassOf _:b0.
Also, OWL-Entity declaration root-triples are shared between different axioms.key - OWLTopObjectType, not nullcontainer - either OWLAxiom or OWLAnnotation,
that corresponds to the key, not nulltrue if the graph has been changedtriples,
that belong to both the given content-container and some other one.
There are three cases of triples intersections:
rdfs:subPropertyOf-axiom for punned properties.SubClassOf(A, _:x) and SubClassOf(B, _:x)
would have identical sets of triples for class expression _:x.model - OntModel the model to traverse over,
must correspond to the container, not nullcontainer - OWLObject - a content-container,
for which this operation is performed, not nullSet of Triples in intersectionOWL Graph Model.o - ONTObject-wrapperOntModeltriple - TripleremoveAll in interface org.apache.jena.rdf.model.ModelremoveAll in class org.apache.jena.ontapi.impl.OntGraphModelImplModelInternalGraphModelThe OWL-API serialization may not work correctly without explicit expansion of axioms into a strictly defined form. The cache cleaning encourages repeated reading of the encapsulated graph, and, thus, leads the axioms to a uniform view. Without this operation, the axiomatic representation would look slightly different and the reload test (loading/saving in different formats) would not be passed. Also, absence of uniformed axiomatic view may lead to exceptions, since some OWL-storers require explicit declarations, which may not be present, if the ontology was assembled manually. It is important to invalidate whole the cache, since user-defined axioms may content parts of other axioms, such as annotation assertions, declarations, data-range definitions, etc.
clearCacheIfNeeded in interface InternalGraphModelInternalGraphModelclearCache in interface InternalGraphModelInternalReadGraphModel.components,
InternalReadGraphModel.objectFactory and InternalReadGraphModel.searchModel caches.
Auxiliary method.cache for all components parsed from the given container.
todo: is a smarter mechanism to invalidate the related components possible here?container - OWLObject, not nullcontainer and puts them into the InternalReadGraphModel.components cache.container - OWLObject, not nullInternalGraphModelforceLoad in interface InternalGraphModeladd in interface org.apache.jena.rdf.model.Modeladd in interface org.apache.jena.rdf.model.ModelConadd in interface org.apache.jena.rdf.model.Modeladd in interface org.apache.jena.rdf.model.Modeladd in interface org.apache.jena.rdf.model.Modeladd in interface org.apache.jena.rdf.model.Modelremove in interface org.apache.jena.rdf.model.Modelremove in interface org.apache.jena.rdf.model.ModelConremove in interface org.apache.jena.rdf.model.ModelConremove in interface org.apache.jena.rdf.model.ModelConremoveAll in interface org.apache.jena.rdf.model.Modelremove in interface org.apache.jena.rdf.model.Modelremove in interface org.apache.jena.rdf.model.ModeladdLiteral in interface org.apache.jena.rdf.model.ModelConaddLiteral in interface org.apache.jena.rdf.model.ModelConaddLiteral in interface org.apache.jena.rdf.model.ModelConaddLiteral in interface org.apache.jena.rdf.model.ModelConaddLiteral in interface org.apache.jena.rdf.model.ModelConaddLiteral in interface org.apache.jena.rdf.model.ModelConaddLiteral in interface org.apache.jena.rdf.model.ModelConadd in interface org.apache.jena.rdf.model.ModelConadd in interface org.apache.jena.rdf.model.ModelConadd in interface org.apache.jena.rdf.model.ModelConregister in interface org.apache.jena.rdf.model.Modelunregister in interface org.apache.jena.rdf.model.ModelnotifyEvent in interface org.apache.jena.rdf.model.ModelsetNsPrefix in interface org.apache.jena.shared.PrefixMappingremoveNsPrefix in interface org.apache.jena.shared.PrefixMappingclearNsPrefixMap in interface org.apache.jena.shared.PrefixMappingsetNsPrefixes in interface org.apache.jena.shared.PrefixMappinglock in interface org.apache.jena.shared.PrefixMappingread in interface org.apache.jena.rdf.model.Modelread in interface org.apache.jena.rdf.model.Modelread in interface org.apache.jena.rdf.model.Modelread in interface org.apache.jena.rdf.model.Modelread in interface org.apache.jena.rdf.model.Modelread in interface org.apache.jena.rdf.model.Modelread in interface org.apache.jena.rdf.model.Modelwrite in interface org.apache.jena.rdf.model.Modelwrite in interface org.apache.jena.rdf.model.Modelwrite in interface org.apache.jena.rdf.model.Modelwrite in interface org.apache.jena.rdf.model.ModelA - subtype of OWLAxiomtype - ClassStream of OWLAxiomsDeclaration Axioms for the specified entity.
Note: method may return non-cached axioms.entity - OWLEntity, not nullStream of OWLDeclarationAxiomsAnnotation Assertion Axioms
with the given subject.
Note: method returns non-cached axioms.subject - OWLAnnotationSubject, not nullStream of OWLAnnotationAssertionAxiomsSubClassOf Axioms by the given sub class.subject - OWLClass, not nullStream of OWLSubClassOfAxiomsSubClassOf Axioms by the given super class.object - OWLClass, not nullStream of OWLSubClassOfAxiomsEquivalentClasses Axioms by the given class-component.clazz - OWLClass, not nullStream of OWLEquivalentClassesAxiomsDisjointClasses Axioms by the given class-component.clazz - OWLClass, not nullStream of OWLDisjointClassesAxiomsClassAssertion Axioms by the given class-object.object - OWLClassExpression, not nullStream of OWLClassAssertionAxiomsClassAssertion Axioms by the given individual-subject.subject - OWLIndividual, not nullStream of OWLClassAssertionAxiomsObjectPropertyAssertion Axioms
by the given individual-subject.subject - OWLIndividual, not nullStream of OWLObjectPropertyAssertionAxiomsDataPropertyAssertion Axioms by the given individual-subject.subject - OWLIndividual, not nullStream of OWLDataPropertyAssertionAxiomsObjectPropertyDomain Axioms
by the given property-subject.subject - OWLObjectPropertyExpression, not nullStream of OWLObjectPropertyDomainAxiomsObjectPropertyRange Axioms
by the given property-subject.subject - OWLObjectPropertyExpression, not nullStream of OWLObjectPropertyRangeAxiomsInternalConfig snapshot instance, which is an immutable object.getConfig in interface HasConfigInternalConfig.SnapshotInternalDataFactory, a helper (possibly, with cache) to read OWL-API objects.getObjectFactory in interface HasObjectFactoryModelObjectFactoryObject Factory instance,
which is responsible for mapping Node (and OntObject) to OWLObject.
If the load objects cache is enabled,
the method returns a CacheObjectFactory instance,
that caches OWLObjects and, therefore, may take up a lot of memory.
Otherwise, in case the load cache is disabled, the ModelObjectFactory will be returned.df - DataFactory, not nullexternal - a Map with shared outer caches, not nullModelObjectFactoryOntGraphModelImpl version with search optimizations.
The return model must be used only to collect OWL-API stuff:
OWL Axioms and OWL Objects.
Retrieving jena Ont Objects and Ont Statements must be performed
through the main (this) interface.OntGraphModelImpl with search optimizationsSearchModel - a facility to optimize read operations,
otherwise this same InternalReadGraphModel instance with no optimizations will be returned.
A SearchModel contains a Nodes cache inside and, therefore, may take up a lot of memory.OntModeltrue if SearchModel optimization should be used to speed up content reading.config - InternalConfig, not nullbooleansafeFindNodeAs in interface org.apache.jena.ontapi.common.OntEnhGraphsafeFindNodeAs in class org.apache.jena.ontapi.impl.OntGraphModelImplgetLock in interface org.apache.jena.rdf.model.ModelgetLock in class org.apache.jena.rdf.model.impl.ModelComenterCriticalSection in interface org.apache.jena.shared.LockenterCriticalSection in class org.apache.jena.rdf.model.impl.ModelComleaveCriticalSection in interface org.apache.jena.shared.LockleaveCriticalSection in class org.apache.jena.rdf.model.impl.ModelComN-Ary Axioms by the given OWLObject operand.A - - subtype of OWLNaryAxiomK - - subtype of OWLObjectoperand - InternalReadGraphModel, not nulltype - - class-type of InternalReadGraphModelsearcher - - ByObjectSearcher for InternalReadGraphModel and InternalReadGraphModelStream of InternalReadGraphModelsA - - OWLAxiomK - - OWLObjectsearcher - - ByObjectSearchertype - - Class-type of InternalReadGraphModelparameter - - InternalReadGraphModel, to search byconfig - - InternalConfigStream of InternalReadGraphModels (it is distinct if default settings)true if the graph optimization for referencing axiom functionality is allowed and makes sense.type - OWLComponentTypeconfig - InternalConfigbooleantrue if there is a need to use ByObjectSearcher-search optimization instead of parsing cache.config - InternalConfigbooleantrue if the specified map does not contain annotated axioms.map - ObjectMapbooleanentity - OWLObject to check, not nullexcludes - Array, with containers
(that must be either OWLAxiom or OWLAnnotation) to exclude from considerationOptional around the container objectbooleantoString in class org.apache.jena.rdf.model.impl.ModelComMap that has Enum-keys using the specified parameters.K - subtype of EnumV - anything, a value typetype - Class-type of InternalReadGraphModelkeys - Stream with InternalReadGraphModel-keysloader - Function to collect InternalReadGraphModel-valuesMaptype.O - type of owl-objecttype - OWLComponentType, not nullStream of OWLObjectstype - OWLComponentType, not nullo - OWLObject of the typebooleantype in the form of ObjectMap.O - OWLObject class-type that corresponds the typetype - OWLComponentType, not nullObjectMap of InternalReadGraphModelsObjectMap container for the given OWLComponentType.type - OWLComponentType, not nullObjectMaptype.type - OWLComponentType - owl object type, that is used in the object's cacheconf - InternalConfigIterator of ONTObject with the given typetrue if ObjectsSearcher optimization
should be used to fill the component cache for the specified type.config - InternalConfig, not nullbooleanMap.MapInternalReadGraphModel.content cache, that may hold a component of the given type.type - OWLComponentType, not nullStream of ONTObject - containers from the content cacheInternalReadGraphModel.content cache, that may hold a component of the given type.type - OWLComponentType, not nullStream of OWLObject - containers from the content cacheInternalReadGraphModel.content cache, that may hold a component of the given type.R - anythingtype - OWLComponentType, not nulltoStream - a Function to provide Stream of InternalReadGraphModel
for a given OWLTopObjectType, not nullwithAnnotations - a BiPredicate to select only those InternalReadGraphModel,
which have OWL annotations, not nullStream of InternalReadGraphModel - containers from the content cacheStream of OWLTopObjectType to ObjectMap.
The input must contain only those elements
for which the OWLTopObjectType.isAxiom() method returns true.keys - Stream of OWLTopObjectTypeStream of ObjectMap containing OWLAxiomsObjectMap for the given OWLTopObjectType.
The OWLTopObjectType.isAxiom() method for the input must return true.key - OWLTopObjectType, not nullObjectMapObjectMapObjectMap-cache.X - either OWLAxiom or OWLAnnotationkey - OWLTopObjectType, not nullObjectMapMap.MapStream of ObjectMapsMap.MapObjectMap container for the given OWLTopObjectType.key - OWLTopObjectTypeObjectMap