Class AnnotationAssertionTranslator.AxiomImpl.SimpleImpl

java.lang.Object
com.github.owlcs.ontapi.owlapi.OWLObjectImpl
com.github.owlcs.ontapi.internal.objects.ONTObjectImpl
com.github.owlcs.ontapi.internal.objects.ONTStatementImpl
com.github.owlcs.ontapi.internal.objects.ONTAxiomImpl<org.semanticweb.owlapi.model.OWLAnnotationAssertionAxiom>
com.github.owlcs.ontapi.internal.axioms.AbstractPropertyAssertionTranslator.AssertionImpl<org.semanticweb.owlapi.model.OWLAnnotationAssertionAxiom,org.semanticweb.owlapi.model.OWLAnnotationSubject,org.semanticweb.owlapi.model.OWLAnnotationProperty,org.semanticweb.owlapi.model.OWLAnnotationValue>
com.github.owlcs.ontapi.internal.axioms.AnnotationAssertionTranslator.AxiomImpl
com.github.owlcs.ontapi.internal.axioms.AnnotationAssertionTranslator.AxiomImpl.SimpleImpl
All Implemented Interfaces:
com.github.owlcs.ontapi.internal.axioms.WithAssertion.Simple<org.semanticweb.owlapi.model.OWLAnnotationSubject,org.semanticweb.owlapi.model.OWLAnnotationProperty,org.semanticweb.owlapi.model.OWLAnnotationValue>, HasConfig, HasObjectFactory, AsStatement, ModelObject<org.semanticweb.owlapi.model.OWLAnnotationAssertionAxiom>, ONTComposite, WithAnnotations, WithoutAnnotations, ONTObject<org.semanticweb.owlapi.model.OWLAnnotationAssertionAxiom>, WithMerge<ONTObject<org.semanticweb.owlapi.model.OWLAnnotationAssertionAxiom>>, Serializable, Comparable<org.semanticweb.owlapi.model.OWLObject>, org.apache.jena.graph.FrontsTriple, org.semanticweb.owlapi.model.HasAnnotationPropertiesInSignature, org.semanticweb.owlapi.model.HasAnnotations, org.semanticweb.owlapi.model.HasAnnotationValue, org.semanticweb.owlapi.model.HasAnonymousIndividuals, org.semanticweb.owlapi.model.HasClassesInSignature, org.semanticweb.owlapi.model.HasComponents, org.semanticweb.owlapi.model.HasContainsEntityInSignature, org.semanticweb.owlapi.model.HasDataPropertiesInSignature, org.semanticweb.owlapi.model.HasDatatypesInSignature, org.semanticweb.owlapi.model.HasHashIndex, org.semanticweb.owlapi.model.HasIndex, org.semanticweb.owlapi.model.HasIndividualsInSignature, org.semanticweb.owlapi.model.HasObjectPropertiesInSignature, org.semanticweb.owlapi.model.HasProperty<org.semanticweb.owlapi.model.OWLAnnotationProperty>, org.semanticweb.owlapi.model.HasSignature, org.semanticweb.owlapi.model.HasSubject<org.semanticweb.owlapi.model.OWLAnnotationSubject>, org.semanticweb.owlapi.model.IsAnonymous, org.semanticweb.owlapi.model.OWLAnnotationAssertionAxiom, org.semanticweb.owlapi.model.OWLAnnotationAxiom, org.semanticweb.owlapi.model.OWLAnnotationObject, org.semanticweb.owlapi.model.OWLAxiom, org.semanticweb.owlapi.model.OWLObject
Enclosing class:
AnnotationAssertionTranslator.AxiomImpl

public static class AnnotationAssertionTranslator.AxiomImpl.SimpleImpl extends AnnotationAssertionTranslator.AxiomImpl implements com.github.owlcs.ontapi.internal.axioms.WithAssertion.Simple<org.semanticweb.owlapi.model.OWLAnnotationSubject,org.semanticweb.owlapi.model.OWLAnnotationProperty,org.semanticweb.owlapi.model.OWLAnnotationValue>
An OWLAnnotationAssertionAxiom that has no sub-annotations.
See Also:
  • Constructor Details

    • SimpleImpl

      protected SimpleImpl(org.apache.jena.graph.Triple t, Supplier<org.apache.jena.ontapi.model.OntModel> m)
  • Method Details

    • containsDatatype

      public boolean containsDatatype(org.semanticweb.owlapi.model.OWLDatatype datatype)
      Description copied from class: ONTObjectImpl
      Answers true iff the given OWL named data range (datatype) is present in the object's signature.
      Overrides:
      containsDatatype in class ONTObjectImpl
      Parameters:
      datatype - OWLDatatype, not null
      Returns:
      boolean
    • containsAnnotationProperty

      public boolean containsAnnotationProperty(org.semanticweb.owlapi.model.OWLAnnotationProperty property)
      Description copied from class: ONTObjectImpl
      Answers true iff the given OWL annotation property is present in the object's signature.
      Overrides:
      containsAnnotationProperty in class ONTObjectImpl
      Parameters:
      property - OWLAnnotationProperty, not null
      Returns:
      boolean
    • getAnonymousIndividualSet

      public Set<org.semanticweb.owlapi.model.OWLAnonymousIndividual> getAnonymousIndividualSet()
      Description copied from class: OWLObjectImpl
      Gets the anonymous individuals occurring in this object. The set is a copy, changes are not reflected back.
      Overrides:
      getAnonymousIndividualSet in class ONTObjectImpl
      Returns:
      a modifiable sorted Set of the anonymous individuals
    • getAnnotationPropertySet

      public Set<org.semanticweb.owlapi.model.OWLAnnotationProperty> getAnnotationPropertySet()
      Description copied from class: OWLObjectImpl
      Obtains the annotation properties that are in the signature of this object. The set is a copy, changes are not reflected back.
      Overrides:
      getAnnotationPropertySet in class ONTObjectImpl
      Returns:
      a modifiable sorted Set of the annotation properties that are in the signature of this object
    • getDatatypeSet

      public Set<org.semanticweb.owlapi.model.OWLDatatype> getDatatypeSet()
      Description copied from class: OWLObjectImpl
      Gets the datatypes that are in the signature of this object. The set is a copy, changes are not reflected back.
      Overrides:
      getDatatypeSet in class ONTObjectImpl
      Returns:
      a modifiable sorted Set of the datatypes that are in the signature of this object
    • getSignatureSet

      public Set<org.semanticweb.owlapi.model.OWLEntity> getSignatureSet()
      Description copied from class: OWLObjectImpl
      Gets the signature of this object. The set is a copy, changes are not reflected back.
      Overrides:
      getSignatureSet in class ONTObjectImpl
      Returns:
      a modifiable sorted Set of entities that represents the signature of this object
    • findLiteral

      protected org.semanticweb.owlapi.model.OWLLiteral findLiteral(ModelObjectFactory factory)
    • findONTSubject

      ONTObject<? extends org.semanticweb.owlapi.model.OWLAnnotationSubject> findONTSubject(ModelObjectFactory factory)
    • findONTPredicate

      ONTObject<? extends org.semanticweb.owlapi.model.OWLAnnotationProperty> findONTPredicate(ModelObjectFactory factory)
    • findONTObject

      ONTObject<? extends org.semanticweb.owlapi.model.OWLAnnotationValue> findONTObject(ModelObjectFactory factory)
    • fetchONTSubject

      default ONTObject<? extends org.semanticweb.owlapi.model.OWLAnnotationSubject> fetchONTSubject(org.apache.jena.ontapi.model.OntStatement statement, ModelObjectFactory factory)
    • fetchONTPredicate

      default ONTObject<? extends org.semanticweb.owlapi.model.OWLAnnotationProperty> fetchONTPredicate(org.apache.jena.ontapi.model.OntStatement statement, ModelObjectFactory factory)
    • fetchONTObject

      default ONTObject<? extends org.semanticweb.owlapi.model.OWLAnnotationValue> fetchONTObject(org.apache.jena.ontapi.model.OntStatement statement, ModelObjectFactory factory)
    • getSubject

      default org.semanticweb.owlapi.model.OWLAnnotationSubject getSubject()
      Specified by:
      getSubject in interface org.semanticweb.owlapi.model.HasSubject<S extends org.semanticweb.owlapi.model.OWLObject>
    • getProperty

      default org.semanticweb.owlapi.model.OWLAnnotationProperty getProperty()
      Specified by:
      getProperty in interface org.semanticweb.owlapi.model.HasProperty<S extends org.semanticweb.owlapi.model.OWLObject>
    • getValue

      default org.semanticweb.owlapi.model.OWLAnnotationValue getValue()
    • getONTSubject

      default ONTObject<? extends org.semanticweb.owlapi.model.OWLAnnotationSubject> getONTSubject()
    • getONTPredicate

      default ONTObject<? extends org.semanticweb.owlapi.model.OWLAnnotationProperty> getONTPredicate()
    • getONTObject

      default ONTObject<? extends org.semanticweb.owlapi.model.OWLAnnotationValue> getONTObject()
    • getFSubject

      default org.semanticweb.owlapi.model.OWLAnnotationSubject getFSubject()
    • getFPredicate

      default org.semanticweb.owlapi.model.OWLAnnotationProperty getFPredicate()
    • getFObject

      default org.semanticweb.owlapi.model.OWLAnnotationValue getFObject()
    • getOWLComponentsAsSet

      default Set<? extends org.semanticweb.owlapi.model.OWLObject> getOWLComponentsAsSet(ModelObjectFactory factory)
    • objects

      default Stream<ONTObject<? extends org.semanticweb.owlapi.model.OWLObject>> objects()
      Description copied from interface: ONTComposite
      Lists all components in the form of Stream. Neither this object nor parts of its components are not included in the result: it content only top-level direct components. Note that HasComponents.components() may also contain non-OWLObject things: integers (e.g. cardinality), Lists (e.g. ObjectOneOf), etc, while this method is only for OWLObjects which are represented as ONTObjects.
      Specified by:
      objects in interface ONTComposite
      Returns:
      Stream of ONTObjects
      See Also:
    • hasURIObject

      default boolean hasURIObject()
      Answers true iff the subject is a URI resource.
      Returns:
      boolean
    • hasURISubject

      default boolean hasURISubject()
      Answers true iff the object is a URI resource.
      Returns:
      boolean
    • getSubjectURI

      default String getSubjectURI()
      Answers a URI of the triple's subject.
      Returns:
      URI of the subject
      Throws:
      RuntimeException - in case the main triple has no subject uri (b-node instead)
    • getObjectURI

      default String getObjectURI()
      Answers a URI of the triple's object.
      Returns:
      URI of the object
      Throws:
      RuntimeException - in case the main triple has no object uri (b-node or literal instead)
    • getOWLComponentsAsSet

      default Set<? extends org.semanticweb.owlapi.model.OWLObject> getOWLComponentsAsSet()
      Gets all OWL characteristic components in the form of Set.
      Returns:
      a sorted Set of OWLObjects
    • isClassExpression

      default boolean isClassExpression()
      Answers true iff this is an OWL Class Expression.
      Returns:
      boolean
    • isAnonymousIndividual

      default boolean isAnonymousIndividual()
      Answers true iff this is an OWL Anonymous Individual.
      Returns:
      boolean
    • isNamedClass

      default boolean isNamedClass()
      Answers true iff this is an OWL Class.
      Returns:
      boolean
    • isNamedIndividual

      default boolean isNamedIndividual()
      Answers true iff this is an OWL Named Individual.
      Returns:
      boolean
    • isDatatype

      default boolean isDatatype()
      Answers true iff this is an OWL Datatype.
      Returns:
      boolean
    • isObjectProperty

      default boolean isObjectProperty()
      Answers true iff this is an OWL Object Property.
      Returns:
      boolean
    • isDataProperty

      default boolean isDataProperty()
      Answers true iff this is an OWL Data Property.
      Returns:
      boolean
    • isAnnotationProperty

      default boolean isAnnotationProperty()
      Answers true iff this is an OWL Annotation Property.
      Returns:
      boolean