Class AnnotationPropertyRangeTranslator.AxiomImpl

java.lang.Object
com.github.owlcs.ontapi.owlapi.OWLObjectImpl
com.github.owlcs.ontapi.internal.objects.ONTObjectImpl
com.github.owlcs.ontapi.internal.objects.ONTStatementImpl
com.github.owlcs.ontapi.internal.objects.ONTAxiomImpl<org.semanticweb.owlapi.model.OWLAnnotationPropertyRangeAxiom>
com.github.owlcs.ontapi.internal.axioms.AbstractPropertyRangeTranslator.RangeAxiomImpl<org.semanticweb.owlapi.model.OWLAnnotationPropertyRangeAxiom,org.semanticweb.owlapi.model.OWLAnnotationProperty,org.semanticweb.owlapi.model.IRI>
com.github.owlcs.ontapi.internal.axioms.AnnotationPropertyRangeTranslator.AxiomImpl
All Implemented Interfaces:
HasConfig, HasObjectFactory, AsStatement, ModelObject<org.semanticweb.owlapi.model.OWLAnnotationPropertyRangeAxiom>, ONTComposite, WithAnnotations, ONTObject<org.semanticweb.owlapi.model.OWLAnnotationPropertyRangeAxiom>, WithMerge<ONTObject<org.semanticweb.owlapi.model.OWLAnnotationPropertyRangeAxiom>>, Serializable, Comparable<org.semanticweb.owlapi.model.OWLObject>, org.apache.jena.graph.FrontsTriple, org.semanticweb.owlapi.model.HasAnnotationPropertiesInSignature, org.semanticweb.owlapi.model.HasAnnotations, org.semanticweb.owlapi.model.HasAnonymousIndividuals, org.semanticweb.owlapi.model.HasClassesInSignature, org.semanticweb.owlapi.model.HasComponents, org.semanticweb.owlapi.model.HasContainsEntityInSignature, org.semanticweb.owlapi.model.HasDataPropertiesInSignature, org.semanticweb.owlapi.model.HasDatatypesInSignature, org.semanticweb.owlapi.model.HasHashIndex, org.semanticweb.owlapi.model.HasIndex, org.semanticweb.owlapi.model.HasIndividualsInSignature, org.semanticweb.owlapi.model.HasObjectPropertiesInSignature, org.semanticweb.owlapi.model.HasProperty<org.semanticweb.owlapi.model.OWLAnnotationProperty>, org.semanticweb.owlapi.model.HasRange<org.semanticweb.owlapi.model.IRI>, org.semanticweb.owlapi.model.HasSignature, org.semanticweb.owlapi.model.IsAnonymous, org.semanticweb.owlapi.model.OWLAnnotationAxiom, org.semanticweb.owlapi.model.OWLAnnotationObject, org.semanticweb.owlapi.model.OWLAnnotationPropertyRangeAxiom, org.semanticweb.owlapi.model.OWLAxiom, org.semanticweb.owlapi.model.OWLObject
Direct Known Subclasses:
AnnotationPropertyRangeTranslator.AxiomImpl.SimpleImpl, AnnotationPropertyRangeTranslator.AxiomImpl.WithAnnotationsImpl
Enclosing class:
AnnotationPropertyRangeTranslator

public abstract static class AnnotationPropertyRangeTranslator.AxiomImpl extends AbstractPropertyRangeTranslator.RangeAxiomImpl<org.semanticweb.owlapi.model.OWLAnnotationPropertyRangeAxiom,org.semanticweb.owlapi.model.OWLAnnotationProperty,org.semanticweb.owlapi.model.IRI> implements org.semanticweb.owlapi.model.OWLAnnotationPropertyRangeAxiom
See Also:
  • Constructor Details

    • AxiomImpl

      protected AxiomImpl(org.apache.jena.graph.Triple t, Supplier<org.apache.jena.ontapi.model.OntModel> m)
  • Method Details

    • create

      public static AnnotationPropertyRangeTranslator.AxiomImpl create(org.apache.jena.ontapi.model.OntStatement statement, ModelObjectFactory factory, AxiomsSettings config)
      Creates an ONTObject container that is also OWLAnnotationPropertyRangeAxiom.
      Parameters:
      statement - OntStatement, not null
      factory - ONTObjectFactory, not null
      config - AxiomsSettings, not null
      Returns:
      AnnotationPropertyRangeTranslator.AxiomImpl
    • getURISubject

      public ONTObject<? extends org.semanticweb.owlapi.model.OWLAnnotationProperty> getURISubject(ModelObjectFactory factory)
    • getURIObject

      public ONTObject<? extends org.semanticweb.owlapi.model.IRI> getURIObject(ModelObjectFactory factory)
    • subjectFromStatement

      public ONTObject<? extends org.semanticweb.owlapi.model.OWLAnnotationProperty> subjectFromStatement(org.apache.jena.ontapi.model.OntStatement statement, ModelObjectFactory factory)
    • objectFromStatement

      public ONTObject<? extends org.semanticweb.owlapi.model.IRI> objectFromStatement(org.apache.jena.ontapi.model.OntStatement statement, ModelObjectFactory factory)
    • createAnnotatedAxiom

      protected org.semanticweb.owlapi.model.OWLAnnotationPropertyRangeAxiom createAnnotatedAxiom(Collection<org.semanticweb.owlapi.model.OWLAnnotation> annotations)
      Description copied from class: ONTAxiomImpl
      Creates a fresh system-wide axiom with the given annotations. The resulting axiom should not contain model references.
      Specified by:
      createAnnotatedAxiom in class ONTAxiomImpl<org.semanticweb.owlapi.model.OWLAnnotationPropertyRangeAxiom>
      Parameters:
      annotations - a Collection of OWLAnnotations to bind to the axiom
      Returns:
      ONTAxiomImpl
    • canContainNamedClasses

      public final boolean canContainNamedClasses()
      Description copied from interface: ONTComposite
      Answers true if this object-container is allowed to contain (named) OWL classes.
      Specified by:
      canContainNamedClasses in interface ONTComposite
      Returns:
      boolean
    • canContainNamedIndividuals

      public final boolean canContainNamedIndividuals()
      Description copied from interface: ONTComposite
      Answers true if this object-container is allowed to contain named individuals.
      Specified by:
      canContainNamedIndividuals in interface ONTComposite
      Returns:
      boolean
    • canContainObjectProperties

      public final boolean canContainObjectProperties()
      Description copied from interface: ONTComposite
      Answers true if this object-container may contain named object properties.
      Specified by:
      canContainObjectProperties in interface ONTComposite
      Returns:
      boolean
    • canContainDataProperties

      public final boolean canContainDataProperties()
      Description copied from interface: ONTComposite
      Answers true if this object-container may contain data properties.
      Specified by:
      canContainDataProperties in interface ONTComposite
      Returns:
      boolean
    • canContainClassExpressions

      public final boolean canContainClassExpressions()
      Description copied from interface: ONTComposite
      Answers true if this object-container is allowed to contain nested class-expressions.
      Specified by:
      canContainClassExpressions in interface ONTComposite
      Returns:
      boolean
    • getONTSubject

      ONTObject<? extends org.semanticweb.owlapi.model.OWLAnnotationProperty> getONTSubject(ModelObjectFactory factory)
      Finds the ONTObject that matches the subject using the factory.
      Parameters:
      factory - ModelObjectFactory to fetch an ONTObject, not null
      Returns:
      an ONTObject that can be seen as wrapper of WithTwoObjects
    • getONTObject

      ONTObject<? extends org.semanticweb.owlapi.model.IRI> getONTObject(ModelObjectFactory factory)
      Finds the ONTObject that matches the object using the factory.
      Parameters:
      factory - ModelObjectFactory to fetch an ONTObject, not null
      Returns:
      an ONTObject that can be seen as wrapper of WithTwoObjects
    • getONTSubject

      default ONTObject<? extends org.semanticweb.owlapi.model.OWLAnnotationProperty> getONTSubject()
      Gets the subject from the base triple of this axiom.
      Returns:
      ONTObject with WithTwoObjects
    • getONTObject

      default ONTObject<? extends org.semanticweb.owlapi.model.IRI> getONTObject()
      Gets the object from the base triple of this axiom.
      Returns:
      ONTObject with WithTwoObjects
    • getOWLComponentsAsSet

      default Set<? extends org.semanticweb.owlapi.model.OWLObject> getOWLComponentsAsSet(ModelObjectFactory factory)
    • hasURIObject

      default boolean hasURIObject()
      Answers true iff the subject is a URI resource.
      Returns:
      boolean
    • hasURISubject

      default boolean hasURISubject()
      Answers true iff the object is a URI resource.
      Returns:
      boolean
    • getSubjectURI

      default String getSubjectURI()
      Answers a URI of the triple's subject.
      Returns:
      URI of the subject
      Throws:
      RuntimeException - in case the main triple has no subject uri (b-node instead)
    • getObjectURI

      default String getObjectURI()
      Answers a URI of the triple's object.
      Returns:
      URI of the object
      Throws:
      RuntimeException - in case the main triple has no object uri (b-node or literal instead)
    • getOWLComponentsAsSet

      default Set<? extends org.semanticweb.owlapi.model.OWLObject> getOWLComponentsAsSet()
      Gets all OWL characteristic components in the form of Set.
      Returns:
      a sorted Set of OWLObjects
    • isClassExpression

      default boolean isClassExpression()
      Answers true iff this is an OWL Class Expression.
      Returns:
      boolean
    • isAnonymousIndividual

      default boolean isAnonymousIndividual()
      Answers true iff this is an OWL Anonymous Individual.
      Returns:
      boolean
    • isNamedClass

      default boolean isNamedClass()
      Answers true iff this is an OWL Class.
      Returns:
      boolean
    • isNamedIndividual

      default boolean isNamedIndividual()
      Answers true iff this is an OWL Named Individual.
      Returns:
      boolean
    • isDatatype

      default boolean isDatatype()
      Answers true iff this is an OWL Datatype.
      Returns:
      boolean
    • isObjectProperty

      default boolean isObjectProperty()
      Answers true iff this is an OWL Object Property.
      Returns:
      boolean
    • isDataProperty

      default boolean isDataProperty()
      Answers true iff this is an OWL Data Property.
      Returns:
      boolean
    • isAnnotationProperty

      default boolean isAnnotationProperty()
      Answers true iff this is an OWL Annotation Property.
      Returns:
      boolean