Class DeclarationTranslator.AxiomImpl.SimpleImpl

All Implemented Interfaces:
HasConfig, HasObjectFactory, AsStatement, ModelObject<org.semanticweb.owlapi.model.OWLDeclarationAxiom>, ONTComposite, WithAnnotations, WithoutAnnotations, ONTObject<org.semanticweb.owlapi.model.OWLDeclarationAxiom>, WithMerge<ONTObject<org.semanticweb.owlapi.model.OWLDeclarationAxiom>>, Serializable, Comparable<org.semanticweb.owlapi.model.OWLObject>, org.apache.jena.graph.FrontsTriple, org.semanticweb.owlapi.model.HasAnnotationPropertiesInSignature, org.semanticweb.owlapi.model.HasAnnotations, org.semanticweb.owlapi.model.HasAnonymousIndividuals, org.semanticweb.owlapi.model.HasClassesInSignature, org.semanticweb.owlapi.model.HasComponents, org.semanticweb.owlapi.model.HasContainsEntityInSignature, org.semanticweb.owlapi.model.HasDataPropertiesInSignature, org.semanticweb.owlapi.model.HasDatatypesInSignature, org.semanticweb.owlapi.model.HasHashIndex, org.semanticweb.owlapi.model.HasIndex, org.semanticweb.owlapi.model.HasIndividualsInSignature, org.semanticweb.owlapi.model.HasObjectPropertiesInSignature, org.semanticweb.owlapi.model.HasSignature, org.semanticweb.owlapi.model.IsAnonymous, org.semanticweb.owlapi.model.OWLAxiom, org.semanticweb.owlapi.model.OWLDeclarationAxiom, org.semanticweb.owlapi.model.OWLObject
Enclosing class:
DeclarationTranslator.AxiomImpl

public static class DeclarationTranslator.AxiomImpl.SimpleImpl extends DeclarationTranslator.AxiomImpl implements WithoutAnnotations
An OWLDeclarationAxiom that has no annotations.
See Also:
  • Constructor Details

    • SimpleImpl

      protected SimpleImpl(org.apache.jena.graph.Triple t, Supplier<org.apache.jena.ontapi.model.OntModel> m)
  • Method Details

    • containsEntity

      public boolean containsEntity(org.semanticweb.owlapi.model.OWLEntity entity)
      Description copied from class: ONTObjectImpl
      Answers true iff the given entity is present in the object's signature.
      Overrides:
      containsEntity in class ONTObjectImpl
      Parameters:
      entity - OWLEntity, not null
      Returns:
      boolean
    • getSignatureSet

      public Set<org.semanticweb.owlapi.model.OWLEntity> getSignatureSet()
      Description copied from class: OWLObjectImpl
      Gets the signature of this object. The set is a copy, changes are not reflected back.
      Overrides:
      getSignatureSet in class ONTObjectImpl
      Returns:
      a modifiable sorted Set of entities that represents the signature of this object
    • getDatatypeSet

      public Set<org.semanticweb.owlapi.model.OWLDatatype> getDatatypeSet()
      Description copied from class: OWLObjectImpl
      Gets the datatypes that are in the signature of this object. The set is a copy, changes are not reflected back.
      Overrides:
      getDatatypeSet in class ONTObjectImpl
      Returns:
      a modifiable sorted Set of the datatypes that are in the signature of this object
    • getAnnotationPropertySet

      public Set<org.semanticweb.owlapi.model.OWLAnnotationProperty> getAnnotationPropertySet()
      Description copied from class: OWLObjectImpl
      Obtains the annotation properties that are in the signature of this object. The set is a copy, changes are not reflected back.
      Overrides:
      getAnnotationPropertySet in class ONTObjectImpl
      Returns:
      a modifiable sorted Set of the annotation properties that are in the signature of this object
    • canContainAnonymousIndividuals

      public boolean canContainAnonymousIndividuals()
      Description copied from interface: ONTComposite
      Answers true if this object-container is allowed to contain anonymous individuals.
      Specified by:
      canContainAnonymousIndividuals in interface ONTComposite
      Returns:
      boolean
    • isAnnotated

      public boolean isAnnotated()
      Description copied from interface: WithAnnotations
      Answers true if this object (axiom or annotation) has sub-annotations.
      Specified by:
      isAnnotated in interface org.semanticweb.owlapi.model.OWLAxiom
      Specified by:
      isAnnotated in interface WithAnnotations
      Specified by:
      isAnnotated in interface WithoutAnnotations
      Returns:
      boolean
      See Also:
      • OWLAxiom.isAnnotated()
    • isClassExpression

      default boolean isClassExpression()
      Answers true iff this is an OWL Class Expression.
      Returns:
      boolean
    • isAnonymousIndividual

      default boolean isAnonymousIndividual()
      Answers true iff this is an OWL Anonymous Individual.
      Returns:
      boolean
    • isNamedClass

      default boolean isNamedClass()
      Answers true iff this is an OWL Class.
      Returns:
      boolean
    • isNamedIndividual

      default boolean isNamedIndividual()
      Answers true iff this is an OWL Named Individual.
      Returns:
      boolean
    • isDatatype

      default boolean isDatatype()
      Answers true iff this is an OWL Datatype.
      Returns:
      boolean
    • isObjectProperty

      default boolean isObjectProperty()
      Answers true iff this is an OWL Object Property.
      Returns:
      boolean
    • isDataProperty

      default boolean isDataProperty()
      Answers true iff this is an OWL Data Property.
      Returns:
      boolean
    • isAnnotationProperty

      default boolean isAnnotationProperty()
      Answers true iff this is an OWL Annotation Property.
      Returns:
      boolean