Class InverseFunctionalObjectPropertyTranslator.AxiomImpl.ComplexImpl

java.lang.Object
com.github.owlcs.ontapi.owlapi.OWLObjectImpl
com.github.owlcs.ontapi.internal.objects.ONTObjectImpl
com.github.owlcs.ontapi.internal.objects.ONTStatementImpl
com.github.owlcs.ontapi.internal.objects.ONTAxiomImpl<org.semanticweb.owlapi.model.OWLInverseFunctionalObjectPropertyAxiom>
com.github.owlcs.ontapi.internal.axioms.AbstractPropertyTypeTranslator.UnaryAxiomImpl<org.semanticweb.owlapi.model.OWLInverseFunctionalObjectPropertyAxiom,org.semanticweb.owlapi.model.OWLObjectPropertyExpression>
com.github.owlcs.ontapi.internal.axioms.AbstractPropertyTypeTranslator.ObjectAxiomImpl<org.semanticweb.owlapi.model.OWLInverseFunctionalObjectPropertyAxiom>
com.github.owlcs.ontapi.internal.axioms.InverseFunctionalObjectPropertyTranslator.AxiomImpl
com.github.owlcs.ontapi.internal.axioms.InverseFunctionalObjectPropertyTranslator.AxiomImpl.ComplexImpl
All Implemented Interfaces:
com.github.owlcs.ontapi.internal.axioms.WithOneObject.Complex<InverseFunctionalObjectPropertyTranslator.AxiomImpl.ComplexImpl,org.semanticweb.owlapi.model.OWLObjectPropertyExpression>, HasConfig, HasObjectFactory, AsStatement, ModelObject<org.semanticweb.owlapi.model.OWLInverseFunctionalObjectPropertyAxiom>, ONTComposite, WithAnnotations, WithContent<InverseFunctionalObjectPropertyTranslator.AxiomImpl.ComplexImpl>, ONTObject<org.semanticweb.owlapi.model.OWLInverseFunctionalObjectPropertyAxiom>, WithMerge<ONTObject<org.semanticweb.owlapi.model.OWLInverseFunctionalObjectPropertyAxiom>>, Serializable, Comparable<org.semanticweb.owlapi.model.OWLObject>, org.apache.jena.graph.FrontsTriple, org.semanticweb.owlapi.model.HasAnnotationPropertiesInSignature, org.semanticweb.owlapi.model.HasAnnotations, org.semanticweb.owlapi.model.HasAnonymousIndividuals, org.semanticweb.owlapi.model.HasClassesInSignature, org.semanticweb.owlapi.model.HasComponents, org.semanticweb.owlapi.model.HasContainsEntityInSignature, org.semanticweb.owlapi.model.HasDataPropertiesInSignature, org.semanticweb.owlapi.model.HasDatatypesInSignature, org.semanticweb.owlapi.model.HasHashIndex, org.semanticweb.owlapi.model.HasIndex, org.semanticweb.owlapi.model.HasIndividualsInSignature, org.semanticweb.owlapi.model.HasObjectPropertiesInSignature, org.semanticweb.owlapi.model.HasProperty<org.semanticweb.owlapi.model.OWLObjectPropertyExpression>, org.semanticweb.owlapi.model.HasSignature, org.semanticweb.owlapi.model.IsAnonymous, org.semanticweb.owlapi.model.OWLAxiom, org.semanticweb.owlapi.model.OWLInverseFunctionalObjectPropertyAxiom, org.semanticweb.owlapi.model.OWLLogicalAxiom, org.semanticweb.owlapi.model.OWLObject, org.semanticweb.owlapi.model.OWLObjectPropertyAxiom, org.semanticweb.owlapi.model.OWLObjectPropertyCharacteristicAxiom, org.semanticweb.owlapi.model.OWLPropertyAxiom, org.semanticweb.owlapi.model.OWLSubClassOfAxiomShortCut, org.semanticweb.owlapi.model.OWLUnaryPropertyAxiom<org.semanticweb.owlapi.model.OWLObjectPropertyExpression>
Enclosing class:
InverseFunctionalObjectPropertyTranslator.AxiomImpl

public static class InverseFunctionalObjectPropertyTranslator.AxiomImpl.ComplexImpl extends InverseFunctionalObjectPropertyTranslator.AxiomImpl implements com.github.owlcs.ontapi.internal.axioms.WithOneObject.Complex<InverseFunctionalObjectPropertyTranslator.AxiomImpl.ComplexImpl,org.semanticweb.owlapi.model.OWLObjectPropertyExpression>
An OWLInverseFunctionalObjectPropertyAxiom that either has annotations or an anonymous object property expression (inverse object property) in the main triple's subject position. It has a public constructor since this class is more generic then InverseFunctionalObjectPropertyTranslator.AxiomImpl.SimpleImpl.
See Also:
  • Field Details

  • Constructor Details

    • ComplexImpl

      public ComplexImpl(org.apache.jena.graph.Triple t, Supplier<org.apache.jena.ontapi.model.OntModel> m)
  • Method Details

    • getContentCache

      Description copied from interface: WithContent
      Returns the content-cache-container, which is created by the method WithContent.createContentCache().
      Specified by:
      getContentCache in interface WithContent<InverseFunctionalObjectPropertyTranslator.AxiomImpl.ComplexImpl>
      Returns:
      InternalCache.Loading for an array
      See Also:
    • sameContent

      protected boolean sameContent(ONTStatementImpl other)
      Description copied from class: ONTStatementImpl
      Answers true if this object and the given have the same content. Two OWLObjects may have same content, but different base triples (see ONTStatementImpl.sameTriple(ONTStatementImpl)).
      Overrides:
      sameContent in class AbstractPropertyTypeTranslator.ObjectAxiomImpl<org.semanticweb.owlapi.model.OWLInverseFunctionalObjectPropertyAxiom>
      Parameters:
      other - ONTStatementImpl, not null
      Returns:
      boolean
    • merge

      public ONTObject<org.semanticweb.owlapi.model.OWLInverseFunctionalObjectPropertyAxiom> merge(ONTObject<org.semanticweb.owlapi.model.OWLInverseFunctionalObjectPropertyAxiom> other)
      Description copied from interface: WithMerge
      Merges this object and the given other into a new one of the same type WithMerge.
      Specified by:
      merge in interface WithMerge<ONTObject<org.semanticweb.owlapi.model.OWLInverseFunctionalObjectPropertyAxiom>>
      Overrides:
      merge in class ONTAxiomImpl<org.semanticweb.owlapi.model.OWLInverseFunctionalObjectPropertyAxiom>
      Parameters:
      other - that equals to this object, not null
      Returns:
      a new WithMerge which equal to this
    • findURISubject

      ONTObject<? extends org.semanticweb.owlapi.model.OWLObjectPropertyExpression> findURISubject(ModelObjectFactory factory)
    • fetchONTSubject

      ONTObject<? extends org.semanticweb.owlapi.model.OWLObjectPropertyExpression> fetchONTSubject(org.apache.jena.ontapi.model.OntStatement statement, ModelObjectFactory factory)
    • getONTValue

      default ONTObject<? extends org.semanticweb.owlapi.model.OWLObjectPropertyExpression> getONTValue()
    • getOWLComponentsAsSet

      default Set<? extends org.semanticweb.owlapi.model.OWLObject> getOWLComponentsAsSet(ModelObjectFactory factory)
    • hasURIObject

      default boolean hasURIObject()
      Answers true iff the subject is a URI resource.
      Returns:
      boolean
    • hasURISubject

      default boolean hasURISubject()
      Answers true iff the object is a URI resource.
      Returns:
      boolean
    • getSubjectURI

      default String getSubjectURI()
      Answers a URI of the triple's subject.
      Returns:
      URI of the subject
      Throws:
      RuntimeException - in case the main triple has no subject uri (b-node instead)
    • getObjectURI

      default String getObjectURI()
      Answers a URI of the triple's object.
      Returns:
      URI of the object
      Throws:
      RuntimeException - in case the main triple has no object uri (b-node or literal instead)
    • getOWLComponentsAsSet

      default Set<? extends org.semanticweb.owlapi.model.OWLObject> getOWLComponentsAsSet()
      Gets all OWL characteristic components in the form of Set.
      Returns:
      a sorted Set of OWLObjects
    • isClassExpression

      default boolean isClassExpression()
      Answers true iff this is an OWL Class Expression.
      Returns:
      boolean
    • isAnonymousIndividual

      default boolean isAnonymousIndividual()
      Answers true iff this is an OWL Anonymous Individual.
      Returns:
      boolean
    • isNamedClass

      default boolean isNamedClass()
      Answers true iff this is an OWL Class.
      Returns:
      boolean
    • isNamedIndividual

      default boolean isNamedIndividual()
      Answers true iff this is an OWL Named Individual.
      Returns:
      boolean
    • isDatatype

      default boolean isDatatype()
      Answers true iff this is an OWL Datatype.
      Returns:
      boolean
    • isObjectProperty

      default boolean isObjectProperty()
      Answers true iff this is an OWL Object Property.
      Returns:
      boolean
    • isDataProperty

      default boolean isDataProperty()
      Answers true iff this is an OWL Data Property.
      Returns:
      boolean
    • isAnnotationProperty

      default boolean isAnnotationProperty()
      Answers true iff this is an OWL Annotation Property.
      Returns:
      boolean