Class IrreflexiveObjectPropertyTranslator

java.lang.Object
com.github.owlcs.ontapi.internal.BaseSearcher
com.github.owlcs.ontapi.internal.AxiomTranslator<org.semanticweb.owlapi.model.OWLIrreflexiveObjectPropertyAxiom>
com.github.owlcs.ontapi.internal.axioms.AbstractPropertyTypeTranslator<org.semanticweb.owlapi.model.OWLIrreflexiveObjectPropertyAxiom,org.apache.jena.ontapi.model.OntObjectProperty>
com.github.owlcs.ontapi.internal.axioms.IrreflexiveObjectPropertyTranslator
All Implemented Interfaces:
ObjectsSearcher<org.semanticweb.owlapi.model.OWLIrreflexiveObjectPropertyAxiom>

public class IrreflexiveObjectPropertyTranslator extends AbstractPropertyTypeTranslator<org.semanticweb.owlapi.model.OWLIrreflexiveObjectPropertyAxiom,org.apache.jena.ontapi.model.OntObjectProperty>
A translator that provides OWLIrreflexiveObjectPropertyAxiom implementations. Object property with owl:IrreflexiveProperty type. Example:

 :ob-prop-2 rdf:type owl:ObjectProperty , owl:IrreflexiveProperty .
 
Created by @ssz on 18.10.2016.
  • Constructor Details

    • IrreflexiveObjectPropertyTranslator

      public IrreflexiveObjectPropertyTranslator()
  • Method Details

    • toAxiomImpl

      public ONTObject<org.semanticweb.owlapi.model.OWLIrreflexiveObjectPropertyAxiom> toAxiomImpl(org.apache.jena.ontapi.model.OntStatement statement, ModelObjectFactory factory, AxiomsSettings config)
      Description copied from class: AxiomTranslator
      Creates an OWL Axiom impl from a statement. Impl note: the method returns ONTAxiomImpl instance that is attached to the model.
      Specified by:
      toAxiomImpl in class AxiomTranslator<org.semanticweb.owlapi.model.OWLIrreflexiveObjectPropertyAxiom>
      Parameters:
      statement - OntStatement the statement which determines the axiom
      factory - ModelObjectFactory the data factory to create OWL-API objects
      config - AxiomsSettings to control the process
      Returns:
      ONTObject around OWLAxiom
    • toAxiomWrap

      public ONTObject<org.semanticweb.owlapi.model.OWLIrreflexiveObjectPropertyAxiom> toAxiomWrap(org.apache.jena.ontapi.model.OntStatement statement, ONTObjectFactory factory, AxiomsSettings config)
      Description copied from class: AxiomTranslator
      Creates an OWL Axiom wrapper from a statement. Impl note: the method returns a simple ONT Wrapper with an actual AxiomTranslator instance inside, that is created by the system-wide Data Factory.
      Specified by:
      toAxiomWrap in class AxiomTranslator<org.semanticweb.owlapi.model.OWLIrreflexiveObjectPropertyAxiom>
      Parameters:
      statement - OntStatement the statement which determines the axiom
      factory - ONTObjectFactory the data factory to create OWL-API objects
      config - AxiomsSettings to control the process
      Returns:
      ONTObject around OWLAxiom
    • getSearchTriples

      protected final Collection<org.apache.jena.graph.Triple> getSearchTriples(org.semanticweb.owlapi.model.OWLIrreflexiveObjectPropertyAxiom axiom)
      Description copied from class: AxiomTranslator
      Returns a collection of triples for search optimization. Usually, each of the returned triples has a URI-subject and URI-object. This is a helper method to optimize searching on a direct model (i.e., when there is no internal cache).
      Overrides:
      getSearchTriples in class AxiomTranslator<Axiom extends org.semanticweb.owlapi.model.OWLAxiom>
      Parameters:
      axiom - AxiomTranslator to extract triples, not null
      Returns:
      a Collection of Triples, can be empty