Class ObjectPropertyAssertionTranslator.AxiomImpl.SimpleImpl
java.lang.Object
com.github.owlcs.ontapi.owlapi.OWLObjectImpl
com.github.owlcs.ontapi.internal.objects.ONTObjectImpl
com.github.owlcs.ontapi.internal.objects.ONTStatementImpl
com.github.owlcs.ontapi.internal.objects.ONTAxiomImpl<org.semanticweb.owlapi.model.OWLObjectPropertyAssertionAxiom>
com.github.owlcs.ontapi.internal.axioms.AbstractPropertyAssertionTranslator.AssertionImpl<org.semanticweb.owlapi.model.OWLObjectPropertyAssertionAxiom,org.semanticweb.owlapi.model.OWLIndividual,org.semanticweb.owlapi.model.OWLObjectPropertyExpression,org.semanticweb.owlapi.model.OWLIndividual>
com.github.owlcs.ontapi.internal.axioms.ObjectPropertyAssertionTranslator.AxiomImpl
com.github.owlcs.ontapi.internal.axioms.ObjectPropertyAssertionTranslator.AxiomImpl.SimpleImpl
- All Implemented Interfaces:
com.github.owlcs.ontapi.internal.axioms.WithAssertion.Simple<org.semanticweb.owlapi.model.OWLIndividual,,org.semanticweb.owlapi.model.OWLObjectPropertyExpression, org.semanticweb.owlapi.model.OWLIndividual> HasConfig,HasObjectFactory,AsStatement,ModelObject<org.semanticweb.owlapi.model.OWLObjectPropertyAssertionAxiom>,ONTComposite,WithAnnotations,WithoutAnnotations,ONTObject<org.semanticweb.owlapi.model.OWLObjectPropertyAssertionAxiom>,WithMerge<ONTObject<org.semanticweb.owlapi.model.OWLObjectPropertyAssertionAxiom>>,Serializable,Comparable<org.semanticweb.owlapi.model.OWLObject>,org.apache.jena.graph.FrontsTriple,org.semanticweb.owlapi.model.HasAnnotationPropertiesInSignature,org.semanticweb.owlapi.model.HasAnnotations,org.semanticweb.owlapi.model.HasAnonymousIndividuals,org.semanticweb.owlapi.model.HasClassesInSignature,org.semanticweb.owlapi.model.HasComponents,org.semanticweb.owlapi.model.HasContainsEntityInSignature,org.semanticweb.owlapi.model.HasDataPropertiesInSignature,org.semanticweb.owlapi.model.HasDatatypesInSignature,org.semanticweb.owlapi.model.HasHashIndex,org.semanticweb.owlapi.model.HasIndex,org.semanticweb.owlapi.model.HasIndividualsInSignature,org.semanticweb.owlapi.model.HasObject<org.semanticweb.owlapi.model.OWLIndividual>,org.semanticweb.owlapi.model.HasObjectPropertiesInSignature,org.semanticweb.owlapi.model.HasProperty<org.semanticweb.owlapi.model.OWLObjectPropertyExpression>,org.semanticweb.owlapi.model.HasSignature,org.semanticweb.owlapi.model.HasSubject<org.semanticweb.owlapi.model.OWLIndividual>,org.semanticweb.owlapi.model.IsAnonymous,org.semanticweb.owlapi.model.OWLAxiom,org.semanticweb.owlapi.model.OWLIndividualAxiom,org.semanticweb.owlapi.model.OWLLogicalAxiom,org.semanticweb.owlapi.model.OWLObject,org.semanticweb.owlapi.model.OWLObjectPropertyAssertionAxiom,org.semanticweb.owlapi.model.OWLPropertyAssertionAxiom<org.semanticweb.owlapi.model.OWLObjectPropertyExpression,,org.semanticweb.owlapi.model.OWLIndividual> org.semanticweb.owlapi.model.OWLSubClassOfAxiomShortCut
- Enclosing class:
ObjectPropertyAssertionTranslator.AxiomImpl
public static class ObjectPropertyAssertionTranslator.AxiomImpl.SimpleImpl
extends ObjectPropertyAssertionTranslator.AxiomImpl
implements com.github.owlcs.ontapi.internal.axioms.WithAssertion.Simple<org.semanticweb.owlapi.model.OWLIndividual,org.semanticweb.owlapi.model.OWLObjectPropertyExpression,org.semanticweb.owlapi.model.OWLIndividual>
An
OWLObjectPropertyAssertionAxiom that has no sub-annotations.- See Also:
-
Nested Class Summary
Nested classes/interfaces inherited from class com.github.owlcs.ontapi.internal.axioms.ObjectPropertyAssertionTranslator.AxiomImpl
ObjectPropertyAssertionTranslator.AxiomImpl.SimpleImpl, ObjectPropertyAssertionTranslator.AxiomImpl.WithAnnotationsImpl -
Field Summary
Fields inherited from class com.github.owlcs.ontapi.internal.objects.ONTAxiomImpl
SET_HASH_CODEFields inherited from class com.github.owlcs.ontapi.internal.objects.ONTStatementImpl
object, predicate, subjectFields inherited from class com.github.owlcs.ontapi.internal.objects.ONTObjectImpl
modelFields inherited from class com.github.owlcs.ontapi.owlapi.OWLObjectImpl
DEFAULT_COMPARATOR, hashCode, NO_ANNOTATIONSFields inherited from interface com.github.owlcs.ontapi.internal.WithMerge
ONT_OBJECT_MERGER -
Constructor Summary
ConstructorsModifierConstructorDescriptionprotectedSimpleImpl(org.apache.jena.graph.Triple t, Supplier<org.apache.jena.ontapi.model.OntModel> m) -
Method Summary
Modifier and TypeMethodDescriptionbooleancontainsNamedIndividual(org.semanticweb.owlapi.model.OWLNamedIndividual individual) Answerstrueiff the given OWL named individual is present in the object's signature.default ONTObject<? extends org.semanticweb.owlapi.model.OWLIndividual> fetchONTObject(org.apache.jena.ontapi.model.OntStatement statement, ModelObjectFactory factory) default ONTObject<? extends org.semanticweb.owlapi.model.OWLObjectPropertyExpression> fetchONTPredicate(org.apache.jena.ontapi.model.OntStatement statement, ModelObjectFactory factory) default ONTObject<? extends org.semanticweb.owlapi.model.OWLIndividual> fetchONTSubject(org.apache.jena.ontapi.model.OntStatement statement, ModelObjectFactory factory) ONTObject<? extends org.semanticweb.owlapi.model.OWLIndividual> findONTObject(ModelObjectFactory factory) ONTObject<? extends org.semanticweb.owlapi.model.OWLObjectPropertyExpression> findONTPredicate(ModelObjectFactory factory) ONTObject<? extends org.semanticweb.owlapi.model.OWLIndividual> findONTSubject(ModelObjectFactory factory) Set<org.semanticweb.owlapi.model.OWLAnonymousIndividual> Gets the anonymous individuals occurring in this object.default org.semanticweb.owlapi.model.OWLIndividualdefault org.semanticweb.owlapi.model.OWLObjectPropertyExpressiondefault org.semanticweb.owlapi.model.OWLIndividualdefault StringAnswers a URI of the triple's object.default ONTObject<? extends org.semanticweb.owlapi.model.OWLIndividual> default ONTObject<? extends org.semanticweb.owlapi.model.OWLObjectPropertyExpression> default ONTObject<? extends org.semanticweb.owlapi.model.OWLIndividual> default Set<? extends org.semanticweb.owlapi.model.OWLObject> Gets all OWL characteristic components in the form ofSet.default Set<? extends org.semanticweb.owlapi.model.OWLObject> getOWLComponentsAsSet(ModelObjectFactory factory) default org.semanticweb.owlapi.model.OWLObjectPropertyExpressionSet<org.semanticweb.owlapi.model.OWLEntity> Gets the signature of this object.default org.semanticweb.owlapi.model.OWLIndividualdefault StringAnswers a URI of the triple's subject.default org.semanticweb.owlapi.model.OWLIndividualgetValue()default booleanAnswerstrueiff the subject is a URI resource.default booleanAnswerstrueiff the object is a URI resource.default booleanAnswerstrueiff this is anOWL Annotation Property.default booleanAnswerstrueiff this is anOWL Anonymous Individual.default booleanAnswerstrueiff this is anOWL Class Expression.default booleanAnswerstrueiff this is anOWL Data Property.default booleanAnswerstrueiff this is anOWL Datatype.default booleanAnswerstrueiff this is anOWL Class.default booleanAnswerstrueiff this is anOWL Named Individual.default booleanAnswerstrueiff this is anOWL Object Property.objects()Lists all components in the form ofStream.Methods inherited from class com.github.owlcs.ontapi.internal.axioms.ObjectPropertyAssertionTranslator.AxiomImpl
asOWLSubClassOfAxiom, canContainAnnotationProperties, canContainAnonymousIndividuals, canContainDataProperties, canContainDatatypes, collectNamedIndividuals, containsObjectProperty, create, createAnnotatedAxiom, findONTObject, findONTPredicate, findONTProperty, findONTSubject, getNamedIndividualSet, getObjectPropertySet, getSimplified, isInSimplifiedFormMethods inherited from class com.github.owlcs.ontapi.internal.axioms.AbstractPropertyAssertionTranslator.AssertionImpl
canContainClassExpressions, canContainNamedClasses, findByURIOrBlankId, getObject, getProperty, getSubject, getValue, sameContentMethods inherited from class com.github.owlcs.ontapi.internal.objects.ONTAxiomImpl
collectAnnotations, eraseModel, getAnnotatedAxiom, getAxiomWithoutAnnotations, getConfig, getNNF, getObjectURI, getOWLObject, getSubjectBlankNodeId, getSubjectURI, hasURIObject, hasURIResource, hasURIResource, hasURISubject, merge, setHashCode, triplesMethods inherited from class com.github.owlcs.ontapi.internal.objects.ONTStatementImpl
appendAnnotations, asStatement, asTriple, equals, factoryAnnotations, fromNode, getObjectNode, getPredicateNode, getSubjectNode, sameAs, sameComponents, sameObject, samePredicate, sameSubject, sameTriple, stripMethods inherited from class com.github.owlcs.ontapi.internal.objects.ONTObjectImpl
containsAnnotationProperty, containsDataProperty, containsDatatype, containsEntity, containsEntityInSignature, containsNamedClass, createContentSet, eraseModel, getAnnotationPropertySet, getClassExpressionSet, getDataPropertySet, getDatatypeSet, getModel, getNamedClassSet, getObjectFactory, getPersonalityModel, toStringMethods inherited from class com.github.owlcs.ontapi.owlapi.OWLObjectImpl
annotationPropertiesInSignature, anonymousIndividuals, classesInSignature, compareIterators, compareTo, createSet, createSet, createSortedSet, createSortedSet, dataPropertiesInSignature, datatypesInSignature, equalIterators, equalStreams, forOutput, getAnnotationPropertiesInSignature, getAnonymousIndividuals, getClassesInSignature, getDataPropertiesInSignature, getDatatypesInSignature, getIndividualsInSignature, getNestedClassExpressions, getObjectPropertiesInSignature, getSignature, hashCode, individualsInSignature, mergeAnnotations, nestedClassExpressions, notSame, objectPropertiesInSignature, prepareAnnotations, signature, toContentListMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface com.github.owlcs.ontapi.internal.objects.AsStatement
asStatement, asTripleMethods inherited from interface java.lang.Comparable
compareToMethods inherited from interface org.semanticweb.owlapi.model.HasAnnotationPropertiesInSignature
annotationPropertiesInSignature, getAnnotationPropertiesInSignatureMethods inherited from interface org.semanticweb.owlapi.model.HasAnnotations
annotations, annotations, getAnnotations, getAnnotationsMethods inherited from interface org.semanticweb.owlapi.model.HasAnonymousIndividuals
anonymousIndividuals, getAnonymousIndividualsMethods inherited from interface org.semanticweb.owlapi.model.HasClassesInSignature
classesInSignature, getClassesInSignatureMethods inherited from interface org.semanticweb.owlapi.model.HasContainsEntityInSignature
containsEntityInSignatureMethods inherited from interface org.semanticweb.owlapi.model.HasDataPropertiesInSignature
dataPropertiesInSignature, getDataPropertiesInSignatureMethods inherited from interface org.semanticweb.owlapi.model.HasDatatypesInSignature
datatypesInSignature, getDatatypesInSignatureMethods inherited from interface org.semanticweb.owlapi.model.HasIndividualsInSignature
getIndividualsInSignature, individualsInSignatureMethods inherited from interface com.github.owlcs.ontapi.internal.HasObjectFactory
getDataFactory, getObjectFactoryMethods inherited from interface org.semanticweb.owlapi.model.HasObjectPropertiesInSignature
getObjectPropertiesInSignature, objectPropertiesInSignatureMethods inherited from interface org.semanticweb.owlapi.model.HasSignature
getSignature, signature, unsortedSignatureMethods inherited from interface org.semanticweb.owlapi.model.IsAnonymous
isAnonymous, isNamedMethods inherited from interface com.github.owlcs.ontapi.internal.objects.ModelObject
getModelMethods inherited from interface com.github.owlcs.ontapi.internal.objects.ONTComposite
canContainAnnotationProperties, canContainAnonymousIndividuals, canContainClassExpressions, canContainDataProperties, canContainDatatypes, canContainNamedClasses, canContainNamedIndividuals, canContainObjectPropertiesMethods inherited from interface org.semanticweb.owlapi.model.OWLAxiom
equalsIgnoreAnnotations, getAnnotatedAxiom, getAnnotatedAxiom, getAnnotatedAxiom, getAxiomWithoutAnnotations, getNNF, isAnnotationAxiom, isAxiom, isIndividual, isOfType, isOfType, isOfType, typeIndexMethods inherited from interface org.semanticweb.owlapi.model.OWLLogicalAxiom
isLogicalAxiomMethods inherited from interface org.semanticweb.owlapi.model.OWLObject
getNestedClassExpressions, hasSharedStructure, isAnonymousExpression, isBottomEntity, isIRI, isOntology, isTopEntity, nestedClassExpressionsMethods inherited from interface org.semanticweb.owlapi.model.OWLObjectPropertyAssertionAxiom
accept, accept, accept, accept, getAxiomType, getAxiomWithoutAnnotations, hashIndexMethods inherited from interface org.semanticweb.owlapi.model.OWLPropertyAssertionAxiom
components, componentsAnnotationsFirst, componentsWithoutAnnotations, getObject, getProperty, getSubject, initHashCodeMethods inherited from interface com.github.owlcs.ontapi.internal.axioms.WithAssertion.Simple
isAnnotatedMethods inherited from interface com.github.owlcs.ontapi.internal.objects.WithoutAnnotations
annotations, annotationsAsList
-
Constructor Details
-
SimpleImpl
protected SimpleImpl(org.apache.jena.graph.Triple t, Supplier<org.apache.jena.ontapi.model.OntModel> m)
-
-
Method Details
-
getAnonymousIndividualSet
Description copied from class:OWLObjectImplGets the anonymous individuals occurring in this object. The set is a copy, changes are not reflected back.- Overrides:
getAnonymousIndividualSetin classONTObjectImpl- Returns:
- a modifiable sorted
Setof the anonymous individuals
-
getSignatureSet
Description copied from class:OWLObjectImplGets the signature of this object. The set is a copy, changes are not reflected back.- Overrides:
getSignatureSetin classONTObjectImpl- Returns:
- a modifiable sorted
Setof entities that represents the signature of this object
-
containsNamedIndividual
public boolean containsNamedIndividual(org.semanticweb.owlapi.model.OWLNamedIndividual individual) Description copied from class:ONTObjectImplAnswerstrueiff the given OWL named individual is present in the object's signature.- Overrides:
containsNamedIndividualin classONTObjectImpl- Parameters:
individual-OWLNamedIndividual, notnull- Returns:
- boolean
-
findONTSubject
ONTObject<? extends org.semanticweb.owlapi.model.OWLIndividual> findONTSubject(ModelObjectFactory factory) -
findONTPredicate
ONTObject<? extends org.semanticweb.owlapi.model.OWLObjectPropertyExpression> findONTPredicate(ModelObjectFactory factory) -
findONTObject
ONTObject<? extends org.semanticweb.owlapi.model.OWLIndividual> findONTObject(ModelObjectFactory factory) -
fetchONTSubject
default ONTObject<? extends org.semanticweb.owlapi.model.OWLIndividual> fetchONTSubject(org.apache.jena.ontapi.model.OntStatement statement, ModelObjectFactory factory) -
fetchONTPredicate
default ONTObject<? extends org.semanticweb.owlapi.model.OWLObjectPropertyExpression> fetchONTPredicate(org.apache.jena.ontapi.model.OntStatement statement, ModelObjectFactory factory) -
fetchONTObject
default ONTObject<? extends org.semanticweb.owlapi.model.OWLIndividual> fetchONTObject(org.apache.jena.ontapi.model.OntStatement statement, ModelObjectFactory factory) -
getSubject
default org.semanticweb.owlapi.model.OWLIndividual getSubject()- Specified by:
getSubjectin interfaceorg.semanticweb.owlapi.model.HasSubject<S extends org.semanticweb.owlapi.model.OWLObject>
-
getProperty
default org.semanticweb.owlapi.model.OWLObjectPropertyExpression getProperty()- Specified by:
getPropertyin interfaceorg.semanticweb.owlapi.model.HasProperty<S extends org.semanticweb.owlapi.model.OWLObject>
-
getValue
default org.semanticweb.owlapi.model.OWLIndividual getValue() -
getONTSubject
-
getONTPredicate
default ONTObject<? extends org.semanticweb.owlapi.model.OWLObjectPropertyExpression> getONTPredicate() -
getONTObject
-
getFSubject
default org.semanticweb.owlapi.model.OWLIndividual getFSubject() -
getFPredicate
default org.semanticweb.owlapi.model.OWLObjectPropertyExpression getFPredicate() -
getFObject
default org.semanticweb.owlapi.model.OWLIndividual getFObject() -
getOWLComponentsAsSet
default Set<? extends org.semanticweb.owlapi.model.OWLObject> getOWLComponentsAsSet(ModelObjectFactory factory) -
objects
Description copied from interface:ONTCompositeLists all components in the form ofStream. Neither this object nor parts of its components are not included in the result: it content only top-level direct components. Note thatHasComponents.components()may also contain non-OWLObjectthings: integers (e.g. cardinality),Lists (e.g.ObjectOneOf), etc, while this method is only forOWLObjects which are represented asONTObjects.- Specified by:
objectsin interfaceONTComposite- Returns:
StreamofONTObjects- See Also:
-
hasURIObject
default boolean hasURIObject()Answerstrueiff the subject is a URI resource.- Returns:
- boolean
-
hasURISubject
default boolean hasURISubject()Answerstrueiff the object is a URI resource.- Returns:
- boolean
-
getSubjectURI
Answers a URI of the triple's subject.- Returns:
- URI of the subject
- Throws:
RuntimeException- in case the main triple has no subject uri (b-node instead)
-
getObjectURI
Answers a URI of the triple's object.- Returns:
- URI of the object
- Throws:
RuntimeException- in case the main triple has no object uri (b-node or literal instead)
-
getOWLComponentsAsSet
Gets all OWL characteristic components in the form ofSet.- Returns:
- a sorted
SetofOWLObjects
-
isClassExpression
default boolean isClassExpression()Answerstrueiff this is anOWL Class Expression.- Returns:
- boolean
-
isAnonymousIndividual
default boolean isAnonymousIndividual()Answerstrueiff this is anOWL Anonymous Individual.- Returns:
- boolean
-
isNamedClass
default boolean isNamedClass()Answerstrueiff this is anOWL Class.- Returns:
- boolean
-
isNamedIndividual
default boolean isNamedIndividual()Answerstrueiff this is anOWL Named Individual.- Returns:
- boolean
-
isDatatype
default boolean isDatatype()Answerstrueiff this is anOWL Datatype.- Returns:
- boolean
-
isObjectProperty
default boolean isObjectProperty()Answerstrueiff this is anOWL Object Property.- Returns:
- boolean
-
isDataProperty
default boolean isDataProperty()Answerstrueiff this is anOWL Data Property.- Returns:
- boolean
-
isAnnotationProperty
default boolean isAnnotationProperty()Answerstrueiff this is anOWL Annotation Property.- Returns:
- boolean
-