Class SubAnnotationPropertyOfTranslator.AxiomImpl.SimpleImpl

java.lang.Object
com.github.owlcs.ontapi.owlapi.OWLObjectImpl
com.github.owlcs.ontapi.internal.objects.ONTObjectImpl
com.github.owlcs.ontapi.internal.objects.ONTStatementImpl
com.github.owlcs.ontapi.internal.objects.ONTAxiomImpl<org.semanticweb.owlapi.model.OWLSubAnnotationPropertyOfAxiom>
com.github.owlcs.ontapi.internal.axioms.AbstractSubPropertyTranslator.SubPropertyAxiomImpl<org.semanticweb.owlapi.model.OWLSubAnnotationPropertyOfAxiom,org.semanticweb.owlapi.model.OWLAnnotationProperty>
com.github.owlcs.ontapi.internal.axioms.SubAnnotationPropertyOfTranslator.AxiomImpl
com.github.owlcs.ontapi.internal.axioms.SubAnnotationPropertyOfTranslator.AxiomImpl.SimpleImpl
All Implemented Interfaces:
com.github.owlcs.ontapi.internal.axioms.WithTwoObjects.Simple<org.semanticweb.owlapi.model.OWLAnnotationProperty,org.semanticweb.owlapi.model.OWLAnnotationProperty>, com.github.owlcs.ontapi.internal.axioms.WithTwoObjects.Unary<org.semanticweb.owlapi.model.OWLAnnotationProperty>, com.github.owlcs.ontapi.internal.axioms.WithTwoObjects.UnarySimple<org.semanticweb.owlapi.model.OWLAnnotationProperty>, HasConfig, HasObjectFactory, AsStatement, ModelObject<org.semanticweb.owlapi.model.OWLSubAnnotationPropertyOfAxiom>, ONTComposite, WithAnnotations, WithoutAnnotations, ONTObject<org.semanticweb.owlapi.model.OWLSubAnnotationPropertyOfAxiom>, WithMerge<ONTObject<org.semanticweb.owlapi.model.OWLSubAnnotationPropertyOfAxiom>>, Serializable, Comparable<org.semanticweb.owlapi.model.OWLObject>, org.apache.jena.graph.FrontsTriple, org.semanticweb.owlapi.model.HasAnnotationPropertiesInSignature, org.semanticweb.owlapi.model.HasAnnotations, org.semanticweb.owlapi.model.HasAnonymousIndividuals, org.semanticweb.owlapi.model.HasClassesInSignature, org.semanticweb.owlapi.model.HasComponents, org.semanticweb.owlapi.model.HasContainsEntityInSignature, org.semanticweb.owlapi.model.HasDataPropertiesInSignature, org.semanticweb.owlapi.model.HasDatatypesInSignature, org.semanticweb.owlapi.model.HasHashIndex, org.semanticweb.owlapi.model.HasIndex, org.semanticweb.owlapi.model.HasIndividualsInSignature, org.semanticweb.owlapi.model.HasObjectPropertiesInSignature, org.semanticweb.owlapi.model.HasSignature, org.semanticweb.owlapi.model.IsAnonymous, org.semanticweb.owlapi.model.OWLAnnotationAxiom, org.semanticweb.owlapi.model.OWLAnnotationObject, org.semanticweb.owlapi.model.OWLAxiom, org.semanticweb.owlapi.model.OWLObject, org.semanticweb.owlapi.model.OWLSubAnnotationPropertyOfAxiom
Enclosing class:
SubAnnotationPropertyOfTranslator.AxiomImpl

protected static class SubAnnotationPropertyOfTranslator.AxiomImpl.SimpleImpl extends SubAnnotationPropertyOfTranslator.AxiomImpl implements com.github.owlcs.ontapi.internal.axioms.WithTwoObjects.UnarySimple<org.semanticweb.owlapi.model.OWLAnnotationProperty>
An OWLSubAnnotationPropertyOfAxiom that has named object properties as subject and object and has no annotations.
See Also:
  • Constructor Details

    • SimpleImpl

      protected SimpleImpl(org.apache.jena.graph.Triple t, Supplier<org.apache.jena.ontapi.model.OntModel> m)
  • Method Details

    • getAnnotationPropertySet

      public Set<org.semanticweb.owlapi.model.OWLAnnotationProperty> getAnnotationPropertySet()
      Description copied from class: OWLObjectImpl
      Obtains the annotation properties that are in the signature of this object. The set is a copy, changes are not reflected back.
      Overrides:
      getAnnotationPropertySet in class ONTObjectImpl
      Returns:
      a modifiable sorted Set of the annotation properties that are in the signature of this object
    • getSignatureSet

      public Set<org.semanticweb.owlapi.model.OWLEntity> getSignatureSet()
      Description copied from class: OWLObjectImpl
      Gets the signature of this object. The set is a copy, changes are not reflected back.
      Overrides:
      getSignatureSet in class ONTObjectImpl
      Returns:
      a modifiable sorted Set of entities that represents the signature of this object
    • containsAnnotationProperty

      public boolean containsAnnotationProperty(org.semanticweb.owlapi.model.OWLAnnotationProperty property)
      Description copied from class: ONTObjectImpl
      Answers true iff the given OWL annotation property is present in the object's signature.
      Overrides:
      containsAnnotationProperty in class ONTObjectImpl
      Parameters:
      property - OWLAnnotationProperty, not null
      Returns:
      boolean
    • subjectFromStatement

      ONTObject<? extends org.semanticweb.owlapi.model.OWLAnnotationProperty> subjectFromStatement(org.apache.jena.ontapi.model.OntStatement statement, ModelObjectFactory factory)
      Picks the ONTObject that matches the subject of the given statement using the factory.
      Parameters:
      statement - OntStatement, the source to parse, not null
      factory - ModelObjectFactory to fetch an ONTObject, not null
      Returns:
      an ONTObject that can be seen as wrapper of WithTwoObjects
    • objectFromStatement

      ONTObject<? extends org.semanticweb.owlapi.model.OWLAnnotationProperty> objectFromStatement(org.apache.jena.ontapi.model.OntStatement statement, ModelObjectFactory factory)
      Picks the ONTObject that matches the object of the given statement using the factory.
      Parameters:
      statement - OntStatement, the source to parse, not null
      factory - ModelObjectFactory to fetch an ONTObject, not null
      Returns:
      an ONTObject that can be seen as wrapper of WithTwoObjects
    • getONTSubject

      default ONTObject<? extends org.semanticweb.owlapi.model.OWLAnnotationProperty> getONTSubject()
      Gets the subject from the base triple of this axiom.
      Returns:
      ONTObject with WithTwoObjects
    • getONTObject

      default ONTObject<? extends org.semanticweb.owlapi.model.OWLAnnotationProperty> getONTObject()
      Gets the object from the base triple of this axiom.
      Returns:
      ONTObject with WithTwoObjects
    • getOWLComponentsAsSet

      default Set<? extends org.semanticweb.owlapi.model.OWLObject> getOWLComponentsAsSet(ModelObjectFactory factory)
    • hasURIObject

      default boolean hasURIObject()
      Answers true iff the subject is a URI resource.
      Returns:
      boolean
    • hasURISubject

      default boolean hasURISubject()
      Answers true iff the object is a URI resource.
      Returns:
      boolean
    • getSubjectURI

      default String getSubjectURI()
      Answers a URI of the triple's subject.
      Returns:
      URI of the subject
      Throws:
      RuntimeException - in case the main triple has no subject uri (b-node instead)
    • getObjectURI

      default String getObjectURI()
      Answers a URI of the triple's object.
      Returns:
      URI of the object
      Throws:
      RuntimeException - in case the main triple has no object uri (b-node or literal instead)
    • getOWLComponentsAsSet

      default Set<? extends org.semanticweb.owlapi.model.OWLObject> getOWLComponentsAsSet()
      Gets all OWL characteristic components in the form of Set.
      Returns:
      a sorted Set of OWLObjects
    • isClassExpression

      default boolean isClassExpression()
      Answers true iff this is an OWL Class Expression.
      Returns:
      boolean
    • isAnonymousIndividual

      default boolean isAnonymousIndividual()
      Answers true iff this is an OWL Anonymous Individual.
      Returns:
      boolean
    • isNamedClass

      default boolean isNamedClass()
      Answers true iff this is an OWL Class.
      Returns:
      boolean
    • isNamedIndividual

      default boolean isNamedIndividual()
      Answers true iff this is an OWL Named Individual.
      Returns:
      boolean
    • isDatatype

      default boolean isDatatype()
      Answers true iff this is an OWL Datatype.
      Returns:
      boolean
    • isObjectProperty

      default boolean isObjectProperty()
      Answers true iff this is an OWL Object Property.
      Returns:
      boolean
    • isDataProperty

      default boolean isDataProperty()
      Answers true iff this is an OWL Data Property.
      Returns:
      boolean
    • isAnnotationProperty

      default boolean isAnnotationProperty()
      Answers true iff this is an OWL Annotation Property.
      Returns:
      boolean