Class SubClassOfTranslator.AxiomImpl.SimpleImpl

All Implemented Interfaces:
com.github.owlcs.ontapi.internal.axioms.WithTwoObjects.Simple<org.semanticweb.owlapi.model.OWLClassExpression,org.semanticweb.owlapi.model.OWLClassExpression>, com.github.owlcs.ontapi.internal.axioms.WithTwoObjects.Unary<org.semanticweb.owlapi.model.OWLClassExpression>, com.github.owlcs.ontapi.internal.axioms.WithTwoObjects.UnarySimple<org.semanticweb.owlapi.model.OWLClassExpression>, HasConfig, HasObjectFactory, AsStatement, ModelObject<org.semanticweb.owlapi.model.OWLSubClassOfAxiom>, ONTComposite, WithAnnotations, WithoutAnnotations, ONTObject<org.semanticweb.owlapi.model.OWLSubClassOfAxiom>, WithMerge<ONTObject<org.semanticweb.owlapi.model.OWLSubClassOfAxiom>>, Serializable, Comparable<org.semanticweb.owlapi.model.OWLObject>, org.apache.jena.graph.FrontsTriple, org.semanticweb.owlapi.model.HasAnnotationPropertiesInSignature, org.semanticweb.owlapi.model.HasAnnotations, org.semanticweb.owlapi.model.HasAnonymousIndividuals, org.semanticweb.owlapi.model.HasClassesInSignature, org.semanticweb.owlapi.model.HasComponents, org.semanticweb.owlapi.model.HasContainsEntityInSignature, org.semanticweb.owlapi.model.HasDataPropertiesInSignature, org.semanticweb.owlapi.model.HasDatatypesInSignature, org.semanticweb.owlapi.model.HasHashIndex, org.semanticweb.owlapi.model.HasIndex, org.semanticweb.owlapi.model.HasIndividualsInSignature, org.semanticweb.owlapi.model.HasObjectPropertiesInSignature, org.semanticweb.owlapi.model.HasSignature, org.semanticweb.owlapi.model.IsAnonymous, org.semanticweb.owlapi.model.OWLAxiom, org.semanticweb.owlapi.model.OWLClassAxiom, org.semanticweb.owlapi.model.OWLLogicalAxiom, org.semanticweb.owlapi.model.OWLObject, org.semanticweb.owlapi.model.OWLSubClassOfAxiom
Enclosing class:
SubClassOfTranslator.AxiomImpl

public static class SubClassOfTranslator.AxiomImpl.SimpleImpl extends SubClassOfTranslator.AxiomImpl implements com.github.owlcs.ontapi.internal.axioms.WithTwoObjects.UnarySimple<org.semanticweb.owlapi.model.OWLClassExpression>
An OWLSubClassOfAxiom that has named classes as subject and object and has no annotations.
See Also:
  • Constructor Details

    • SimpleImpl

      protected SimpleImpl(org.apache.jena.graph.Triple t, Supplier<org.apache.jena.ontapi.model.OntModel> m)
  • Method Details

    • sameContent

      protected boolean sameContent(ONTStatementImpl other)
      Description copied from class: ONTStatementImpl
      Answers true if this object and the given have the same content. Two OWLObjects may have same content, but different base triples (see ONTStatementImpl.sameTriple(ONTStatementImpl)).
      Specified by:
      sameContent in class ONTStatementImpl
      Parameters:
      other - ONTStatementImpl, not null
      Returns:
      boolean
    • getNamedClassSet

      public Set<org.semanticweb.owlapi.model.OWLClass> getNamedClassSet()
      Description copied from class: OWLObjectImpl
      Gets the classes in the signature of this object. The returned set is a subset of the signature, and is not backed by the signature; it is a modifiable collection and changes are not reflected by the signature.
      Overrides:
      getNamedClassSet in class ONTObjectImpl
      Returns:
      a modifiable sorted Set containing the classes that are in the signature of this object
    • getClassExpressionSet

      public Set<org.semanticweb.owlapi.model.OWLClassExpression> getClassExpressionSet()
      Description copied from class: OWLObjectImpl
      Gets all the nested (includes top level) class expressions that are used in this object. The set is a copy, changes are not reflected back.
      Overrides:
      getClassExpressionSet in class ONTObjectImpl
      Returns:
      a modifiable unordered Set of OWLClassExpressions that represent the nested class expressions used in this object
    • getSignatureSet

      public Set<org.semanticweb.owlapi.model.OWLEntity> getSignatureSet()
      Description copied from class: OWLObjectImpl
      Gets the signature of this object. The set is a copy, changes are not reflected back.
      Overrides:
      getSignatureSet in class ONTObjectImpl
      Returns:
      a modifiable sorted Set of entities that represents the signature of this object
    • containsNamedClass

      public boolean containsNamedClass(org.semanticweb.owlapi.model.OWLClass clazz)
      Description copied from class: ONTObjectImpl
      Answers true iff the given OWL class is present in the object's signature.
      Overrides:
      containsNamedClass in class ONTObjectImpl
      Parameters:
      clazz - OWLClass, not null
      Returns:
      boolean
    • canContainDatatypes

      public boolean canContainDatatypes()
      Description copied from interface: ONTComposite
      Answers true if this object-container may contain datatypes.
      Specified by:
      canContainDatatypes in interface ONTComposite
      Returns:
      boolean
    • canContainNamedIndividuals

      public boolean canContainNamedIndividuals()
      Description copied from interface: ONTComposite
      Answers true if this object-container is allowed to contain named individuals.
      Specified by:
      canContainNamedIndividuals in interface ONTComposite
      Returns:
      boolean
    • canContainDataProperties

      public boolean canContainDataProperties()
      Description copied from interface: ONTComposite
      Answers true if this object-container may contain data properties.
      Specified by:
      canContainDataProperties in interface ONTComposite
      Returns:
      boolean
    • canContainObjectProperties

      public boolean canContainObjectProperties()
      Description copied from interface: ONTComposite
      Answers true if this object-container may contain named object properties.
      Specified by:
      canContainObjectProperties in interface ONTComposite
      Returns:
      boolean
    • canContainAnnotationProperties

      public boolean canContainAnnotationProperties()
      Description copied from interface: ONTComposite
      Answers true if this object-container may contain annotation properties.
      Specified by:
      canContainAnnotationProperties in interface ONTComposite
      Overrides:
      canContainAnnotationProperties in class SubClassOfTranslator.AxiomImpl
      Returns:
      boolean
    • canContainAnonymousIndividuals

      public boolean canContainAnonymousIndividuals()
      Description copied from interface: ONTComposite
      Answers true if this object-container is allowed to contain anonymous individuals.
      Specified by:
      canContainAnonymousIndividuals in interface ONTComposite
      Returns:
      boolean
    • subjectFromStatement

      ONTObject<? extends org.semanticweb.owlapi.model.OWLClassExpression> subjectFromStatement(org.apache.jena.ontapi.model.OntStatement statement, ModelObjectFactory factory)
      Picks the ONTObject that matches the subject of the given statement using the factory.
      Parameters:
      statement - OntStatement, the source to parse, not null
      factory - ModelObjectFactory to fetch an ONTObject, not null
      Returns:
      an ONTObject that can be seen as wrapper of WithTwoObjects
    • objectFromStatement

      ONTObject<? extends org.semanticweb.owlapi.model.OWLClassExpression> objectFromStatement(org.apache.jena.ontapi.model.OntStatement statement, ModelObjectFactory factory)
      Picks the ONTObject that matches the object of the given statement using the factory.
      Parameters:
      statement - OntStatement, the source to parse, not null
      factory - ModelObjectFactory to fetch an ONTObject, not null
      Returns:
      an ONTObject that can be seen as wrapper of WithTwoObjects
    • getONTSubject

      default ONTObject<? extends org.semanticweb.owlapi.model.OWLClassExpression> getONTSubject()
      Gets the subject from the base triple of this axiom.
      Returns:
      ONTObject with WithTwoObjects
    • getONTObject

      default ONTObject<? extends org.semanticweb.owlapi.model.OWLClassExpression> getONTObject()
      Gets the object from the base triple of this axiom.
      Returns:
      ONTObject with WithTwoObjects
    • getOWLComponentsAsSet

      default Set<? extends org.semanticweb.owlapi.model.OWLObject> getOWLComponentsAsSet(ModelObjectFactory factory)
    • hasURIObject

      default boolean hasURIObject()
      Answers true iff the subject is a URI resource.
      Returns:
      boolean
    • hasURISubject

      default boolean hasURISubject()
      Answers true iff the object is a URI resource.
      Returns:
      boolean
    • getSubjectURI

      default String getSubjectURI()
      Answers a URI of the triple's subject.
      Returns:
      URI of the subject
      Throws:
      RuntimeException - in case the main triple has no subject uri (b-node instead)
    • getObjectURI

      default String getObjectURI()
      Answers a URI of the triple's object.
      Returns:
      URI of the object
      Throws:
      RuntimeException - in case the main triple has no object uri (b-node or literal instead)
    • getOWLComponentsAsSet

      default Set<? extends org.semanticweb.owlapi.model.OWLObject> getOWLComponentsAsSet()
      Gets all OWL characteristic components in the form of Set.
      Returns:
      a sorted Set of OWLObjects
    • isClassExpression

      default boolean isClassExpression()
      Answers true iff this is an OWL Class Expression.
      Returns:
      boolean
    • isAnonymousIndividual

      default boolean isAnonymousIndividual()
      Answers true iff this is an OWL Anonymous Individual.
      Returns:
      boolean
    • isNamedClass

      default boolean isNamedClass()
      Answers true iff this is an OWL Class.
      Returns:
      boolean
    • isNamedIndividual

      default boolean isNamedIndividual()
      Answers true iff this is an OWL Named Individual.
      Returns:
      boolean
    • isDatatype

      default boolean isDatatype()
      Answers true iff this is an OWL Datatype.
      Returns:
      boolean
    • isObjectProperty

      default boolean isObjectProperty()
      Answers true iff this is an OWL Object Property.
      Returns:
      boolean
    • isDataProperty

      default boolean isDataProperty()
      Answers true iff this is an OWL Data Property.
      Returns:
      boolean
    • isAnnotationProperty

      default boolean isAnnotationProperty()
      Answers true iff this is an OWL Annotation Property.
      Returns:
      boolean