Class TransitiveObjectPropertyTranslator.AxiomImpl

java.lang.Object
com.github.owlcs.ontapi.owlapi.OWLObjectImpl
com.github.owlcs.ontapi.internal.objects.ONTObjectImpl
com.github.owlcs.ontapi.internal.objects.ONTStatementImpl
com.github.owlcs.ontapi.internal.objects.ONTAxiomImpl<org.semanticweb.owlapi.model.OWLTransitiveObjectPropertyAxiom>
com.github.owlcs.ontapi.internal.axioms.AbstractPropertyTypeTranslator.UnaryAxiomImpl<org.semanticweb.owlapi.model.OWLTransitiveObjectPropertyAxiom,org.semanticweb.owlapi.model.OWLObjectPropertyExpression>
com.github.owlcs.ontapi.internal.axioms.AbstractPropertyTypeTranslator.ObjectAxiomImpl<org.semanticweb.owlapi.model.OWLTransitiveObjectPropertyAxiom>
com.github.owlcs.ontapi.internal.axioms.TransitiveObjectPropertyTranslator.AxiomImpl
All Implemented Interfaces:
HasConfig, HasObjectFactory, AsStatement, ModelObject<org.semanticweb.owlapi.model.OWLTransitiveObjectPropertyAxiom>, ONTComposite, WithAnnotations, ONTObject<org.semanticweb.owlapi.model.OWLTransitiveObjectPropertyAxiom>, WithMerge<ONTObject<org.semanticweb.owlapi.model.OWLTransitiveObjectPropertyAxiom>>, Serializable, Comparable<org.semanticweb.owlapi.model.OWLObject>, org.apache.jena.graph.FrontsTriple, org.semanticweb.owlapi.model.HasAnnotationPropertiesInSignature, org.semanticweb.owlapi.model.HasAnnotations, org.semanticweb.owlapi.model.HasAnonymousIndividuals, org.semanticweb.owlapi.model.HasClassesInSignature, org.semanticweb.owlapi.model.HasComponents, org.semanticweb.owlapi.model.HasContainsEntityInSignature, org.semanticweb.owlapi.model.HasDataPropertiesInSignature, org.semanticweb.owlapi.model.HasDatatypesInSignature, org.semanticweb.owlapi.model.HasHashIndex, org.semanticweb.owlapi.model.HasIndex, org.semanticweb.owlapi.model.HasIndividualsInSignature, org.semanticweb.owlapi.model.HasObjectPropertiesInSignature, org.semanticweb.owlapi.model.HasProperty<org.semanticweb.owlapi.model.OWLObjectPropertyExpression>, org.semanticweb.owlapi.model.HasSignature, org.semanticweb.owlapi.model.IsAnonymous, org.semanticweb.owlapi.model.OWLAxiom, org.semanticweb.owlapi.model.OWLLogicalAxiom, org.semanticweb.owlapi.model.OWLObject, org.semanticweb.owlapi.model.OWLObjectPropertyAxiom, org.semanticweb.owlapi.model.OWLObjectPropertyCharacteristicAxiom, org.semanticweb.owlapi.model.OWLPropertyAxiom, org.semanticweb.owlapi.model.OWLTransitiveObjectPropertyAxiom, org.semanticweb.owlapi.model.OWLUnaryPropertyAxiom<org.semanticweb.owlapi.model.OWLObjectPropertyExpression>
Direct Known Subclasses:
TransitiveObjectPropertyTranslator.AxiomImpl.ComplexImpl, TransitiveObjectPropertyTranslator.AxiomImpl.SimpleImpl
Enclosing class:
TransitiveObjectPropertyTranslator

public abstract static class TransitiveObjectPropertyTranslator.AxiomImpl extends AbstractPropertyTypeTranslator.ObjectAxiomImpl<org.semanticweb.owlapi.model.OWLTransitiveObjectPropertyAxiom> implements org.semanticweb.owlapi.model.OWLTransitiveObjectPropertyAxiom
See Also:
  • Constructor Details

    • AxiomImpl

      protected AxiomImpl(org.apache.jena.graph.Triple t, Supplier<org.apache.jena.ontapi.model.OntModel> m)
  • Method Details

    • create

      public static TransitiveObjectPropertyTranslator.AxiomImpl create(org.apache.jena.ontapi.model.OntStatement statement, ModelObjectFactory factory, AxiomsSettings config)
      Creates an ONTObject container, that is also OWLTransitiveObjectPropertyAxiom.
      Parameters:
      statement - OntStatement, not null
      factory - ONTObjectFactory, not null
      config - AxiomsSettings, not null
      Returns:
      TransitiveObjectPropertyTranslator.AxiomImpl
    • createAnnotatedAxiom

      protected org.semanticweb.owlapi.model.OWLTransitiveObjectPropertyAxiom createAnnotatedAxiom(Collection<org.semanticweb.owlapi.model.OWLAnnotation> annotations)
      Description copied from class: ONTAxiomImpl
      Creates a fresh system-wide axiom with the given annotations. The resulting axiom should not contain model references.
      Specified by:
      createAnnotatedAxiom in class ONTAxiomImpl<org.semanticweb.owlapi.model.OWLTransitiveObjectPropertyAxiom>
      Parameters:
      annotations - a Collection of OWLAnnotations to bind to the axiom
      Returns:
      ONTAxiomImpl
    • findONTValue

      ONTObject<? extends org.semanticweb.owlapi.model.OWLObjectPropertyExpression> findONTValue(ModelObjectFactory factory)
    • getONTValue

      default ONTObject<? extends org.semanticweb.owlapi.model.OWLObjectPropertyExpression> getONTValue()
    • getOWLComponentsAsSet

      default Set<? extends org.semanticweb.owlapi.model.OWLObject> getOWLComponentsAsSet(ModelObjectFactory factory)
    • hasURIObject

      default boolean hasURIObject()
      Answers true iff the subject is a URI resource.
      Returns:
      boolean
    • hasURISubject

      default boolean hasURISubject()
      Answers true iff the object is a URI resource.
      Returns:
      boolean
    • getSubjectURI

      default String getSubjectURI()
      Answers a URI of the triple's subject.
      Returns:
      URI of the subject
      Throws:
      RuntimeException - in case the main triple has no subject uri (b-node instead)
    • getObjectURI

      default String getObjectURI()
      Answers a URI of the triple's object.
      Returns:
      URI of the object
      Throws:
      RuntimeException - in case the main triple has no object uri (b-node or literal instead)
    • getOWLComponentsAsSet

      default Set<? extends org.semanticweb.owlapi.model.OWLObject> getOWLComponentsAsSet()
      Gets all OWL characteristic components in the form of Set.
      Returns:
      a sorted Set of OWLObjects
    • isClassExpression

      default boolean isClassExpression()
      Answers true iff this is an OWL Class Expression.
      Returns:
      boolean
    • isAnonymousIndividual

      default boolean isAnonymousIndividual()
      Answers true iff this is an OWL Anonymous Individual.
      Returns:
      boolean
    • isNamedClass

      default boolean isNamedClass()
      Answers true iff this is an OWL Class.
      Returns:
      boolean
    • isNamedIndividual

      default boolean isNamedIndividual()
      Answers true iff this is an OWL Named Individual.
      Returns:
      boolean
    • isDatatype

      default boolean isDatatype()
      Answers true iff this is an OWL Datatype.
      Returns:
      boolean
    • isObjectProperty

      default boolean isObjectProperty()
      Answers true iff this is an OWL Object Property.
      Returns:
      boolean
    • isDataProperty

      default boolean isDataProperty()
      Answers true iff this is an OWL Data Property.
      Returns:
      boolean
    • isAnnotationProperty

      default boolean isAnnotationProperty()
      Answers true iff this is an OWL Annotation Property.
      Returns:
      boolean