Class ONTAnonymousClassExpressionImpl.OHV

java.lang.Object
com.github.owlcs.ontapi.owlapi.OWLObjectImpl
com.github.owlcs.ontapi.internal.objects.ONTObjectImpl
com.github.owlcs.ontapi.internal.objects.ONTResourceImpl
com.github.owlcs.ontapi.internal.objects.ONTExpressionImpl<org.apache.jena.ontapi.model.OntClass.ObjectHasValue>
com.github.owlcs.ontapi.internal.objects.ONTAnonymousClassExpressionImpl<org.apache.jena.ontapi.model.OntClass.ObjectHasValue,org.semanticweb.owlapi.model.OWLObjectHasValue>
com.github.owlcs.ontapi.internal.objects.ONTAnonymousClassExpressionImpl.Simple<org.apache.jena.ontapi.model.OntClass.ObjectHasValue,org.semanticweb.owlapi.model.OWLObjectHasValue>
com.github.owlcs.ontapi.internal.objects.ONTAnonymousClassExpressionImpl.Restriction<org.apache.jena.ontapi.model.OntClass.ObjectHasValue,org.semanticweb.owlapi.model.OWLObjectHasValue>
com.github.owlcs.ontapi.internal.objects.ONTAnonymousClassExpressionImpl.WithObjectProperty<org.apache.jena.ontapi.model.OntClass.ObjectHasValue,org.semanticweb.owlapi.model.OWLObjectHasValue>
com.github.owlcs.ontapi.internal.objects.ONTAnonymousClassExpressionImpl.OHV
All Implemented Interfaces:
AsNode, AsRDFNode, HasObjectFactory, ModelObject<org.semanticweb.owlapi.model.OWLObjectHasValue>, ONTComposite, WithContent<ONTExpressionImpl<org.apache.jena.ontapi.model.OntClass.ObjectHasValue>>, ONTObject<org.semanticweb.owlapi.model.OWLObjectHasValue>, Serializable, Comparable<org.semanticweb.owlapi.model.OWLObject>, org.semanticweb.owlapi.model.AsOWLClass, org.semanticweb.owlapi.model.HasAnnotationPropertiesInSignature, org.semanticweb.owlapi.model.HasAnonymousIndividuals, org.semanticweb.owlapi.model.HasClassesInSignature, org.semanticweb.owlapi.model.HasComponents, org.semanticweb.owlapi.model.HasContainsEntityInSignature, org.semanticweb.owlapi.model.HasDataPropertiesInSignature, org.semanticweb.owlapi.model.HasDatatypesInSignature, org.semanticweb.owlapi.model.HasFiller<org.semanticweb.owlapi.model.OWLIndividual>, org.semanticweb.owlapi.model.HasHashIndex, org.semanticweb.owlapi.model.HasIndex, org.semanticweb.owlapi.model.HasIndividualsInSignature, org.semanticweb.owlapi.model.HasObjectPropertiesInSignature, org.semanticweb.owlapi.model.HasProperty<org.semanticweb.owlapi.model.OWLObjectPropertyExpression>, org.semanticweb.owlapi.model.HasSignature, org.semanticweb.owlapi.model.IsAnonymous, org.semanticweb.owlapi.model.OWLAnonymousClassExpression, org.semanticweb.owlapi.model.OWLClassExpression, org.semanticweb.owlapi.model.OWLHasValueRestriction<org.semanticweb.owlapi.model.OWLIndividual>, org.semanticweb.owlapi.model.OWLObject, org.semanticweb.owlapi.model.OWLObjectHasValue, org.semanticweb.owlapi.model.OWLObjectRestriction, org.semanticweb.owlapi.model.OWLPropertyRange, org.semanticweb.owlapi.model.OWLRestriction, org.semanticweb.owlapi.model.SWRLPredicate
Enclosing class:
ONTAnonymousClassExpressionImpl<ONT extends org.apache.jena.ontapi.model.OntClass,OWL extends org.semanticweb.owlapi.model.OWLAnonymousClassExpression>

public static class ONTAnonymousClassExpressionImpl.OHV extends ONTAnonymousClassExpressionImpl.WithObjectProperty<org.apache.jena.ontapi.model.OntClass.ObjectHasValue,org.semanticweb.owlapi.model.OWLObjectHasValue> implements org.semanticweb.owlapi.model.OWLObjectHasValue
See Also:
  • Constructor Details

  • Method Details

    • asRDFNode

      public org.apache.jena.ontapi.model.OntClass.ObjectHasValue asRDFNode()
      Description copied from interface: AsRDFNode
      Answers the RDFNode associated with this object.
      Specified by:
      asRDFNode in interface AsRDFNode
      Specified by:
      asRDFNode in class ONTExpressionImpl<org.apache.jena.ontapi.model.OntClass.ObjectHasValue>
      Returns:
      RDF Model Node, cannot be null
    • objects

      public Stream<ONTObject<? extends org.semanticweb.owlapi.model.OWLObject>> objects()
      Description copied from interface: ONTComposite
      Lists all components in the form of Stream. Neither this object nor parts of its components are not included in the result: it content only top-level direct components. Note that HasComponents.components() may also contain non-OWLObject things: integers (e.g. cardinality), Lists (e.g. ObjectOneOf), etc, while this method is only for OWLObjects which are represented as ONTObjects.
      Specified by:
      objects in interface ONTComposite
      Overrides:
      objects in class ONTAnonymousClassExpressionImpl.WithObjectProperty<org.apache.jena.ontapi.model.OntClass.ObjectHasValue,org.semanticweb.owlapi.model.OWLObjectHasValue>
      Returns:
      Stream of ONTObjects
      See Also:
    • asSomeValuesFrom

      public org.semanticweb.owlapi.model.OWLObjectSomeValuesFrom asSomeValuesFrom()
      Specified by:
      asSomeValuesFrom in interface org.semanticweb.owlapi.model.OWLHasValueRestriction<org.semanticweb.owlapi.model.OWLIndividual>
    • getFiller

      public org.semanticweb.owlapi.model.OWLIndividual getFiller()
      Specified by:
      getFiller in interface org.semanticweb.owlapi.model.HasFiller<org.semanticweb.owlapi.model.OWLIndividual>
    • getONTIndividual

      public ONTObject<? extends org.semanticweb.owlapi.model.OWLIndividual> getONTIndividual()
    • findIndividual

      protected ONTObject<? extends org.semanticweb.owlapi.model.OWLIndividual> findIndividual(ModelObjectFactory factory)
    • collectContent

      protected Object[] collectContent(org.apache.jena.ontapi.model.OntClass.ObjectHasValue ce, ONTObjectFactory factory)
      Description copied from class: ONTExpressionImpl
      Collects the cache Array. The array was chosen as the best option in sense of memory consumption and access speed.
      Overrides:
      collectContent in class ONTAnonymousClassExpressionImpl.WithObjectProperty<org.apache.jena.ontapi.model.OntClass.ObjectHasValue,org.semanticweb.owlapi.model.OWLObjectHasValue>
      Parameters:
      ce - ONTExpressionImpl, not null
      factory - ONTObjectFactory, not null
      Returns:
      an Array of Objects (content items)
      See Also:
    • initContent

      protected Object[] initContent(org.apache.jena.ontapi.model.OntClass.ObjectHasValue ce, ONTObjectFactory factory)
      Description copied from class: ONTExpressionImpl
      Initializes the object's content and calculates its hashcode. Together, this must be faster.
      Overrides:
      initContent in class ONTAnonymousClassExpressionImpl.WithObjectProperty<org.apache.jena.ontapi.model.OntClass.ObjectHasValue,org.semanticweb.owlapi.model.OWLObjectHasValue>
      Parameters:
      ce - ONTExpressionImpl the source Jena resource, not null
      factory - ONTObjectFactory, not null
      Returns:
      an Array of Objects (content items)
      See Also:
    • containsObjectProperty

      public boolean containsObjectProperty(org.semanticweb.owlapi.model.OWLObjectProperty property)
      Description copied from class: ONTObjectImpl
      Answers true iff the given OWL named object property expression (OWLObjectProperty) is present in the object's signature.
      Overrides:
      containsObjectProperty in class ONTObjectImpl
      Parameters:
      property - OWLObjectProperty, not null
      Returns:
      boolean
    • containsNamedIndividual

      public boolean containsNamedIndividual(org.semanticweb.owlapi.model.OWLNamedIndividual individual)
      Description copied from class: ONTObjectImpl
      Answers true iff the given OWL named individual is present in the object's signature.
      Overrides:
      containsNamedIndividual in class ONTObjectImpl
      Parameters:
      individual - OWLNamedIndividual, not null
      Returns:
      boolean
    • getSignatureSet

      public Set<org.semanticweb.owlapi.model.OWLEntity> getSignatureSet()
      Description copied from class: OWLObjectImpl
      Gets the signature of this object. The set is a copy, changes are not reflected back.
      Overrides:
      getSignatureSet in class ONTObjectImpl
      Returns:
      a modifiable sorted Set of entities that represents the signature of this object
    • getObjectPropertySet

      public Set<org.semanticweb.owlapi.model.OWLObjectProperty> getObjectPropertySet()
      Description copied from class: OWLObjectImpl
      Obtains the (named) object properties that are in the signature of this object. The set is a copy, changes are not reflected back.
      Overrides:
      getObjectPropertySet in class ONTObjectImpl
      Returns:
      a modifiable sorted Set of the object properties that are in the signature of this object
    • getNamedProperty

      protected org.semanticweb.owlapi.model.OWLObjectProperty getNamedProperty()
    • getNamedIndividualSet

      public Set<org.semanticweb.owlapi.model.OWLNamedIndividual> getNamedIndividualSet()
      Description copied from class: OWLObjectImpl
      Gets all the individuals that are in the signature of this object. The set is a copy, changes are not reflected back.
      Overrides:
      getNamedIndividualSet in class ONTObjectImpl
      Returns:
      a modifiable sorted Set containing the individuals that are in the signature of this object
    • getAnonymousIndividualSet

      public Set<org.semanticweb.owlapi.model.OWLAnonymousIndividual> getAnonymousIndividualSet()
      Description copied from class: OWLObjectImpl
      Gets the anonymous individuals occurring in this object. The set is a copy, changes are not reflected back.
      Overrides:
      getAnonymousIndividualSet in class ONTObjectImpl
      Returns:
      a modifiable sorted Set of the anonymous individuals
    • getClassExpressionSet

      public Set<org.semanticweb.owlapi.model.OWLClassExpression> getClassExpressionSet()
      Description copied from class: OWLObjectImpl
      Gets all the nested (includes top level) class expressions that are used in this object. The set is a copy, changes are not reflected back.
      Overrides:
      getClassExpressionSet in class ONTObjectImpl
      Returns:
      a modifiable unordered Set of OWLClassExpressions that represent the nested class expressions used in this object
    • canContainDataProperties

      public boolean canContainDataProperties()
      Description copied from interface: ONTComposite
      Answers true if this object-container may contain data properties.
      Specified by:
      canContainDataProperties in interface ONTComposite
      Returns:
      boolean
    • canContainNamedClasses

      public boolean canContainNamedClasses()
      Description copied from interface: ONTComposite
      Answers true if this object-container is allowed to contain (named) OWL classes.
      Specified by:
      canContainNamedClasses in interface ONTComposite
      Returns:
      boolean
    • canContainDatatypes

      public boolean canContainDatatypes()
      Description copied from interface: ONTComposite
      Answers true if this object-container may contain datatypes.
      Specified by:
      canContainDatatypes in interface ONTComposite
      Returns:
      boolean
    • eraseModel

      public org.semanticweb.owlapi.model.OWLObjectHasValue eraseModel()
      Description copied from interface: ModelObject
      Answers with an object that equals to the ONTObject.getOWLObject(), but without any model information inside.

      Such unattached object can be used in whatever way, while the object ONTObject.getOWLObject() requires more attention: it will not allow GC to dispose of the model, as there is a strong reference (or a facility to get such reference) to the model inside that object.

      Specified by:
      eraseModel in interface ModelObject<org.semanticweb.owlapi.model.OWLObjectHasValue>
      Returns:
      ModelObject
      See Also:
    • isAnonymousIndividual

      default boolean isAnonymousIndividual()
      Answers true iff this is an OWL Anonymous Individual.
      Returns:
      boolean
    • isNamedClass

      default boolean isNamedClass()
      Answers true iff this is an OWL Class.
      Returns:
      boolean
    • isNamedIndividual

      default boolean isNamedIndividual()
      Answers true iff this is an OWL Named Individual.
      Returns:
      boolean
    • isDatatype

      default boolean isDatatype()
      Answers true iff this is an OWL Datatype.
      Returns:
      boolean
    • isObjectProperty

      default boolean isObjectProperty()
      Answers true iff this is an OWL Object Property.
      Returns:
      boolean
    • isDataProperty

      default boolean isDataProperty()
      Answers true iff this is an OWL Data Property.
      Returns:
      boolean
    • isAnnotationProperty

      default boolean isAnnotationProperty()
      Answers true iff this is an OWL Annotation Property.
      Returns:
      boolean