Class ONTAnonymousClassExpressionImpl.UF

java.lang.Object
com.github.owlcs.ontapi.owlapi.OWLObjectImpl
com.github.owlcs.ontapi.internal.objects.ONTObjectImpl
com.github.owlcs.ontapi.internal.objects.ONTResourceImpl
com.github.owlcs.ontapi.internal.objects.ONTExpressionImpl<org.apache.jena.ontapi.model.OntClass.UnionOf>
com.github.owlcs.ontapi.internal.objects.ONTAnonymousClassExpressionImpl<org.apache.jena.ontapi.model.OntClass.UnionOf,org.semanticweb.owlapi.model.OWLObjectUnionOf>
com.github.owlcs.ontapi.internal.objects.ONTAnonymousClassExpressionImpl.WithMembers<org.apache.jena.ontapi.model.OntClass,org.apache.jena.ontapi.model.OntClass.UnionOf,org.semanticweb.owlapi.model.OWLClassExpression,org.semanticweb.owlapi.model.OWLObjectUnionOf>
com.github.owlcs.ontapi.internal.objects.ONTAnonymousClassExpressionImpl.WithClassMembers<org.apache.jena.ontapi.model.OntClass.UnionOf,org.semanticweb.owlapi.model.OWLObjectUnionOf>
com.github.owlcs.ontapi.internal.objects.ONTAnonymousClassExpressionImpl.UF
All Implemented Interfaces:
AsNode, AsRDFNode, HasObjectFactory, ModelObject<org.semanticweb.owlapi.model.OWLObjectUnionOf>, ONTComposite, WithContent<ONTExpressionImpl<org.apache.jena.ontapi.model.OntClass.UnionOf>>, ONTObject<org.semanticweb.owlapi.model.OWLObjectUnionOf>, Serializable, Comparable<org.semanticweb.owlapi.model.OWLObject>, org.semanticweb.owlapi.model.AsOWLClass, org.semanticweb.owlapi.model.HasAnnotationPropertiesInSignature, org.semanticweb.owlapi.model.HasAnonymousIndividuals, org.semanticweb.owlapi.model.HasClassesInSignature, org.semanticweb.owlapi.model.HasComponents, org.semanticweb.owlapi.model.HasContainsEntityInSignature, org.semanticweb.owlapi.model.HasDataPropertiesInSignature, org.semanticweb.owlapi.model.HasDatatypesInSignature, org.semanticweb.owlapi.model.HasHashIndex, org.semanticweb.owlapi.model.HasIndex, org.semanticweb.owlapi.model.HasIndividualsInSignature, org.semanticweb.owlapi.model.HasObjectPropertiesInSignature, org.semanticweb.owlapi.model.HasOperands<org.semanticweb.owlapi.model.OWLClassExpression>, org.semanticweb.owlapi.model.HasSignature, org.semanticweb.owlapi.model.IsAnonymous, org.semanticweb.owlapi.model.OWLAnonymousClassExpression, org.semanticweb.owlapi.model.OWLBooleanClassExpression, org.semanticweb.owlapi.model.OWLClassExpression, org.semanticweb.owlapi.model.OWLNaryBooleanClassExpression, org.semanticweb.owlapi.model.OWLObject, org.semanticweb.owlapi.model.OWLObjectUnionOf, org.semanticweb.owlapi.model.OWLPropertyRange, org.semanticweb.owlapi.model.SWRLPredicate
Enclosing class:
ONTAnonymousClassExpressionImpl<ONT extends org.apache.jena.ontapi.model.OntClass,OWL extends org.semanticweb.owlapi.model.OWLAnonymousClassExpression>

public static class ONTAnonymousClassExpressionImpl.UF extends ONTAnonymousClassExpressionImpl.WithClassMembers<org.apache.jena.ontapi.model.OntClass.UnionOf,org.semanticweb.owlapi.model.OWLObjectUnionOf> implements org.semanticweb.owlapi.model.OWLObjectUnionOf
See Also:
  • Constructor Details

  • Method Details

    • asRDFNode

      public org.apache.jena.ontapi.model.OntClass.UnionOf asRDFNode()
      Description copied from interface: AsRDFNode
      Answers the RDFNode associated with this object.
      Specified by:
      asRDFNode in interface AsRDFNode
      Specified by:
      asRDFNode in class ONTExpressionImpl<org.apache.jena.ontapi.model.OntClass.UnionOf>
      Returns:
      RDF Model Node, cannot be null
    • asDisjunctSet

      public Set<org.semanticweb.owlapi.model.OWLClassExpression> asDisjunctSet()
      Specified by:
      asDisjunctSet in interface org.semanticweb.owlapi.model.OWLClassExpression
      Overrides:
      asDisjunctSet in class ONTAnonymousClassExpressionImpl<org.apache.jena.ontapi.model.OntClass.UnionOf,org.semanticweb.owlapi.model.OWLObjectUnionOf>
    • disjunctSet

      public Stream<org.semanticweb.owlapi.model.OWLClassExpression> disjunctSet()
      Specified by:
      disjunctSet in interface org.semanticweb.owlapi.model.OWLClassExpression
      Overrides:
      disjunctSet in class ONTAnonymousClassExpressionImpl<org.apache.jena.ontapi.model.OntClass.UnionOf,org.semanticweb.owlapi.model.OWLObjectUnionOf>
    • eraseModel

      public org.semanticweb.owlapi.model.OWLObjectUnionOf eraseModel()
      Description copied from interface: ModelObject
      Answers with an object that equals to the ONTObject.getOWLObject(), but without any model information inside.

      Such unattached object can be used in whatever way, while the object ONTObject.getOWLObject() requires more attention: it will not allow GC to dispose of the model, as there is a strong reference (or a facility to get such reference) to the model inside that object.

      Specified by:
      eraseModel in interface ModelObject<org.semanticweb.owlapi.model.OWLObjectUnionOf>
      Returns:
      ModelObject
      See Also:
    • isAnonymousIndividual

      default boolean isAnonymousIndividual()
      Answers true iff this is an OWL Anonymous Individual.
      Returns:
      boolean
    • isNamedClass

      default boolean isNamedClass()
      Answers true iff this is an OWL Class.
      Returns:
      boolean
    • isNamedIndividual

      default boolean isNamedIndividual()
      Answers true iff this is an OWL Named Individual.
      Returns:
      boolean
    • isDatatype

      default boolean isDatatype()
      Answers true iff this is an OWL Datatype.
      Returns:
      boolean
    • isObjectProperty

      default boolean isObjectProperty()
      Answers true iff this is an OWL Object Property.
      Returns:
      boolean
    • isDataProperty

      default boolean isDataProperty()
      Answers true iff this is an OWL Data Property.
      Returns:
      boolean
    • isAnnotationProperty

      default boolean isAnnotationProperty()
      Answers true iff this is an OWL Annotation Property.
      Returns:
      boolean