Class ONTAnonymousDataRangeImpl.OF
java.lang.Object
com.github.owlcs.ontapi.owlapi.OWLObjectImpl
com.github.owlcs.ontapi.internal.objects.ONTObjectImpl
com.github.owlcs.ontapi.internal.objects.ONTResourceImpl
com.github.owlcs.ontapi.internal.objects.ONTExpressionImpl<org.apache.jena.ontapi.model.OntDataRange.OneOf>
com.github.owlcs.ontapi.internal.objects.ONTAnonymousDataRangeImpl<org.apache.jena.ontapi.model.OntDataRange.OneOf,org.semanticweb.owlapi.model.OWLDataOneOf>
com.github.owlcs.ontapi.internal.objects.ONTAnonymousDataRangeImpl.WithMembers<org.apache.jena.rdf.model.Literal,org.apache.jena.ontapi.model.OntDataRange.OneOf,org.semanticweb.owlapi.model.OWLLiteral,org.semanticweb.owlapi.model.OWLDataOneOf>
com.github.owlcs.ontapi.internal.objects.ONTAnonymousDataRangeImpl.OF
- All Implemented Interfaces:
AsNode,AsRDFNode,HasObjectFactory,ModelObject<org.semanticweb.owlapi.model.OWLDataOneOf>,ONTComposite,WithContent<ONTExpressionImpl<org.apache.jena.ontapi.model.OntDataRange.OneOf>>,ONTObject<org.semanticweb.owlapi.model.OWLDataOneOf>,Serializable,Comparable<org.semanticweb.owlapi.model.OWLObject>,org.semanticweb.owlapi.model.AsOWLDatatype,org.semanticweb.owlapi.model.HasAnnotationPropertiesInSignature,org.semanticweb.owlapi.model.HasAnonymousIndividuals,org.semanticweb.owlapi.model.HasClassesInSignature,org.semanticweb.owlapi.model.HasComponents,org.semanticweb.owlapi.model.HasContainsEntityInSignature,org.semanticweb.owlapi.model.HasDataPropertiesInSignature,org.semanticweb.owlapi.model.HasDatatypesInSignature,org.semanticweb.owlapi.model.HasHashIndex,org.semanticweb.owlapi.model.HasIndex,org.semanticweb.owlapi.model.HasIndividualsInSignature,org.semanticweb.owlapi.model.HasObjectPropertiesInSignature,org.semanticweb.owlapi.model.HasOperands<org.semanticweb.owlapi.model.OWLLiteral>,org.semanticweb.owlapi.model.HasSignature,org.semanticweb.owlapi.model.IsAnonymous,org.semanticweb.owlapi.model.OWLDataOneOf,org.semanticweb.owlapi.model.OWLDataRange,org.semanticweb.owlapi.model.OWLObject,org.semanticweb.owlapi.model.OWLPropertyRange,org.semanticweb.owlapi.model.SWRLPredicate
- Enclosing class:
ONTAnonymousDataRangeImpl<ONT extends org.apache.jena.ontapi.model.OntDataRange,OWL extends org.semanticweb.owlapi.model.OWLDataRange>
public static class ONTAnonymousDataRangeImpl.OF
extends ONTAnonymousDataRangeImpl.WithMembers<org.apache.jena.rdf.model.Literal,org.apache.jena.ontapi.model.OntDataRange.OneOf,org.semanticweb.owlapi.model.OWLLiteral,org.semanticweb.owlapi.model.OWLDataOneOf>
implements org.semanticweb.owlapi.model.OWLDataOneOf
- See Also:
-
Nested Class Summary
Nested classes/interfaces inherited from class com.github.owlcs.ontapi.internal.objects.ONTAnonymousDataRangeImpl
ONTAnonymousDataRangeImpl.CF, ONTAnonymousDataRangeImpl.IF, ONTAnonymousDataRangeImpl.OF, ONTAnonymousDataRangeImpl.R, ONTAnonymousDataRangeImpl.UF, ONTAnonymousDataRangeImpl.WithDRMembers<ONT extends org.apache.jena.ontapi.model.OntDataRange.Combination<org.apache.jena.ontapi.model.OntDataRange>,OWL extends org.semanticweb.owlapi.model.OWLDataRange>, ONTAnonymousDataRangeImpl.WithMembers<ONT_M extends org.apache.jena.rdf.model.RDFNode, ONT_D extends org.apache.jena.ontapi.model.OntDataRange.Combination<ONT_M>, OWL_M extends org.semanticweb.owlapi.model.OWLObject, OWL_D extends org.semanticweb.owlapi.model.OWLDataRange> -
Field Summary
Fields inherited from class com.github.owlcs.ontapi.internal.objects.ONTExpressionImpl
contentFields inherited from class com.github.owlcs.ontapi.internal.objects.ONTResourceImpl
nodeFields inherited from class com.github.owlcs.ontapi.internal.objects.ONTObjectImpl
modelFields inherited from class com.github.owlcs.ontapi.owlapi.OWLObjectImpl
DEFAULT_COMPARATOR, hashCode, NO_ANNOTATIONS -
Constructor Summary
ConstructorsModifierConstructorDescriptionprotectedOF(BlankNodeId id, Supplier<org.apache.jena.ontapi.model.OntModel> m) -
Method Summary
Modifier and TypeMethodDescriptionorg.apache.jena.ontapi.model.OntDataRange.OneOfAnswers theRDFNodeassociated with this object.org.semanticweb.owlapi.model.OWLDataOneOfAnswers with an object that equals to theONTObject.getOWLObject(), but without any model information inside.protected ONTObject<? extends org.semanticweb.owlapi.model.OWLLiteral> fromContentItem(Object item, ModelObjectFactory factory) Extracts anONTAnonymousDataRangeImpl.WithMembersfrom content item.default booleanAnswerstrueiff this is anOWL Annotation Property.default booleanAnswerstrueiff this is anOWL Anonymous Individual.default booleanAnswerstrueiff this is anOWL Class Expression.default booleanAnswerstrueiff this is anOWL Data Property.default booleanAnswerstrueiff this is anOWL Datatype.default booleanAnswerstrueiff this is anOWL Class.default booleanAnswerstrueiff this is anOWL Named Individual.default booleanAnswerstrueiff this is anOWL Object Property.protected ONTObject<? extends org.semanticweb.owlapi.model.OWLLiteral> map(org.apache.jena.rdf.model.Literal literal, ONTObjectFactory factory) Translates JenaONTAnonymousDataRangeImpl.WithMembersresource to OWL-APIONTAnonymousDataRangeImpl.WithMembersequivalent.protected ObjecttoContentItem(ONTObject<? extends org.semanticweb.owlapi.model.OWLLiteral> literal) Prepares anONTAnonymousDataRangeImpl.WithMembersto store in cache (content array).Stream<org.semanticweb.owlapi.model.OWLLiteral> values()Methods inherited from class com.github.owlcs.ontapi.internal.objects.ONTAnonymousDataRangeImpl.WithMembers
collectContent, factoryObjects, getOperandsAsList, initContent, members, objects, objects, operands, operandsMethods inherited from class com.github.owlcs.ontapi.internal.objects.ONTAnonymousDataRangeImpl
canContainAnnotationProperties, canContainAnonymousIndividuals, canContainClassExpressions, canContainDataProperties, canContainNamedClasses, canContainNamedIndividuals, canContainObjectProperties, create, create, getOWLObjectMethods inherited from class com.github.owlcs.ontapi.internal.objects.ONTExpressionImpl
asNode, collectContent, equals, getBlankNodeId, getContentCache, toCE, toContentItem, toContentItem, toContentItem, toContentItem, toContentItem, toContentItem, toDR, toIndividual, toLiteral, toNDP, toOPE, triplesMethods inherited from class com.github.owlcs.ontapi.internal.objects.ONTResourceImpl
as, getLiteralLabel, getURI, sameAsMethods inherited from class com.github.owlcs.ontapi.internal.objects.ONTObjectImpl
containsAnnotationProperty, containsDataProperty, containsDatatype, containsEntity, containsEntityInSignature, containsNamedClass, containsNamedIndividual, containsObjectProperty, createContentSet, eraseModel, getAnnotationPropertySet, getAnonymousIndividualSet, getClassExpressionSet, getDataPropertySet, getDatatypeSet, getModel, getNamedClassSet, getNamedIndividualSet, getObjectFactory, getObjectPropertySet, getPersonalityModel, getSignatureSet, toStringMethods inherited from class com.github.owlcs.ontapi.owlapi.OWLObjectImpl
annotationPropertiesInSignature, anonymousIndividuals, classesInSignature, compareIterators, compareTo, createSet, createSet, createSortedSet, createSortedSet, dataPropertiesInSignature, datatypesInSignature, equalIterators, equalStreams, forOutput, getAnnotationPropertiesInSignature, getAnonymousIndividuals, getClassesInSignature, getDataPropertiesInSignature, getDatatypesInSignature, getIndividualsInSignature, getNestedClassExpressions, getObjectPropertiesInSignature, getSignature, hashCode, individualsInSignature, mergeAnnotations, nestedClassExpressions, notSame, objectPropertiesInSignature, prepareAnnotations, signature, toContentListMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface org.semanticweb.owlapi.model.AsOWLDatatype
asOWLDatatype, isOWLDatatypeMethods inherited from interface java.lang.Comparable
compareToMethods inherited from interface org.semanticweb.owlapi.model.HasAnnotationPropertiesInSignature
annotationPropertiesInSignature, getAnnotationPropertiesInSignatureMethods inherited from interface org.semanticweb.owlapi.model.HasAnonymousIndividuals
anonymousIndividuals, getAnonymousIndividualsMethods inherited from interface org.semanticweb.owlapi.model.HasClassesInSignature
classesInSignature, getClassesInSignatureMethods inherited from interface org.semanticweb.owlapi.model.HasComponents
componentsAnnotationsFirst, componentsWithoutAnnotationsMethods inherited from interface org.semanticweb.owlapi.model.HasContainsEntityInSignature
containsEntityInSignatureMethods inherited from interface org.semanticweb.owlapi.model.HasDataPropertiesInSignature
dataPropertiesInSignature, getDataPropertiesInSignatureMethods inherited from interface org.semanticweb.owlapi.model.HasDatatypesInSignature
datatypesInSignature, getDatatypesInSignatureMethods inherited from interface org.semanticweb.owlapi.model.HasIndividualsInSignature
getIndividualsInSignature, individualsInSignatureMethods inherited from interface com.github.owlcs.ontapi.internal.HasObjectFactory
getDataFactoryMethods inherited from interface org.semanticweb.owlapi.model.HasObjectPropertiesInSignature
getObjectPropertiesInSignature, objectPropertiesInSignatureMethods inherited from interface org.semanticweb.owlapi.model.HasOperands
getOperandsAsList, operandsMethods inherited from interface org.semanticweb.owlapi.model.HasSignature
getSignature, signature, unsortedSignatureMethods inherited from interface org.semanticweb.owlapi.model.IsAnonymous
isAnonymous, isNamedMethods inherited from interface com.github.owlcs.ontapi.internal.objects.ModelObject
getModelMethods inherited from interface com.github.owlcs.ontapi.internal.objects.ONTComposite
canContainDatatypesMethods inherited from interface org.semanticweb.owlapi.model.OWLDataOneOf
accept, accept, accept, accept, accept, accept, components, getDataRangeType, getValues, hashIndex, initHashCode, typeIndexMethods inherited from interface org.semanticweb.owlapi.model.OWLDataRange
isTopDatatypeMethods inherited from interface org.semanticweb.owlapi.model.OWLObject
getNestedClassExpressions, hasSharedStructure, isAnonymousExpression, isAxiom, isBottomEntity, isIndividual, isIRI, isOntology, isTopEntity, nestedClassExpressionsMethods inherited from interface com.github.owlcs.ontapi.internal.objects.WithContent
clearContent, createContentCache, getContent, hasContent, putContent
-
Constructor Details
-
OF
-
-
Method Details
-
asRDFNode
public org.apache.jena.ontapi.model.OntDataRange.OneOf asRDFNode()Description copied from interface:AsRDFNodeAnswers theRDFNodeassociated with this object.- Specified by:
asRDFNodein interfaceAsRDFNode- Specified by:
asRDFNodein classONTExpressionImpl<org.apache.jena.ontapi.model.OntDataRange.OneOf>- Returns:
RDF Model Node, cannot benull
-
map
protected ONTObject<? extends org.semanticweb.owlapi.model.OWLLiteral> map(org.apache.jena.rdf.model.Literal literal, ONTObjectFactory factory) Description copied from class:ONTAnonymousDataRangeImpl.WithMembersTranslates JenaONTAnonymousDataRangeImpl.WithMembersresource to OWL-APIONTAnonymousDataRangeImpl.WithMembersequivalent.- Specified by:
mapin classONTAnonymousDataRangeImpl.WithMembers<org.apache.jena.rdf.model.Literal,org.apache.jena.ontapi.model.OntDataRange.OneOf, org.semanticweb.owlapi.model.OWLLiteral, org.semanticweb.owlapi.model.OWLDataOneOf> - Parameters:
literal-ONTAnonymousDataRangeImpl.WithMembers, notnullfactory-ONTObjectFactory, notnull- Returns:
- an
ONTObjectthat wrapsONTAnonymousDataRangeImpl.WithMembers
-
values
- Specified by:
valuesin interfaceorg.semanticweb.owlapi.model.OWLDataOneOf
-
toContentItem
protected Object toContentItem(ONTObject<? extends org.semanticweb.owlapi.model.OWLLiteral> literal) Description copied from class:ONTAnonymousDataRangeImpl.WithMembersPrepares anONTAnonymousDataRangeImpl.WithMembersto store in cache (content array).- Specified by:
toContentItemin classONTAnonymousDataRangeImpl.WithMembers<org.apache.jena.rdf.model.Literal,org.apache.jena.ontapi.model.OntDataRange.OneOf, org.semanticweb.owlapi.model.OWLLiteral, org.semanticweb.owlapi.model.OWLDataOneOf> - Parameters:
literal- theONTObjectthat wrapsONTAnonymousDataRangeImpl.WithMembers, notnull- Returns:
Object
-
fromContentItem
protected ONTObject<? extends org.semanticweb.owlapi.model.OWLLiteral> fromContentItem(Object item, ModelObjectFactory factory) Description copied from class:ONTAnonymousDataRangeImpl.WithMembersExtracts anONTAnonymousDataRangeImpl.WithMembersfrom content item.- Specified by:
fromContentItemin classONTAnonymousDataRangeImpl.WithMembers<org.apache.jena.rdf.model.Literal,org.apache.jena.ontapi.model.OntDataRange.OneOf, org.semanticweb.owlapi.model.OWLLiteral, org.semanticweb.owlapi.model.OWLDataOneOf> - Parameters:
item- anObjectfrom cache, notnullfactory-ONTObjectFactory, notnull- Returns:
- an
ONTObjectthat wrapsONTAnonymousDataRangeImpl.WithMembers
-
eraseModel
public org.semanticweb.owlapi.model.OWLDataOneOf eraseModel()Description copied from interface:ModelObjectAnswers with an object that equals to theONTObject.getOWLObject(), but without any model information inside.Such unattached object can be used in whatever way, while the object
ONTObject.getOWLObject()requires more attention: it will not allow GC to dispose of the model, as there is a strong reference (or a facility to get such reference) to the model inside that object.- Specified by:
eraseModelin interfaceModelObject<org.semanticweb.owlapi.model.OWLDataOneOf>- Returns:
ModelObject- See Also:
-
isClassExpression
default boolean isClassExpression()Answerstrueiff this is anOWL Class Expression.- Returns:
- boolean
-
isAnonymousIndividual
default boolean isAnonymousIndividual()Answerstrueiff this is anOWL Anonymous Individual.- Returns:
- boolean
-
isNamedClass
default boolean isNamedClass()Answerstrueiff this is anOWL Class.- Returns:
- boolean
-
isNamedIndividual
default boolean isNamedIndividual()Answerstrueiff this is anOWL Named Individual.- Returns:
- boolean
-
isDatatype
default boolean isDatatype()Answerstrueiff this is anOWL Datatype.- Returns:
- boolean
-
isObjectProperty
default boolean isObjectProperty()Answerstrueiff this is anOWL Object Property.- Returns:
- boolean
-
isDataProperty
default boolean isDataProperty()Answerstrueiff this is anOWL Data Property.- Returns:
- boolean
-
isAnnotationProperty
default boolean isAnnotationProperty()Answerstrueiff this is anOWL Annotation Property.- Returns:
- boolean
-