Interface WithAnnotations

All Superinterfaces:
org.semanticweb.owlapi.model.HasAnnotations
All Known Subinterfaces:
WithoutAnnotations
All Known Implementing Classes:
AbstractListBasedTranslator.WithListImpl, AbstractNaryTranslator.ClassNaryAxiomImpl, AbstractNaryTranslator.DataPropertyNaryAxiomImpl, AbstractNaryTranslator.IndividualNaryAxiomImpl, AbstractNaryTranslator.NaryAxiomImpl, AbstractNaryTranslator.ObjectPropertyNaryAxiomImpl, AbstractNegativePropertyAssertionTranslator.NegativeAssertionImpl, AbstractPropertyAssertionTranslator.AssertionImpl, AbstractPropertyDomainTranslator.ClassDomainAxiomImpl, AbstractPropertyDomainTranslator.DomainAxiomImpl, AbstractPropertyRangeTranslator.RangeAxiomImpl, AbstractPropertyTypeTranslator.ObjectAxiomImpl, AbstractPropertyTypeTranslator.UnaryAxiomImpl, AbstractSubPropertyTranslator.SubPropertyAxiomImpl, AnnotationAssertionTranslator.AxiomImpl, AnnotationAssertionTranslator.AxiomImpl.SimpleImpl, AnnotationAssertionTranslator.AxiomImpl.WithAnnotationsImpl, AnnotationPropertyDomainTranslator.AxiomImpl, AnnotationPropertyDomainTranslator.AxiomImpl.SimpleImpl, AnnotationPropertyDomainTranslator.AxiomImpl.WithAnnotationsImpl, AnnotationPropertyRangeTranslator.AxiomImpl, AnnotationPropertyRangeTranslator.AxiomImpl.SimpleImpl, AnnotationPropertyRangeTranslator.AxiomImpl.WithAnnotationsImpl, AsymmetricObjectPropertyTranslator.AxiomImpl, AsymmetricObjectPropertyTranslator.AxiomImpl.ComplexImpl, AsymmetricObjectPropertyTranslator.AxiomImpl.SimpleImpl, ClassAssertionTranslator.AxiomImpl, ClassAssertionTranslator.AxiomImpl.ComplexImpl, ClassAssertionTranslator.AxiomImpl.SimpleImpl, DataPropertyAssertionTranslator.AxiomImpl, DataPropertyAssertionTranslator.AxiomImpl.SimpleImpl, DataPropertyAssertionTranslator.AxiomImpl.WithAnnotationsImpl, DataPropertyDomainTranslator.AxiomImpl, DataPropertyDomainTranslator.AxiomImpl.ComplexImpl, DataPropertyDomainTranslator.AxiomImpl.SimpleImpl, DataPropertyRangeTranslator.AxiomImpl, DataPropertyRangeTranslator.AxiomImpl.ComplexImpl, DataPropertyRangeTranslator.AxiomImpl.SimpleImpl, DatatypeDefinitionTranslator.AxiomImpl, DatatypeDefinitionTranslator.AxiomImpl.ComplexImpl, DatatypeDefinitionTranslator.AxiomImpl.SimpleImpl, DeclarationTranslator.AxiomImpl, DeclarationTranslator.AxiomImpl.SimpleImpl, DeclarationTranslator.AxiomImpl.WithAnnotationsImpl, DifferentIndividualsTranslator.AxiomImpl, DifferentIndividualsTranslator.AxiomImpl.ComplexImpl, DifferentIndividualsTranslator.AxiomImpl.SimpleImpl, DisjointClassesTranslator.AxiomImpl, DisjointClassesTranslator.AxiomImpl.ComplexImpl, DisjointClassesTranslator.AxiomImpl.SimpleImpl, DisjointDataPropertiesTranslator.AxiomImpl, DisjointDataPropertiesTranslator.AxiomImpl.ComplexImpl, DisjointDataPropertiesTranslator.AxiomImpl.SimpleImpl, DisjointObjectPropertiesTranslator.AxiomImpl, DisjointObjectPropertiesTranslator.AxiomImpl.ComplexImpl, DisjointObjectPropertiesTranslator.AxiomImpl.SimpleImpl, DisjointUnionTranslator.AxiomImpl, EquivalentClassesTranslator.AxiomImpl, EquivalentClassesTranslator.AxiomImpl.ComplexImpl, EquivalentClassesTranslator.AxiomImpl.SimpleImpl, EquivalentDataPropertiesTranslator.AxiomImpl, EquivalentDataPropertiesTranslator.AxiomImpl.SimpleImpl, EquivalentDataPropertiesTranslator.AxiomImpl.WithAnnotationsImpl, EquivalentObjectPropertiesTranslator.AxiomImpl, EquivalentObjectPropertiesTranslator.AxiomImpl.ComplexImpl, EquivalentObjectPropertiesTranslator.AxiomImpl.SimpleImpl, FunctionalDataPropertyTranslator.AxiomImpl, FunctionalDataPropertyTranslator.AxiomImpl.ComplexImpl, FunctionalDataPropertyTranslator.AxiomImpl.SimpleImpl, FunctionalObjectPropertyTranslator.AxiomImpl, FunctionalObjectPropertyTranslator.AxiomImpl.ComplexImpl, FunctionalObjectPropertyTranslator.AxiomImpl.SimpleImpl, HasKeyTranslator.AxiomImpl, InverseFunctionalObjectPropertyTranslator.AxiomImpl, InverseFunctionalObjectPropertyTranslator.AxiomImpl.ComplexImpl, InverseFunctionalObjectPropertyTranslator.AxiomImpl.SimpleImpl, InverseObjectPropertiesTranslator.AxiomImpl, InverseObjectPropertiesTranslator.AxiomImpl.ComplexImpl, InverseObjectPropertiesTranslator.AxiomImpl.SimpleImpl, IrreflexiveObjectPropertyTranslator.AxiomImpl, IrreflexiveObjectPropertyTranslator.AxiomImpl.ComplexImpl, IrreflexiveObjectPropertyTranslator.AxiomImpl.SimpleImpl, NegativeDataPropertyAssertionTranslator.AxiomImpl, NegativeObjectPropertyAssertionTranslator.AxiomImpl, ObjectPropertyAssertionTranslator.AxiomImpl, ObjectPropertyAssertionTranslator.AxiomImpl.SimpleImpl, ObjectPropertyAssertionTranslator.AxiomImpl.WithAnnotationsImpl, ObjectPropertyDomainTranslator.AxiomImpl, ObjectPropertyDomainTranslator.AxiomImpl.ComplexImpl, ObjectPropertyDomainTranslator.AxiomImpl.SimpleImpl, ObjectPropertyRangeTranslator.AxiomImpl, ObjectPropertyRangeTranslator.AxiomImpl.ComplexImpl, ObjectPropertyRangeTranslator.AxiomImpl.SimpleImpl, ONTAnnotationImpl, ONTAnnotationImpl.SimpleImpl, ONTAnnotationImpl.WithAnnotationsImpl, ONTAxiomImpl, ONTStatementImpl, ReflexiveObjectPropertyTranslator.AxiomImpl, ReflexiveObjectPropertyTranslator.AxiomImpl.ComplexImpl, ReflexiveObjectPropertyTranslator.AxiomImpl.SimpleImpl, SameIndividualTranslator.AxiomImpl, SameIndividualTranslator.AxiomImpl.ComplexImpl, SameIndividualTranslator.AxiomImpl.SimpleImpl, SubAnnotationPropertyOfTranslator.AxiomImpl, SubAnnotationPropertyOfTranslator.AxiomImpl.ComplexImpl, SubAnnotationPropertyOfTranslator.AxiomImpl.SimpleImpl, SubClassOfTranslator.AxiomImpl, SubClassOfTranslator.AxiomImpl.ComplexImpl, SubClassOfTranslator.AxiomImpl.SimpleImpl, SubDataPropertyOfTranslator.AxiomImpl, SubDataPropertyOfTranslator.AxiomImpl.ComplexImpl, SubDataPropertyOfTranslator.AxiomImpl.SimpleImpl, SubObjectPropertyOfTranslator.AxiomImpl, SubObjectPropertyOfTranslator.AxiomImpl.ComplexImpl, SubObjectPropertyOfTranslator.AxiomImpl.SimpleImpl, SubPropertyChainOfTranslator.AxiomImpl, SWRLRuleTranslator.AxiomImpl, SymmetricObjectPropertyTranslator.AxiomImpl, SymmetricObjectPropertyTranslator.AxiomImpl.ComplexImpl, SymmetricObjectPropertyTranslator.AxiomImpl.SimpleImpl, TransitiveObjectPropertyTranslator.AxiomImpl, TransitiveObjectPropertyTranslator.AxiomImpl.ComplexImpl, TransitiveObjectPropertyTranslator.AxiomImpl.SimpleImpl

public interface WithAnnotations extends org.semanticweb.owlapi.model.HasAnnotations
The generic interface describing an object that has annotation. Created by @szz on 01.10.2019.
Since:
2.0.0
  • Method Summary

    Modifier and Type
    Method
    Description
    Stream<org.semanticweb.owlapi.model.OWLAnnotation>
    Lists all OWLAnnotations on this object.
    List<org.semanticweb.owlapi.model.OWLAnnotation>
    Answers a sorted and distinct List of OWLAnnotations on this object.
    boolean
    Answers true if this object (axiom or annotation) has sub-annotations.

    Methods inherited from interface org.semanticweb.owlapi.model.HasAnnotations

    annotations, annotations, getAnnotations, getAnnotations
  • Method Details

    • isAnnotated

      boolean isAnnotated()
      Answers true if this object (axiom or annotation) has sub-annotations.
      Returns:
      boolean
      See Also:
      • OWLAxiom.isAnnotated()
    • annotations

      Stream<org.semanticweb.owlapi.model.OWLAnnotation> annotations()
      Lists all OWLAnnotations on this object. The stream must be ordered, nonull, distinct and sorted.
      Specified by:
      annotations in interface org.semanticweb.owlapi.model.HasAnnotations
      Returns:
      a Stream of OWLAnnotations
      See Also:
      • HasAnnotations.annotations()
    • annotationsAsList

      List<org.semanticweb.owlapi.model.OWLAnnotation> annotationsAsList()
      Answers a sorted and distinct List of OWLAnnotations on this object. The returned List is unmodifiable.
      Specified by:
      annotationsAsList in interface org.semanticweb.owlapi.model.HasAnnotations
      Returns:
      an unmodifiable List of OWLAnnotations
      See Also:
      • HasAnnotations.annotationsAsList()