Class EquivalentClassesAxiomImpl
java.lang.Object
com.github.owlcs.ontapi.owlapi.OWLObjectImpl
com.github.owlcs.ontapi.owlapi.axioms.AxiomImpl
com.github.owlcs.ontapi.owlapi.axioms.LogicalAxiomImpl
com.github.owlcs.ontapi.owlapi.axioms.ClassAxiomImpl
com.github.owlcs.ontapi.owlapi.axioms.NaryClassAxiomImpl
com.github.owlcs.ontapi.owlapi.axioms.EquivalentClassesAxiomImpl
- All Implemented Interfaces:
Serializable,Comparable<org.semanticweb.owlapi.model.OWLObject>,org.semanticweb.owlapi.model.HasAnnotationPropertiesInSignature,org.semanticweb.owlapi.model.HasAnnotations,org.semanticweb.owlapi.model.HasAnonymousIndividuals,org.semanticweb.owlapi.model.HasClassesInSignature,org.semanticweb.owlapi.model.HasComponents,org.semanticweb.owlapi.model.HasContainsEntityInSignature,org.semanticweb.owlapi.model.HasDataPropertiesInSignature,org.semanticweb.owlapi.model.HasDatatypesInSignature,org.semanticweb.owlapi.model.HasHashIndex,org.semanticweb.owlapi.model.HasIndex,org.semanticweb.owlapi.model.HasIndividualsInSignature,org.semanticweb.owlapi.model.HasObjectPropertiesInSignature,org.semanticweb.owlapi.model.HasOperands<org.semanticweb.owlapi.model.OWLClassExpression>,org.semanticweb.owlapi.model.HasSignature,org.semanticweb.owlapi.model.IsAnonymous,org.semanticweb.owlapi.model.OWLAxiom,org.semanticweb.owlapi.model.OWLClassAxiom,org.semanticweb.owlapi.model.OWLEquivalentClassesAxiom,org.semanticweb.owlapi.model.OWLLogicalAxiom,org.semanticweb.owlapi.model.OWLNaryAxiom<org.semanticweb.owlapi.model.OWLClassExpression>,org.semanticweb.owlapi.model.OWLNaryClassAxiom,org.semanticweb.owlapi.model.OWLObject,org.semanticweb.owlapi.model.OWLSubClassOfAxiomSetShortCut
public class EquivalentClassesAxiomImpl
extends NaryClassAxiomImpl
implements org.semanticweb.owlapi.model.OWLEquivalentClassesAxiom
- See Also:
-
Field Summary
Fields inherited from class com.github.owlcs.ontapi.owlapi.axioms.NaryClassAxiomImpl
classesFields inherited from class com.github.owlcs.ontapi.owlapi.axioms.AxiomImpl
annotationsFields inherited from class com.github.owlcs.ontapi.owlapi.OWLObjectImpl
DEFAULT_COMPARATOR, hashCode, NO_ANNOTATIONS -
Constructor Summary
ConstructorsConstructorDescriptionEquivalentClassesAxiomImpl(Collection<? extends org.semanticweb.owlapi.model.OWLClassExpression> classes, Collection<org.semanticweb.owlapi.model.OWLAnnotation> annotations) -
Method Summary
Modifier and TypeMethodDescriptionCollection<org.semanticweb.owlapi.model.OWLSubClassOfAxiom> Collection<org.semanticweb.owlapi.model.OWLEquivalentClassesAxiom> booleanbooleanboolean<T extends org.semanticweb.owlapi.model.OWLAxiom>
TgetAnnotatedAxiom(Stream<org.semanticweb.owlapi.model.OWLAnnotation> anns) static booleanisNamed(org.semanticweb.owlapi.model.OWLClassExpression ce) Answerstrueif the given class expression is a named class, but notowl:Thingand notowl:Nothing.Stream<org.semanticweb.owlapi.model.OWLClass> Collection<org.semanticweb.owlapi.model.OWLEquivalentClassesAxiom> Methods inherited from class com.github.owlcs.ontapi.owlapi.axioms.NaryClassAxiomImpl
classExpressions, contains, getClassExpressionsMinus, getOperandsAsListMethods inherited from class com.github.owlcs.ontapi.owlapi.axioms.AxiomImpl
annotations, annotationsAsList, getNNF, isAnnotatedMethods inherited from class com.github.owlcs.ontapi.owlapi.OWLObjectImpl
annotationPropertiesInSignature, anonymousIndividuals, classesInSignature, compareIterators, compareTo, containsEntityInSignature, createSet, createSet, createSortedSet, createSortedSet, dataPropertiesInSignature, datatypesInSignature, equalIterators, equals, equalStreams, forOutput, getAnnotationPropertiesInSignature, getAnnotationPropertySet, getAnonymousIndividuals, getAnonymousIndividualSet, getClassesInSignature, getClassExpressionSet, getDataPropertiesInSignature, getDataPropertySet, getDatatypeSet, getDatatypesInSignature, getIndividualsInSignature, getNamedClassSet, getNamedIndividualSet, getNestedClassExpressions, getObjectPropertiesInSignature, getObjectPropertySet, getSignature, getSignatureSet, hashCode, individualsInSignature, mergeAnnotations, nestedClassExpressions, notSame, objectPropertiesInSignature, prepareAnnotations, signature, toContentList, toStringMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface java.lang.Comparable
compareToMethods inherited from interface org.semanticweb.owlapi.model.HasAnnotationPropertiesInSignature
annotationPropertiesInSignature, getAnnotationPropertiesInSignatureMethods inherited from interface org.semanticweb.owlapi.model.HasAnnotations
annotations, annotations, annotations, annotationsAsList, getAnnotations, getAnnotationsMethods inherited from interface org.semanticweb.owlapi.model.HasAnonymousIndividuals
anonymousIndividuals, getAnonymousIndividualsMethods inherited from interface org.semanticweb.owlapi.model.HasClassesInSignature
classesInSignature, getClassesInSignatureMethods inherited from interface org.semanticweb.owlapi.model.HasContainsEntityInSignature
containsEntityInSignatureMethods inherited from interface org.semanticweb.owlapi.model.HasDataPropertiesInSignature
dataPropertiesInSignature, getDataPropertiesInSignatureMethods inherited from interface org.semanticweb.owlapi.model.HasDatatypesInSignature
datatypesInSignature, getDatatypesInSignatureMethods inherited from interface org.semanticweb.owlapi.model.HasIndividualsInSignature
getIndividualsInSignature, individualsInSignatureMethods inherited from interface org.semanticweb.owlapi.model.HasObjectPropertiesInSignature
getObjectPropertiesInSignature, objectPropertiesInSignatureMethods inherited from interface org.semanticweb.owlapi.model.HasOperands
getOperandsAsListMethods inherited from interface org.semanticweb.owlapi.model.HasSignature
getSignature, signature, unsortedSignatureMethods inherited from interface org.semanticweb.owlapi.model.IsAnonymous
isAnonymous, isNamedMethods inherited from interface org.semanticweb.owlapi.model.OWLAxiom
equalsIgnoreAnnotations, getAnnotatedAxiom, getAnnotatedAxiom, getAxiomWithoutAnnotations, getNNF, isAnnotated, isAnnotationAxiom, isAxiom, isIndividual, isOfType, isOfType, isOfType, typeIndexMethods inherited from interface org.semanticweb.owlapi.model.OWLEquivalentClassesAxiom
accept, accept, accept, accept, getAxiomType, getNamedClasses, hashIndexMethods inherited from interface org.semanticweb.owlapi.model.OWLLogicalAxiom
isLogicalAxiomMethods inherited from interface org.semanticweb.owlapi.model.OWLNaryAxiom
allMatch, allMatchAllPairs, anyMatch, anyMatchAllPairs, forEach, forEachAllPairs, walkAllPairwise, walkPairwiseMethods inherited from interface org.semanticweb.owlapi.model.OWLNaryClassAxiom
classExpressions, components, componentsAnnotationsFirst, componentsWithoutAnnotations, contains, getClassExpressions, getClassExpressionsAsList, getClassExpressionsMinus, initHashCode, operandsMethods inherited from interface org.semanticweb.owlapi.model.OWLObject
getNestedClassExpressions, hasSharedStructure, isAnonymousExpression, isBottomEntity, isIRI, isOntology, isTopEntity, nestedClassExpressions
-
Constructor Details
-
EquivalentClassesAxiomImpl
public EquivalentClassesAxiomImpl(Collection<? extends org.semanticweb.owlapi.model.OWLClassExpression> classes, Collection<org.semanticweb.owlapi.model.OWLAnnotation> annotations) - Parameters:
classes- aCollectionofOWLClassExpressions, the equivalent classesannotations- aCollectionofOWLAnnotations
-
-
Method Details
-
isNamed
public static boolean isNamed(org.semanticweb.owlapi.model.OWLClassExpression ce) Answerstrueif the given class expression is a named class, but notowl:Thingand notowl:Nothing.- Parameters:
ce-OWLClassExpression, notnull- Returns:
- boolean
-
getAxiomWithoutAnnotations
- Specified by:
getAxiomWithoutAnnotationsin interfaceorg.semanticweb.owlapi.model.OWLAxiom- Specified by:
getAxiomWithoutAnnotationsin interfaceorg.semanticweb.owlapi.model.OWLEquivalentClassesAxiom
-
getAnnotatedAxiom
public <T extends org.semanticweb.owlapi.model.OWLAxiom> T getAnnotatedAxiom(@Nonnull Stream<org.semanticweb.owlapi.model.OWLAnnotation> anns) - Specified by:
getAnnotatedAxiomin interfaceorg.semanticweb.owlapi.model.OWLAxiom
-
asPairwiseAxioms
- Specified by:
asPairwiseAxiomsin interfaceorg.semanticweb.owlapi.model.OWLEquivalentClassesAxiom- Specified by:
asPairwiseAxiomsin interfaceorg.semanticweb.owlapi.model.OWLNaryAxiom<org.semanticweb.owlapi.model.OWLClassExpression>
-
splitToAnnotatedPairs
- Specified by:
splitToAnnotatedPairsin interfaceorg.semanticweb.owlapi.model.OWLEquivalentClassesAxiom- Specified by:
splitToAnnotatedPairsin interfaceorg.semanticweb.owlapi.model.OWLNaryAxiom<org.semanticweb.owlapi.model.OWLClassExpression>
-
containsNamedEquivalentClass
public boolean containsNamedEquivalentClass()- Specified by:
containsNamedEquivalentClassin interfaceorg.semanticweb.owlapi.model.OWLEquivalentClassesAxiom
-
containsOWLNothing
public boolean containsOWLNothing()- Specified by:
containsOWLNothingin interfaceorg.semanticweb.owlapi.model.OWLEquivalentClassesAxiom
-
containsOWLThing
public boolean containsOWLThing()- Specified by:
containsOWLThingin interfaceorg.semanticweb.owlapi.model.OWLEquivalentClassesAxiom
-
namedClasses
- Specified by:
namedClassesin interfaceorg.semanticweb.owlapi.model.OWLEquivalentClassesAxiom
-
asOWLSubClassOfAxioms
- Specified by:
asOWLSubClassOfAxiomsin interfaceorg.semanticweb.owlapi.model.OWLSubClassOfAxiomSetShortCut
-