Class GraphStats

java.lang.Object
com.github.owlcs.ontapi.transforms.GraphStats

public class GraphStats extends Object
A transformation statistic object, which is an outcome of transform process. Notice that it holds everything in memory.

Created by @ssz on 27.06.2018.

  • Field Details

  • Constructor Details

    • GraphStats

      protected GraphStats(org.apache.jena.graph.Graph graph)
  • Method Details

    • putTriples

      protected void putTriples(Transform transform, Set<org.apache.jena.graph.Triple> added, Set<org.apache.jena.graph.Triple> deleted, Set<org.apache.jena.graph.Triple> unparsed)
    • put

      protected void put(GraphStats.Type type, String name, Set<org.apache.jena.graph.Triple> triples)
    • putStats

      protected void putStats(GraphStats other)
    • getTriples

      public Set<org.apache.jena.graph.Triple> getTriples(GraphStats.Type type, String name)
    • triples

      public Stream<org.apache.jena.graph.Triple> triples(GraphStats.Type type)
    • hasTriples

      public boolean hasTriples(GraphStats.Type type, String name)
    • hasTriples

      public boolean hasTriples(GraphStats.Type type)
    • hasTriples

      public boolean hasTriples()
    • isNotEmpty

      public boolean isNotEmpty()
    • map

      protected Map<String,Set<org.apache.jena.graph.Triple>> map(GraphStats.Type type)
    • getGraph

      public org.apache.jena.graph.Graph getGraph()
    • stats

      public Stream<GraphStats> stats(boolean deep)
      Lists all encapsulated Stats object.
      Parameters:
      deep - if true all sub-stats will be included recursively in the result stream also, otherwise only top-level sub-stats are expected in the return stream
      Returns:
      Stream of GraphStats