Package com.github.owlcs.ontapi
Interface OntologyManager.DocumentSourceMapping
- All Superinterfaces:
Serializable
- Enclosing interface:
OntologyManager
- Functional Interface:
- This is a functional interface and can therefore be used as the assignment target for a lambda expression or method reference.
@FunctionalInterface
public static interface OntologyManager.DocumentSourceMapping
extends Serializable
The Document Source mapping.
To customize ontology loading.
- Since:
- 1.0.1
- See Also:
-
Method Summary
Modifier and TypeMethodDescriptiondefault org.semanticweb.owlapi.io.OWLOntologyDocumentSourcemap(org.semanticweb.owlapi.model.IRI iri) Finds aOWL Document Sourceobject by theIRIthat may be either version IRI or ontology IRI.org.semanticweb.owlapi.io.OWLOntologyDocumentSourcemap(org.semanticweb.owlapi.model.OWLOntologyID id) Finds aOWL Document Sourceobject by theOntology ID.
-
Method Details
-
map
org.semanticweb.owlapi.io.OWLOntologyDocumentSource map(org.semanticweb.owlapi.model.OWLOntologyID id) Finds aOWL Document Sourceobject by theOntology ID.- Parameters:
id-OWLOntologyID, notnull- Returns:
OWLOntologyDocumentSourceornull
-
map
default org.semanticweb.owlapi.io.OWLOntologyDocumentSource map(org.semanticweb.owlapi.model.IRI iri) Finds aOWL Document Sourceobject by theIRIthat may be either version IRI or ontology IRI.- Parameters:
iri-IRI, notnull- Returns:
OWLOntologyDocumentSourceornullif no mapping found- Since:
- 1.3.2
-