Class AnnotationPropertyRangeTranslator.AxiomImpl
java.lang.Object
com.github.owlcs.ontapi.owlapi.OWLObjectImpl
com.github.owlcs.ontapi.internal.objects.ONTObjectImpl
com.github.owlcs.ontapi.internal.objects.ONTStatementImpl
com.github.owlcs.ontapi.internal.objects.ONTAxiomImpl<org.semanticweb.owlapi.model.OWLAnnotationPropertyRangeAxiom>
com.github.owlcs.ontapi.internal.axioms.AbstractPropertyRangeTranslator.RangeAxiomImpl<org.semanticweb.owlapi.model.OWLAnnotationPropertyRangeAxiom,org.semanticweb.owlapi.model.OWLAnnotationProperty,org.semanticweb.owlapi.model.IRI>
com.github.owlcs.ontapi.internal.axioms.AnnotationPropertyRangeTranslator.AxiomImpl
- All Implemented Interfaces:
HasConfig,HasObjectFactory,AsStatement,ModelObject<org.semanticweb.owlapi.model.OWLAnnotationPropertyRangeAxiom>,ONTComposite,WithAnnotations,ONTObject<org.semanticweb.owlapi.model.OWLAnnotationPropertyRangeAxiom>,WithMerge<ONTObject<org.semanticweb.owlapi.model.OWLAnnotationPropertyRangeAxiom>>,Serializable,Comparable<org.semanticweb.owlapi.model.OWLObject>,org.apache.jena.graph.FrontsTriple,org.semanticweb.owlapi.model.HasAnnotationPropertiesInSignature,org.semanticweb.owlapi.model.HasAnnotations,org.semanticweb.owlapi.model.HasAnonymousIndividuals,org.semanticweb.owlapi.model.HasClassesInSignature,org.semanticweb.owlapi.model.HasComponents,org.semanticweb.owlapi.model.HasContainsEntityInSignature,org.semanticweb.owlapi.model.HasDataPropertiesInSignature,org.semanticweb.owlapi.model.HasDatatypesInSignature,org.semanticweb.owlapi.model.HasHashIndex,org.semanticweb.owlapi.model.HasIndex,org.semanticweb.owlapi.model.HasIndividualsInSignature,org.semanticweb.owlapi.model.HasObjectPropertiesInSignature,org.semanticweb.owlapi.model.HasProperty<org.semanticweb.owlapi.model.OWLAnnotationProperty>,org.semanticweb.owlapi.model.HasRange<org.semanticweb.owlapi.model.IRI>,org.semanticweb.owlapi.model.HasSignature,org.semanticweb.owlapi.model.IsAnonymous,org.semanticweb.owlapi.model.OWLAnnotationAxiom,org.semanticweb.owlapi.model.OWLAnnotationObject,org.semanticweb.owlapi.model.OWLAnnotationPropertyRangeAxiom,org.semanticweb.owlapi.model.OWLAxiom,org.semanticweb.owlapi.model.OWLObject
- Direct Known Subclasses:
AnnotationPropertyRangeTranslator.AxiomImpl.SimpleImpl,AnnotationPropertyRangeTranslator.AxiomImpl.WithAnnotationsImpl
- Enclosing class:
AnnotationPropertyRangeTranslator
public abstract static class AnnotationPropertyRangeTranslator.AxiomImpl
extends AbstractPropertyRangeTranslator.RangeAxiomImpl<org.semanticweb.owlapi.model.OWLAnnotationPropertyRangeAxiom,org.semanticweb.owlapi.model.OWLAnnotationProperty,org.semanticweb.owlapi.model.IRI>
implements org.semanticweb.owlapi.model.OWLAnnotationPropertyRangeAxiom
- See Also:
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic classAnOWLAnnotationPropertyRangeAxiomwithout annotations.static classAnOWLAnnotationPropertyRangeAxiomwith annotations. -
Field Summary
Fields inherited from class com.github.owlcs.ontapi.internal.objects.ONTAxiomImpl
SET_HASH_CODEFields inherited from class com.github.owlcs.ontapi.internal.objects.ONTStatementImpl
object, predicate, subjectFields inherited from class com.github.owlcs.ontapi.internal.objects.ONTObjectImpl
modelFields inherited from class com.github.owlcs.ontapi.owlapi.OWLObjectImpl
DEFAULT_COMPARATOR, hashCode, NO_ANNOTATIONSFields inherited from interface com.github.owlcs.ontapi.internal.WithMerge
ONT_OBJECT_MERGER -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionfinal booleanAnswerstrueif this object-container is allowed to contain nested class-expressions.final booleanAnswerstrueif this object-container may contain data properties.final booleanAnswerstrueif this object-container is allowed to contain (named) OWL classes.final booleanAnswerstrueif this object-container is allowed to contain named individuals.final booleanAnswerstrueif this object-container may contain named object properties.create(org.apache.jena.ontapi.model.OntStatement statement, ModelObjectFactory factory, AxiomsSettings config) Creates anONTObjectcontainer that is alsoOWLAnnotationPropertyRangeAxiom.protected org.semanticweb.owlapi.model.OWLAnnotationPropertyRangeAxiomcreateAnnotatedAxiom(Collection<org.semanticweb.owlapi.model.OWLAnnotation> annotations) Creates a fresh system-wideaxiomwith the given annotations.default StringAnswers a URI of the triple's object.default ONTObject<? extends org.semanticweb.owlapi.model.IRI> Gets the object from the base triple of this axiom.ONTObject<? extends org.semanticweb.owlapi.model.IRI> getONTObject(ModelObjectFactory factory) Finds theONTObjectthat matches the object using thefactory.default ONTObject<? extends org.semanticweb.owlapi.model.OWLAnnotationProperty> Gets the subject from the base triple of this axiom.ONTObject<? extends org.semanticweb.owlapi.model.OWLAnnotationProperty> getONTSubject(ModelObjectFactory factory) Finds theONTObjectthat matches the subject using thefactory.default Set<? extends org.semanticweb.owlapi.model.OWLObject> Gets all OWL characteristic components in the form ofSet.default Set<? extends org.semanticweb.owlapi.model.OWLObject> getOWLComponentsAsSet(ModelObjectFactory factory) default StringAnswers a URI of the triple's subject.ONTObject<? extends org.semanticweb.owlapi.model.IRI> getURIObject(ModelObjectFactory factory) ONTObject<? extends org.semanticweb.owlapi.model.OWLAnnotationProperty> getURISubject(ModelObjectFactory factory) default booleanAnswerstrueiff the subject is a URI resource.default booleanAnswerstrueiff the object is a URI resource.default booleanAnswerstrueiff this is anOWL Annotation Property.default booleanAnswerstrueiff this is anOWL Anonymous Individual.default booleanAnswerstrueiff this is anOWL Class Expression.default booleanAnswerstrueiff this is anOWL Data Property.default booleanAnswerstrueiff this is anOWL Datatype.default booleanAnswerstrueiff this is anOWL Class.default booleanAnswerstrueiff this is anOWL Named Individual.default booleanAnswerstrueiff this is anOWL Object Property.ONTObject<? extends org.semanticweb.owlapi.model.IRI> objectFromStatement(org.apache.jena.ontapi.model.OntStatement statement, ModelObjectFactory factory) ONTObject<? extends org.semanticweb.owlapi.model.OWLAnnotationProperty> subjectFromStatement(org.apache.jena.ontapi.model.OntStatement statement, ModelObjectFactory factory) Methods inherited from class com.github.owlcs.ontapi.internal.axioms.AbstractPropertyRangeTranslator.RangeAxiomImpl
getProperty, getRangeMethods inherited from class com.github.owlcs.ontapi.internal.objects.ONTAxiomImpl
collectAnnotations, eraseModel, getAnnotatedAxiom, getAxiomWithoutAnnotations, getConfig, getNNF, getObjectURI, getOWLObject, getSubjectBlankNodeId, getSubjectURI, hasURIObject, hasURIResource, hasURIResource, hasURISubject, merge, setHashCode, triplesMethods inherited from class com.github.owlcs.ontapi.internal.objects.ONTStatementImpl
appendAnnotations, asStatement, asTriple, equals, factoryAnnotations, fromNode, getObjectNode, getPredicateNode, getSubjectNode, sameAs, sameComponents, sameContent, sameObject, samePredicate, sameSubject, sameTriple, stripMethods inherited from class com.github.owlcs.ontapi.internal.objects.ONTObjectImpl
containsAnnotationProperty, containsDataProperty, containsDatatype, containsEntity, containsEntityInSignature, containsNamedClass, containsNamedIndividual, containsObjectProperty, createContentSet, eraseModel, getAnnotationPropertySet, getAnonymousIndividualSet, getClassExpressionSet, getDataPropertySet, getDatatypeSet, getModel, getNamedClassSet, getNamedIndividualSet, getObjectFactory, getObjectPropertySet, getPersonalityModel, getSignatureSet, toStringMethods inherited from class com.github.owlcs.ontapi.owlapi.OWLObjectImpl
annotationPropertiesInSignature, anonymousIndividuals, classesInSignature, compareIterators, compareTo, createSet, createSet, createSortedSet, createSortedSet, dataPropertiesInSignature, datatypesInSignature, equalIterators, equalStreams, forOutput, getAnnotationPropertiesInSignature, getAnonymousIndividuals, getClassesInSignature, getDataPropertiesInSignature, getDatatypesInSignature, getIndividualsInSignature, getNestedClassExpressions, getObjectPropertiesInSignature, getSignature, hashCode, individualsInSignature, mergeAnnotations, nestedClassExpressions, notSame, objectPropertiesInSignature, prepareAnnotations, signature, toContentListMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface com.github.owlcs.ontapi.internal.objects.AsStatement
asStatement, asTripleMethods inherited from interface java.lang.Comparable
compareToMethods inherited from interface org.semanticweb.owlapi.model.HasAnnotationPropertiesInSignature
annotationPropertiesInSignature, getAnnotationPropertiesInSignatureMethods inherited from interface org.semanticweb.owlapi.model.HasAnnotations
annotations, annotations, getAnnotations, getAnnotationsMethods inherited from interface org.semanticweb.owlapi.model.HasAnonymousIndividuals
anonymousIndividuals, getAnonymousIndividualsMethods inherited from interface org.semanticweb.owlapi.model.HasClassesInSignature
classesInSignature, getClassesInSignatureMethods inherited from interface org.semanticweb.owlapi.model.HasContainsEntityInSignature
containsEntityInSignatureMethods inherited from interface org.semanticweb.owlapi.model.HasDataPropertiesInSignature
dataPropertiesInSignature, getDataPropertiesInSignatureMethods inherited from interface org.semanticweb.owlapi.model.HasDatatypesInSignature
datatypesInSignature, getDatatypesInSignatureMethods inherited from interface org.semanticweb.owlapi.model.HasIndividualsInSignature
getIndividualsInSignature, individualsInSignatureMethods inherited from interface com.github.owlcs.ontapi.internal.HasObjectFactory
getDataFactory, getObjectFactoryMethods inherited from interface org.semanticweb.owlapi.model.HasObjectPropertiesInSignature
getObjectPropertiesInSignature, objectPropertiesInSignatureMethods inherited from interface org.semanticweb.owlapi.model.HasProperty
getPropertyMethods inherited from interface org.semanticweb.owlapi.model.HasRange
getRangeMethods inherited from interface org.semanticweb.owlapi.model.HasSignature
getSignature, signature, unsortedSignatureMethods inherited from interface org.semanticweb.owlapi.model.IsAnonymous
isAnonymous, isNamedMethods inherited from interface com.github.owlcs.ontapi.internal.objects.ModelObject
getModelMethods inherited from interface com.github.owlcs.ontapi.internal.objects.ONTComposite
canContainAnnotationProperties, canContainAnonymousIndividuals, canContainDatatypes, objectsMethods inherited from interface org.semanticweb.owlapi.model.OWLAnnotationAxiom
isAnnotationAxiomMethods inherited from interface org.semanticweb.owlapi.model.OWLAnnotationObject
asAnonymousIndividual, asIRIMethods inherited from interface org.semanticweb.owlapi.model.OWLAnnotationPropertyRangeAxiom
accept, accept, accept, accept, components, componentsAnnotationsFirst, componentsWithoutAnnotations, getAxiomType, getAxiomWithoutAnnotations, hashIndex, initHashCodeMethods inherited from interface org.semanticweb.owlapi.model.OWLAxiom
equalsIgnoreAnnotations, getAnnotatedAxiom, getAnnotatedAxiom, getAnnotatedAxiom, getAxiomWithoutAnnotations, getNNF, isAnnotated, isAxiom, isIndividual, isLogicalAxiom, isOfType, isOfType, isOfType, typeIndexMethods inherited from interface org.semanticweb.owlapi.model.OWLObject
getNestedClassExpressions, hasSharedStructure, isAnonymousExpression, isBottomEntity, isIRI, isOntology, isTopEntity, nestedClassExpressionsMethods inherited from interface com.github.owlcs.ontapi.internal.objects.WithAnnotations
annotations, annotationsAsList, isAnnotated
-
Constructor Details
-
AxiomImpl
protected AxiomImpl(org.apache.jena.graph.Triple t, Supplier<org.apache.jena.ontapi.model.OntModel> m)
-
-
Method Details
-
create
public static AnnotationPropertyRangeTranslator.AxiomImpl create(org.apache.jena.ontapi.model.OntStatement statement, ModelObjectFactory factory, AxiomsSettings config) Creates anONTObjectcontainer that is alsoOWLAnnotationPropertyRangeAxiom.- Parameters:
statement-OntStatement, notnullfactory-ONTObjectFactory, notnullconfig-AxiomsSettings, notnull- Returns:
AnnotationPropertyRangeTranslator.AxiomImpl
-
getURISubject
public ONTObject<? extends org.semanticweb.owlapi.model.OWLAnnotationProperty> getURISubject(ModelObjectFactory factory) -
getURIObject
public ONTObject<? extends org.semanticweb.owlapi.model.IRI> getURIObject(ModelObjectFactory factory) -
subjectFromStatement
public ONTObject<? extends org.semanticweb.owlapi.model.OWLAnnotationProperty> subjectFromStatement(org.apache.jena.ontapi.model.OntStatement statement, ModelObjectFactory factory) -
objectFromStatement
public ONTObject<? extends org.semanticweb.owlapi.model.IRI> objectFromStatement(org.apache.jena.ontapi.model.OntStatement statement, ModelObjectFactory factory) -
createAnnotatedAxiom
protected org.semanticweb.owlapi.model.OWLAnnotationPropertyRangeAxiom createAnnotatedAxiom(Collection<org.semanticweb.owlapi.model.OWLAnnotation> annotations) Description copied from class:ONTAxiomImplCreates a fresh system-wideaxiomwith the given annotations. The resulting axiom should not contain model references.- Specified by:
createAnnotatedAxiomin classONTAxiomImpl<org.semanticweb.owlapi.model.OWLAnnotationPropertyRangeAxiom>- Parameters:
annotations- aCollectionofOWLAnnotations to bind to the axiom- Returns:
ONTAxiomImpl
-
canContainNamedClasses
public final boolean canContainNamedClasses()Description copied from interface:ONTCompositeAnswerstrueif this object-container is allowed to contain (named) OWL classes.- Specified by:
canContainNamedClassesin interfaceONTComposite- Returns:
- boolean
-
canContainNamedIndividuals
public final boolean canContainNamedIndividuals()Description copied from interface:ONTCompositeAnswerstrueif this object-container is allowed to contain named individuals.- Specified by:
canContainNamedIndividualsin interfaceONTComposite- Returns:
- boolean
-
canContainObjectProperties
public final boolean canContainObjectProperties()Description copied from interface:ONTCompositeAnswerstrueif this object-container may contain named object properties.- Specified by:
canContainObjectPropertiesin interfaceONTComposite- Returns:
- boolean
-
canContainDataProperties
public final boolean canContainDataProperties()Description copied from interface:ONTCompositeAnswerstrueif this object-container may contain data properties.- Specified by:
canContainDataPropertiesin interfaceONTComposite- Returns:
- boolean
-
canContainClassExpressions
public final boolean canContainClassExpressions()Description copied from interface:ONTCompositeAnswerstrueif this object-container is allowed to contain nested class-expressions.- Specified by:
canContainClassExpressionsin interfaceONTComposite- Returns:
- boolean
-
getONTSubject
ONTObject<? extends org.semanticweb.owlapi.model.OWLAnnotationProperty> getONTSubject(ModelObjectFactory factory) Finds theONTObjectthat matches the subject using thefactory.- Parameters:
factory-ModelObjectFactoryto fetch anONTObject, notnull- Returns:
- an
ONTObjectthat can be seen as wrapper ofWithTwoObjects
-
getONTObject
Finds theONTObjectthat matches the object using thefactory.- Parameters:
factory-ModelObjectFactoryto fetch anONTObject, notnull- Returns:
- an
ONTObjectthat can be seen as wrapper ofWithTwoObjects
-
getONTSubject
Gets the subject from the base triple of this axiom.- Returns:
ONTObjectwithWithTwoObjects
-
getONTObject
Gets the object from the base triple of this axiom.- Returns:
ONTObjectwithWithTwoObjects
-
getOWLComponentsAsSet
default Set<? extends org.semanticweb.owlapi.model.OWLObject> getOWLComponentsAsSet(ModelObjectFactory factory) -
hasURIObject
default boolean hasURIObject()Answerstrueiff the subject is a URI resource.- Returns:
- boolean
-
hasURISubject
default boolean hasURISubject()Answerstrueiff the object is a URI resource.- Returns:
- boolean
-
getSubjectURI
Answers a URI of the triple's subject.- Returns:
- URI of the subject
- Throws:
RuntimeException- in case the main triple has no subject uri (b-node instead)
-
getObjectURI
Answers a URI of the triple's object.- Returns:
- URI of the object
- Throws:
RuntimeException- in case the main triple has no object uri (b-node or literal instead)
-
getOWLComponentsAsSet
Gets all OWL characteristic components in the form ofSet.- Returns:
- a sorted
SetofOWLObjects
-
isClassExpression
default boolean isClassExpression()Answerstrueiff this is anOWL Class Expression.- Returns:
- boolean
-
isAnonymousIndividual
default boolean isAnonymousIndividual()Answerstrueiff this is anOWL Anonymous Individual.- Returns:
- boolean
-
isNamedClass
default boolean isNamedClass()Answerstrueiff this is anOWL Class.- Returns:
- boolean
-
isNamedIndividual
default boolean isNamedIndividual()Answerstrueiff this is anOWL Named Individual.- Returns:
- boolean
-
isDatatype
default boolean isDatatype()Answerstrueiff this is anOWL Datatype.- Returns:
- boolean
-
isObjectProperty
default boolean isObjectProperty()Answerstrueiff this is anOWL Object Property.- Returns:
- boolean
-
isDataProperty
default boolean isDataProperty()Answerstrueiff this is anOWL Data Property.- Returns:
- boolean
-
isAnnotationProperty
default boolean isAnnotationProperty()Answerstrueiff this is anOWL Annotation Property.- Returns:
- boolean
-