Class DeclarationTranslator.AxiomImpl.SimpleImpl
java.lang.Object
com.github.owlcs.ontapi.owlapi.OWLObjectImpl
com.github.owlcs.ontapi.internal.objects.ONTObjectImpl
com.github.owlcs.ontapi.internal.objects.ONTStatementImpl
com.github.owlcs.ontapi.internal.objects.ONTAxiomImpl<org.semanticweb.owlapi.model.OWLDeclarationAxiom>
com.github.owlcs.ontapi.internal.axioms.DeclarationTranslator.AxiomImpl
com.github.owlcs.ontapi.internal.axioms.DeclarationTranslator.AxiomImpl.SimpleImpl
- All Implemented Interfaces:
HasConfig,HasObjectFactory,AsStatement,ModelObject<org.semanticweb.owlapi.model.OWLDeclarationAxiom>,ONTComposite,WithAnnotations,WithoutAnnotations,ONTObject<org.semanticweb.owlapi.model.OWLDeclarationAxiom>,WithMerge<ONTObject<org.semanticweb.owlapi.model.OWLDeclarationAxiom>>,Serializable,Comparable<org.semanticweb.owlapi.model.OWLObject>,org.apache.jena.graph.FrontsTriple,org.semanticweb.owlapi.model.HasAnnotationPropertiesInSignature,org.semanticweb.owlapi.model.HasAnnotations,org.semanticweb.owlapi.model.HasAnonymousIndividuals,org.semanticweb.owlapi.model.HasClassesInSignature,org.semanticweb.owlapi.model.HasComponents,org.semanticweb.owlapi.model.HasContainsEntityInSignature,org.semanticweb.owlapi.model.HasDataPropertiesInSignature,org.semanticweb.owlapi.model.HasDatatypesInSignature,org.semanticweb.owlapi.model.HasHashIndex,org.semanticweb.owlapi.model.HasIndex,org.semanticweb.owlapi.model.HasIndividualsInSignature,org.semanticweb.owlapi.model.HasObjectPropertiesInSignature,org.semanticweb.owlapi.model.HasSignature,org.semanticweb.owlapi.model.IsAnonymous,org.semanticweb.owlapi.model.OWLAxiom,org.semanticweb.owlapi.model.OWLDeclarationAxiom,org.semanticweb.owlapi.model.OWLObject
- Enclosing class:
DeclarationTranslator.AxiomImpl
public static class DeclarationTranslator.AxiomImpl.SimpleImpl
extends DeclarationTranslator.AxiomImpl
implements WithoutAnnotations
An
OWLDeclarationAxiom that has no annotations.- See Also:
-
Nested Class Summary
Nested classes/interfaces inherited from class com.github.owlcs.ontapi.internal.axioms.DeclarationTranslator.AxiomImpl
DeclarationTranslator.AxiomImpl.SimpleImpl, DeclarationTranslator.AxiomImpl.WithAnnotationsImpl -
Field Summary
Fields inherited from class com.github.owlcs.ontapi.internal.objects.ONTAxiomImpl
SET_HASH_CODEFields inherited from class com.github.owlcs.ontapi.internal.objects.ONTStatementImpl
object, predicate, subjectFields inherited from class com.github.owlcs.ontapi.internal.objects.ONTObjectImpl
modelFields inherited from class com.github.owlcs.ontapi.owlapi.OWLObjectImpl
DEFAULT_COMPARATOR, hashCode, NO_ANNOTATIONSFields inherited from interface com.github.owlcs.ontapi.internal.WithMerge
ONT_OBJECT_MERGER -
Constructor Summary
ConstructorsModifierConstructorDescriptionprotectedSimpleImpl(org.apache.jena.graph.Triple t, Supplier<org.apache.jena.ontapi.model.OntModel> m) -
Method Summary
Modifier and TypeMethodDescriptionbooleanAnswerstrueif this object-container is allowed to contain anonymous individuals.booleancontainsEntity(org.semanticweb.owlapi.model.OWLEntity entity) Answerstrueiff the given entity is present in the object's signature.Set<org.semanticweb.owlapi.model.OWLAnnotationProperty> Obtains the annotation properties that are in the signature of this object.Set<org.semanticweb.owlapi.model.OWLDatatype> Gets the datatypes that are in the signature of this object.Set<org.semanticweb.owlapi.model.OWLEntity> Gets the signature of this object.booleanAnswerstrueif this object (axiom or annotation) has sub-annotations.default booleanAnswerstrueiff this is anOWL Annotation Property.default booleanAnswerstrueiff this is anOWL Anonymous Individual.default booleanAnswerstrueiff this is anOWL Class Expression.default booleanAnswerstrueiff this is anOWL Data Property.default booleanAnswerstrueiff this is anOWL Datatype.default booleanAnswerstrueiff this is anOWL Class.default booleanAnswerstrueiff this is anOWL Named Individual.default booleanAnswerstrueiff this is anOWL Object Property.Methods inherited from class com.github.owlcs.ontapi.internal.axioms.DeclarationTranslator.AxiomImpl
asStatement, create, createAnnotatedAxiom, findONTEntity, getClassExpressionSet, getDataPropertySet, getEntity, getNamedClassSet, getNamedIndividualSet, getObjectPropertySet, getONTEntity, getResource, getResourceType, objects, sameContentMethods inherited from class com.github.owlcs.ontapi.internal.objects.ONTAxiomImpl
collectAnnotations, eraseModel, getAnnotatedAxiom, getAxiomWithoutAnnotations, getConfig, getNNF, getObjectURI, getOWLObject, getSubjectBlankNodeId, getSubjectURI, hasURIObject, hasURIResource, hasURIResource, hasURISubject, merge, setHashCode, triplesMethods inherited from class com.github.owlcs.ontapi.internal.objects.ONTStatementImpl
appendAnnotations, asTriple, equals, factoryAnnotations, fromNode, getObjectNode, getPredicateNode, getSubjectNode, sameAs, sameComponents, sameObject, samePredicate, sameSubject, sameTriple, stripMethods inherited from class com.github.owlcs.ontapi.internal.objects.ONTObjectImpl
containsAnnotationProperty, containsDataProperty, containsDatatype, containsEntityInSignature, containsNamedClass, containsNamedIndividual, containsObjectProperty, createContentSet, eraseModel, getAnonymousIndividualSet, getModel, getObjectFactory, getPersonalityModel, toStringMethods inherited from class com.github.owlcs.ontapi.owlapi.OWLObjectImpl
annotationPropertiesInSignature, anonymousIndividuals, classesInSignature, compareIterators, compareTo, createSet, createSet, createSortedSet, createSortedSet, dataPropertiesInSignature, datatypesInSignature, equalIterators, equalStreams, forOutput, getAnnotationPropertiesInSignature, getAnonymousIndividuals, getClassesInSignature, getDataPropertiesInSignature, getDatatypesInSignature, getIndividualsInSignature, getNestedClassExpressions, getObjectPropertiesInSignature, getSignature, hashCode, individualsInSignature, mergeAnnotations, nestedClassExpressions, notSame, objectPropertiesInSignature, prepareAnnotations, signature, toContentListMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface java.lang.Comparable
compareToMethods inherited from interface org.semanticweb.owlapi.model.HasAnnotationPropertiesInSignature
annotationPropertiesInSignature, getAnnotationPropertiesInSignatureMethods inherited from interface org.semanticweb.owlapi.model.HasAnnotations
annotations, annotations, getAnnotations, getAnnotationsMethods inherited from interface org.semanticweb.owlapi.model.HasAnonymousIndividuals
anonymousIndividuals, getAnonymousIndividualsMethods inherited from interface org.semanticweb.owlapi.model.HasClassesInSignature
classesInSignature, getClassesInSignatureMethods inherited from interface org.semanticweb.owlapi.model.HasContainsEntityInSignature
containsEntityInSignatureMethods inherited from interface org.semanticweb.owlapi.model.HasDataPropertiesInSignature
dataPropertiesInSignature, getDataPropertiesInSignatureMethods inherited from interface org.semanticweb.owlapi.model.HasDatatypesInSignature
datatypesInSignature, getDatatypesInSignatureMethods inherited from interface org.semanticweb.owlapi.model.HasIndividualsInSignature
getIndividualsInSignature, individualsInSignatureMethods inherited from interface com.github.owlcs.ontapi.internal.HasObjectFactory
getDataFactoryMethods inherited from interface org.semanticweb.owlapi.model.HasObjectPropertiesInSignature
getObjectPropertiesInSignature, objectPropertiesInSignatureMethods inherited from interface org.semanticweb.owlapi.model.HasSignature
getSignature, signature, unsortedSignatureMethods inherited from interface org.semanticweb.owlapi.model.IsAnonymous
isAnonymous, isNamedMethods inherited from interface com.github.owlcs.ontapi.internal.objects.ModelObject
getModelMethods inherited from interface com.github.owlcs.ontapi.internal.objects.ONTComposite
canContainAnnotationProperties, canContainClassExpressions, canContainDataProperties, canContainDatatypes, canContainNamedClasses, canContainNamedIndividuals, canContainObjectPropertiesMethods inherited from interface org.semanticweb.owlapi.model.OWLAxiom
equalsIgnoreAnnotations, getAnnotatedAxiom, getAnnotatedAxiom, getAnnotatedAxiom, getAxiomWithoutAnnotations, getNNF, isAnnotationAxiom, isAxiom, isIndividual, isLogicalAxiom, isOfType, isOfType, isOfType, typeIndexMethods inherited from interface org.semanticweb.owlapi.model.OWLDeclarationAxiom
accept, accept, accept, accept, components, componentsAnnotationsFirst, componentsWithoutAnnotations, getAxiomType, getAxiomWithoutAnnotations, hashIndex, initHashCodeMethods inherited from interface org.semanticweb.owlapi.model.OWLObject
getNestedClassExpressions, hasSharedStructure, isAnonymousExpression, isBottomEntity, isIRI, isOntology, isTopEntity, nestedClassExpressionsMethods inherited from interface com.github.owlcs.ontapi.internal.objects.WithoutAnnotations
annotations, annotationsAsList
-
Constructor Details
-
SimpleImpl
protected SimpleImpl(org.apache.jena.graph.Triple t, Supplier<org.apache.jena.ontapi.model.OntModel> m)
-
-
Method Details
-
containsEntity
public boolean containsEntity(org.semanticweb.owlapi.model.OWLEntity entity) Description copied from class:ONTObjectImplAnswerstrueiff the given entity is present in the object's signature.- Overrides:
containsEntityin classONTObjectImpl- Parameters:
entity-OWLEntity, notnull- Returns:
- boolean
-
getSignatureSet
Description copied from class:OWLObjectImplGets the signature of this object. The set is a copy, changes are not reflected back.- Overrides:
getSignatureSetin classONTObjectImpl- Returns:
- a modifiable sorted
Setof entities that represents the signature of this object
-
getDatatypeSet
Description copied from class:OWLObjectImplGets the datatypes that are in the signature of this object. The set is a copy, changes are not reflected back.- Overrides:
getDatatypeSetin classONTObjectImpl- Returns:
- a modifiable sorted
Setof the datatypes that are in the signature of this object
-
getAnnotationPropertySet
Description copied from class:OWLObjectImplObtains the annotation properties that are in the signature of this object. The set is a copy, changes are not reflected back.- Overrides:
getAnnotationPropertySetin classONTObjectImpl- Returns:
- a modifiable sorted
Setof the annotation properties that are in the signature of this object
-
canContainAnonymousIndividuals
public boolean canContainAnonymousIndividuals()Description copied from interface:ONTCompositeAnswerstrueif this object-container is allowed to contain anonymous individuals.- Specified by:
canContainAnonymousIndividualsin interfaceONTComposite- Returns:
- boolean
-
isAnnotated
public boolean isAnnotated()Description copied from interface:WithAnnotationsAnswerstrueif this object (axiom or annotation) has sub-annotations.- Specified by:
isAnnotatedin interfaceorg.semanticweb.owlapi.model.OWLAxiom- Specified by:
isAnnotatedin interfaceWithAnnotations- Specified by:
isAnnotatedin interfaceWithoutAnnotations- Returns:
- boolean
- See Also:
-
isClassExpression
default boolean isClassExpression()Answerstrueiff this is anOWL Class Expression.- Returns:
- boolean
-
isAnonymousIndividual
default boolean isAnonymousIndividual()Answerstrueiff this is anOWL Anonymous Individual.- Returns:
- boolean
-
isNamedClass
default boolean isNamedClass()Answerstrueiff this is anOWL Class.- Returns:
- boolean
-
isNamedIndividual
default boolean isNamedIndividual()Answerstrueiff this is anOWL Named Individual.- Returns:
- boolean
-
isDatatype
default boolean isDatatype()Answerstrueiff this is anOWL Datatype.- Returns:
- boolean
-
isObjectProperty
default boolean isObjectProperty()Answerstrueiff this is anOWL Object Property.- Returns:
- boolean
-
isDataProperty
default boolean isDataProperty()Answerstrueiff this is anOWL Data Property.- Returns:
- boolean
-
isAnnotationProperty
default boolean isAnnotationProperty()Answerstrueiff this is anOWL Annotation Property.- Returns:
- boolean
-