Class FunctionalDataPropertyTranslator
java.lang.Object
com.github.owlcs.ontapi.internal.BaseSearcher
com.github.owlcs.ontapi.internal.AxiomTranslator<org.semanticweb.owlapi.model.OWLFunctionalDataPropertyAxiom>
com.github.owlcs.ontapi.internal.axioms.AbstractPropertyTypeTranslator<org.semanticweb.owlapi.model.OWLFunctionalDataPropertyAxiom,org.apache.jena.ontapi.model.OntDataProperty>
com.github.owlcs.ontapi.internal.axioms.FunctionalDataPropertyTranslator
- All Implemented Interfaces:
ObjectsSearcher<org.semanticweb.owlapi.model.OWLFunctionalDataPropertyAxiom>
public class FunctionalDataPropertyTranslator
extends AbstractPropertyTypeTranslator<org.semanticweb.owlapi.model.OWLFunctionalDataPropertyAxiom,org.apache.jena.ontapi.model.OntDataProperty>
A translator that provides
OWLFunctionalDataPropertyAxiom implementations.
Example:
foaf:gender rdf:type owl:DatatypeProperty , owl:FunctionalProperty ;
Created by @ssz on 30.09.2016.
-
Nested Class Summary
Nested ClassesNested classes/interfaces inherited from class com.github.owlcs.ontapi.internal.axioms.AbstractPropertyTypeTranslator
AbstractPropertyTypeTranslator.ObjectAxiomImpl<A extends org.semanticweb.owlapi.model.OWLObjectPropertyCharacteristicAxiom>, AbstractPropertyTypeTranslator.UnaryAxiomImpl<A extends org.semanticweb.owlapi.model.OWLUnaryPropertyAxiom<P>,P extends org.semanticweb.owlapi.model.OWLPropertyExpression> -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionprotected final Collection<org.apache.jena.graph.Triple> getSearchTriples(org.semanticweb.owlapi.model.OWLFunctionalDataPropertyAxiom axiom) Returns a collection oftriples for search optimization.ONTObject<org.semanticweb.owlapi.model.OWLFunctionalDataPropertyAxiom> toAxiomImpl(org.apache.jena.ontapi.model.OntStatement statement, ModelObjectFactory factory, AxiomsSettings config) Creates an OWL Axiom impl from a statement.ONTObject<org.semanticweb.owlapi.model.OWLFunctionalDataPropertyAxiom> toAxiomWrap(org.apache.jena.ontapi.model.OntStatement statement, ONTObjectFactory factory, AxiomsSettings config) Creates an OWL Axiom wrapper from a statement.Methods inherited from class com.github.owlcs.ontapi.internal.axioms.AbstractPropertyTypeTranslator
listStatements, testStatement, writeMethods inherited from class com.github.owlcs.ontapi.internal.AxiomTranslator
axioms, containsONTObject, findONTObject, get, getConfig, getObjectFactory, listAxioms, listONTObjects, listSearchStatements, listSearchStatements, statements, testStatement, toAxiom, toAxiomMethods inherited from class com.github.owlcs.ontapi.internal.BaseSearcher
getSystemResources, getTranslator, listByObject, listByPredicate, listByPredicateAndObject, listBySubject, listBySubjectAndPredicate, listStatements, listStatements, selectTranslators, split, toAxiom, translate
-
Constructor Details
-
FunctionalDataPropertyTranslator
public FunctionalDataPropertyTranslator()
-
-
Method Details
-
toAxiomImpl
public ONTObject<org.semanticweb.owlapi.model.OWLFunctionalDataPropertyAxiom> toAxiomImpl(org.apache.jena.ontapi.model.OntStatement statement, ModelObjectFactory factory, AxiomsSettings config) Description copied from class:AxiomTranslatorCreates an OWL Axiom impl from a statement. Impl note: the method returnsONTAxiomImplinstance that is attached to the model.- Specified by:
toAxiomImplin classAxiomTranslator<org.semanticweb.owlapi.model.OWLFunctionalDataPropertyAxiom>- Parameters:
statement-OntStatementthe statement which determines the axiomfactory-ModelObjectFactorythe data factory to create OWL-API objectsconfig-AxiomsSettingsto control the process- Returns:
ONTObjectaroundOWLAxiom
-
toAxiomWrap
public ONTObject<org.semanticweb.owlapi.model.OWLFunctionalDataPropertyAxiom> toAxiomWrap(org.apache.jena.ontapi.model.OntStatement statement, ONTObjectFactory factory, AxiomsSettings config) Description copied from class:AxiomTranslatorCreates an OWL Axiom wrapper from a statement. Impl note: the method returns a simpleONT Wrapperwith an actualAxiomTranslatorinstance inside, that is created by the system-wideData Factory.- Specified by:
toAxiomWrapin classAxiomTranslator<org.semanticweb.owlapi.model.OWLFunctionalDataPropertyAxiom>- Parameters:
statement-OntStatementthe statement which determines the axiomfactory-ONTObjectFactorythe data factory to create OWL-API objectsconfig-AxiomsSettingsto control the process- Returns:
ONTObjectaroundOWLAxiom
-
getSearchTriples
protected final Collection<org.apache.jena.graph.Triple> getSearchTriples(org.semanticweb.owlapi.model.OWLFunctionalDataPropertyAxiom axiom) Description copied from class:AxiomTranslatorReturns a collection oftriples for search optimization. Usually, each of the returned triples has a URI-subject and URI-object. This is a helper method to optimize searching on a direct model (i.e., when there is no internal cache).- Overrides:
getSearchTriplesin classAxiomTranslator<Axiom extends org.semanticweb.owlapi.model.OWLAxiom>- Parameters:
axiom-AxiomTranslatorto extract triples, notnull- Returns:
- a
CollectionofTriples, can be empty
-