content
protected final InternalCache.Loading<InverseFunctionalObjectPropertyTranslator.AxiomImpl.ComplexImpl,Object[]> content
com.github.owlcs.ontapi.internal.axioms.WithOneObject.Complex<InverseFunctionalObjectPropertyTranslator.AxiomImpl.ComplexImpl,org.semanticweb.owlapi.model.OWLObjectPropertyExpression> , HasConfig, HasObjectFactory, AsStatement, ModelObject<org.semanticweb.owlapi.model.OWLInverseFunctionalObjectPropertyAxiom>, ONTComposite, WithAnnotations, WithContent<InverseFunctionalObjectPropertyTranslator.AxiomImpl.ComplexImpl>, ONTObject<org.semanticweb.owlapi.model.OWLInverseFunctionalObjectPropertyAxiom>, WithMerge<ONTObject<org.semanticweb.owlapi.model.OWLInverseFunctionalObjectPropertyAxiom>>, Serializable, Comparable<org.semanticweb.owlapi.model.OWLObject>, org.apache.jena.graph.FrontsTriple, org.semanticweb.owlapi.model.HasAnnotationPropertiesInSignature, org.semanticweb.owlapi.model.HasAnnotations, org.semanticweb.owlapi.model.HasAnonymousIndividuals, org.semanticweb.owlapi.model.HasClassesInSignature, org.semanticweb.owlapi.model.HasComponents, org.semanticweb.owlapi.model.HasContainsEntityInSignature, org.semanticweb.owlapi.model.HasDataPropertiesInSignature, org.semanticweb.owlapi.model.HasDatatypesInSignature, org.semanticweb.owlapi.model.HasHashIndex, org.semanticweb.owlapi.model.HasIndex, org.semanticweb.owlapi.model.HasIndividualsInSignature, org.semanticweb.owlapi.model.HasObjectPropertiesInSignature, org.semanticweb.owlapi.model.HasProperty<org.semanticweb.owlapi.model.OWLObjectPropertyExpression>, org.semanticweb.owlapi.model.HasSignature, org.semanticweb.owlapi.model.IsAnonymous, org.semanticweb.owlapi.model.OWLAxiom, org.semanticweb.owlapi.model.OWLInverseFunctionalObjectPropertyAxiom, org.semanticweb.owlapi.model.OWLLogicalAxiom, org.semanticweb.owlapi.model.OWLObject, org.semanticweb.owlapi.model.OWLObjectPropertyAxiom, org.semanticweb.owlapi.model.OWLObjectPropertyCharacteristicAxiom, org.semanticweb.owlapi.model.OWLPropertyAxiom, org.semanticweb.owlapi.model.OWLSubClassOfAxiomShortCut, org.semanticweb.owlapi.model.OWLUnaryPropertyAxiom<org.semanticweb.owlapi.model.OWLObjectPropertyExpression>InverseFunctionalObjectPropertyTranslator.AxiomImplOWLInverseFunctionalObjectPropertyAxiom
that either has annotations or an anonymous object property expression (inverse object property)
in the main triple's subject position.
It has a public constructor since this class is more generic then InverseFunctionalObjectPropertyTranslator.AxiomImpl.SimpleImpl.InverseFunctionalObjectPropertyTranslator.AxiomImpl.ComplexImpl, InverseFunctionalObjectPropertyTranslator.AxiomImpl.SimpleImplprotected final InternalCache.Loading<InverseFunctionalObjectPropertyTranslator.AxiomImpl.ComplexImpl,Object[]> SET_HASH_CODEobject, predicate, subjectmodelDEFAULT_COMPARATOR, hashCode, NO_ANNOTATIONSONT_OBJECT_MERGERComplexImpl(org.apache.jena.graph.Triple t,
Supplier<org.apache.jena.ontapi.model.OntModel> m) ONTObject<? extends org.semanticweb.owlapi.model.OWLObjectPropertyExpression> fetchONTSubject(org.apache.jena.ontapi.model.OntStatement statement,
ModelObjectFactory factory) ONTObject<? extends org.semanticweb.owlapi.model.OWLObjectPropertyExpression> findURISubject(ModelObjectFactory factory) WithContent.createContentCache().default Stringdefault ONTObject<? extends org.semanticweb.owlapi.model.OWLObjectPropertyExpression> default Set<? extends org.semanticweb.owlapi.model.OWLObject> Set.default Set<? extends org.semanticweb.owlapi.model.OWLObject> getOWLComponentsAsSet(ModelObjectFactory factory) default Stringdefault booleantrue iff the subject is a URI resource.default booleantrue iff the object is a URI resource.default booleantrue iff
this is an OWL Annotation Property.default booleantrue iff
this is an OWL Anonymous Individual.default booleantrue iff
this is an OWL Class Expression.default booleantrue iff
this is an OWL Data Property.default booleantrue iff
this is an OWL Datatype.default booleantrue iff
this is an OWL Class.default booleantrue iff
this is an OWL Named Individual.default booleantrue iff
this is an OWL Object Property.ONTObject<org.semanticweb.owlapi.model.OWLInverseFunctionalObjectPropertyAxiom> other into a new one of the same type WithMerge.protected booleansameContent(ONTStatementImpl other) true if this object and the given have the same content.asOWLSubClassOfAxiom, create, createAnnotatedAxiomcanContainDataProperties, fetchONTSubject, findURISubjectcanContainAnnotationProperties, canContainAnonymousIndividuals, canContainClassExpressions, canContainDatatypes, canContainNamedClasses, canContainNamedIndividuals, getPropertycollectAnnotations, eraseModel, getAnnotatedAxiom, getAxiomWithoutAnnotations, getConfig, getNNF, getObjectURI, getOWLObject, getSubjectBlankNodeId, getSubjectURI, hasURIObject, hasURIResource, hasURIResource, hasURISubject, setHashCode, triplesappendAnnotations, asStatement, asTriple, equals, factoryAnnotations, fromNode, getObjectNode, getPredicateNode, getSubjectNode, sameAs, sameComponents, sameObject, samePredicate, sameSubject, sameTriple, stripcontainsAnnotationProperty, containsDataProperty, containsDatatype, containsEntity, containsEntityInSignature, containsNamedClass, containsNamedIndividual, containsObjectProperty, createContentSet, eraseModel, getAnnotationPropertySet, getAnonymousIndividualSet, getClassExpressionSet, getDataPropertySet, getDatatypeSet, getModel, getNamedClassSet, getNamedIndividualSet, getObjectFactory, getObjectPropertySet, getPersonalityModel, getSignatureSet, toStringannotationPropertiesInSignature, anonymousIndividuals, classesInSignature, compareIterators, compareTo, createSet, createSet, createSortedSet, createSortedSet, dataPropertiesInSignature, datatypesInSignature, equalIterators, equalStreams, forOutput, getAnnotationPropertiesInSignature, getAnonymousIndividuals, getClassesInSignature, getDataPropertiesInSignature, getDatatypesInSignature, getIndividualsInSignature, getNestedClassExpressions, getObjectPropertiesInSignature, getSignature, hashCode, individualsInSignature, mergeAnnotations, nestedClassExpressions, notSame, objectPropertiesInSignature, prepareAnnotations, signature, toContentListclone, finalize, getClass, notify, notifyAll, wait, wait, waitasStatement, asTriplecompareToannotationPropertiesInSignature, getAnnotationPropertiesInSignatureannotations, annotations, getAnnotations, getAnnotationsanonymousIndividuals, getAnonymousIndividualsclassesInSignature, getClassesInSignaturecontainsEntityInSignaturedataPropertiesInSignature, getDataPropertiesInSignaturedatatypesInSignature, getDatatypesInSignaturegetIndividualsInSignature, individualsInSignaturegetDataFactory, getObjectFactorygetObjectPropertiesInSignature, objectPropertiesInSignaturegetPropertygetSignature, signature, unsortedSignatureisAnonymous, isNamedgetModelcanContainAnnotationProperties, canContainAnonymousIndividuals, canContainClassExpressions, canContainDataProperties, canContainDatatypes, canContainNamedClasses, canContainNamedIndividuals, canContainObjectPropertiesequalsIgnoreAnnotations, getAnnotatedAxiom, getAnnotatedAxiom, getAnnotatedAxiom, getAxiomWithoutAnnotations, getNNF, isAnnotated, isAnnotationAxiom, isAxiom, isIndividual, isOfType, isOfType, isOfType, typeIndexaccept, accept, accept, accept, getAxiomType, getAxiomWithoutAnnotations, hashIndexisLogicalAxiomgetNestedClassExpressions, hasSharedStructure, isAnonymousExpression, isBottomEntity, isIRI, isOntology, isTopEntity, nestedClassExpressionscomponents, componentsAnnotationsFirst, componentsWithoutAnnotations, initHashCodeclearContent, createContentCache, getContent, hasContent, putContentannotations, annotationsAsList, collectContent, findONTValue, isAnnotated, objectsWithContentWithContent.createContentCache().getContentCache in interface WithContent<InverseFunctionalObjectPropertyTranslator.AxiomImpl.ComplexImpl>InternalCache.Loading for an arrayONTStatementImpltrue if this object and the given have the same content.
Two OWLObjects may have same content,
but different base triples (see ONTStatementImpl.sameTriple(ONTStatementImpl)).sameContent in class AbstractPropertyTypeTranslator.ObjectAxiomImpl<org.semanticweb.owlapi.model.OWLInverseFunctionalObjectPropertyAxiom>other - ONTStatementImpl, not nullWithMergeother into a new one of the same type WithMerge.merge in interface WithMerge<ONTObject<org.semanticweb.owlapi.model.OWLInverseFunctionalObjectPropertyAxiom>>merge in class ONTAxiomImpl<org.semanticweb.owlapi.model.OWLInverseFunctionalObjectPropertyAxiom>other - that equals to this object, not nullWithMerge which equal to thistrue iff the subject is a URI resource.true iff the object is a URI resource.RuntimeException - in case the main triple has no subject uri (b-node instead)RuntimeException - in case the main triple has no object uri (b-node or literal instead)Set.Set of OWLObjectstrue iff
this is an OWL Class Expression.true iff
this is an OWL Anonymous Individual.true iff
this is an OWL Class.true iff
this is an OWL Named Individual.true iff
this is an OWL Datatype.true iff
this is an OWL Object Property.true iff
this is an OWL Data Property.true iff
this is an OWL Annotation Property.