content
protected final InternalCache.Loading<InverseObjectPropertiesTranslator.AxiomImpl.ComplexImpl,Object[]> content
com.github.owlcs.ontapi.internal.axioms.WithManyObjects.Complex<InverseObjectPropertiesTranslator.AxiomImpl.ComplexImpl,org.semanticweb.owlapi.model.OWLObjectPropertyExpression> , HasConfig, HasObjectFactory, AsStatement, ModelObject<org.semanticweb.owlapi.model.OWLInverseObjectPropertiesAxiom>, ONTComposite, WithAnnotations, WithContent<InverseObjectPropertiesTranslator.AxiomImpl.ComplexImpl>, ONTObject<org.semanticweb.owlapi.model.OWLInverseObjectPropertiesAxiom>, WithMerge<ONTObject<org.semanticweb.owlapi.model.OWLInverseObjectPropertiesAxiom>>, Serializable, Comparable<org.semanticweb.owlapi.model.OWLObject>, org.apache.jena.graph.FrontsTriple, org.semanticweb.owlapi.model.HasAnnotationPropertiesInSignature, org.semanticweb.owlapi.model.HasAnnotations, org.semanticweb.owlapi.model.HasAnonymousIndividuals, org.semanticweb.owlapi.model.HasClassesInSignature, org.semanticweb.owlapi.model.HasComponents, org.semanticweb.owlapi.model.HasContainsEntityInSignature, org.semanticweb.owlapi.model.HasDataPropertiesInSignature, org.semanticweb.owlapi.model.HasDatatypesInSignature, org.semanticweb.owlapi.model.HasHashIndex, org.semanticweb.owlapi.model.HasIndex, org.semanticweb.owlapi.model.HasIndividualsInSignature, org.semanticweb.owlapi.model.HasObjectPropertiesInSignature, org.semanticweb.owlapi.model.HasOperands<org.semanticweb.owlapi.model.OWLObjectPropertyExpression>, org.semanticweb.owlapi.model.HasSignature, org.semanticweb.owlapi.model.IsAnonymous, org.semanticweb.owlapi.model.OWLAxiom, org.semanticweb.owlapi.model.OWLInverseObjectPropertiesAxiom, org.semanticweb.owlapi.model.OWLLogicalAxiom, org.semanticweb.owlapi.model.OWLNaryAxiom<org.semanticweb.owlapi.model.OWLObjectPropertyExpression>, org.semanticweb.owlapi.model.OWLNaryPropertyAxiom<org.semanticweb.owlapi.model.OWLObjectPropertyExpression>, org.semanticweb.owlapi.model.OWLObject, org.semanticweb.owlapi.model.OWLObjectPropertyAxiom, org.semanticweb.owlapi.model.OWLPropertyAxiomInverseObjectPropertiesTranslator.AxiomImplOWLInverseObjectPropertiesAxiom
that either has annotations or anonymous object expressions (OWLObjectInverseOf)
in subject or object positions.
It has a public constructor since it is more generic then InverseObjectPropertiesTranslator.AxiomImpl.SimpleImpl.InverseObjectPropertiesTranslator.AxiomImpl.ComplexImpl, InverseObjectPropertiesTranslator.AxiomImpl.SimpleImplprotected final InternalCache.Loading<InverseObjectPropertiesTranslator.AxiomImpl.ComplexImpl,Object[]> SET_HASH_CODEobject, predicate, subjectmodelDEFAULT_COMPARATOR, hashCode, NO_ANNOTATIONSONT_OBJECT_MERGERprotected ComplexImpl(Object s,
String p,
Object o,
Supplier<org.apache.jena.ontapi.model.OntModel> m) ComplexImpl(org.apache.jena.graph.Triple t,
Supplier<org.apache.jena.ontapi.model.OntModel> m) default Stream<org.semanticweb.owlapi.model.OWLAnnotation> OWLAnnotations on this object.default List<org.semanticweb.owlapi.model.OWLAnnotation> List of OWLAnnotations on this object.fetchONTComponents(org.apache.jena.ontapi.model.OntStatement statement,
ModelObjectFactory factory) ONTObjects) in the form of sorted Set.ONTObject<? extends org.semanticweb.owlapi.model.OWLObjectPropertyExpression> findByURI(String uri,
ModelObjectFactory factory) ONTObject-wrapper from the factory.WithContent.createContentCache().ONTObject<? extends org.semanticweb.owlapi.model.OWLObjectPropertyExpression> default Stringdefault Set<? extends org.semanticweb.owlapi.model.OWLObject> Set.ONTObject<? extends org.semanticweb.owlapi.model.OWLObjectPropertyExpression> default Set<org.semanticweb.owlapi.model.OWLObjectPropertyExpression> getSetMinus(org.semanticweb.owlapi.model.OWLObjectPropertyExpression... excludes) Set with exclusion of the specified.default Stringdefault booleantrue iff the subject is a URI resource.default booleantrue iff the object is a URI resource.default booleantrue if this object (axiom or annotation) has sub-annotations.default booleantrue iff
this is an OWL Annotation Property.default booleantrue iff
this is an OWL Anonymous Individual.default booleantrue iff
this is an OWL Class Expression.default booleantrue iff
this is an OWL Data Property.default booleantrue iff
this is an OWL Datatype.default booleantrue iff
this is an OWL Class.default booleantrue iff
this is an OWL Named Individual.default booleantrue iff
this is an OWL Object Property.org.apache.jena.util.iterator.ExtendedIterator<ONTObject<? extends org.semanticweb.owlapi.model.OWLObjectPropertyExpression>> listONTComponents(org.apache.jena.ontapi.model.OntStatement statement,
ModelObjectFactory factory) org.apache.jena.util.iterator.ExtendedIterator<ONTObject<? extends org.semanticweb.owlapi.model.OWLObjectPropertyExpression>> listONTComponents(org.apache.jena.ontapi.model.OntStatement statement,
ModelObjectFactory factory) members()objects()Stream.protected booleansameContent(ONTStatementImpl other) true if this object and the given have the same content.sorted()default ObjectasPairwiseAxioms, asSubObjectPropertyOfAxioms, canContainAnnotationProperties, canContainAnonymousIndividuals, canContainClassExpressions, canContainDataProperties, canContainDatatypes, canContainNamedClasses, canContainNamedIndividuals, create, createAnnotatedAxiom, findByURI, getFirstProperty, getPropertiesMinus, getSecondProperty, listONTComponents, merge, properties, splitToAnnotatedPairscollectAnnotations, eraseModel, getAnnotatedAxiom, getAxiomWithoutAnnotations, getConfig, getNNF, getObjectURI, getOWLObject, getSubjectBlankNodeId, getSubjectURI, hasURIObject, hasURIResource, hasURIResource, hasURISubject, setHashCode, triplesappendAnnotations, asStatement, asTriple, equals, factoryAnnotations, fromNode, getObjectNode, getPredicateNode, getSubjectNode, sameAs, sameComponents, sameObject, samePredicate, sameSubject, sameTriple, stripcontainsAnnotationProperty, containsDataProperty, containsDatatype, containsEntity, containsEntityInSignature, containsNamedClass, containsNamedIndividual, containsObjectProperty, createContentSet, eraseModel, getAnnotationPropertySet, getAnonymousIndividualSet, getClassExpressionSet, getDataPropertySet, getDatatypeSet, getModel, getNamedClassSet, getNamedIndividualSet, getObjectFactory, getObjectPropertySet, getPersonalityModel, getSignatureSet, toStringannotationPropertiesInSignature, anonymousIndividuals, classesInSignature, compareIterators, compareTo, createSet, createSet, createSortedSet, createSortedSet, dataPropertiesInSignature, datatypesInSignature, equalIterators, equalStreams, forOutput, getAnnotationPropertiesInSignature, getAnonymousIndividuals, getClassesInSignature, getDataPropertiesInSignature, getDatatypesInSignature, getIndividualsInSignature, getNestedClassExpressions, getObjectPropertiesInSignature, getSignature, hashCode, individualsInSignature, mergeAnnotations, nestedClassExpressions, notSame, objectPropertiesInSignature, prepareAnnotations, signature, toContentListclone, finalize, getClass, notify, notifyAll, wait, wait, waitasStatement, asTriplecompareToannotationPropertiesInSignature, getAnnotationPropertiesInSignatureannotations, annotations, getAnnotations, getAnnotationsanonymousIndividuals, getAnonymousIndividualsclassesInSignature, getClassesInSignaturecontainsEntityInSignaturedataPropertiesInSignature, getDataPropertiesInSignaturedatatypesInSignature, getDatatypesInSignaturegetIndividualsInSignature, individualsInSignaturegetDataFactory, getObjectFactorygetObjectPropertiesInSignature, objectPropertiesInSignaturegetOperandsAsListgetSignature, signature, unsortedSignatureisAnonymous, isNamedgetModelcanContainAnnotationProperties, canContainAnonymousIndividuals, canContainClassExpressions, canContainDataProperties, canContainDatatypes, canContainNamedClasses, canContainNamedIndividuals, canContainObjectPropertiesequalsIgnoreAnnotations, getAnnotatedAxiom, getAnnotatedAxiom, getAnnotatedAxiom, getAxiomWithoutAnnotations, getNNF, isAnnotated, isAnnotationAxiom, isAxiom, isIndividual, isOfType, isOfType, isOfType, typeIndexaccept, accept, accept, accept, getAxiomType, getAxiomWithoutAnnotations, hashIndexisLogicalAxiomallMatch, allMatchAllPairs, anyMatch, anyMatchAllPairs, forEach, forEachAllPairs, walkAllPairwise, walkPairwisecomponents, componentsAnnotationsFirst, componentsWithoutAnnotations, getProperties, initHashCode, operandsgetNestedClassExpressions, hasSharedStructure, isAnonymousExpression, isBottomEntity, isIRI, isOntology, isTopEntity, nestedClassExpressionsclearContent, createContentCache, getContent, hasContent, putContentcollectContent, fromContentItem, getOWLComponentsAsSet, members, objects, sortedWithContentWithContent.createContentCache().getContentCache in interface WithContent<InverseObjectPropertiesTranslator.AxiomImpl.ComplexImpl>InternalCache.Loading for an arraygetFirstONTProperty in class InverseObjectPropertiesTranslator.AxiomImplgetSecondONTProperty in class InverseObjectPropertiesTranslator.AxiomImplONTStatementImpltrue if this object and the given have the same content.
Two OWLObjects may have same content,
but different base triples (see ONTStatementImpl.sameTriple(ONTStatementImpl)).sameContent in class ONTStatementImplother - ONTStatementImpl, not nullONTObject-wrapper from the factory.uri - String, an entity URI, not nullfactory - ModelObjectFactory, not nullONTObject of WithManyObjectsstatement - OntStatement, the source, not nullfactory - ModelObjectFactory, not nullExtendedIterator of ONTObject with type WithManyObjectsONTObjects) in the form of sorted Set.statement - OntStatement, the source, not nullfactory - ModelObjectFactory, not nullSet of ONTObject with type WithManyObjectsStream of ONTObjects that wrap WithManyObjectssStream of ONTObjects that wrap WithManyObjectssONTCompositeStream.
Neither this object nor parts of its components are not included in the result:
it content only top-level direct components.
Note that HasComponents.components() may also contain non-OWLObject things:
integers (e.g. cardinality), Lists (e.g. ObjectOneOf), etc,
while this method is only for OWLObjects which are represented as ONTObjects.objects in interface ONTCompositeStream of ONTObjectsSet with exclusion of the specified.excludes - an Array of WithManyObjectss, not nullSet of WithManyObjectsstrue iff the subject is a URI resource.true iff the object is a URI resource.RuntimeException - in case the main triple has no subject uri (b-node instead)RuntimeException - in case the main triple has no object uri (b-node or literal instead)Set.Set of OWLObjectstrue iff
this is an OWL Class Expression.true iff
this is an OWL Anonymous Individual.true iff
this is an OWL Class.true iff
this is an OWL Named Individual.true iff
this is an OWL Datatype.true iff
this is an OWL Object Property.true iff
this is an OWL Data Property.true iff
this is an OWL Annotation Property.statement - OntStatement, not nullfactory - ModelObjectFactory to create ONTObjects, not nullExtendedIterator of ONTObjects with WithListsWithAnnotationstrue if this object (axiom or annotation) has sub-annotations.isAnnotated in interface org.semanticweb.owlapi.model.OWLAxiomisAnnotated in interface WithAnnotationsWithAnnotationsannotations in interface org.semanticweb.owlapi.model.HasAnnotationsannotations in interface WithAnnotationsStream of OWLAnnotationsWithAnnotationsList of OWLAnnotations on this object.
The returned List is unmodifiable.annotationsAsList in interface org.semanticweb.owlapi.model.HasAnnotationsannotationsAsList in interface WithAnnotationsList of OWLAnnotationsx - ONTObject to cache, not null