Class SubAnnotationPropertyOfTranslator.AxiomImpl.SimpleImpl
java.lang.Object
com.github.owlcs.ontapi.owlapi.OWLObjectImpl
com.github.owlcs.ontapi.internal.objects.ONTObjectImpl
com.github.owlcs.ontapi.internal.objects.ONTStatementImpl
com.github.owlcs.ontapi.internal.objects.ONTAxiomImpl<org.semanticweb.owlapi.model.OWLSubAnnotationPropertyOfAxiom>
com.github.owlcs.ontapi.internal.axioms.AbstractSubPropertyTranslator.SubPropertyAxiomImpl<org.semanticweb.owlapi.model.OWLSubAnnotationPropertyOfAxiom,org.semanticweb.owlapi.model.OWLAnnotationProperty>
com.github.owlcs.ontapi.internal.axioms.SubAnnotationPropertyOfTranslator.AxiomImpl
com.github.owlcs.ontapi.internal.axioms.SubAnnotationPropertyOfTranslator.AxiomImpl.SimpleImpl
- All Implemented Interfaces:
com.github.owlcs.ontapi.internal.axioms.WithTwoObjects.Simple<org.semanticweb.owlapi.model.OWLAnnotationProperty,,org.semanticweb.owlapi.model.OWLAnnotationProperty> com.github.owlcs.ontapi.internal.axioms.WithTwoObjects.Unary<org.semanticweb.owlapi.model.OWLAnnotationProperty>,com.github.owlcs.ontapi.internal.axioms.WithTwoObjects.UnarySimple<org.semanticweb.owlapi.model.OWLAnnotationProperty>,HasConfig,HasObjectFactory,AsStatement,ModelObject<org.semanticweb.owlapi.model.OWLSubAnnotationPropertyOfAxiom>,ONTComposite,WithAnnotations,WithoutAnnotations,ONTObject<org.semanticweb.owlapi.model.OWLSubAnnotationPropertyOfAxiom>,WithMerge<ONTObject<org.semanticweb.owlapi.model.OWLSubAnnotationPropertyOfAxiom>>,Serializable,Comparable<org.semanticweb.owlapi.model.OWLObject>,org.apache.jena.graph.FrontsTriple,org.semanticweb.owlapi.model.HasAnnotationPropertiesInSignature,org.semanticweb.owlapi.model.HasAnnotations,org.semanticweb.owlapi.model.HasAnonymousIndividuals,org.semanticweb.owlapi.model.HasClassesInSignature,org.semanticweb.owlapi.model.HasComponents,org.semanticweb.owlapi.model.HasContainsEntityInSignature,org.semanticweb.owlapi.model.HasDataPropertiesInSignature,org.semanticweb.owlapi.model.HasDatatypesInSignature,org.semanticweb.owlapi.model.HasHashIndex,org.semanticweb.owlapi.model.HasIndex,org.semanticweb.owlapi.model.HasIndividualsInSignature,org.semanticweb.owlapi.model.HasObjectPropertiesInSignature,org.semanticweb.owlapi.model.HasSignature,org.semanticweb.owlapi.model.IsAnonymous,org.semanticweb.owlapi.model.OWLAnnotationAxiom,org.semanticweb.owlapi.model.OWLAnnotationObject,org.semanticweb.owlapi.model.OWLAxiom,org.semanticweb.owlapi.model.OWLObject,org.semanticweb.owlapi.model.OWLSubAnnotationPropertyOfAxiom
- Enclosing class:
SubAnnotationPropertyOfTranslator.AxiomImpl
protected static class SubAnnotationPropertyOfTranslator.AxiomImpl.SimpleImpl
extends SubAnnotationPropertyOfTranslator.AxiomImpl
implements com.github.owlcs.ontapi.internal.axioms.WithTwoObjects.UnarySimple<org.semanticweb.owlapi.model.OWLAnnotationProperty>
An
OWLSubAnnotationPropertyOfAxiom
that has named object properties as subject and object and has no annotations.- See Also:
-
Nested Class Summary
Nested classes/interfaces inherited from class com.github.owlcs.ontapi.internal.axioms.SubAnnotationPropertyOfTranslator.AxiomImpl
SubAnnotationPropertyOfTranslator.AxiomImpl.ComplexImpl, SubAnnotationPropertyOfTranslator.AxiomImpl.SimpleImpl -
Field Summary
Fields inherited from class com.github.owlcs.ontapi.internal.objects.ONTAxiomImpl
SET_HASH_CODEFields inherited from class com.github.owlcs.ontapi.internal.objects.ONTStatementImpl
object, predicate, subjectFields inherited from class com.github.owlcs.ontapi.internal.objects.ONTObjectImpl
modelFields inherited from class com.github.owlcs.ontapi.owlapi.OWLObjectImpl
DEFAULT_COMPARATOR, hashCode, NO_ANNOTATIONSFields inherited from interface com.github.owlcs.ontapi.internal.WithMerge
ONT_OBJECT_MERGER -
Constructor Summary
ConstructorsModifierConstructorDescriptionprotectedSimpleImpl(org.apache.jena.graph.Triple t, Supplier<org.apache.jena.ontapi.model.OntModel> m) -
Method Summary
Modifier and TypeMethodDescriptionbooleancontainsAnnotationProperty(org.semanticweb.owlapi.model.OWLAnnotationProperty property) Answerstrueiff the given OWL annotation property is present in the object's signature.Set<org.semanticweb.owlapi.model.OWLAnnotationProperty> Obtains the annotation properties that are in the signature of this object.default StringAnswers a URI of the triple's object.default ONTObject<? extends org.semanticweb.owlapi.model.OWLAnnotationProperty> Gets the object from the base triple of this axiom.default ONTObject<? extends org.semanticweb.owlapi.model.OWLAnnotationProperty> Gets the subject from the base triple of this axiom.default Set<? extends org.semanticweb.owlapi.model.OWLObject> Gets all OWL characteristic components in the form ofSet.default Set<? extends org.semanticweb.owlapi.model.OWLObject> getOWLComponentsAsSet(ModelObjectFactory factory) Set<org.semanticweb.owlapi.model.OWLEntity> Gets the signature of this object.default StringAnswers a URI of the triple's subject.default booleanAnswerstrueiff the subject is a URI resource.default booleanAnswerstrueiff the object is a URI resource.default booleanAnswerstrueiff this is anOWL Annotation Property.default booleanAnswerstrueiff this is anOWL Anonymous Individual.default booleanAnswerstrueiff this is anOWL Class Expression.default booleanAnswerstrueiff this is anOWL Data Property.default booleanAnswerstrueiff this is anOWL Datatype.default booleanAnswerstrueiff this is anOWL Class.default booleanAnswerstrueiff this is anOWL Named Individual.default booleanAnswerstrueiff this is anOWL Object Property.ONTObject<? extends org.semanticweb.owlapi.model.OWLAnnotationProperty> objectFromStatement(org.apache.jena.ontapi.model.OntStatement statement, ModelObjectFactory factory) ONTObject<? extends org.semanticweb.owlapi.model.OWLAnnotationProperty> subjectFromStatement(org.apache.jena.ontapi.model.OntStatement statement, ModelObjectFactory factory) Methods inherited from class com.github.owlcs.ontapi.internal.axioms.SubAnnotationPropertyOfTranslator.AxiomImpl
canContainDataProperties, canContainObjectProperties, create, createAnnotatedAxiom, findByURI, objectFromStatement, subjectFromStatementMethods inherited from class com.github.owlcs.ontapi.internal.axioms.AbstractSubPropertyTranslator.SubPropertyAxiomImpl
canContainAnonymousIndividuals, canContainClassExpressions, canContainDatatypes, canContainNamedClasses, canContainNamedIndividuals, getSubProperty, getSuperProperty, sameContentMethods inherited from class com.github.owlcs.ontapi.internal.objects.ONTAxiomImpl
collectAnnotations, eraseModel, getAnnotatedAxiom, getAxiomWithoutAnnotations, getConfig, getNNF, getObjectURI, getOWLObject, getSubjectBlankNodeId, getSubjectURI, hasURIObject, hasURIResource, hasURIResource, hasURISubject, merge, setHashCode, triplesMethods inherited from class com.github.owlcs.ontapi.internal.objects.ONTStatementImpl
appendAnnotations, asStatement, asTriple, equals, factoryAnnotations, fromNode, getObjectNode, getPredicateNode, getSubjectNode, sameAs, sameComponents, sameObject, samePredicate, sameSubject, sameTriple, stripMethods inherited from class com.github.owlcs.ontapi.internal.objects.ONTObjectImpl
containsDataProperty, containsDatatype, containsEntity, containsEntityInSignature, containsNamedClass, containsNamedIndividual, containsObjectProperty, createContentSet, eraseModel, getAnonymousIndividualSet, getClassExpressionSet, getDataPropertySet, getDatatypeSet, getModel, getNamedClassSet, getNamedIndividualSet, getObjectFactory, getObjectPropertySet, getPersonalityModel, toStringMethods inherited from class com.github.owlcs.ontapi.owlapi.OWLObjectImpl
annotationPropertiesInSignature, anonymousIndividuals, classesInSignature, compareIterators, compareTo, createSet, createSet, createSortedSet, createSortedSet, dataPropertiesInSignature, datatypesInSignature, equalIterators, equalStreams, forOutput, getAnnotationPropertiesInSignature, getAnonymousIndividuals, getClassesInSignature, getDataPropertiesInSignature, getDatatypesInSignature, getIndividualsInSignature, getNestedClassExpressions, getObjectPropertiesInSignature, getSignature, hashCode, individualsInSignature, mergeAnnotations, nestedClassExpressions, notSame, objectPropertiesInSignature, prepareAnnotations, signature, toContentListMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface com.github.owlcs.ontapi.internal.objects.AsStatement
asStatement, asTripleMethods inherited from interface java.lang.Comparable
compareToMethods inherited from interface org.semanticweb.owlapi.model.HasAnnotationPropertiesInSignature
annotationPropertiesInSignature, getAnnotationPropertiesInSignatureMethods inherited from interface org.semanticweb.owlapi.model.HasAnnotations
annotations, annotations, getAnnotations, getAnnotationsMethods inherited from interface org.semanticweb.owlapi.model.HasAnonymousIndividuals
anonymousIndividuals, getAnonymousIndividualsMethods inherited from interface org.semanticweb.owlapi.model.HasClassesInSignature
classesInSignature, getClassesInSignatureMethods inherited from interface org.semanticweb.owlapi.model.HasContainsEntityInSignature
containsEntityInSignatureMethods inherited from interface org.semanticweb.owlapi.model.HasDataPropertiesInSignature
dataPropertiesInSignature, getDataPropertiesInSignatureMethods inherited from interface org.semanticweb.owlapi.model.HasDatatypesInSignature
datatypesInSignature, getDatatypesInSignatureMethods inherited from interface org.semanticweb.owlapi.model.HasIndividualsInSignature
getIndividualsInSignature, individualsInSignatureMethods inherited from interface com.github.owlcs.ontapi.internal.HasObjectFactory
getDataFactory, getObjectFactoryMethods inherited from interface org.semanticweb.owlapi.model.HasObjectPropertiesInSignature
getObjectPropertiesInSignature, objectPropertiesInSignatureMethods inherited from interface org.semanticweb.owlapi.model.HasSignature
getSignature, signature, unsortedSignatureMethods inherited from interface org.semanticweb.owlapi.model.IsAnonymous
isAnonymous, isNamedMethods inherited from interface com.github.owlcs.ontapi.internal.objects.ModelObject
getModelMethods inherited from interface com.github.owlcs.ontapi.internal.objects.ONTComposite
canContainAnnotationProperties, canContainAnonymousIndividuals, canContainClassExpressions, canContainDataProperties, canContainDatatypes, canContainNamedClasses, canContainNamedIndividuals, canContainObjectPropertiesMethods inherited from interface org.semanticweb.owlapi.model.OWLAnnotationAxiom
isAnnotationAxiomMethods inherited from interface org.semanticweb.owlapi.model.OWLAnnotationObject
asAnonymousIndividual, asIRIMethods inherited from interface org.semanticweb.owlapi.model.OWLAxiom
equalsIgnoreAnnotations, getAnnotatedAxiom, getAnnotatedAxiom, getAnnotatedAxiom, getAxiomWithoutAnnotations, getNNF, isAxiom, isIndividual, isLogicalAxiom, isOfType, isOfType, isOfType, typeIndexMethods inherited from interface org.semanticweb.owlapi.model.OWLObject
getNestedClassExpressions, hasSharedStructure, isAnonymousExpression, isBottomEntity, isIRI, isOntology, isTopEntity, nestedClassExpressionsMethods inherited from interface org.semanticweb.owlapi.model.OWLSubAnnotationPropertyOfAxiom
accept, accept, accept, accept, components, componentsAnnotationsFirst, componentsWithoutAnnotations, getAxiomType, getAxiomWithoutAnnotations, getSubProperty, getSuperProperty, hashIndex, initHashCodeMethods inherited from interface com.github.owlcs.ontapi.internal.objects.WithoutAnnotations
annotations, annotationsAsListMethods inherited from interface com.github.owlcs.ontapi.internal.axioms.WithTwoObjects.Simple
getONTObject, getONTSubject, isAnnotated, objectsMethods inherited from interface com.github.owlcs.ontapi.internal.axioms.WithTwoObjects.Unary
findByURI, getURIObject, getURISubject
-
Constructor Details
-
SimpleImpl
protected SimpleImpl(org.apache.jena.graph.Triple t, Supplier<org.apache.jena.ontapi.model.OntModel> m)
-
-
Method Details
-
getAnnotationPropertySet
Description copied from class:OWLObjectImplObtains the annotation properties that are in the signature of this object. The set is a copy, changes are not reflected back.- Overrides:
getAnnotationPropertySetin classONTObjectImpl- Returns:
- a modifiable sorted
Setof the annotation properties that are in the signature of this object
-
getSignatureSet
Description copied from class:OWLObjectImplGets the signature of this object. The set is a copy, changes are not reflected back.- Overrides:
getSignatureSetin classONTObjectImpl- Returns:
- a modifiable sorted
Setof entities that represents the signature of this object
-
containsAnnotationProperty
public boolean containsAnnotationProperty(org.semanticweb.owlapi.model.OWLAnnotationProperty property) Description copied from class:ONTObjectImplAnswerstrueiff the given OWL annotation property is present in the object's signature.- Overrides:
containsAnnotationPropertyin classONTObjectImpl- Parameters:
property-OWLAnnotationProperty, notnull- Returns:
- boolean
-
subjectFromStatement
ONTObject<? extends org.semanticweb.owlapi.model.OWLAnnotationProperty> subjectFromStatement(org.apache.jena.ontapi.model.OntStatement statement, ModelObjectFactory factory) - Parameters:
statement-OntStatement, the source to parse, notnullfactory-ModelObjectFactoryto fetch anONTObject, notnull- Returns:
- an
ONTObjectthat can be seen as wrapper ofWithTwoObjects
-
objectFromStatement
ONTObject<? extends org.semanticweb.owlapi.model.OWLAnnotationProperty> objectFromStatement(org.apache.jena.ontapi.model.OntStatement statement, ModelObjectFactory factory) - Parameters:
statement-OntStatement, the source to parse, notnullfactory-ModelObjectFactoryto fetch anONTObject, notnull- Returns:
- an
ONTObjectthat can be seen as wrapper ofWithTwoObjects
-
getONTSubject
Gets the subject from the base triple of this axiom.- Returns:
ONTObjectwithWithTwoObjects
-
getONTObject
Gets the object from the base triple of this axiom.- Returns:
ONTObjectwithWithTwoObjects
-
getOWLComponentsAsSet
default Set<? extends org.semanticweb.owlapi.model.OWLObject> getOWLComponentsAsSet(ModelObjectFactory factory) -
hasURIObject
default boolean hasURIObject()Answerstrueiff the subject is a URI resource.- Returns:
- boolean
-
hasURISubject
default boolean hasURISubject()Answerstrueiff the object is a URI resource.- Returns:
- boolean
-
getSubjectURI
Answers a URI of the triple's subject.- Returns:
- URI of the subject
- Throws:
RuntimeException- in case the main triple has no subject uri (b-node instead)
-
getObjectURI
Answers a URI of the triple's object.- Returns:
- URI of the object
- Throws:
RuntimeException- in case the main triple has no object uri (b-node or literal instead)
-
getOWLComponentsAsSet
Gets all OWL characteristic components in the form ofSet.- Returns:
- a sorted
SetofOWLObjects
-
isClassExpression
default boolean isClassExpression()Answerstrueiff this is anOWL Class Expression.- Returns:
- boolean
-
isAnonymousIndividual
default boolean isAnonymousIndividual()Answerstrueiff this is anOWL Anonymous Individual.- Returns:
- boolean
-
isNamedClass
default boolean isNamedClass()Answerstrueiff this is anOWL Class.- Returns:
- boolean
-
isNamedIndividual
default boolean isNamedIndividual()Answerstrueiff this is anOWL Named Individual.- Returns:
- boolean
-
isDatatype
default boolean isDatatype()Answerstrueiff this is anOWL Datatype.- Returns:
- boolean
-
isObjectProperty
default boolean isObjectProperty()Answerstrueiff this is anOWL Object Property.- Returns:
- boolean
-
isDataProperty
default boolean isDataProperty()Answerstrueiff this is anOWL Data Property.- Returns:
- boolean
-
isAnnotationProperty
default boolean isAnnotationProperty()Answerstrueiff this is anOWL Annotation Property.- Returns:
- boolean
-