Class SubClassOfTranslator.AxiomImpl.SimpleImpl
java.lang.Object
com.github.owlcs.ontapi.owlapi.OWLObjectImpl
com.github.owlcs.ontapi.internal.objects.ONTObjectImpl
com.github.owlcs.ontapi.internal.objects.ONTStatementImpl
com.github.owlcs.ontapi.internal.objects.ONTAxiomImpl<org.semanticweb.owlapi.model.OWLSubClassOfAxiom>
com.github.owlcs.ontapi.internal.axioms.SubClassOfTranslator.AxiomImpl
com.github.owlcs.ontapi.internal.axioms.SubClassOfTranslator.AxiomImpl.SimpleImpl
- All Implemented Interfaces:
com.github.owlcs.ontapi.internal.axioms.WithTwoObjects.Simple<org.semanticweb.owlapi.model.OWLClassExpression,,org.semanticweb.owlapi.model.OWLClassExpression> com.github.owlcs.ontapi.internal.axioms.WithTwoObjects.Unary<org.semanticweb.owlapi.model.OWLClassExpression>,com.github.owlcs.ontapi.internal.axioms.WithTwoObjects.UnarySimple<org.semanticweb.owlapi.model.OWLClassExpression>,HasConfig,HasObjectFactory,AsStatement,ModelObject<org.semanticweb.owlapi.model.OWLSubClassOfAxiom>,ONTComposite,WithAnnotations,WithoutAnnotations,ONTObject<org.semanticweb.owlapi.model.OWLSubClassOfAxiom>,WithMerge<ONTObject<org.semanticweb.owlapi.model.OWLSubClassOfAxiom>>,Serializable,Comparable<org.semanticweb.owlapi.model.OWLObject>,org.apache.jena.graph.FrontsTriple,org.semanticweb.owlapi.model.HasAnnotationPropertiesInSignature,org.semanticweb.owlapi.model.HasAnnotations,org.semanticweb.owlapi.model.HasAnonymousIndividuals,org.semanticweb.owlapi.model.HasClassesInSignature,org.semanticweb.owlapi.model.HasComponents,org.semanticweb.owlapi.model.HasContainsEntityInSignature,org.semanticweb.owlapi.model.HasDataPropertiesInSignature,org.semanticweb.owlapi.model.HasDatatypesInSignature,org.semanticweb.owlapi.model.HasHashIndex,org.semanticweb.owlapi.model.HasIndex,org.semanticweb.owlapi.model.HasIndividualsInSignature,org.semanticweb.owlapi.model.HasObjectPropertiesInSignature,org.semanticweb.owlapi.model.HasSignature,org.semanticweb.owlapi.model.IsAnonymous,org.semanticweb.owlapi.model.OWLAxiom,org.semanticweb.owlapi.model.OWLClassAxiom,org.semanticweb.owlapi.model.OWLLogicalAxiom,org.semanticweb.owlapi.model.OWLObject,org.semanticweb.owlapi.model.OWLSubClassOfAxiom
- Enclosing class:
SubClassOfTranslator.AxiomImpl
public static class SubClassOfTranslator.AxiomImpl.SimpleImpl
extends SubClassOfTranslator.AxiomImpl
implements com.github.owlcs.ontapi.internal.axioms.WithTwoObjects.UnarySimple<org.semanticweb.owlapi.model.OWLClassExpression>
An
OWLSubClassOfAxiom that has named classes as subject and object and has no annotations.- See Also:
-
Nested Class Summary
Nested classes/interfaces inherited from class com.github.owlcs.ontapi.internal.axioms.SubClassOfTranslator.AxiomImpl
SubClassOfTranslator.AxiomImpl.ComplexImpl, SubClassOfTranslator.AxiomImpl.SimpleImpl -
Field Summary
Fields inherited from class com.github.owlcs.ontapi.internal.objects.ONTAxiomImpl
SET_HASH_CODEFields inherited from class com.github.owlcs.ontapi.internal.objects.ONTStatementImpl
object, predicate, subjectFields inherited from class com.github.owlcs.ontapi.internal.objects.ONTObjectImpl
modelFields inherited from class com.github.owlcs.ontapi.owlapi.OWLObjectImpl
DEFAULT_COMPARATOR, hashCode, NO_ANNOTATIONSFields inherited from interface com.github.owlcs.ontapi.internal.WithMerge
ONT_OBJECT_MERGER -
Constructor Summary
ConstructorsModifierConstructorDescriptionprotectedSimpleImpl(org.apache.jena.graph.Triple t, Supplier<org.apache.jena.ontapi.model.OntModel> m) -
Method Summary
Modifier and TypeMethodDescriptionbooleanAnswerstrueif this object-container may contain annotation properties.booleanAnswerstrueif this object-container is allowed to contain anonymous individuals.booleanAnswerstrueif this object-container may contain data properties.booleanAnswerstrueif this object-container may contain datatypes.booleanAnswerstrueif this object-container is allowed to contain named individuals.booleanAnswerstrueif this object-container may contain named object properties.booleancontainsNamedClass(org.semanticweb.owlapi.model.OWLClass clazz) Answerstrueiff the given OWL class is present in the object's signature.Set<org.semanticweb.owlapi.model.OWLClassExpression> Gets all the nested (includes top level) class expressions that are used in this object.Set<org.semanticweb.owlapi.model.OWLClass> Gets the classes in the signature of this object.default StringAnswers a URI of the triple's object.default ONTObject<? extends org.semanticweb.owlapi.model.OWLClassExpression> Gets the object from the base triple of this axiom.default ONTObject<? extends org.semanticweb.owlapi.model.OWLClassExpression> Gets the subject from the base triple of this axiom.default Set<? extends org.semanticweb.owlapi.model.OWLObject> Gets all OWL characteristic components in the form ofSet.default Set<? extends org.semanticweb.owlapi.model.OWLObject> getOWLComponentsAsSet(ModelObjectFactory factory) Set<org.semanticweb.owlapi.model.OWLEntity> Gets the signature of this object.default StringAnswers a URI of the triple's subject.default booleanAnswerstrueiff the subject is a URI resource.default booleanAnswerstrueiff the object is a URI resource.default booleanAnswerstrueiff this is anOWL Annotation Property.default booleanAnswerstrueiff this is anOWL Anonymous Individual.default booleanAnswerstrueiff this is anOWL Class Expression.default booleanAnswerstrueiff this is anOWL Data Property.default booleanAnswerstrueiff this is anOWL Datatype.default booleanAnswerstrueiff this is anOWL Class.default booleanAnswerstrueiff this is anOWL Named Individual.default booleanAnswerstrueiff this is anOWL Object Property.ONTObject<? extends org.semanticweb.owlapi.model.OWLClassExpression> objectFromStatement(org.apache.jena.ontapi.model.OntStatement statement, ModelObjectFactory factory) protected booleansameContent(ONTStatementImpl other) Answerstrueif this object and the given have the same content.ONTObject<? extends org.semanticweb.owlapi.model.OWLClassExpression> subjectFromStatement(org.apache.jena.ontapi.model.OntStatement statement, ModelObjectFactory factory) Methods inherited from class com.github.owlcs.ontapi.internal.axioms.SubClassOfTranslator.AxiomImpl
create, createAnnotatedAxiom, findByURI, getSubClass, getSuperClass, isGCI, objectFromStatement, subjectFromStatementMethods inherited from class com.github.owlcs.ontapi.internal.objects.ONTAxiomImpl
collectAnnotations, eraseModel, getAnnotatedAxiom, getAxiomWithoutAnnotations, getConfig, getNNF, getObjectURI, getOWLObject, getSubjectBlankNodeId, getSubjectURI, hasURIObject, hasURIResource, hasURIResource, hasURISubject, merge, setHashCode, triplesMethods inherited from class com.github.owlcs.ontapi.internal.objects.ONTStatementImpl
appendAnnotations, asStatement, asTriple, equals, factoryAnnotations, fromNode, getObjectNode, getPredicateNode, getSubjectNode, sameAs, sameComponents, sameObject, samePredicate, sameSubject, sameTriple, stripMethods inherited from class com.github.owlcs.ontapi.internal.objects.ONTObjectImpl
containsAnnotationProperty, containsDataProperty, containsDatatype, containsEntity, containsEntityInSignature, containsNamedIndividual, containsObjectProperty, createContentSet, eraseModel, getAnnotationPropertySet, getAnonymousIndividualSet, getDataPropertySet, getDatatypeSet, getModel, getNamedIndividualSet, getObjectFactory, getObjectPropertySet, getPersonalityModel, toStringMethods inherited from class com.github.owlcs.ontapi.owlapi.OWLObjectImpl
annotationPropertiesInSignature, anonymousIndividuals, classesInSignature, compareIterators, compareTo, createSet, createSet, createSortedSet, createSortedSet, dataPropertiesInSignature, datatypesInSignature, equalIterators, equalStreams, forOutput, getAnnotationPropertiesInSignature, getAnonymousIndividuals, getClassesInSignature, getDataPropertiesInSignature, getDatatypesInSignature, getIndividualsInSignature, getNestedClassExpressions, getObjectPropertiesInSignature, getSignature, hashCode, individualsInSignature, mergeAnnotations, nestedClassExpressions, notSame, objectPropertiesInSignature, prepareAnnotations, signature, toContentListMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface com.github.owlcs.ontapi.internal.objects.AsStatement
asStatement, asTripleMethods inherited from interface java.lang.Comparable
compareToMethods inherited from interface org.semanticweb.owlapi.model.HasAnnotationPropertiesInSignature
annotationPropertiesInSignature, getAnnotationPropertiesInSignatureMethods inherited from interface org.semanticweb.owlapi.model.HasAnnotations
annotations, annotations, getAnnotations, getAnnotationsMethods inherited from interface org.semanticweb.owlapi.model.HasAnonymousIndividuals
anonymousIndividuals, getAnonymousIndividualsMethods inherited from interface org.semanticweb.owlapi.model.HasClassesInSignature
classesInSignature, getClassesInSignatureMethods inherited from interface org.semanticweb.owlapi.model.HasContainsEntityInSignature
containsEntityInSignatureMethods inherited from interface org.semanticweb.owlapi.model.HasDataPropertiesInSignature
dataPropertiesInSignature, getDataPropertiesInSignatureMethods inherited from interface org.semanticweb.owlapi.model.HasDatatypesInSignature
datatypesInSignature, getDatatypesInSignatureMethods inherited from interface org.semanticweb.owlapi.model.HasIndividualsInSignature
getIndividualsInSignature, individualsInSignatureMethods inherited from interface com.github.owlcs.ontapi.internal.HasObjectFactory
getDataFactory, getObjectFactoryMethods inherited from interface org.semanticweb.owlapi.model.HasObjectPropertiesInSignature
getObjectPropertiesInSignature, objectPropertiesInSignatureMethods inherited from interface org.semanticweb.owlapi.model.HasSignature
getSignature, signature, unsortedSignatureMethods inherited from interface org.semanticweb.owlapi.model.IsAnonymous
isAnonymous, isNamedMethods inherited from interface com.github.owlcs.ontapi.internal.objects.ModelObject
getModelMethods inherited from interface com.github.owlcs.ontapi.internal.objects.ONTComposite
canContainClassExpressions, canContainNamedClassesMethods inherited from interface org.semanticweb.owlapi.model.OWLAxiom
equalsIgnoreAnnotations, getAnnotatedAxiom, getAnnotatedAxiom, getAnnotatedAxiom, getAxiomWithoutAnnotations, getNNF, isAnnotationAxiom, isAxiom, isIndividual, isOfType, isOfType, isOfType, typeIndexMethods inherited from interface org.semanticweb.owlapi.model.OWLLogicalAxiom
isLogicalAxiomMethods inherited from interface org.semanticweb.owlapi.model.OWLObject
getNestedClassExpressions, hasSharedStructure, isAnonymousExpression, isBottomEntity, isIRI, isOntology, isTopEntity, nestedClassExpressionsMethods inherited from interface org.semanticweb.owlapi.model.OWLSubClassOfAxiom
accept, accept, accept, accept, components, componentsAnnotationsFirst, componentsWithoutAnnotations, getAxiomType, getAxiomWithoutAnnotations, hashIndex, initHashCodeMethods inherited from interface com.github.owlcs.ontapi.internal.objects.WithoutAnnotations
annotations, annotationsAsListMethods inherited from interface com.github.owlcs.ontapi.internal.axioms.WithTwoObjects.Simple
getONTObject, getONTSubject, isAnnotated, objectsMethods inherited from interface com.github.owlcs.ontapi.internal.axioms.WithTwoObjects.Unary
findByURI, getURIObject, getURISubject
-
Constructor Details
-
SimpleImpl
protected SimpleImpl(org.apache.jena.graph.Triple t, Supplier<org.apache.jena.ontapi.model.OntModel> m)
-
-
Method Details
-
sameContent
Description copied from class:ONTStatementImplAnswerstrueif this object and the given have the same content. TwoOWLObjects may have same content, but different base triples (seeONTStatementImpl.sameTriple(ONTStatementImpl)).- Specified by:
sameContentin classONTStatementImpl- Parameters:
other-ONTStatementImpl, notnull- Returns:
- boolean
-
getNamedClassSet
Description copied from class:OWLObjectImplGets the classes in the signature of this object. The returned set is a subset of the signature, and is not backed by the signature; it is a modifiable collection and changes are not reflected by the signature.- Overrides:
getNamedClassSetin classONTObjectImpl- Returns:
- a modifiable sorted
Setcontaining the classes that are in the signature of this object
-
getClassExpressionSet
Description copied from class:OWLObjectImplGets all the nested (includes top level) class expressions that are used in this object. The set is a copy, changes are not reflected back.- Overrides:
getClassExpressionSetin classONTObjectImpl- Returns:
- a modifiable unordered
SetofOWLClassExpressions that represent the nested class expressions used in this object
-
getSignatureSet
Description copied from class:OWLObjectImplGets the signature of this object. The set is a copy, changes are not reflected back.- Overrides:
getSignatureSetin classONTObjectImpl- Returns:
- a modifiable sorted
Setof entities that represents the signature of this object
-
containsNamedClass
public boolean containsNamedClass(org.semanticweb.owlapi.model.OWLClass clazz) Description copied from class:ONTObjectImplAnswerstrueiff the given OWL class is present in the object's signature.- Overrides:
containsNamedClassin classONTObjectImpl- Parameters:
clazz-OWLClass, notnull- Returns:
- boolean
-
canContainDatatypes
public boolean canContainDatatypes()Description copied from interface:ONTCompositeAnswerstrueif this object-container may contain datatypes.- Specified by:
canContainDatatypesin interfaceONTComposite- Returns:
- boolean
-
canContainNamedIndividuals
public boolean canContainNamedIndividuals()Description copied from interface:ONTCompositeAnswerstrueif this object-container is allowed to contain named individuals.- Specified by:
canContainNamedIndividualsin interfaceONTComposite- Returns:
- boolean
-
canContainDataProperties
public boolean canContainDataProperties()Description copied from interface:ONTCompositeAnswerstrueif this object-container may contain data properties.- Specified by:
canContainDataPropertiesin interfaceONTComposite- Returns:
- boolean
-
canContainObjectProperties
public boolean canContainObjectProperties()Description copied from interface:ONTCompositeAnswerstrueif this object-container may contain named object properties.- Specified by:
canContainObjectPropertiesin interfaceONTComposite- Returns:
- boolean
-
canContainAnnotationProperties
public boolean canContainAnnotationProperties()Description copied from interface:ONTCompositeAnswerstrueif this object-container may contain annotation properties.- Specified by:
canContainAnnotationPropertiesin interfaceONTComposite- Overrides:
canContainAnnotationPropertiesin classSubClassOfTranslator.AxiomImpl- Returns:
- boolean
-
canContainAnonymousIndividuals
public boolean canContainAnonymousIndividuals()Description copied from interface:ONTCompositeAnswerstrueif this object-container is allowed to contain anonymous individuals.- Specified by:
canContainAnonymousIndividualsin interfaceONTComposite- Returns:
- boolean
-
subjectFromStatement
ONTObject<? extends org.semanticweb.owlapi.model.OWLClassExpression> subjectFromStatement(org.apache.jena.ontapi.model.OntStatement statement, ModelObjectFactory factory) - Parameters:
statement-OntStatement, the source to parse, notnullfactory-ModelObjectFactoryto fetch anONTObject, notnull- Returns:
- an
ONTObjectthat can be seen as wrapper ofWithTwoObjects
-
objectFromStatement
ONTObject<? extends org.semanticweb.owlapi.model.OWLClassExpression> objectFromStatement(org.apache.jena.ontapi.model.OntStatement statement, ModelObjectFactory factory) - Parameters:
statement-OntStatement, the source to parse, notnullfactory-ModelObjectFactoryto fetch anONTObject, notnull- Returns:
- an
ONTObjectthat can be seen as wrapper ofWithTwoObjects
-
getONTSubject
Gets the subject from the base triple of this axiom.- Returns:
ONTObjectwithWithTwoObjects
-
getONTObject
Gets the object from the base triple of this axiom.- Returns:
ONTObjectwithWithTwoObjects
-
getOWLComponentsAsSet
default Set<? extends org.semanticweb.owlapi.model.OWLObject> getOWLComponentsAsSet(ModelObjectFactory factory) -
hasURIObject
default boolean hasURIObject()Answerstrueiff the subject is a URI resource.- Returns:
- boolean
-
hasURISubject
default boolean hasURISubject()Answerstrueiff the object is a URI resource.- Returns:
- boolean
-
getSubjectURI
Answers a URI of the triple's subject.- Returns:
- URI of the subject
- Throws:
RuntimeException- in case the main triple has no subject uri (b-node instead)
-
getObjectURI
Answers a URI of the triple's object.- Returns:
- URI of the object
- Throws:
RuntimeException- in case the main triple has no object uri (b-node or literal instead)
-
getOWLComponentsAsSet
Gets all OWL characteristic components in the form ofSet.- Returns:
- a sorted
SetofOWLObjects
-
isClassExpression
default boolean isClassExpression()Answerstrueiff this is anOWL Class Expression.- Returns:
- boolean
-
isAnonymousIndividual
default boolean isAnonymousIndividual()Answerstrueiff this is anOWL Anonymous Individual.- Returns:
- boolean
-
isNamedClass
default boolean isNamedClass()Answerstrueiff this is anOWL Class.- Returns:
- boolean
-
isNamedIndividual
default boolean isNamedIndividual()Answerstrueiff this is anOWL Named Individual.- Returns:
- boolean
-
isDatatype
default boolean isDatatype()Answerstrueiff this is anOWL Datatype.- Returns:
- boolean
-
isObjectProperty
default boolean isObjectProperty()Answerstrueiff this is anOWL Object Property.- Returns:
- boolean
-
isDataProperty
default boolean isDataProperty()Answerstrueiff this is anOWL Data Property.- Returns:
- boolean
-
isAnnotationProperty
default boolean isAnnotationProperty()Answerstrueiff this is anOWL Annotation Property.- Returns:
- boolean
-