Class TransitiveObjectPropertyTranslator.AxiomImpl
java.lang.Object
com.github.owlcs.ontapi.owlapi.OWLObjectImpl
com.github.owlcs.ontapi.internal.objects.ONTObjectImpl
com.github.owlcs.ontapi.internal.objects.ONTStatementImpl
com.github.owlcs.ontapi.internal.objects.ONTAxiomImpl<org.semanticweb.owlapi.model.OWLTransitiveObjectPropertyAxiom>
com.github.owlcs.ontapi.internal.axioms.AbstractPropertyTypeTranslator.UnaryAxiomImpl<org.semanticweb.owlapi.model.OWLTransitiveObjectPropertyAxiom,org.semanticweb.owlapi.model.OWLObjectPropertyExpression>
com.github.owlcs.ontapi.internal.axioms.AbstractPropertyTypeTranslator.ObjectAxiomImpl<org.semanticweb.owlapi.model.OWLTransitiveObjectPropertyAxiom>
com.github.owlcs.ontapi.internal.axioms.TransitiveObjectPropertyTranslator.AxiomImpl
- All Implemented Interfaces:
HasConfig,HasObjectFactory,AsStatement,ModelObject<org.semanticweb.owlapi.model.OWLTransitiveObjectPropertyAxiom>,ONTComposite,WithAnnotations,ONTObject<org.semanticweb.owlapi.model.OWLTransitiveObjectPropertyAxiom>,WithMerge<ONTObject<org.semanticweb.owlapi.model.OWLTransitiveObjectPropertyAxiom>>,Serializable,Comparable<org.semanticweb.owlapi.model.OWLObject>,org.apache.jena.graph.FrontsTriple,org.semanticweb.owlapi.model.HasAnnotationPropertiesInSignature,org.semanticweb.owlapi.model.HasAnnotations,org.semanticweb.owlapi.model.HasAnonymousIndividuals,org.semanticweb.owlapi.model.HasClassesInSignature,org.semanticweb.owlapi.model.HasComponents,org.semanticweb.owlapi.model.HasContainsEntityInSignature,org.semanticweb.owlapi.model.HasDataPropertiesInSignature,org.semanticweb.owlapi.model.HasDatatypesInSignature,org.semanticweb.owlapi.model.HasHashIndex,org.semanticweb.owlapi.model.HasIndex,org.semanticweb.owlapi.model.HasIndividualsInSignature,org.semanticweb.owlapi.model.HasObjectPropertiesInSignature,org.semanticweb.owlapi.model.HasProperty<org.semanticweb.owlapi.model.OWLObjectPropertyExpression>,org.semanticweb.owlapi.model.HasSignature,org.semanticweb.owlapi.model.IsAnonymous,org.semanticweb.owlapi.model.OWLAxiom,org.semanticweb.owlapi.model.OWLLogicalAxiom,org.semanticweb.owlapi.model.OWLObject,org.semanticweb.owlapi.model.OWLObjectPropertyAxiom,org.semanticweb.owlapi.model.OWLObjectPropertyCharacteristicAxiom,org.semanticweb.owlapi.model.OWLPropertyAxiom,org.semanticweb.owlapi.model.OWLTransitiveObjectPropertyAxiom,org.semanticweb.owlapi.model.OWLUnaryPropertyAxiom<org.semanticweb.owlapi.model.OWLObjectPropertyExpression>
- Direct Known Subclasses:
TransitiveObjectPropertyTranslator.AxiomImpl.ComplexImpl,TransitiveObjectPropertyTranslator.AxiomImpl.SimpleImpl
- Enclosing class:
TransitiveObjectPropertyTranslator
public abstract static class TransitiveObjectPropertyTranslator.AxiomImpl
extends AbstractPropertyTypeTranslator.ObjectAxiomImpl<org.semanticweb.owlapi.model.OWLTransitiveObjectPropertyAxiom>
implements org.semanticweb.owlapi.model.OWLTransitiveObjectPropertyAxiom
- See Also:
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic classAnOWLTransitiveObjectPropertyAxiomthat either has annotations or an anonymous object property expression (inverse object property) in the main triple's subject position.static classAnOWLTransitiveObjectPropertyAxiomthat has a named object property as subject and has no annotations. -
Field Summary
Fields inherited from class com.github.owlcs.ontapi.internal.objects.ONTAxiomImpl
SET_HASH_CODEFields inherited from class com.github.owlcs.ontapi.internal.objects.ONTStatementImpl
object, predicate, subjectFields inherited from class com.github.owlcs.ontapi.internal.objects.ONTObjectImpl
modelFields inherited from class com.github.owlcs.ontapi.owlapi.OWLObjectImpl
DEFAULT_COMPARATOR, hashCode, NO_ANNOTATIONSFields inherited from interface com.github.owlcs.ontapi.internal.WithMerge
ONT_OBJECT_MERGER -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncreate(org.apache.jena.ontapi.model.OntStatement statement, ModelObjectFactory factory, AxiomsSettings config) Creates anONTObjectcontainer, that is alsoOWLTransitiveObjectPropertyAxiom.protected org.semanticweb.owlapi.model.OWLTransitiveObjectPropertyAxiomcreateAnnotatedAxiom(Collection<org.semanticweb.owlapi.model.OWLAnnotation> annotations) Creates a fresh system-wideaxiomwith the given annotations.ONTObject<? extends org.semanticweb.owlapi.model.OWLObjectPropertyExpression> findONTValue(ModelObjectFactory factory) default StringAnswers a URI of the triple's object.default ONTObject<? extends org.semanticweb.owlapi.model.OWLObjectPropertyExpression> default Set<? extends org.semanticweb.owlapi.model.OWLObject> Gets all OWL characteristic components in the form ofSet.default Set<? extends org.semanticweb.owlapi.model.OWLObject> getOWLComponentsAsSet(ModelObjectFactory factory) default StringAnswers a URI of the triple's subject.default booleanAnswerstrueiff the subject is a URI resource.default booleanAnswerstrueiff the object is a URI resource.default booleanAnswerstrueiff this is anOWL Annotation Property.default booleanAnswerstrueiff this is anOWL Anonymous Individual.default booleanAnswerstrueiff this is anOWL Class Expression.default booleanAnswerstrueiff this is anOWL Data Property.default booleanAnswerstrueiff this is anOWL Datatype.default booleanAnswerstrueiff this is anOWL Class.default booleanAnswerstrueiff this is anOWL Named Individual.default booleanAnswerstrueiff this is anOWL Object Property.Methods inherited from class com.github.owlcs.ontapi.internal.axioms.AbstractPropertyTypeTranslator.ObjectAxiomImpl
canContainDataProperties, fetchONTSubject, findURISubject, sameContentMethods inherited from class com.github.owlcs.ontapi.internal.axioms.AbstractPropertyTypeTranslator.UnaryAxiomImpl
canContainAnnotationProperties, canContainAnonymousIndividuals, canContainClassExpressions, canContainDatatypes, canContainNamedClasses, canContainNamedIndividuals, getPropertyMethods inherited from class com.github.owlcs.ontapi.internal.objects.ONTAxiomImpl
collectAnnotations, eraseModel, getAnnotatedAxiom, getAxiomWithoutAnnotations, getConfig, getNNF, getObjectURI, getOWLObject, getSubjectBlankNodeId, getSubjectURI, hasURIObject, hasURIResource, hasURIResource, hasURISubject, merge, setHashCode, triplesMethods inherited from class com.github.owlcs.ontapi.internal.objects.ONTStatementImpl
appendAnnotations, asStatement, asTriple, equals, factoryAnnotations, fromNode, getObjectNode, getPredicateNode, getSubjectNode, sameAs, sameComponents, sameObject, samePredicate, sameSubject, sameTriple, stripMethods inherited from class com.github.owlcs.ontapi.internal.objects.ONTObjectImpl
containsAnnotationProperty, containsDataProperty, containsDatatype, containsEntity, containsEntityInSignature, containsNamedClass, containsNamedIndividual, containsObjectProperty, createContentSet, eraseModel, getAnnotationPropertySet, getAnonymousIndividualSet, getClassExpressionSet, getDataPropertySet, getDatatypeSet, getModel, getNamedClassSet, getNamedIndividualSet, getObjectFactory, getObjectPropertySet, getPersonalityModel, getSignatureSet, toStringMethods inherited from class com.github.owlcs.ontapi.owlapi.OWLObjectImpl
annotationPropertiesInSignature, anonymousIndividuals, classesInSignature, compareIterators, compareTo, createSet, createSet, createSortedSet, createSortedSet, dataPropertiesInSignature, datatypesInSignature, equalIterators, equalStreams, forOutput, getAnnotationPropertiesInSignature, getAnonymousIndividuals, getClassesInSignature, getDataPropertiesInSignature, getDatatypesInSignature, getIndividualsInSignature, getNestedClassExpressions, getObjectPropertiesInSignature, getSignature, hashCode, individualsInSignature, mergeAnnotations, nestedClassExpressions, notSame, objectPropertiesInSignature, prepareAnnotations, signature, toContentListMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface com.github.owlcs.ontapi.internal.objects.AsStatement
asStatement, asTripleMethods inherited from interface java.lang.Comparable
compareToMethods inherited from interface org.semanticweb.owlapi.model.HasAnnotationPropertiesInSignature
annotationPropertiesInSignature, getAnnotationPropertiesInSignatureMethods inherited from interface org.semanticweb.owlapi.model.HasAnnotations
annotations, annotations, getAnnotations, getAnnotationsMethods inherited from interface org.semanticweb.owlapi.model.HasAnonymousIndividuals
anonymousIndividuals, getAnonymousIndividualsMethods inherited from interface org.semanticweb.owlapi.model.HasClassesInSignature
classesInSignature, getClassesInSignatureMethods inherited from interface org.semanticweb.owlapi.model.HasContainsEntityInSignature
containsEntityInSignatureMethods inherited from interface org.semanticweb.owlapi.model.HasDataPropertiesInSignature
dataPropertiesInSignature, getDataPropertiesInSignatureMethods inherited from interface org.semanticweb.owlapi.model.HasDatatypesInSignature
datatypesInSignature, getDatatypesInSignatureMethods inherited from interface org.semanticweb.owlapi.model.HasIndividualsInSignature
getIndividualsInSignature, individualsInSignatureMethods inherited from interface com.github.owlcs.ontapi.internal.HasObjectFactory
getDataFactory, getObjectFactoryMethods inherited from interface org.semanticweb.owlapi.model.HasObjectPropertiesInSignature
getObjectPropertiesInSignature, objectPropertiesInSignatureMethods inherited from interface org.semanticweb.owlapi.model.HasProperty
getPropertyMethods inherited from interface org.semanticweb.owlapi.model.HasSignature
getSignature, signature, unsortedSignatureMethods inherited from interface org.semanticweb.owlapi.model.IsAnonymous
isAnonymous, isNamedMethods inherited from interface com.github.owlcs.ontapi.internal.objects.ModelObject
getModelMethods inherited from interface com.github.owlcs.ontapi.internal.objects.ONTComposite
canContainObjectProperties, objectsMethods inherited from interface org.semanticweb.owlapi.model.OWLAxiom
equalsIgnoreAnnotations, getAnnotatedAxiom, getAnnotatedAxiom, getAnnotatedAxiom, getAxiomWithoutAnnotations, getNNF, isAnnotated, isAnnotationAxiom, isAxiom, isIndividual, isOfType, isOfType, isOfType, typeIndexMethods inherited from interface org.semanticweb.owlapi.model.OWLLogicalAxiom
isLogicalAxiomMethods inherited from interface org.semanticweb.owlapi.model.OWLObject
getNestedClassExpressions, hasSharedStructure, isAnonymousExpression, isBottomEntity, isIRI, isOntology, isTopEntity, nestedClassExpressionsMethods inherited from interface org.semanticweb.owlapi.model.OWLTransitiveObjectPropertyAxiom
accept, accept, accept, accept, getAxiomType, getAxiomWithoutAnnotations, hashIndexMethods inherited from interface org.semanticweb.owlapi.model.OWLUnaryPropertyAxiom
components, componentsAnnotationsFirst, componentsWithoutAnnotations, initHashCodeMethods inherited from interface com.github.owlcs.ontapi.internal.objects.WithAnnotations
annotations, annotationsAsList, isAnnotated
-
Constructor Details
-
AxiomImpl
protected AxiomImpl(org.apache.jena.graph.Triple t, Supplier<org.apache.jena.ontapi.model.OntModel> m)
-
-
Method Details
-
create
public static TransitiveObjectPropertyTranslator.AxiomImpl create(org.apache.jena.ontapi.model.OntStatement statement, ModelObjectFactory factory, AxiomsSettings config) Creates anONTObjectcontainer, that is alsoOWLTransitiveObjectPropertyAxiom.- Parameters:
statement-OntStatement, notnullfactory-ONTObjectFactory, notnullconfig-AxiomsSettings, notnull- Returns:
TransitiveObjectPropertyTranslator.AxiomImpl
-
createAnnotatedAxiom
protected org.semanticweb.owlapi.model.OWLTransitiveObjectPropertyAxiom createAnnotatedAxiom(Collection<org.semanticweb.owlapi.model.OWLAnnotation> annotations) Description copied from class:ONTAxiomImplCreates a fresh system-wideaxiomwith the given annotations. The resulting axiom should not contain model references.- Specified by:
createAnnotatedAxiomin classONTAxiomImpl<org.semanticweb.owlapi.model.OWLTransitiveObjectPropertyAxiom>- Parameters:
annotations- aCollectionofOWLAnnotations to bind to the axiom- Returns:
ONTAxiomImpl
-
findONTValue
ONTObject<? extends org.semanticweb.owlapi.model.OWLObjectPropertyExpression> findONTValue(ModelObjectFactory factory) -
getONTValue
-
getOWLComponentsAsSet
default Set<? extends org.semanticweb.owlapi.model.OWLObject> getOWLComponentsAsSet(ModelObjectFactory factory) -
hasURIObject
default boolean hasURIObject()Answerstrueiff the subject is a URI resource.- Returns:
- boolean
-
hasURISubject
default boolean hasURISubject()Answerstrueiff the object is a URI resource.- Returns:
- boolean
-
getSubjectURI
Answers a URI of the triple's subject.- Returns:
- URI of the subject
- Throws:
RuntimeException- in case the main triple has no subject uri (b-node instead)
-
getObjectURI
Answers a URI of the triple's object.- Returns:
- URI of the object
- Throws:
RuntimeException- in case the main triple has no object uri (b-node or literal instead)
-
getOWLComponentsAsSet
Gets all OWL characteristic components in the form ofSet.- Returns:
- a sorted
SetofOWLObjects
-
isClassExpression
default boolean isClassExpression()Answerstrueiff this is anOWL Class Expression.- Returns:
- boolean
-
isAnonymousIndividual
default boolean isAnonymousIndividual()Answerstrueiff this is anOWL Anonymous Individual.- Returns:
- boolean
-
isNamedClass
default boolean isNamedClass()Answerstrueiff this is anOWL Class.- Returns:
- boolean
-
isNamedIndividual
default boolean isNamedIndividual()Answerstrueiff this is anOWL Named Individual.- Returns:
- boolean
-
isDatatype
default boolean isDatatype()Answerstrueiff this is anOWL Datatype.- Returns:
- boolean
-
isObjectProperty
default boolean isObjectProperty()Answerstrueiff this is anOWL Object Property.- Returns:
- boolean
-
isDataProperty
default boolean isDataProperty()Answerstrueiff this is anOWL Data Property.- Returns:
- boolean
-
isAnnotationProperty
default boolean isAnnotationProperty()Answerstrueiff this is anOWL Annotation Property.- Returns:
- boolean
-