Class ONTAnonymousClassExpressionImpl.OHV
java.lang.Object
com.github.owlcs.ontapi.owlapi.OWLObjectImpl
com.github.owlcs.ontapi.internal.objects.ONTObjectImpl
com.github.owlcs.ontapi.internal.objects.ONTResourceImpl
com.github.owlcs.ontapi.internal.objects.ONTExpressionImpl<org.apache.jena.ontapi.model.OntClass.ObjectHasValue>
com.github.owlcs.ontapi.internal.objects.ONTAnonymousClassExpressionImpl<org.apache.jena.ontapi.model.OntClass.ObjectHasValue,org.semanticweb.owlapi.model.OWLObjectHasValue>
com.github.owlcs.ontapi.internal.objects.ONTAnonymousClassExpressionImpl.Simple<org.apache.jena.ontapi.model.OntClass.ObjectHasValue,org.semanticweb.owlapi.model.OWLObjectHasValue>
com.github.owlcs.ontapi.internal.objects.ONTAnonymousClassExpressionImpl.Restriction<org.apache.jena.ontapi.model.OntClass.ObjectHasValue,org.semanticweb.owlapi.model.OWLObjectHasValue>
com.github.owlcs.ontapi.internal.objects.ONTAnonymousClassExpressionImpl.WithObjectProperty<org.apache.jena.ontapi.model.OntClass.ObjectHasValue,org.semanticweb.owlapi.model.OWLObjectHasValue>
com.github.owlcs.ontapi.internal.objects.ONTAnonymousClassExpressionImpl.OHV
- All Implemented Interfaces:
AsNode,AsRDFNode,HasObjectFactory,ModelObject<org.semanticweb.owlapi.model.OWLObjectHasValue>,ONTComposite,WithContent<ONTExpressionImpl<org.apache.jena.ontapi.model.OntClass.ObjectHasValue>>,ONTObject<org.semanticweb.owlapi.model.OWLObjectHasValue>,Serializable,Comparable<org.semanticweb.owlapi.model.OWLObject>,org.semanticweb.owlapi.model.AsOWLClass,org.semanticweb.owlapi.model.HasAnnotationPropertiesInSignature,org.semanticweb.owlapi.model.HasAnonymousIndividuals,org.semanticweb.owlapi.model.HasClassesInSignature,org.semanticweb.owlapi.model.HasComponents,org.semanticweb.owlapi.model.HasContainsEntityInSignature,org.semanticweb.owlapi.model.HasDataPropertiesInSignature,org.semanticweb.owlapi.model.HasDatatypesInSignature,org.semanticweb.owlapi.model.HasFiller<org.semanticweb.owlapi.model.OWLIndividual>,org.semanticweb.owlapi.model.HasHashIndex,org.semanticweb.owlapi.model.HasIndex,org.semanticweb.owlapi.model.HasIndividualsInSignature,org.semanticweb.owlapi.model.HasObjectPropertiesInSignature,org.semanticweb.owlapi.model.HasProperty<org.semanticweb.owlapi.model.OWLObjectPropertyExpression>,org.semanticweb.owlapi.model.HasSignature,org.semanticweb.owlapi.model.IsAnonymous,org.semanticweb.owlapi.model.OWLAnonymousClassExpression,org.semanticweb.owlapi.model.OWLClassExpression,org.semanticweb.owlapi.model.OWLHasValueRestriction<org.semanticweb.owlapi.model.OWLIndividual>,org.semanticweb.owlapi.model.OWLObject,org.semanticweb.owlapi.model.OWLObjectHasValue,org.semanticweb.owlapi.model.OWLObjectRestriction,org.semanticweb.owlapi.model.OWLPropertyRange,org.semanticweb.owlapi.model.OWLRestriction,org.semanticweb.owlapi.model.SWRLPredicate
- Enclosing class:
ONTAnonymousClassExpressionImpl<ONT extends org.apache.jena.ontapi.model.OntClass,OWL extends org.semanticweb.owlapi.model.OWLAnonymousClassExpression>
public static class ONTAnonymousClassExpressionImpl.OHV
extends ONTAnonymousClassExpressionImpl.WithObjectProperty<org.apache.jena.ontapi.model.OntClass.ObjectHasValue,org.semanticweb.owlapi.model.OWLObjectHasValue>
implements org.semanticweb.owlapi.model.OWLObjectHasValue
- See Also:
-
Nested Class Summary
Nested classes/interfaces inherited from class com.github.owlcs.ontapi.internal.objects.ONTAnonymousClassExpressionImpl
ONTAnonymousClassExpressionImpl.CF, ONTAnonymousClassExpressionImpl.DAVF, ONTAnonymousClassExpressionImpl.DEC, ONTAnonymousClassExpressionImpl.DHV, ONTAnonymousClassExpressionImpl.DMAC, ONTAnonymousClassExpressionImpl.DMIC, ONTAnonymousClassExpressionImpl.DSVF, ONTAnonymousClassExpressionImpl.IF, ONTAnonymousClassExpressionImpl.NDAVF, ONTAnonymousClassExpressionImpl.NDSVF, ONTAnonymousClassExpressionImpl.OAVF, ONTAnonymousClassExpressionImpl.OEC, ONTAnonymousClassExpressionImpl.OF, ONTAnonymousClassExpressionImpl.OHS, ONTAnonymousClassExpressionImpl.OHV, ONTAnonymousClassExpressionImpl.OMAC, ONTAnonymousClassExpressionImpl.OMIC, ONTAnonymousClassExpressionImpl.OSVF, ONTAnonymousClassExpressionImpl.Restriction<ONT extends org.apache.jena.ontapi.model.OntClass,OWL extends org.semanticweb.owlapi.model.OWLAnonymousClassExpression>, ONTAnonymousClassExpressionImpl.Simple<ONT extends org.apache.jena.ontapi.model.OntClass, OWL extends org.semanticweb.owlapi.model.OWLAnonymousClassExpression>, ONTAnonymousClassExpressionImpl.UF, ONTAnonymousClassExpressionImpl.WithClassAndObjectProperty<ONT extends org.apache.jena.ontapi.model.OntClass.ComponentRestriction<org.apache.jena.ontapi.model.OntClass, org.apache.jena.ontapi.model.OntObjectProperty>, OWL extends org.semanticweb.owlapi.model.OWLRestriction>, ONTAnonymousClassExpressionImpl.WithClassAndObjectPropertyAndCardinality<ONT extends org.apache.jena.ontapi.model.OntClass.CardinalityRestriction<org.apache.jena.ontapi.model.OntClass, org.apache.jena.ontapi.model.OntObjectProperty>, OWL extends org.semanticweb.owlapi.model.OWLRestriction>, ONTAnonymousClassExpressionImpl.WithClassMembers<ONT extends org.apache.jena.ontapi.model.OntClass.CollectionOf<org.apache.jena.ontapi.model.OntClass>, OWL extends org.semanticweb.owlapi.model.OWLAnonymousClassExpression>, ONTAnonymousClassExpressionImpl.WithDataProperty<ONT extends org.apache.jena.ontapi.model.OntClass, OWL extends org.semanticweb.owlapi.model.OWLRestriction>, ONTAnonymousClassExpressionImpl.WithDataPropertyUnary<ONT extends org.apache.jena.ontapi.model.OntClass.UnaryRestriction<org.apache.jena.ontapi.model.OntDataProperty>, OWL extends org.semanticweb.owlapi.model.OWLRestriction>, ONTAnonymousClassExpressionImpl.WithDataRangeAndDataProperty<ONT extends org.apache.jena.ontapi.model.OntClass.Restriction, OWL extends org.semanticweb.owlapi.model.OWLRestriction>, ONTAnonymousClassExpressionImpl.WithDataRangeAndDataPropertyAndCardinality<ONT extends org.apache.jena.ontapi.model.OntClass.CardinalityRestriction<org.apache.jena.ontapi.model.OntDataRange, org.apache.jena.ontapi.model.OntDataProperty>, OWL extends org.semanticweb.owlapi.model.OWLRestriction>, ONTAnonymousClassExpressionImpl.WithDataRangeAndDataPropertyNary<ONT extends org.apache.jena.ontapi.model.OntClass.NaryRestriction<org.apache.jena.ontapi.model.OntDataRange, org.apache.jena.ontapi.model.OntDataProperty>, OWL extends org.semanticweb.owlapi.model.OWLRestriction>, ONTAnonymousClassExpressionImpl.WithDataRangeAndDataPropertyUnary<ONT extends org.apache.jena.ontapi.model.OntClass.ComponentRestriction<org.apache.jena.ontapi.model.OntDataRange, org.apache.jena.ontapi.model.OntDataProperty>, OWL extends org.semanticweb.owlapi.model.OWLRestriction>, ONTAnonymousClassExpressionImpl.WithMembers<ONT_M extends org.apache.jena.ontapi.model.OntObject, ONT_C extends org.apache.jena.ontapi.model.OntClass.CollectionOf<ONT_M>, OWL_M extends org.semanticweb.owlapi.model.OWLObject, OWL_C extends org.semanticweb.owlapi.model.OWLAnonymousClassExpression>, ONTAnonymousClassExpressionImpl.WithObjectProperty<ONT extends org.apache.jena.ontapi.model.OntClass.UnaryRestriction<org.apache.jena.ontapi.model.OntObjectProperty>, OWL extends org.semanticweb.owlapi.model.OWLRestriction> -
Field Summary
Fields inherited from class com.github.owlcs.ontapi.internal.objects.ONTExpressionImpl
contentFields inherited from class com.github.owlcs.ontapi.internal.objects.ONTResourceImpl
nodeFields inherited from class com.github.owlcs.ontapi.internal.objects.ONTObjectImpl
modelFields inherited from class com.github.owlcs.ontapi.owlapi.OWLObjectImpl
DEFAULT_COMPARATOR, hashCode, NO_ANNOTATIONS -
Constructor Summary
ConstructorsModifierConstructorDescriptionprotectedOHV(BlankNodeId n, Supplier<org.apache.jena.ontapi.model.OntModel> m) -
Method Summary
Modifier and TypeMethodDescriptionorg.apache.jena.ontapi.model.OntClass.ObjectHasValueAnswers theRDFNodeassociated with this object.org.semanticweb.owlapi.model.OWLObjectSomeValuesFrombooleanAnswerstrueif this object-container may contain data properties.booleanAnswerstrueif this object-container may contain datatypes.booleanAnswerstrueif this object-container is allowed to contain (named) OWL classes.protected Object[]collectContent(org.apache.jena.ontapi.model.OntClass.ObjectHasValue ce, ONTObjectFactory factory) Collects the cache Array.booleancontainsNamedIndividual(org.semanticweb.owlapi.model.OWLNamedIndividual individual) Answerstrueiff the given OWL named individual is present in the object's signature.booleancontainsObjectProperty(org.semanticweb.owlapi.model.OWLObjectProperty property) Answerstrueiff the given OWL named object property expression (OWLObjectProperty) is present in the object's signature.org.semanticweb.owlapi.model.OWLObjectHasValueAnswers with an object that equals to theONTObject.getOWLObject(), but without any model information inside.protected ONTObject<? extends org.semanticweb.owlapi.model.OWLIndividual> findIndividual(ModelObjectFactory factory) Set<org.semanticweb.owlapi.model.OWLAnonymousIndividual> Gets the anonymous individuals occurring in this object.Set<org.semanticweb.owlapi.model.OWLClassExpression> Gets all the nested (includes top level) class expressions that are used in this object.org.semanticweb.owlapi.model.OWLIndividualSet<org.semanticweb.owlapi.model.OWLNamedIndividual> Gets all the individuals that are in the signature of this object.protected org.semanticweb.owlapi.model.OWLObjectPropertySet<org.semanticweb.owlapi.model.OWLObjectProperty> Obtains the (named) object properties that are in the signature of this object.ONTObject<? extends org.semanticweb.owlapi.model.OWLIndividual> Set<org.semanticweb.owlapi.model.OWLEntity> Gets the signature of this object.protected Object[]initContent(org.apache.jena.ontapi.model.OntClass.ObjectHasValue ce, ONTObjectFactory factory) Initializes the object's content and calculates its hashcode.default booleanAnswerstrueiff this is anOWL Annotation Property.default booleanAnswerstrueiff this is anOWL Anonymous Individual.default booleanAnswerstrueiff this is anOWL Data Property.default booleanAnswerstrueiff this is anOWL Datatype.default booleanAnswerstrueiff this is anOWL Class.default booleanAnswerstrueiff this is anOWL Named Individual.default booleanAnswerstrueiff this is anOWL Object Property.objects()Lists all components in the form ofStream.Methods inherited from class com.github.owlcs.ontapi.internal.objects.ONTAnonymousClassExpressionImpl.WithObjectProperty
findOPE, getONTObjectPropertyExpression, getPropertyMethods inherited from class com.github.owlcs.ontapi.internal.objects.ONTAnonymousClassExpressionImpl
asConjunctSet, asDisjunctSet, canContainAnnotationProperties, conjunctSet, containsConjunct, create, create, disjunctSet, getComplementNNF, getNNF, getNNFClassVisitor, getObjectComplementOf, getOWLObject, isClassExpression, isOWLNothing, isOWLThingMethods inherited from class com.github.owlcs.ontapi.internal.objects.ONTExpressionImpl
asNode, collectContent, equals, getBlankNodeId, getContentCache, toCE, toContentItem, toContentItem, toContentItem, toContentItem, toContentItem, toContentItem, toDR, toIndividual, toLiteral, toNDP, toOPE, triplesMethods inherited from class com.github.owlcs.ontapi.internal.objects.ONTResourceImpl
as, getLiteralLabel, getURI, sameAsMethods inherited from class com.github.owlcs.ontapi.internal.objects.ONTObjectImpl
containsAnnotationProperty, containsDataProperty, containsDatatype, containsEntity, containsEntityInSignature, containsNamedClass, createContentSet, eraseModel, getAnnotationPropertySet, getDataPropertySet, getDatatypeSet, getModel, getNamedClassSet, getObjectFactory, getPersonalityModel, toStringMethods inherited from class com.github.owlcs.ontapi.owlapi.OWLObjectImpl
annotationPropertiesInSignature, anonymousIndividuals, classesInSignature, compareIterators, compareTo, createSet, createSet, createSortedSet, createSortedSet, dataPropertiesInSignature, datatypesInSignature, equalIterators, equalStreams, forOutput, getAnnotationPropertiesInSignature, getAnonymousIndividuals, getClassesInSignature, getDataPropertiesInSignature, getDatatypesInSignature, getIndividualsInSignature, getNestedClassExpressions, getObjectPropertiesInSignature, getSignature, hashCode, individualsInSignature, mergeAnnotations, nestedClassExpressions, notSame, objectPropertiesInSignature, prepareAnnotations, signature, toContentListMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface org.semanticweb.owlapi.model.AsOWLClass
asOWLClass, isOWLClassMethods inherited from interface java.lang.Comparable
compareToMethods inherited from interface org.semanticweb.owlapi.model.HasAnnotationPropertiesInSignature
annotationPropertiesInSignature, getAnnotationPropertiesInSignatureMethods inherited from interface org.semanticweb.owlapi.model.HasAnonymousIndividuals
anonymousIndividuals, getAnonymousIndividualsMethods inherited from interface org.semanticweb.owlapi.model.HasClassesInSignature
classesInSignature, getClassesInSignatureMethods inherited from interface org.semanticweb.owlapi.model.HasComponents
componentsAnnotationsFirst, componentsWithoutAnnotationsMethods inherited from interface org.semanticweb.owlapi.model.HasContainsEntityInSignature
containsEntityInSignatureMethods inherited from interface org.semanticweb.owlapi.model.HasDataPropertiesInSignature
dataPropertiesInSignature, getDataPropertiesInSignatureMethods inherited from interface org.semanticweb.owlapi.model.HasDatatypesInSignature
datatypesInSignature, getDatatypesInSignatureMethods inherited from interface org.semanticweb.owlapi.model.HasIndividualsInSignature
getIndividualsInSignature, individualsInSignatureMethods inherited from interface com.github.owlcs.ontapi.internal.HasObjectFactory
getDataFactoryMethods inherited from interface org.semanticweb.owlapi.model.HasObjectPropertiesInSignature
getObjectPropertiesInSignature, objectPropertiesInSignatureMethods inherited from interface org.semanticweb.owlapi.model.HasSignature
getSignature, signature, unsortedSignatureMethods inherited from interface org.semanticweb.owlapi.model.IsAnonymous
isAnonymous, isNamedMethods inherited from interface com.github.owlcs.ontapi.internal.objects.ModelObject
getModelMethods inherited from interface com.github.owlcs.ontapi.internal.objects.ONTComposite
canContainAnonymousIndividuals, canContainClassExpressions, canContainNamedIndividuals, canContainObjectPropertiesMethods inherited from interface org.semanticweb.owlapi.model.OWLClassExpression
asConjunctSet, asDisjunctSet, conjunctSet, containsConjunct, disjunctSet, getComplementNNF, getNNF, getObjectComplementOf, isClassExpressionLiteral, isOWLNothing, isOWLThingMethods inherited from interface org.semanticweb.owlapi.model.OWLHasValueRestriction
components, getValue, initHashCodeMethods inherited from interface org.semanticweb.owlapi.model.OWLObject
getNestedClassExpressions, hasSharedStructure, isAnonymousExpression, isAxiom, isBottomEntity, isIndividual, isIRI, isOntology, isTopEntity, nestedClassExpressionsMethods inherited from interface org.semanticweb.owlapi.model.OWLObjectHasValue
accept, accept, accept, accept, getClassExpressionType, hashIndex, typeIndexMethods inherited from interface org.semanticweb.owlapi.model.OWLObjectRestriction
getProperty, isObjectRestrictionMethods inherited from interface org.semanticweb.owlapi.model.OWLRestriction
isDataRestrictionMethods inherited from interface com.github.owlcs.ontapi.internal.objects.WithContent
clearContent, createContentCache, getContent, hasContent, putContent
-
Constructor Details
-
OHV
-
-
Method Details
-
asRDFNode
public org.apache.jena.ontapi.model.OntClass.ObjectHasValue asRDFNode()Description copied from interface:AsRDFNodeAnswers theRDFNodeassociated with this object.- Specified by:
asRDFNodein interfaceAsRDFNode- Specified by:
asRDFNodein classONTExpressionImpl<org.apache.jena.ontapi.model.OntClass.ObjectHasValue>- Returns:
RDF Model Node, cannot benull
-
objects
Description copied from interface:ONTCompositeLists all components in the form ofStream. Neither this object nor parts of its components are not included in the result: it content only top-level direct components. Note thatHasComponents.components()may also contain non-OWLObjectthings: integers (e.g. cardinality),Lists (e.g.ObjectOneOf), etc, while this method is only forOWLObjects which are represented asONTObjects.- Specified by:
objectsin interfaceONTComposite- Overrides:
objectsin classONTAnonymousClassExpressionImpl.WithObjectProperty<org.apache.jena.ontapi.model.OntClass.ObjectHasValue,org.semanticweb.owlapi.model.OWLObjectHasValue> - Returns:
StreamofONTObjects- See Also:
-
asSomeValuesFrom
public org.semanticweb.owlapi.model.OWLObjectSomeValuesFrom asSomeValuesFrom()- Specified by:
asSomeValuesFromin interfaceorg.semanticweb.owlapi.model.OWLHasValueRestriction<org.semanticweb.owlapi.model.OWLIndividual>
-
getFiller
public org.semanticweb.owlapi.model.OWLIndividual getFiller()- Specified by:
getFillerin interfaceorg.semanticweb.owlapi.model.HasFiller<org.semanticweb.owlapi.model.OWLIndividual>
-
getONTIndividual
-
findIndividual
protected ONTObject<? extends org.semanticweb.owlapi.model.OWLIndividual> findIndividual(ModelObjectFactory factory) -
collectContent
protected Object[] collectContent(org.apache.jena.ontapi.model.OntClass.ObjectHasValue ce, ONTObjectFactory factory) Description copied from class:ONTExpressionImplCollects the cache Array. The array was chosen as the best option in sense of memory consumption and access speed.- Overrides:
collectContentin classONTAnonymousClassExpressionImpl.WithObjectProperty<org.apache.jena.ontapi.model.OntClass.ObjectHasValue,org.semanticweb.owlapi.model.OWLObjectHasValue> - Parameters:
ce-ONTExpressionImpl, notnullfactory-ONTObjectFactory, notnull- Returns:
- an
ArrayofObjects (content items) - See Also:
-
initContent
protected Object[] initContent(org.apache.jena.ontapi.model.OntClass.ObjectHasValue ce, ONTObjectFactory factory) Description copied from class:ONTExpressionImplInitializes the object's content and calculates its hashcode. Together, this must be faster.- Overrides:
initContentin classONTAnonymousClassExpressionImpl.WithObjectProperty<org.apache.jena.ontapi.model.OntClass.ObjectHasValue,org.semanticweb.owlapi.model.OWLObjectHasValue> - Parameters:
ce-ONTExpressionImplthe source Jena resource, notnullfactory-ONTObjectFactory, notnull- Returns:
- an
ArrayofObjects (content items) - See Also:
-
containsObjectProperty
public boolean containsObjectProperty(org.semanticweb.owlapi.model.OWLObjectProperty property) Description copied from class:ONTObjectImplAnswerstrueiff the given OWL named object property expression (OWLObjectProperty) is present in the object's signature.- Overrides:
containsObjectPropertyin classONTObjectImpl- Parameters:
property-OWLObjectProperty, notnull- Returns:
- boolean
-
containsNamedIndividual
public boolean containsNamedIndividual(org.semanticweb.owlapi.model.OWLNamedIndividual individual) Description copied from class:ONTObjectImplAnswerstrueiff the given OWL named individual is present in the object's signature.- Overrides:
containsNamedIndividualin classONTObjectImpl- Parameters:
individual-OWLNamedIndividual, notnull- Returns:
- boolean
-
getSignatureSet
Description copied from class:OWLObjectImplGets the signature of this object. The set is a copy, changes are not reflected back.- Overrides:
getSignatureSetin classONTObjectImpl- Returns:
- a modifiable sorted
Setof entities that represents the signature of this object
-
getObjectPropertySet
Description copied from class:OWLObjectImplObtains the (named) object properties that are in the signature of this object. The set is a copy, changes are not reflected back.- Overrides:
getObjectPropertySetin classONTObjectImpl- Returns:
- a modifiable sorted
Setof the object properties that are in the signature of this object
-
getNamedProperty
protected org.semanticweb.owlapi.model.OWLObjectProperty getNamedProperty() -
getNamedIndividualSet
Description copied from class:OWLObjectImplGets all the individuals that are in the signature of this object. The set is a copy, changes are not reflected back.- Overrides:
getNamedIndividualSetin classONTObjectImpl- Returns:
- a modifiable sorted
Setcontaining the individuals that are in the signature of this object
-
getAnonymousIndividualSet
Description copied from class:OWLObjectImplGets the anonymous individuals occurring in this object. The set is a copy, changes are not reflected back.- Overrides:
getAnonymousIndividualSetin classONTObjectImpl- Returns:
- a modifiable sorted
Setof the anonymous individuals
-
getClassExpressionSet
Description copied from class:OWLObjectImplGets all the nested (includes top level) class expressions that are used in this object. The set is a copy, changes are not reflected back.- Overrides:
getClassExpressionSetin classONTObjectImpl- Returns:
- a modifiable unordered
SetofOWLClassExpressions that represent the nested class expressions used in this object
-
canContainDataProperties
public boolean canContainDataProperties()Description copied from interface:ONTCompositeAnswerstrueif this object-container may contain data properties.- Specified by:
canContainDataPropertiesin interfaceONTComposite- Returns:
- boolean
-
canContainNamedClasses
public boolean canContainNamedClasses()Description copied from interface:ONTCompositeAnswerstrueif this object-container is allowed to contain (named) OWL classes.- Specified by:
canContainNamedClassesin interfaceONTComposite- Returns:
- boolean
-
canContainDatatypes
public boolean canContainDatatypes()Description copied from interface:ONTCompositeAnswerstrueif this object-container may contain datatypes.- Specified by:
canContainDatatypesin interfaceONTComposite- Returns:
- boolean
-
eraseModel
public org.semanticweb.owlapi.model.OWLObjectHasValue eraseModel()Description copied from interface:ModelObjectAnswers with an object that equals to theONTObject.getOWLObject(), but without any model information inside.Such unattached object can be used in whatever way, while the object
ONTObject.getOWLObject()requires more attention: it will not allow GC to dispose of the model, as there is a strong reference (or a facility to get such reference) to the model inside that object.- Specified by:
eraseModelin interfaceModelObject<org.semanticweb.owlapi.model.OWLObjectHasValue>- Returns:
ModelObject- See Also:
-
isAnonymousIndividual
default boolean isAnonymousIndividual()Answerstrueiff this is anOWL Anonymous Individual.- Returns:
- boolean
-
isNamedClass
default boolean isNamedClass()Answerstrueiff this is anOWL Class.- Returns:
- boolean
-
isNamedIndividual
default boolean isNamedIndividual()Answerstrueiff this is anOWL Named Individual.- Returns:
- boolean
-
isDatatype
default boolean isDatatype()Answerstrueiff this is anOWL Datatype.- Returns:
- boolean
-
isObjectProperty
default boolean isObjectProperty()Answerstrueiff this is anOWL Object Property.- Returns:
- boolean
-
isDataProperty
default boolean isDataProperty()Answerstrueiff this is anOWL Data Property.- Returns:
- boolean
-
isAnnotationProperty
default boolean isAnnotationProperty()Answerstrueiff this is anOWL Annotation Property.- Returns:
- boolean
-