Class ONTAnonymousClassExpressionImpl.UF
java.lang.Object
com.github.owlcs.ontapi.owlapi.OWLObjectImpl
com.github.owlcs.ontapi.internal.objects.ONTObjectImpl
com.github.owlcs.ontapi.internal.objects.ONTResourceImpl
com.github.owlcs.ontapi.internal.objects.ONTExpressionImpl<org.apache.jena.ontapi.model.OntClass.UnionOf>
com.github.owlcs.ontapi.internal.objects.ONTAnonymousClassExpressionImpl<org.apache.jena.ontapi.model.OntClass.UnionOf,org.semanticweb.owlapi.model.OWLObjectUnionOf>
com.github.owlcs.ontapi.internal.objects.ONTAnonymousClassExpressionImpl.WithMembers<org.apache.jena.ontapi.model.OntClass,org.apache.jena.ontapi.model.OntClass.UnionOf,org.semanticweb.owlapi.model.OWLClassExpression,org.semanticweb.owlapi.model.OWLObjectUnionOf>
com.github.owlcs.ontapi.internal.objects.ONTAnonymousClassExpressionImpl.WithClassMembers<org.apache.jena.ontapi.model.OntClass.UnionOf,org.semanticweb.owlapi.model.OWLObjectUnionOf>
com.github.owlcs.ontapi.internal.objects.ONTAnonymousClassExpressionImpl.UF
- All Implemented Interfaces:
AsNode,AsRDFNode,HasObjectFactory,ModelObject<org.semanticweb.owlapi.model.OWLObjectUnionOf>,ONTComposite,WithContent<ONTExpressionImpl<org.apache.jena.ontapi.model.OntClass.UnionOf>>,ONTObject<org.semanticweb.owlapi.model.OWLObjectUnionOf>,Serializable,Comparable<org.semanticweb.owlapi.model.OWLObject>,org.semanticweb.owlapi.model.AsOWLClass,org.semanticweb.owlapi.model.HasAnnotationPropertiesInSignature,org.semanticweb.owlapi.model.HasAnonymousIndividuals,org.semanticweb.owlapi.model.HasClassesInSignature,org.semanticweb.owlapi.model.HasComponents,org.semanticweb.owlapi.model.HasContainsEntityInSignature,org.semanticweb.owlapi.model.HasDataPropertiesInSignature,org.semanticweb.owlapi.model.HasDatatypesInSignature,org.semanticweb.owlapi.model.HasHashIndex,org.semanticweb.owlapi.model.HasIndex,org.semanticweb.owlapi.model.HasIndividualsInSignature,org.semanticweb.owlapi.model.HasObjectPropertiesInSignature,org.semanticweb.owlapi.model.HasOperands<org.semanticweb.owlapi.model.OWLClassExpression>,org.semanticweb.owlapi.model.HasSignature,org.semanticweb.owlapi.model.IsAnonymous,org.semanticweb.owlapi.model.OWLAnonymousClassExpression,org.semanticweb.owlapi.model.OWLBooleanClassExpression,org.semanticweb.owlapi.model.OWLClassExpression,org.semanticweb.owlapi.model.OWLNaryBooleanClassExpression,org.semanticweb.owlapi.model.OWLObject,org.semanticweb.owlapi.model.OWLObjectUnionOf,org.semanticweb.owlapi.model.OWLPropertyRange,org.semanticweb.owlapi.model.SWRLPredicate
- Enclosing class:
ONTAnonymousClassExpressionImpl<ONT extends org.apache.jena.ontapi.model.OntClass,OWL extends org.semanticweb.owlapi.model.OWLAnonymousClassExpression>
public static class ONTAnonymousClassExpressionImpl.UF
extends ONTAnonymousClassExpressionImpl.WithClassMembers<org.apache.jena.ontapi.model.OntClass.UnionOf,org.semanticweb.owlapi.model.OWLObjectUnionOf>
implements org.semanticweb.owlapi.model.OWLObjectUnionOf
- See Also:
-
Nested Class Summary
Nested classes/interfaces inherited from class com.github.owlcs.ontapi.internal.objects.ONTAnonymousClassExpressionImpl
ONTAnonymousClassExpressionImpl.CF, ONTAnonymousClassExpressionImpl.DAVF, ONTAnonymousClassExpressionImpl.DEC, ONTAnonymousClassExpressionImpl.DHV, ONTAnonymousClassExpressionImpl.DMAC, ONTAnonymousClassExpressionImpl.DMIC, ONTAnonymousClassExpressionImpl.DSVF, ONTAnonymousClassExpressionImpl.IF, ONTAnonymousClassExpressionImpl.NDAVF, ONTAnonymousClassExpressionImpl.NDSVF, ONTAnonymousClassExpressionImpl.OAVF, ONTAnonymousClassExpressionImpl.OEC, ONTAnonymousClassExpressionImpl.OF, ONTAnonymousClassExpressionImpl.OHS, ONTAnonymousClassExpressionImpl.OHV, ONTAnonymousClassExpressionImpl.OMAC, ONTAnonymousClassExpressionImpl.OMIC, ONTAnonymousClassExpressionImpl.OSVF, ONTAnonymousClassExpressionImpl.Restriction<ONT extends org.apache.jena.ontapi.model.OntClass,OWL extends org.semanticweb.owlapi.model.OWLAnonymousClassExpression>, ONTAnonymousClassExpressionImpl.Simple<ONT extends org.apache.jena.ontapi.model.OntClass, OWL extends org.semanticweb.owlapi.model.OWLAnonymousClassExpression>, ONTAnonymousClassExpressionImpl.UF, ONTAnonymousClassExpressionImpl.WithClassAndObjectProperty<ONT extends org.apache.jena.ontapi.model.OntClass.ComponentRestriction<org.apache.jena.ontapi.model.OntClass, org.apache.jena.ontapi.model.OntObjectProperty>, OWL extends org.semanticweb.owlapi.model.OWLRestriction>, ONTAnonymousClassExpressionImpl.WithClassAndObjectPropertyAndCardinality<ONT extends org.apache.jena.ontapi.model.OntClass.CardinalityRestriction<org.apache.jena.ontapi.model.OntClass, org.apache.jena.ontapi.model.OntObjectProperty>, OWL extends org.semanticweb.owlapi.model.OWLRestriction>, ONTAnonymousClassExpressionImpl.WithClassMembers<ONT extends org.apache.jena.ontapi.model.OntClass.CollectionOf<org.apache.jena.ontapi.model.OntClass>, OWL extends org.semanticweb.owlapi.model.OWLAnonymousClassExpression>, ONTAnonymousClassExpressionImpl.WithDataProperty<ONT extends org.apache.jena.ontapi.model.OntClass, OWL extends org.semanticweb.owlapi.model.OWLRestriction>, ONTAnonymousClassExpressionImpl.WithDataPropertyUnary<ONT extends org.apache.jena.ontapi.model.OntClass.UnaryRestriction<org.apache.jena.ontapi.model.OntDataProperty>, OWL extends org.semanticweb.owlapi.model.OWLRestriction>, ONTAnonymousClassExpressionImpl.WithDataRangeAndDataProperty<ONT extends org.apache.jena.ontapi.model.OntClass.Restriction, OWL extends org.semanticweb.owlapi.model.OWLRestriction>, ONTAnonymousClassExpressionImpl.WithDataRangeAndDataPropertyAndCardinality<ONT extends org.apache.jena.ontapi.model.OntClass.CardinalityRestriction<org.apache.jena.ontapi.model.OntDataRange, org.apache.jena.ontapi.model.OntDataProperty>, OWL extends org.semanticweb.owlapi.model.OWLRestriction>, ONTAnonymousClassExpressionImpl.WithDataRangeAndDataPropertyNary<ONT extends org.apache.jena.ontapi.model.OntClass.NaryRestriction<org.apache.jena.ontapi.model.OntDataRange, org.apache.jena.ontapi.model.OntDataProperty>, OWL extends org.semanticweb.owlapi.model.OWLRestriction>, ONTAnonymousClassExpressionImpl.WithDataRangeAndDataPropertyUnary<ONT extends org.apache.jena.ontapi.model.OntClass.ComponentRestriction<org.apache.jena.ontapi.model.OntDataRange, org.apache.jena.ontapi.model.OntDataProperty>, OWL extends org.semanticweb.owlapi.model.OWLRestriction>, ONTAnonymousClassExpressionImpl.WithMembers<ONT_M extends org.apache.jena.ontapi.model.OntObject, ONT_C extends org.apache.jena.ontapi.model.OntClass.CollectionOf<ONT_M>, OWL_M extends org.semanticweb.owlapi.model.OWLObject, OWL_C extends org.semanticweb.owlapi.model.OWLAnonymousClassExpression>, ONTAnonymousClassExpressionImpl.WithObjectProperty<ONT extends org.apache.jena.ontapi.model.OntClass.UnaryRestriction<org.apache.jena.ontapi.model.OntObjectProperty>, OWL extends org.semanticweb.owlapi.model.OWLRestriction> -
Field Summary
Fields inherited from class com.github.owlcs.ontapi.internal.objects.ONTExpressionImpl
contentFields inherited from class com.github.owlcs.ontapi.internal.objects.ONTResourceImpl
nodeFields inherited from class com.github.owlcs.ontapi.internal.objects.ONTObjectImpl
modelFields inherited from class com.github.owlcs.ontapi.owlapi.OWLObjectImpl
DEFAULT_COMPARATOR, hashCode, NO_ANNOTATIONS -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionSet<org.semanticweb.owlapi.model.OWLClassExpression> org.apache.jena.ontapi.model.OntClass.UnionOfAnswers theRDFNodeassociated with this object.Stream<org.semanticweb.owlapi.model.OWLClassExpression> org.semanticweb.owlapi.model.OWLObjectUnionOfAnswers with an object that equals to theONTObject.getOWLObject(), but without any model information inside.default booleanAnswerstrueiff this is anOWL Annotation Property.default booleanAnswerstrueiff this is anOWL Anonymous Individual.default booleanAnswerstrueiff this is anOWL Data Property.default booleanAnswerstrueiff this is anOWL Datatype.default booleanAnswerstrueiff this is anOWL Class.default booleanAnswerstrueiff this is anOWL Named Individual.default booleanAnswerstrueiff this is anOWL Object Property.Methods inherited from class com.github.owlcs.ontapi.internal.objects.ONTAnonymousClassExpressionImpl.WithClassMembers
fromContentItem, map, toContentItemMethods inherited from class com.github.owlcs.ontapi.internal.objects.ONTAnonymousClassExpressionImpl.WithMembers
collectContent, factoryObjects, getOperandsAsList, initContent, members, objects, objects, operands, operandsMethods inherited from class com.github.owlcs.ontapi.internal.objects.ONTAnonymousClassExpressionImpl
asConjunctSet, canContainAnnotationProperties, conjunctSet, containsConjunct, create, create, getComplementNNF, getNNF, getNNFClassVisitor, getObjectComplementOf, getOWLObject, isClassExpression, isOWLNothing, isOWLThingMethods inherited from class com.github.owlcs.ontapi.internal.objects.ONTExpressionImpl
asNode, collectContent, equals, getBlankNodeId, getContentCache, toCE, toContentItem, toContentItem, toContentItem, toContentItem, toContentItem, toContentItem, toDR, toIndividual, toLiteral, toNDP, toOPE, triplesMethods inherited from class com.github.owlcs.ontapi.internal.objects.ONTResourceImpl
as, getLiteralLabel, getURI, sameAsMethods inherited from class com.github.owlcs.ontapi.internal.objects.ONTObjectImpl
containsAnnotationProperty, containsDataProperty, containsDatatype, containsEntity, containsEntityInSignature, containsNamedClass, containsNamedIndividual, containsObjectProperty, createContentSet, eraseModel, getAnnotationPropertySet, getAnonymousIndividualSet, getClassExpressionSet, getDataPropertySet, getDatatypeSet, getModel, getNamedClassSet, getNamedIndividualSet, getObjectFactory, getObjectPropertySet, getPersonalityModel, getSignatureSet, toStringMethods inherited from class com.github.owlcs.ontapi.owlapi.OWLObjectImpl
annotationPropertiesInSignature, anonymousIndividuals, classesInSignature, compareIterators, compareTo, createSet, createSet, createSortedSet, createSortedSet, dataPropertiesInSignature, datatypesInSignature, equalIterators, equalStreams, forOutput, getAnnotationPropertiesInSignature, getAnonymousIndividuals, getClassesInSignature, getDataPropertiesInSignature, getDatatypesInSignature, getIndividualsInSignature, getNestedClassExpressions, getObjectPropertiesInSignature, getSignature, hashCode, individualsInSignature, mergeAnnotations, nestedClassExpressions, notSame, objectPropertiesInSignature, prepareAnnotations, signature, toContentListMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface org.semanticweb.owlapi.model.AsOWLClass
asOWLClass, isOWLClassMethods inherited from interface java.lang.Comparable
compareToMethods inherited from interface org.semanticweb.owlapi.model.HasAnnotationPropertiesInSignature
annotationPropertiesInSignature, getAnnotationPropertiesInSignatureMethods inherited from interface org.semanticweb.owlapi.model.HasAnonymousIndividuals
anonymousIndividuals, getAnonymousIndividualsMethods inherited from interface org.semanticweb.owlapi.model.HasClassesInSignature
classesInSignature, getClassesInSignatureMethods inherited from interface org.semanticweb.owlapi.model.HasComponents
componentsAnnotationsFirst, componentsWithoutAnnotationsMethods inherited from interface org.semanticweb.owlapi.model.HasContainsEntityInSignature
containsEntityInSignatureMethods inherited from interface org.semanticweb.owlapi.model.HasDataPropertiesInSignature
dataPropertiesInSignature, getDataPropertiesInSignatureMethods inherited from interface org.semanticweb.owlapi.model.HasDatatypesInSignature
datatypesInSignature, getDatatypesInSignatureMethods inherited from interface org.semanticweb.owlapi.model.HasIndividualsInSignature
getIndividualsInSignature, individualsInSignatureMethods inherited from interface com.github.owlcs.ontapi.internal.HasObjectFactory
getDataFactoryMethods inherited from interface org.semanticweb.owlapi.model.HasObjectPropertiesInSignature
getObjectPropertiesInSignature, objectPropertiesInSignatureMethods inherited from interface org.semanticweb.owlapi.model.HasOperands
getOperandsAsList, operandsMethods inherited from interface org.semanticweb.owlapi.model.HasSignature
getSignature, signature, unsortedSignatureMethods inherited from interface org.semanticweb.owlapi.model.IsAnonymous
isAnonymous, isNamedMethods inherited from interface com.github.owlcs.ontapi.internal.objects.ModelObject
getModelMethods inherited from interface com.github.owlcs.ontapi.internal.objects.ONTComposite
canContainAnonymousIndividuals, canContainClassExpressions, canContainDataProperties, canContainDatatypes, canContainNamedClasses, canContainNamedIndividuals, canContainObjectPropertiesMethods inherited from interface org.semanticweb.owlapi.model.OWLClassExpression
asConjunctSet, conjunctSet, containsConjunct, getComplementNNF, getNNF, getObjectComplementOf, isClassExpressionLiteral, isOWLNothing, isOWLThingMethods inherited from interface org.semanticweb.owlapi.model.OWLNaryBooleanClassExpression
components, getOperands, initHashCodeMethods inherited from interface org.semanticweb.owlapi.model.OWLObject
getNestedClassExpressions, hasSharedStructure, isAnonymousExpression, isAxiom, isBottomEntity, isIndividual, isIRI, isOntology, isTopEntity, nestedClassExpressionsMethods inherited from interface org.semanticweb.owlapi.model.OWLObjectUnionOf
accept, accept, accept, accept, getClassExpressionType, hashIndex, typeIndexMethods inherited from interface com.github.owlcs.ontapi.internal.objects.WithContent
clearContent, createContentCache, getContent, hasContent, putContent
-
Constructor Details
-
UF
-
-
Method Details
-
asRDFNode
public org.apache.jena.ontapi.model.OntClass.UnionOf asRDFNode()Description copied from interface:AsRDFNodeAnswers theRDFNodeassociated with this object.- Specified by:
asRDFNodein interfaceAsRDFNode- Specified by:
asRDFNodein classONTExpressionImpl<org.apache.jena.ontapi.model.OntClass.UnionOf>- Returns:
RDF Model Node, cannot benull
-
asDisjunctSet
- Specified by:
asDisjunctSetin interfaceorg.semanticweb.owlapi.model.OWLClassExpression- Overrides:
asDisjunctSetin classONTAnonymousClassExpressionImpl<org.apache.jena.ontapi.model.OntClass.UnionOf,org.semanticweb.owlapi.model.OWLObjectUnionOf>
-
disjunctSet
- Specified by:
disjunctSetin interfaceorg.semanticweb.owlapi.model.OWLClassExpression- Overrides:
disjunctSetin classONTAnonymousClassExpressionImpl<org.apache.jena.ontapi.model.OntClass.UnionOf,org.semanticweb.owlapi.model.OWLObjectUnionOf>
-
eraseModel
public org.semanticweb.owlapi.model.OWLObjectUnionOf eraseModel()Description copied from interface:ModelObjectAnswers with an object that equals to theONTObject.getOWLObject(), but without any model information inside.Such unattached object can be used in whatever way, while the object
ONTObject.getOWLObject()requires more attention: it will not allow GC to dispose of the model, as there is a strong reference (or a facility to get such reference) to the model inside that object.- Specified by:
eraseModelin interfaceModelObject<org.semanticweb.owlapi.model.OWLObjectUnionOf>- Returns:
ModelObject- See Also:
-
isAnonymousIndividual
default boolean isAnonymousIndividual()Answerstrueiff this is anOWL Anonymous Individual.- Returns:
- boolean
-
isNamedClass
default boolean isNamedClass()Answerstrueiff this is anOWL Class.- Returns:
- boolean
-
isNamedIndividual
default boolean isNamedIndividual()Answerstrueiff this is anOWL Named Individual.- Returns:
- boolean
-
isDatatype
default boolean isDatatype()Answerstrueiff this is anOWL Datatype.- Returns:
- boolean
-
isObjectProperty
default boolean isObjectProperty()Answerstrueiff this is anOWL Object Property.- Returns:
- boolean
-
isDataProperty
default boolean isDataProperty()Answerstrueiff this is anOWL Data Property.- Returns:
- boolean
-
isAnnotationProperty
default boolean isAnnotationProperty()Answerstrueiff this is anOWL Annotation Property.- Returns:
- boolean
-