Class ONTSWRLAtomImpl.Binary<ONT_P extends org.apache.jena.ontapi.model.OntObject,ONT_F extends org.apache.jena.ontapi.model.OntSWRL.Arg,ONT_S extends org.apache.jena.ontapi.model.OntSWRL.Arg,ONT_R extends org.apache.jena.ontapi.model.OntSWRL.Atom.Binary<ONT_P,ONT_F,ONT_S>,OWL_P extends org.semanticweb.owlapi.model.OWLObject & org.semanticweb.owlapi.model.SWRLPredicate,OWL_F extends org.semanticweb.owlapi.model.SWRLArgument,OWL_S extends org.semanticweb.owlapi.model.SWRLArgument,OWL_R extends org.semanticweb.owlapi.model.SWRLBinaryAtom<OWL_F,OWL_S>>
java.lang.Object
com.github.owlcs.ontapi.owlapi.OWLObjectImpl
com.github.owlcs.ontapi.internal.objects.ONTObjectImpl
com.github.owlcs.ontapi.internal.objects.ONTResourceImpl
com.github.owlcs.ontapi.internal.objects.ONTExpressionImpl<ONT_R>
com.github.owlcs.ontapi.internal.objects.ONTSWRLAtomImpl<ONT_R,OWL_R>
com.github.owlcs.ontapi.internal.objects.ONTSWRLAtomImpl.Binary<ONT_P,ONT_F,ONT_S,ONT_R,OWL_P,OWL_F,OWL_S,OWL_R>
- Type Parameters:
ONT_P- - subtype ofOntObject, predicateONT_F- - subtype ofOntSWRL.Arg, first argumentONT_S- - subtype ofOntSWRL.Arg, second argumentONT_R- - subtype ofOntSWRL.Atom.Binary, the actual jena typeOWL_P- - subtype ofSWRLPredicate, that matchesONTSWRLAtomImpl.BinaryOWL_F- - subtype ofSWRLArgument, that matchesONTSWRLAtomImpl.BinaryOWL_S- - subtype ofSWRLArgument, that matchesONTSWRLAtomImpl.BinaryOWL_R- - subtype ofSWRLBinaryAtom, that matchesONTSWRLAtomImpl.Binary
- All Implemented Interfaces:
AsNode,AsRDFNode,HasObjectFactory,ModelObject<OWL_R>,ONTComposite,WithContent<ONTExpressionImpl<ONT_R>>,ONTObject<OWL_R>,Serializable,Comparable<org.semanticweb.owlapi.model.OWLObject>,org.semanticweb.owlapi.model.HasAnnotationPropertiesInSignature,org.semanticweb.owlapi.model.HasAnonymousIndividuals,org.semanticweb.owlapi.model.HasClassesInSignature,org.semanticweb.owlapi.model.HasComponents,org.semanticweb.owlapi.model.HasContainsEntityInSignature,org.semanticweb.owlapi.model.HasDataPropertiesInSignature,org.semanticweb.owlapi.model.HasDatatypesInSignature,org.semanticweb.owlapi.model.HasHashIndex,org.semanticweb.owlapi.model.HasIndex,org.semanticweb.owlapi.model.HasIndividualsInSignature,org.semanticweb.owlapi.model.HasObjectPropertiesInSignature,org.semanticweb.owlapi.model.HasSignature,org.semanticweb.owlapi.model.IsAnonymous,org.semanticweb.owlapi.model.OWLObject,org.semanticweb.owlapi.model.SWRLAtom,org.semanticweb.owlapi.model.SWRLObject
- Direct Known Subclasses:
ONTSWRLAtomImpl.DPB,ONTSWRLAtomImpl.ObjectBinary
- Enclosing class:
ONTSWRLAtomImpl<ONT extends org.apache.jena.ontapi.model.OntSWRL.Atom<?>,OWL extends org.semanticweb.owlapi.model.SWRLAtom>
protected abstract static class ONTSWRLAtomImpl.Binary<ONT_P extends org.apache.jena.ontapi.model.OntObject,ONT_F extends org.apache.jena.ontapi.model.OntSWRL.Arg,ONT_S extends org.apache.jena.ontapi.model.OntSWRL.Arg,ONT_R extends org.apache.jena.ontapi.model.OntSWRL.Atom.Binary<ONT_P,ONT_F,ONT_S>,OWL_P extends org.semanticweb.owlapi.model.OWLObject & org.semanticweb.owlapi.model.SWRLPredicate,OWL_F extends org.semanticweb.owlapi.model.SWRLArgument,OWL_S extends org.semanticweb.owlapi.model.SWRLArgument,OWL_R extends org.semanticweb.owlapi.model.SWRLBinaryAtom<OWL_F,OWL_S>>
extends ONTSWRLAtomImpl<ONT_R,OWL_R>
An abstract binary atom impl.
- See Also:
-
Nested Class Summary
Nested classes/interfaces inherited from class com.github.owlcs.ontapi.internal.objects.ONTSWRLAtomImpl
ONTSWRLAtomImpl.Binary<ONT_P extends org.apache.jena.ontapi.model.OntObject,ONT_F extends org.apache.jena.ontapi.model.OntSWRL.Arg, ONT_S extends org.apache.jena.ontapi.model.OntSWRL.Arg, ONT_R extends org.apache.jena.ontapi.model.OntSWRL.Atom.Binary<ONT_P, ONT_F, ONT_S>, OWL_P extends org.semanticweb.owlapi.model.OWLObject & org.semanticweb.owlapi.model.SWRLPredicate, OWL_F extends org.semanticweb.owlapi.model.SWRLArgument, OWL_S extends org.semanticweb.owlapi.model.SWRLArgument, OWL_R extends org.semanticweb.owlapi.model.SWRLBinaryAtom<OWL_F, OWL_S>>, ONTSWRLAtomImpl.BN, ONTSWRLAtomImpl.CU, ONTSWRLAtomImpl.DIB, ONTSWRLAtomImpl.DPB, ONTSWRLAtomImpl.DU, ONTSWRLAtomImpl.ObjectBinary<ONT_P extends org.apache.jena.ontapi.model.OntObjectProperty, OWL_P extends org.semanticweb.owlapi.model.OWLObjectPropertyExpression, ONT_R extends org.apache.jena.ontapi.model.OntSWRL.Atom.Binary<ONT_P, org.apache.jena.ontapi.model.OntSWRL.IArg, org.apache.jena.ontapi.model.OntSWRL.IArg>, OWL_R extends org.semanticweb.owlapi.model.SWRLBinaryAtom<org.semanticweb.owlapi.model.SWRLIArgument, org.semanticweb.owlapi.model.SWRLIArgument>>, ONTSWRLAtomImpl.OPB, ONTSWRLAtomImpl.SIB, ONTSWRLAtomImpl.Unary<ONT_P extends org.apache.jena.ontapi.model.OntObject, ONT_A extends org.apache.jena.ontapi.model.OntSWRL.Arg, ONT_R extends org.apache.jena.ontapi.model.OntSWRL.Atom.Unary<ONT_P, ONT_A>, OWL_P extends org.semanticweb.owlapi.model.OWLObject & org.semanticweb.owlapi.model.SWRLPredicate, OWL_A extends org.semanticweb.owlapi.model.SWRLArgument, OWL_R extends org.semanticweb.owlapi.model.SWRLUnaryAtom<OWL_A>> -
Field Summary
Fields inherited from class com.github.owlcs.ontapi.internal.objects.ONTExpressionImpl
contentFields inherited from class com.github.owlcs.ontapi.internal.objects.ONTResourceImpl
nodeFields inherited from class com.github.owlcs.ontapi.internal.objects.ONTObjectImpl
modelFields inherited from class com.github.owlcs.ontapi.owlapi.OWLObjectImpl
DEFAULT_COMPARATOR, hashCode, NO_ANNOTATIONS -
Constructor Summary
ConstructorsModifierConstructorDescriptionprotectedBinary(BlankNodeId n, Supplier<org.apache.jena.ontapi.model.OntModel> m) -
Method Summary
Modifier and TypeMethodDescriptionStream<org.semanticweb.owlapi.model.SWRLArgument> protected Object[]collectContent(ONT_R obj, ONTObjectFactory factory) Collects the cache Array.Answers with an object that equals to theONTObject.getOWLObject(), but without any model information inside.findONTFirstArgument(ONTObjectFactory factory) findONTPredicate(ModelObjectFactory factory) findONTSecondArgument(ONTObjectFactory factory) protected Object[]initContent(ONT_R obj, ONTObjectFactory factory) Initializes the object's content and calculates its hashcode.default booleanAnswerstrueiff this is anOWL Annotation Property.default booleanAnswerstrueiff this is anOWL Anonymous Individual.default booleanAnswerstrueiff this is anOWL Class Expression.default booleanAnswerstrueiff this is anOWL Data Property.default booleanAnswerstrueiff this is anOWL Datatype.default booleanAnswerstrueiff this is anOWL Class.default booleanAnswerstrueiff this is anOWL Named Individual.default booleanAnswerstrueiff this is anOWL Object Property.objects()Lists all components in the form ofStream.Methods inherited from class com.github.owlcs.ontapi.internal.objects.ONTSWRLAtomImpl
canContainAnnotationProperties, create, create, datatypes, fromDArgument, fromIArgument, getOWLObject, individuals, toDArgument, toIArgumentMethods inherited from class com.github.owlcs.ontapi.internal.objects.ONTExpressionImpl
asNode, asRDFNode, collectContent, equals, getBlankNodeId, getContentCache, toCE, toContentItem, toContentItem, toContentItem, toContentItem, toContentItem, toContentItem, toDR, toIndividual, toLiteral, toNDP, toOPE, triplesMethods inherited from class com.github.owlcs.ontapi.internal.objects.ONTResourceImpl
as, getLiteralLabel, getURI, sameAsMethods inherited from class com.github.owlcs.ontapi.internal.objects.ONTObjectImpl
containsAnnotationProperty, containsDataProperty, containsDatatype, containsEntity, containsEntityInSignature, containsNamedClass, containsNamedIndividual, containsObjectProperty, createContentSet, eraseModel, getAnnotationPropertySet, getAnonymousIndividualSet, getClassExpressionSet, getDataPropertySet, getDatatypeSet, getModel, getNamedClassSet, getNamedIndividualSet, getObjectFactory, getObjectPropertySet, getPersonalityModel, getSignatureSet, toStringMethods inherited from class com.github.owlcs.ontapi.owlapi.OWLObjectImpl
annotationPropertiesInSignature, anonymousIndividuals, classesInSignature, compareIterators, compareTo, createSet, createSet, createSortedSet, createSortedSet, dataPropertiesInSignature, datatypesInSignature, equalIterators, equalStreams, forOutput, getAnnotationPropertiesInSignature, getAnonymousIndividuals, getClassesInSignature, getDataPropertiesInSignature, getDatatypesInSignature, getIndividualsInSignature, getNestedClassExpressions, getObjectPropertiesInSignature, getSignature, hashCode, individualsInSignature, mergeAnnotations, nestedClassExpressions, notSame, objectPropertiesInSignature, prepareAnnotations, signature, toContentListMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface java.lang.Comparable
compareToMethods inherited from interface org.semanticweb.owlapi.model.HasAnnotationPropertiesInSignature
annotationPropertiesInSignature, getAnnotationPropertiesInSignatureMethods inherited from interface org.semanticweb.owlapi.model.HasAnonymousIndividuals
anonymousIndividuals, getAnonymousIndividualsMethods inherited from interface org.semanticweb.owlapi.model.HasClassesInSignature
classesInSignature, getClassesInSignatureMethods inherited from interface org.semanticweb.owlapi.model.HasComponents
components, componentsAnnotationsFirst, componentsWithoutAnnotationsMethods inherited from interface org.semanticweb.owlapi.model.HasContainsEntityInSignature
containsEntityInSignatureMethods inherited from interface org.semanticweb.owlapi.model.HasDataPropertiesInSignature
dataPropertiesInSignature, getDataPropertiesInSignatureMethods inherited from interface org.semanticweb.owlapi.model.HasDatatypesInSignature
datatypesInSignature, getDatatypesInSignatureMethods inherited from interface org.semanticweb.owlapi.model.HasHashIndex
hashIndexMethods inherited from interface org.semanticweb.owlapi.model.HasIndex
typeIndexMethods inherited from interface org.semanticweb.owlapi.model.HasIndividualsInSignature
getIndividualsInSignature, individualsInSignatureMethods inherited from interface com.github.owlcs.ontapi.internal.HasObjectFactory
getDataFactoryMethods inherited from interface org.semanticweb.owlapi.model.HasObjectPropertiesInSignature
getObjectPropertiesInSignature, objectPropertiesInSignatureMethods inherited from interface org.semanticweb.owlapi.model.HasSignature
getSignature, signature, unsortedSignatureMethods inherited from interface org.semanticweb.owlapi.model.IsAnonymous
isAnonymous, isNamedMethods inherited from interface com.github.owlcs.ontapi.internal.objects.ModelObject
getModelMethods inherited from interface com.github.owlcs.ontapi.internal.objects.ONTComposite
canContainAnonymousIndividuals, canContainClassExpressions, canContainDataProperties, canContainDatatypes, canContainNamedClasses, canContainNamedIndividuals, canContainObjectPropertiesMethods inherited from interface org.semanticweb.owlapi.model.OWLObject
accept, accept, getNestedClassExpressions, hasSharedStructure, initHashCode, isAnonymousExpression, isAxiom, isBottomEntity, isIndividual, isIRI, isOntology, isTopEntity, nestedClassExpressionsMethods inherited from interface org.semanticweb.owlapi.model.SWRLAtom
getAllArgumentsMethods inherited from interface org.semanticweb.owlapi.model.SWRLObject
accept, acceptMethods inherited from interface com.github.owlcs.ontapi.internal.objects.WithContent
clearContent, createContentCache, getContent, hasContent, putContent
-
Constructor Details
-
Binary
-
-
Method Details
-
getPredicate
-
allArguments
-
getFirstArgument
-
getSecondArgument
-
getONTPredicate
-
getFirstONTArgument
-
getSecondONTArgument
-
findONTFirstArgument
-
findONTSecondArgument
-
findONTPredicate
-
objects
Description copied from interface:ONTCompositeLists all components in the form ofStream. Neither this object nor parts of its components are not included in the result: it content only top-level direct components. Note thatHasComponents.components()may also contain non-OWLObjectthings: integers (e.g. cardinality),Lists (e.g.ObjectOneOf), etc, while this method is only forOWLObjects which are represented asONTObjects. -
eraseModel
Description copied from interface:ModelObjectAnswers with an object that equals to theONTObject.getOWLObject(), but without any model information inside.Such unattached object can be used in whatever way, while the object
ONTObject.getOWLObject()requires more attention: it will not allow GC to dispose of the model, as there is a strong reference (or a facility to get such reference) to the model inside that object.- Returns:
ModelObject- See Also:
-
collectContent
Description copied from class:ONTExpressionImplCollects the cache Array. The array was chosen as the best option in sense of memory consumption and access speed.- Specified by:
collectContentin classONTExpressionImpl<ONT_R extends org.apache.jena.ontapi.model.OntSWRL.Atom.Binary<ONT_P,ONT_F, ONT_S>> - Parameters:
obj-ONTExpressionImpl, notnullfactory-ONTObjectFactory, notnull- Returns:
- an
ArrayofObjects (content items) - See Also:
-
initContent
Description copied from class:ONTExpressionImplInitializes the object's content and calculates its hashcode. Together, this must be faster.- Specified by:
initContentin classONTExpressionImpl<ONT_R extends org.apache.jena.ontapi.model.OntSWRL.Atom.Binary<ONT_P,ONT_F, ONT_S>> - Parameters:
obj-ONTExpressionImplthe source Jena resource, notnullfactory-ONTObjectFactory, notnull- Returns:
- an
ArrayofObjects (content items) - See Also:
-
isClassExpression
default boolean isClassExpression()Answerstrueiff this is anOWL Class Expression.- Returns:
- boolean
-
isAnonymousIndividual
default boolean isAnonymousIndividual()Answerstrueiff this is anOWL Anonymous Individual.- Returns:
- boolean
-
isNamedClass
default boolean isNamedClass()Answerstrueiff this is anOWL Class.- Returns:
- boolean
-
isNamedIndividual
default boolean isNamedIndividual()Answerstrueiff this is anOWL Named Individual.- Returns:
- boolean
-
isDatatype
default boolean isDatatype()Answerstrueiff this is anOWL Datatype.- Returns:
- boolean
-
isObjectProperty
default boolean isObjectProperty()Answerstrueiff this is anOWL Object Property.- Returns:
- boolean
-
isDataProperty
default boolean isDataProperty()Answerstrueiff this is anOWL Data Property.- Returns:
- boolean
-
isAnnotationProperty
default boolean isAnnotationProperty()Answerstrueiff this is anOWL Annotation Property.- Returns:
- boolean
-